@@ -1,17 +1,16 @@
 /* Copyright (C) 2004 - 2006 db4objects Inc. http://www.db4o.com */
-using com.db4o.query;
 
-namespace com.db4odoc.f1.queries
+using Db4objects.Db4o.Query;
+
+namespace Db4objects.Db4odoc.Diagnostics
 {
 	public class ArbitraryQuery : Predicate
 	{
 		private int[] _points;
-    	
 		public ArbitraryQuery(int[] points)
 		{
 			_points=points;
 		}
-    
 		public bool Match(Pilot pilot)
 		{
 			foreach (int points in _points)
@@ -24,4 +23,4 @@ namespace com.db4odoc.f1.queries
 			return pilot.Name.StartsWith("Rubens");
 		}
 	}
-}
+}
\ No newline at end of file
