@@ -1,13 +1,12 @@
-/* Copyright (C) 2004 - 2006 db4objects Inc. http://www.db4o.com */
+/* Copyright (C) 2004 - 2007 db4objects Inc. http://www.db4o.com */
 
-package com.db4odoc.f1.blobs;
+package com.db4odoc.blobs;
 
 import java.io.File;
 
 import com.db4o.ext.Status;
 import com.db4o.types.Blob;
 
-
 public class CarImage {
 	Blob blob;
 	private String fileName = null;
