@@ -1,9 +1,8 @@
-/* Copyright (C) 2004 - 2006 db4objects Inc. http://www.db4o.com */
-
+/* Copyright (C) 2004 - 2007 db4objects Inc. http://www.db4o.com */
 using Db4objects.Db4o;
 using Db4objects.Db4o.Config;
 
-namespace Db4objects.Db4odoc.Evaluations
+namespace Db4objects.Db4odoc.Translators
 {
 
 	public class CarTranslator: IObjectConstructor 
