@@ -1,6 +1,6 @@
-/* Copyright (C) 2004 - 2006 db4objects Inc. http://www.db4o.com */
+/* Copyright (C) 2004 - 2007 db4objects Inc. http://www.db4o.com */
 
-package com.db4odoc.f1.lists;
+package com.db4odoc.lists;
 
 import java.util.ArrayList;
 import java.util.List;
