@@ -1,7 +1,7 @@
 /* Copyright (C) 2004 - 2006 db4objects Inc. http://www.db4o.com */
-using Db4objects.Db4o.Query;
+using com.db4o.query;
 
-namespace Db4objects.Db4odoc.Queries
+namespace com.db4odoc.f1.queries
 {
 	public class ComplexQuery : Predicate
 	{
