@@ -1,8 +1,10 @@
+/* Copyright (C) 2004 - 2007 db4objects Inc. http://www.db4o.com */
 using System.Globalization;
+
 using Db4objects.Db4o;
 using Db4objects.Db4o.Config;
 
-namespace Db4objects.Db4odoc.Evaluations
+namespace Db4objects.Db4odoc.Translators
 {
 	public class CultureInfoTranslator : IObjectConstructor
     {
