@@ -1,7 +1,6 @@
 /* Copyright (C) 2007 db4objects Inc. http://www.db4o.com */
-using System;
 
-namespace Db4objects.Db4odoc.ListDeleting
+namespace Db4objects.Db4odoc.ListOperations
 {
     class DataObject
     {
