@@ -1,4 +1,5 @@
-package com.db4odoc.f1.diagnostics;
+/* Copyright (C) 2004 - 2007 db4objects Inc. http://www.db4o.com */
+package com.db4odoc.diagnostics;
 
 import java.util.Calendar;
 import java.text.DateFormat;
