@@ -1,4 +1,6 @@
-﻿using System.IO;
+﻿/* Copyright (C) 2004 - 2007 db4objects Inc. http://www.db4o.com */
+using System.IO;
+
 using Db4objects.Db4o;
 using Db4objects.Db4o.Query;
 
@@ -6,12 +8,12 @@ namespace Db4objects.Db4odoc.Evaluations
 {
 	public class EvaluationExample 
 	{
-		public readonly static string YapFileName = "formula1.yap";
+		private const string Db4oFileName = "reference.db4o";
 
 		public static void Main(string[] args)
 		{
-			File.Delete(YapFileName);
-			IObjectContainer db = Db4oFactory.OpenFile(YapFileName);
+			File.Delete(Db4oFileName);
+			IObjectContainer db = Db4oFactory.OpenFile(Db4oFileName);
 			try
 			{
 				StoreCars(db);
@@ -24,7 +26,7 @@ namespace Db4objects.Db4odoc.Evaluations
 		}
 		// end Main
 
-		public static void StoreCars(IObjectContainer db)
+        private static void StoreCars(IObjectContainer db)
 		{
 			Pilot pilot1 = new Pilot("Michael Schumacher", 100);
 			Car car1 = new Car("Ferrari");
@@ -40,7 +42,7 @@ namespace Db4objects.Db4odoc.Evaluations
 		}
 		// end StoreCars
 
-		public static void QueryWithEvaluation(IObjectContainer db)
+        private static void QueryWithEvaluation(IObjectContainer db)
 		{
 			IQuery query = db.Query();
 			query.Constrain(typeof (Car));
@@ -50,7 +52,7 @@ namespace Db4objects.Db4odoc.Evaluations
 		}
 		// end QueryWithEvaluation
 
-		public static void ListResult(IObjectSet result)
+        private static void ListResult(IObjectSet result)
 		{
 			System.Console.WriteLine(result.Count);
 			foreach (object item in result)
