@@ -1,4 +1,5 @@
-package com.db4odoc.f1.evaluations;
+/* Copyright (C) 2004 - 2007 db4objects Inc. http://www.db4o.com */
+package com.db4odoc.evaluations;
 
 import com.db4o.query.*;
 
