@@ -1,4 +1,4 @@
-/* Copyright (C) 2004 - 2006 db4objects Inc. http://www.db4o.com */
+/* Copyright (C) 2004 - 2007 db4objects Inc. http://www.db4o.com */
 using System;
 using System.IO;
 using Db4objects.Db4o;
@@ -12,12 +12,12 @@ namespace Db4objects.Db4odoc.Semaphores
 	public class LimitLogins 
 	{
     
-		readonly static string HOST = "localhost";
-		readonly static int PORT = 4455;
-		readonly static string USER = "db4o";
-		readonly static string PASSWORD = "db4o";
+		readonly static string Host = "localhost";
+		readonly static int Port = 4455;
+		readonly static string User = "db4o";
+		readonly static string Password= "db4o";
     
-		readonly static int MAXIMUM_USERS = 10; 
+		readonly static int MaximumUsers = 10; 
     
 		public static IObjectContainer Login()
 		{
@@ -25,7 +25,7 @@ namespace Db4objects.Db4odoc.Semaphores
 			IObjectContainer objectContainer;
 			try 
 			{
-				objectContainer = Db4oFactory.OpenClient(HOST, PORT, USER, PASSWORD);
+				objectContainer = Db4oFactory.OpenClient(Host, Port, User, Password);
 			} 
 			catch (IOException e) 
 			{
@@ -34,7 +34,7 @@ namespace Db4objects.Db4odoc.Semaphores
         
 			bool allowedToLogin = false;
         
-			for (int i = 0; i < MAXIMUM_USERS; i++) 
+			for (int i = 0; i < MaximumUsers; i++) 
 			{
 				if(objectContainer.Ext().SetSemaphore("max_user_check_" + i, 0))
 				{
