@@ -1,7 +1,12 @@
 using System.Globalization;
 
-namespace Db4objects.Db4odoc.Evaluations
+namespace com.db4o.f1.chapter6
 {
+    /// <summary>
+    /// A CultureInfo aware list of objects.
+    /// CultureInfo objects hold a native pointer to 
+    /// a system structure.
+    /// </summary>
     public class LocalizedItemList
     {
         CultureInfo _culture;
