@@ -1,4 +1,4 @@
-/* Copyright (C) 2004 - 2006 db4objects Inc. http://www.db4o.com */
+/* Copyright (C) 2004 - 2007 db4objects Inc. http://www.db4o.com */
 using System;
 using Db4objects.Db4o;
 using Db4objects.Db4o.Ext;
@@ -14,8 +14,8 @@ namespace Db4objects.Db4odoc.Semaphores
 	public class LockManager 
 	{
     
-		readonly private string SEMAPHORE_NAME = "locked: ";
-		readonly private int WAIT_FOR_AVAILABILITY = 300; // 300 milliseconds
+		readonly private string SemaphoreName = "locked: ";
+		readonly private int WaitForAvailability = 300; // 300 milliseconds
     
 		readonly private IExtObjectContainer _objectContainer;
     
@@ -27,13 +27,13 @@ namespace Db4objects.Db4odoc.Semaphores
 		public bool Lock(object obj)
 		{
 			long id = _objectContainer.GetID(obj);
-			return _objectContainer.SetSemaphore(SEMAPHORE_NAME + id, WAIT_FOR_AVAILABILITY);
+			return _objectContainer.SetSemaphore(SemaphoreName + id, WaitForAvailability);
 		}
     
 		public void Unlock(Object obj)
 		{
 			long id = _objectContainer.GetID(obj);
-			_objectContainer.ReleaseSemaphore(SEMAPHORE_NAME + id);
+			_objectContainer.ReleaseSemaphore(SemaphoreName + id);
 		}
 	}
 
