@@ -1,27 +1,28 @@
-package com.db4odoc.f1.queries;
+/* Copyright (C) 2004 - 2007 db4objects Inc. http://www.db4o.com */
+package com.db4odoc.diagnostics;
 
-public class Pilot {    
+public class Pilot {
     private String name;
-    private int points;  
-    
+    private int points;
+
     public Pilot(String name,int points) {
         this.name=name;
         this.points=points;
     }
-        
+
     public int getPoints() {
         return points;
     }
-    
+
     public void addPoints(int points) {
         this.points+=points;
     }
-    
+
     public String getName() {
         return name;
     }
-    
+
     public String toString() {
         return name+"/"+points;
     }
-}
+}
\ No newline at end of file
