@@ -1,8 +1,8 @@
-package com.db4odoc.clientserver;
+/* Copyright (C) 2007 db4objects Inc. http://www.db4o.com */
+package com.db4odoc.transactions;
 
 import java.util.*;
 
-
 public class PressureSensorReadout extends SensorReadout {
     private double pressure;
     
