@@ -1,13 +1,11 @@
-/* Copyright (C) 2004 - 2006 db4objects Inc. http://www.db4o.com */
+/* Copyright (C) 2004 - 2007 db4objects Inc. http://www.db4o.com */
 
-using System;
-
-namespace Db4objects.Db4odoc.Utility
+namespace Db4objects.Db4odoc.Activating
 {
 	public class SensorPanel
 	{
-		private Object _sensor;
-		private SensorPanel _next;
+		public object _sensor;
+		public SensorPanel _next;
 	
 		public SensorPanel()
 		{
@@ -49,26 +47,13 @@ namespace Db4objects.Db4odoc.Utility
 				_next = value;
 			}
 		}
-
-		public Object Sensor
-		{
-			get
-			{
-				return _sensor;
-			}
-            
-			set
-			{
-				_sensor = value;
-			}
-		}
 	
 		protected SensorPanel NewElement(int value)
 		{
 			return new SensorPanel(value);
 		}
 		
-		public override String ToString() 
+		public override string ToString() 
 		{
 			return "Sensor #" + _sensor ;
 		}
