@@ -1,3 +1,4 @@
+/* Copyright (C) 2007 db4objects Inc. http://www.db4o.com */
 package com.db4odoc.clientserver;
 
 import com.db4o.*;
@@ -31,7 +32,7 @@ public class StopServer implements ServerConfiguration {
     
       // get the messageSender for the ObjectContainer 
       MessageSender messageSender = objectContainer.ext()
-          .configure().getMessageSender();
+          .configure().clientServer().getMessageSender();
       
       // send an instance of a StopServer object
       messageSender.send(new StopServer());
