@@ -1,6 +1,7 @@
+/* Copyright (C) 2004 - 2007 db4objects Inc. http://www.db4o.com */
 using System;
 
-namespace Db4objects.Db4odoc.ClientServer
+namespace Db4objects.Db4odoc.Transactions
 {   
     public class TemperatureSensorReadout : SensorReadout
     {
