@@ -1,14 +1,10 @@
-/* Copyright (C) 2004 - 2007  db4objects Inc.  http://www.db4o.com
+/* This file is part of the db4o object database http://www.db4o.com
 
-This file is part of the db4o open source object database.
+Copyright (C) 2004 - 2009  Versant Corporation http://www.versant.com
 
 db4o is free software; you can redistribute it and/or modify it under
-the terms of version 2 of the GNU General Public License as published
-by the Free Software Foundation and as clarified by db4objects' GPL 
-interpretation policy, available at
-http://www.db4o.com/about/company/legalpolicies/gplinterpretation/
-Alternatively you can write to db4objects, Inc., 1900 S Norfolk Street,
-Suite 350, San Mateo, CA 94403, USA.
+the terms of version 3 of the GNU General Public License as published
+by the Free Software Foundation.
 
 db4o is distributed in the hope that it will be useful, but WITHOUT ANY
 WARRANTY; without even the implied warranty of MERCHANTABILITY or
@@ -16,8 +12,7 @@ FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
 for more details.
 
 You should have received a copy of the GNU General Public License along
-with this program; if not, write to the Free Software Foundation, Inc.,
-59 Temple Place - Suite 330, Boston, MA  02111-1307, USA. */
+with this program.  If not, see http://www.gnu.org/licenses/. */
 using System;
 using System.IO;
 
@@ -74,29 +69,29 @@ namespace Db4objects.Db4o.Tutorial.F1.Chapter2
 			Car car1 = new Car("Ferrari");
 			Pilot pilot1 = new Pilot("Michael Schumacher", 100);
 			car1.Pilot = pilot1;
-			db.Set(car1);
+			db.Store(car1);
 		}
         
 		public static void StoreSecondCar(IObjectContainer db)
 		{
 			Pilot pilot2 = new Pilot("Rubens Barrichello", 99);
-			db.Set(pilot2);
+			db.Store(pilot2);
 			Car car2 = new Car("BMW");
 			car2.Pilot = pilot2;
-			db.Set(car2);
+			db.Store(car2);
 		}
 
 		public static void RetrieveAllCarsQBE(IObjectContainer db)
 		{
 			Car proto = new Car(null);
-			IObjectSet result = db.Get(proto);
+			IObjectSet result = db.QueryByExample(proto);
 			ListResult(result);
 		}
         
 		public static void RetrieveAllPilotsQBE(IObjectContainer db)
 		{
 			Pilot proto = new Pilot(null, 0);
-			IObjectSet result = db.Get(proto);
+			IObjectSet result = db.QueryByExample(proto);
 			ListResult(result);
 		}
         
@@ -105,7 +100,7 @@ namespace Db4objects.Db4o.Tutorial.F1.Chapter2
 			Pilot pilotproto = new Pilot("Rubens Barrichello",0);
 			Car carproto = new Car(null);
 			carproto.Pilot = pilotproto;
-			IObjectSet result = db.Get(carproto);
+			IObjectSet result = db.QueryByExample(carproto);
 			ListResult(result);
 		}
         
@@ -141,13 +136,13 @@ namespace Db4objects.Db4o.Tutorial.F1.Chapter2
         
 		public static void RetrieveAllPilots(IObjectContainer db) 
 		{
-			IObjectSet results = db.Get(typeof(Pilot));
+			IObjectSet results = db.QueryByExample(typeof(Pilot));
 			ListResult(results);
 		}
 
 		public static void RetrieveAllCars(IObjectContainer db) 
 		{
-			IObjectSet results = db.Get(typeof(Car));
+			IObjectSet results = db.QueryByExample(typeof(Car));
 			ListResult(results);
 		}
     
@@ -175,35 +170,35 @@ namespace Db4objects.Db4o.Tutorial.F1.Chapter2
   		
 		public static void UpdateCar(IObjectContainer db)
 		{
-			IObjectSet result = db.Get(new Car("Ferrari"));
+			IObjectSet result = db.QueryByExample(new Car("Ferrari"));
 			Car found = (Car)result.Next();
 			found.Pilot = new Pilot("Somebody else", 0);
-			db.Set(found);
-			result = db.Get(new Car("Ferrari"));
+			db.Store(found);
+			result = db.QueryByExample(new Car("Ferrari"));
 			ListResult(result);
 		}
         
 		public static void UpdatePilotSingleSession(IObjectContainer db)
 		{
-			IObjectSet result = db.Get(new Car("Ferrari"));
+			IObjectSet result = db.QueryByExample(new Car("Ferrari"));
 			Car found = (Car)result.Next();
 			found.Pilot.AddPoints(1);
-			db.Set(found);
-			result = db.Get(new Car("Ferrari"));
+			db.Store(found);
+			result = db.QueryByExample(new Car("Ferrari"));
 			ListResult(result);
 		}
         
 		public static void UpdatePilotSeparateSessionsPart1(IObjectContainer db)
 		{
-			IObjectSet result = db.Get(new Car("Ferrari"));
+			IObjectSet result = db.QueryByExample(new Car("Ferrari"));
 			Car found = (Car)result.Next();
 			found.Pilot.AddPoints(1);
-			db.Set(found);
+			db.Store(found);
 		}
         
 		public static void UpdatePilotSeparateSessionsPart2(IObjectContainer db)
 		{
-			IObjectSet result = db.Get(new Car("Ferrari"));
+			IObjectSet result = db.QueryByExample(new Car("Ferrari"));
 			ListResult(result);
 		}
         
@@ -215,24 +210,24 @@ namespace Db4objects.Db4o.Tutorial.F1.Chapter2
         
 		public static void UpdatePilotSeparateSessionsImprovedPart2(IObjectContainer db)
 		{
-			IObjectSet result = db.Get(new Car("Ferrari"));
+			IObjectSet result = db.QueryByExample(new Car("Ferrari"));
 			Car found = (Car)result.Next();
 			found.Pilot.AddPoints(1);
-			db.Set(found);
+			db.Store(found);
 		}
         
 		public static void UpdatePilotSeparateSessionsImprovedPart3(IObjectContainer db)
 		{
-			IObjectSet result = db.Get(new Car("Ferrari"));
+			IObjectSet result = db.QueryByExample(new Car("Ferrari"));
 			ListResult(result);
 		}
         
 		public static void DeleteFlat(IObjectContainer db)
 		{
-			IObjectSet result = db.Get(new Car("Ferrari"));
+			IObjectSet result = db.QueryByExample(new Car("Ferrari"));
 			Car found = (Car)result.Next();
 			db.Delete(found);
-			result = db.Get(new Car(null));
+			result = db.QueryByExample(new Car(null));
 			ListResult(result);
 		}
         
@@ -244,25 +239,25 @@ namespace Db4objects.Db4o.Tutorial.F1.Chapter2
         
 		public static void DeleteDeepPart2(IObjectContainer db)
 		{
-			IObjectSet result = db.Get(new Car("BMW"));
+			IObjectSet result = db.QueryByExample(new Car("BMW"));
 			Car found = (Car)result.Next();
 			db.Delete(found);
-			result = db.Get(new Car(null));
+			result = db.QueryByExample(new Car(null));
 			ListResult(result);
 		}
         
 		public static void DeleteDeepRevisited(IObjectContainer db)
 		{
-			IObjectSet result = db.Get(new Pilot("Michael Schumacher", 0));
+			IObjectSet result = db.QueryByExample(new Pilot("Michael Schumacher", 0));
 			Pilot pilot = (Pilot)result.Next();
 			Car car1 = new Car("Ferrari");
 			Car car2 = new Car("BMW");
 			car1.Pilot = pilot;
 			car2.Pilot = pilot;
-			db.Set(car1);
-			db.Set(car2);
+			db.Store(car1);
+			db.Store(car2);
 			db.Delete(car2);
-			result = db.Get(new Car(null));
+			result = db.QueryByExample(new Car(null));
 			ListResult(result);
 		}
 	}    
