@@ -1,14 +1,10 @@
-/* Copyright (C) 2004 - 2007  db4objects Inc.  http://www.db4o.com
+/* This file is part of the db4o object database http://www.db4o.com
 
-This file is part of the db4o open source object database.
+Copyright (C) 2004 - 2009  Versant Corporation http://www.versant.com
 
 db4o is free software; you can redistribute it and/or modify it under
-the terms of version 2 of the GNU General Public License as published
-by the Free Software Foundation and as clarified by db4objects' GPL 
-interpretation policy, available at
-http://www.db4o.com/about/company/legalpolicies/gplinterpretation/
-Alternatively you can write to db4objects, Inc., 1900 S Norfolk Street,
-Suite 350, San Mateo, CA 94403, USA.
+the terms of version 3 of the GNU General Public License as published
+by the Free Software Foundation.
 
 db4o is distributed in the hope that it will be useful, but WITHOUT ANY
 WARRANTY; without even the implied warranty of MERCHANTABILITY or
@@ -16,8 +12,7 @@ FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
 for more details.
 
 You should have received a copy of the GNU General Public License along
-with this program; if not, write to the Free Software Foundation, Inc.,
-59 Temple Place - Suite 330, Boston, MA  02111-1307, USA. */
+with this program.  If not, see http://www.gnu.org/licenses/. */
 using System;
 using System.Collections;
 using System.IO;
@@ -66,7 +61,7 @@ namespace Db4objects.Db4o.Tutorial.F1.Chapter3
 			Car car1 = new Car("Ferrari");
 			Pilot pilot1 = new Pilot("Michael Schumacher", 100);
 			car1.Pilot = pilot1;
-			db.Set(car1);
+			db.Store(car1);
 		}
         
 		public static void StoreSecondCar(IObjectContainer db)
@@ -76,19 +71,19 @@ namespace Db4objects.Db4o.Tutorial.F1.Chapter3
 			car2.Pilot = pilot2;
 			car2.Snapshot();
 			car2.Snapshot();
-			db.Set(car2);       
+			db.Store(car2);       
 		}
         
 		public static void RetrieveAllSensorReadout(IObjectContainer db)
 		{
-			IObjectSet result = db.Get(typeof(SensorReadout));
+			IObjectSet result = db.QueryByExample(typeof(SensorReadout));
 			ListResult(result);
 		}
         
 		public static void RetrieveSensorReadoutQBE(IObjectContainer db)
 		{
 			SensorReadout proto = new SensorReadout(new double[] { 0.3, 0.1 }, DateTime.MinValue, null);
-			IObjectSet result = db.Get(proto);
+			IObjectSet result = db.QueryByExample(proto);
 			ListResult(result);
 		}
         
@@ -98,19 +93,19 @@ namespace Db4objects.Db4o.Tutorial.F1.Chapter3
 			IList protoHistory = new ArrayList();
 			protoHistory.Add(protoReadout);
 			Car protoCar = new Car(null, protoHistory);
-			IObjectSet result = db.Get(protoCar);
+			IObjectSet result = db.QueryByExample(protoCar);
 			ListResult(result);
 		}
         
 		public static void RetrieveCollections(IObjectContainer db)
 		{
-			IObjectSet result = db.Get(new ArrayList());
+			IObjectSet result = db.QueryByExample(new ArrayList());
 			ListResult(result);
 		}
         
 		public static void RetrieveArrays(IObjectContainer db)
 		{
-			IObjectSet result = db.Get(new double[] { 0.6, 0.4 });
+			IObjectSet result = db.QueryByExample(new double[] { 0.6, 0.4 });
 			ListResult(result);
 		}
         
@@ -182,10 +177,10 @@ namespace Db4objects.Db4o.Tutorial.F1.Chapter3
         
 		public static void UpdateCarPart2(IObjectContainer db)
 		{
-			IObjectSet result = db.Get(new Car("BMW", null));
+			IObjectSet result = db.QueryByExample(new Car("BMW", null));
 			Car car = (Car)result.Next();
 			car.Snapshot();
-			db.Set(car);
+			db.Store(car);
 			RetrieveAllSensorReadout(db);
 		}
         
@@ -196,9 +191,9 @@ namespace Db4objects.Db4o.Tutorial.F1.Chapter3
 			IObjectSet result = query.Descend("_history").Execute();
 			IList history = (IList)result.Next();
 			history.RemoveAt(0);
-			db.Set(history);
+			db.Store(history);
 			Car proto = new Car(null, null);
-			result = db.Get(proto);
+			result = db.QueryByExample(proto);
 			foreach (Car car in result)
 			{	
 				foreach (object readout in car.History)
@@ -215,12 +210,12 @@ namespace Db4objects.Db4o.Tutorial.F1.Chapter3
 
 		public static void DeleteAllPart2(IObjectContainer db)
 		{
-			IObjectSet result = db.Get(new Car(null, null));
+			IObjectSet result = db.QueryByExample(new Car(null, null));
 			foreach (object car in result)
 			{
 				db.Delete(car);
 			}
-			IObjectSet readouts = db.Get(new SensorReadout(null, DateTime.MinValue, null));
+			IObjectSet readouts = db.QueryByExample(new SensorReadout(null, DateTime.MinValue, null));
 			foreach (object readout in readouts)
 			{
 				db.Delete(readout);
