@@ -1,14 +1,10 @@
-/* Copyright (C) 2004 - 2007  db4objects Inc.  http://www.db4o.com
+/* This file is part of the db4o object database http://www.db4o.com
 
-This file is part of the db4o open source object database.
+Copyright (C) 2004 - 2009  Versant Corporation http://www.versant.com
 
 db4o is free software; you can redistribute it and/or modify it under
-the terms of version 2 of the GNU General Public License as published
-by the Free Software Foundation and as clarified by db4objects' GPL 
-interpretation policy, available at
-http://www.db4o.com/about/company/legalpolicies/gplinterpretation/
-Alternatively you can write to db4objects, Inc., 1900 S Norfolk Street,
-Suite 350, San Mateo, CA 94403, USA.
+the terms of version 3 of the GNU General Public License as published
+by the Free Software Foundation.
 
 db4o is distributed in the hope that it will be useful, but WITHOUT ANY
 WARRANTY; without even the implied warranty of MERCHANTABILITY or
@@ -16,8 +12,7 @@ FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
 for more details.
 
 You should have received a copy of the GNU General Public License along
-with this program; if not, write to the Free Software Foundation, Inc.,
-59 Temple Place - Suite 330, Boston, MA  02111-1307, USA. */
+with this program.  If not, see http://www.gnu.org/licenses/. */
 using System;
 using System.IO;
 using Db4objects.Db4o;
@@ -53,7 +48,7 @@ namespace Db4objects.Db4o.Tutorial.F1.Chapter4
             Car car1 = new Car("Ferrari");
             Pilot pilot1 = new Pilot("Michael Schumacher", 100);
             car1.Pilot = pilot1;
-            db.Set(car1);
+            db.Store(car1);
         }
         
         public static void StoreSecondCar(IObjectContainer db)
@@ -63,26 +58,26 @@ namespace Db4objects.Db4o.Tutorial.F1.Chapter4
             car2.Pilot = pilot2;
             car2.Snapshot();
             car2.Snapshot();
-            db.Set(car2);
+            db.Store(car2);
         }
         
         public static void RetrieveAllSensorReadoutsQBE(IObjectContainer db)
         {
             SensorReadout proto = new SensorReadout(DateTime.MinValue, null, null);
-            IObjectSet result = db.Get(proto);
+            IObjectSet result = db.QueryByExample(proto);
             ListResult(result);
         }
         
         public static void RetrieveTemperatureReadoutsQBE(IObjectContainer db)
         {
             SensorReadout proto = new TemperatureSensorReadout(DateTime.MinValue, null, null, 0.0);
-            IObjectSet result = db.Get(proto);
+            IObjectSet result = db.QueryByExample(proto);
             ListResult(result);
         }
         
         public static void RetrieveAllSensorReadoutsQBEAlternative(IObjectContainer db)
         {
-            IObjectSet result = db.Get(typeof(SensorReadout));
+            IObjectSet result = db.QueryByExample(typeof(SensorReadout));
             ListResult(result);
         }
         
@@ -96,7 +91,7 @@ namespace Db4objects.Db4o.Tutorial.F1.Chapter4
         
         public static void RetrieveAllObjects(IObjectContainer db)
         {
-            IObjectSet result = db.Get(new object());
+            IObjectSet result = db.QueryByExample(new object());
             ListResult(result);
         }
     }
