@@ -1,14 +1,10 @@
-/* Copyright (C) 2004 - 2007  db4objects Inc.  http://www.db4o.com
+/* This file is part of the db4o object database http://www.db4o.com
 
-This file is part of the db4o open source object database.
+Copyright (C) 2004 - 2009  Versant Corporation http://www.versant.com
 
 db4o is free software; you can redistribute it and/or modify it under
-the terms of version 2 of the GNU General Public License as published
-by the Free Software Foundation and as clarified by db4objects' GPL 
-interpretation policy, available at
-http://www.db4o.com/about/company/legalpolicies/gplinterpretation/
-Alternatively you can write to db4objects, Inc., 1900 S Norfolk Street,
-Suite 350, San Mateo, CA 94403, USA.
+the terms of version 3 of the GNU General Public License as published
+by the Free Software Foundation.
 
 db4o is distributed in the hope that it will be useful, but WITHOUT ANY
 WARRANTY; without even the implied warranty of MERCHANTABILITY or
@@ -16,8 +12,7 @@ FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
 for more details.
 
 You should have received a copy of the GNU General Public License along
-with this program; if not, write to the Free Software Foundation, Inc.,
-59 Temple Place - Suite 330, Boston, MA  02111-1307, USA. */
+with this program.  If not, see http://www.gnu.org/licenses/. */
 using System.IO;
 using Db4objects.Db4o;
 
@@ -74,7 +69,7 @@ namespace Db4objects.Db4o.Tutorial.F1.Chapter5
             Pilot pilot = new Pilot("Rubens Barrichello", 99);
             Car car = new Car("BMW");
             car.Pilot = pilot;
-            db.Set(car);
+            db.Store(car);
         }
     
         public static void SetSecondCar(IObjectContainer db)
@@ -82,7 +77,7 @@ namespace Db4objects.Db4o.Tutorial.F1.Chapter5
             Pilot pilot = new Pilot("Michael Schumacher", 100);
             Car car = new Car("Ferrari");
             car.Pilot = pilot;
-            db.Set(car);
+            db.Store(car);
         }
     
         public static void AccessLocalServer()
@@ -103,7 +98,7 @@ namespace Db4objects.Db4o.Tutorial.F1.Chapter5
         public static void QueryLocalServer(IObjectServer server)
         {
             IObjectContainer client = server.OpenClient();
-            ListResult(client.Get(new Car(null)));
+            ListResult(client.QueryByExample(new Car(null)));
             client.Close();
         }
         
@@ -117,15 +112,15 @@ namespace Db4objects.Db4o.Tutorial.F1.Chapter5
             IObjectContainer client1 =server.OpenClient();
             IObjectContainer client2 =server.OpenClient();
             Pilot pilot = new Pilot("David Coulthard", 98);
-            IObjectSet result = client1.Get(new Car("BMW"));
+            IObjectSet result = client1.QueryByExample(new Car("BMW"));
             Car car = (Car)result.Next();
             car.Pilot = pilot;
-            client1.Set(car);
-            ListResult(client1.Get(new Car(null)));
-            ListResult(client2.Get(new Car(null)));
+            client1.Store(car);
+            ListResult(client1.QueryByExample(new Car(null)));
+            ListResult(client2.QueryByExample(new Car(null)));
             client1.Commit();
-            ListResult(client1.Get(typeof(Car)));			
-            ListRefreshedResult(client2, client2.Get(typeof(Car)), 2);
+            ListResult(client1.QueryByExample(typeof(Car)));			
+            ListRefreshedResult(client2, client2.QueryByExample(typeof(Car)), 2);
             client1.Close();
             client2.Close();
         }
@@ -134,16 +129,16 @@ namespace Db4objects.Db4o.Tutorial.F1.Chapter5
         {
             IObjectContainer client1 = server.OpenClient();
             IObjectContainer client2 = server.OpenClient();
-            IObjectSet result = client1.Get(new Car("BMW"));
+            IObjectSet result = client1.QueryByExample(new Car("BMW"));
             Car car = (Car)result.Next();
             car.Pilot = new Pilot("Someone else", 0);
-            client1.Set(car);
-            ListResult(client1.Get(new Car(null)));
-            ListResult(client2.Get(new Car(null)));
+            client1.Store(car);
+            ListResult(client1.QueryByExample(new Car(null)));
+            ListResult(client2.QueryByExample(new Car(null)));
             client1.Rollback();
             client1.Ext().Refresh(car, 2);
-            ListResult(client1.Get(new Car(null)));
-            ListResult(client2.Get(new Car(null)));
+            ListResult(client1.QueryByExample(new Car(null)));
+            ListResult(client2.QueryByExample(new Car(null)));
             client1.Close();
             client2.Close();
         }
@@ -167,7 +162,7 @@ namespace Db4objects.Db4o.Tutorial.F1.Chapter5
         public static void QueryRemoteServer(int port, string user, string password)
         {
             IObjectContainer client = Db4oFactory.OpenClient("localhost", port, user, password);
-            ListResult(client.Get(new Car(null)));
+            ListResult(client.QueryByExample(new Car(null)));
             client.Close();
         }
     
@@ -176,15 +171,15 @@ namespace Db4objects.Db4o.Tutorial.F1.Chapter5
             IObjectContainer client1 = Db4oFactory.OpenClient("localhost", port, user, password);
             IObjectContainer client2 = Db4oFactory.OpenClient("localhost", port, user, password);
             Pilot pilot = new Pilot("Jenson Button", 97);
-            IObjectSet result = client1.Get(new Car(null));
+            IObjectSet result = client1.QueryByExample(new Car(null));
             Car car = (Car)result.Next();
             car.Pilot = pilot;
-            client1.Set(car);
-            ListResult(client1.Get(new Car(null)));
-            ListResult(client2.Get(new Car(null)));
+            client1.Store(car);
+            ListResult(client1.QueryByExample(new Car(null)));
+            ListResult(client2.QueryByExample(new Car(null)));
             client1.Commit();
-            ListResult(client1.Get(new Car(null)));
-            ListResult(client2.Get(new Car(null)));
+            ListResult(client1.QueryByExample(new Car(null)));
+            ListResult(client2.QueryByExample(new Car(null)));
             client1.Close();
             client2.Close();
         }
@@ -193,16 +188,16 @@ namespace Db4objects.Db4o.Tutorial.F1.Chapter5
         {
             IObjectContainer client1 = Db4oFactory.OpenClient("localhost", port, user, password);
             IObjectContainer client2 = Db4oFactory.OpenClient("localhost", port, user, password);
-            IObjectSet result = client1.Get(new Car(null));
+            IObjectSet result = client1.QueryByExample(new Car(null));
             Car car = (Car)result.Next();
             car.Pilot = new Pilot("Someone else", 0);
-            client1.Set(car);
-            ListResult(client1.Get(new Car(null)));
-            ListResult(client2.Get(new Car(null)));
+            client1.Store(car);
+            ListResult(client1.QueryByExample(new Car(null)));
+            ListResult(client2.QueryByExample(new Car(null)));
             client1.Rollback();
             client1.Ext().Refresh(car,2);
-            ListResult(client1.Get(new Car(null)));
-            ListResult(client2.Get(new Car(null)));
+            ListResult(client1.QueryByExample(new Car(null)));
+            ListResult(client2.QueryByExample(new Car(null)));
             client1.Close();
             client2.Close();
         }
