@@ -1,14 +1,10 @@
-/* Copyright (C) 2004 - 2007  db4objects Inc.  http://www.db4o.com
+/* This file is part of the db4o object database http://www.db4o.com
 
-This file is part of the db4o open source object database.
+Copyright (C) 2004 - 2009  Versant Corporation http://www.versant.com
 
 db4o is free software; you can redistribute it and/or modify it under
-the terms of version 2 of the GNU General Public License as published
-by the Free Software Foundation and as clarified by db4objects' GPL 
-interpretation policy, available at
-http://www.db4o.com/about/company/legalpolicies/gplinterpretation/
-Alternatively you can write to db4objects, Inc., 1900 S Norfolk Street,
-Suite 350, San Mateo, CA 94403, USA.
+the terms of version 3 of the GNU General Public License as published
+by the Free Software Foundation.
 
 db4o is distributed in the hope that it will be useful, but WITHOUT ANY
 WARRANTY; without even the implied warranty of MERCHANTABILITY or
@@ -16,8 +12,7 @@ FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
 for more details.
 
 You should have received a copy of the GNU General Public License along
-with this program; if not, write to the Free Software Foundation, Inc.,
-59 Temple Place - Suite 330, Boston, MA  02111-1307, USA. */
+with this program.  If not, see http://www.gnu.org/licenses/. */
 using System;
 using System.Threading;
 using Db4objects.Db4o;
@@ -69,7 +64,7 @@ namespace Db4objects.Db4o.Tutorial.F1.Chapter5
                 {
                     if (! stop)
                     {
-                        // wait forever for Notify() from Close()
+                        // wait forever until Close will change stop variable
                         Monitor.Wait(this);
                     }
                 }
@@ -85,7 +80,7 @@ namespace Db4objects.Db4o.Tutorial.F1.Chapter5
         /// messaging callback
         /// see com.db4o.messaging.MessageRecipient#ProcessMessage()
         /// </summary>
-        public void ProcessMessage(IObjectContainer con, object message)
+        public void ProcessMessage(IMessageContext con, object message)
         {
             if (message is StopServer)
             {
