@@ -1,14 +1,10 @@
-/* Copyright (C) 2004 - 2007  db4objects Inc.  http://www.db4o.com
+/* This file is part of the db4o object database http://www.db4o.com
 
-This file is part of the db4o open source object database.
+Copyright (C) 2004 - 2009  Versant Corporation http://www.versant.com
 
 db4o is free software; you can redistribute it and/or modify it under
-the terms of version 2 of the GNU General Public License as published
-by the Free Software Foundation and as clarified by db4objects' GPL 
-interpretation policy, available at
-http://www.db4o.com/about/company/legalpolicies/gplinterpretation/
-Alternatively you can write to db4objects, Inc., 1900 S Norfolk Street,
-Suite 350, San Mateo, CA 94403, USA.
+the terms of version 3 of the GNU General Public License as published
+by the Free Software Foundation.
 
 db4o is distributed in the hope that it will be useful, but WITHOUT ANY
 WARRANTY; without even the implied warranty of MERCHANTABILITY or
@@ -16,8 +12,7 @@ FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
 for more details.
 
 You should have received a copy of the GNU General Public License along
-with this program; if not, write to the Free Software Foundation, Inc.,
-59 Temple Place - Suite 330, Boston, MA  02111-1307, USA. */
+with this program.  If not, see http://www.gnu.org/licenses/. */
 using System;
 using System.IO;
 using Db4objects.Db4o;
@@ -54,13 +49,13 @@ namespace Db4objects.Db4o.Tutorial.F1.Chapter5
             Pilot pilot = new Pilot("Rubens Barrichello", 99);
             Car car = new Car("BMW");
             car.Pilot = pilot;
-            db.Set(car);
+            db.Store(car);
             db.Commit();
         }
     
         public static void ListAllCars(IObjectContainer db)
         {
-            IObjectSet result = db.Get(typeof(Car));
+            IObjectSet result = db.QueryByExample(typeof(Car));
             ListResult(result);
         }
         
@@ -69,26 +64,26 @@ namespace Db4objects.Db4o.Tutorial.F1.Chapter5
             Pilot pilot = new Pilot("Michael Schumacher", 100);
             Car car = new Car("Ferrari");
             car.Pilot = pilot;
-            db.Set(car);
+            db.Store(car);
             db.Rollback();
         }
     
         public static void CarSnapshotRollback(IObjectContainer db)
         {
-            IObjectSet result = db.Get(new Car("BMW"));
+            IObjectSet result = db.QueryByExample(new Car("BMW"));
             Car car = (Car)result.Next();
             car.Snapshot();
-            db.Set(car);
+            db.Store(car);
             db.Rollback();
             Console.WriteLine(car);
         }
     
         public static void CarSnapshotRollbackRefresh(IObjectContainer db)
         {
-            IObjectSet result=db.Get(new Car("BMW"));
+            IObjectSet result=db.QueryByExample(new Car("BMW"));
             Car car=(Car)result.Next();
             car.Snapshot();
-            db.Set(car);
+            db.Store(car);
             db.Rollback();
             db.Ext().Refresh(car, int.MaxValue);
             Console.WriteLine(car);
