@@ -1,14 +1,10 @@
-/* Copyright (C) 2004 - 2007  db4objects Inc.  http://www.db4o.com
+/* This file is part of the db4o object database http://www.db4o.com
 
-This file is part of the db4o open source object database.
+Copyright (C) 2004 - 2009  Versant Corporation http://www.versant.com
 
 db4o is free software; you can redistribute it and/or modify it under
-the terms of version 2 of the GNU General Public License as published
-by the Free Software Foundation and as clarified by db4objects' GPL 
-interpretation policy, available at
-http://www.db4o.com/about/company/legalpolicies/gplinterpretation/
-Alternatively you can write to db4objects, Inc., 1900 S Norfolk Street,
-Suite 350, San Mateo, CA 94403, USA.
+the terms of version 3 of the GNU General Public License as published
+by the Free Software Foundation.
 
 db4o is distributed in the hope that it will be useful, but WITHOUT ANY
 WARRANTY; without even the implied warranty of MERCHANTABILITY or
@@ -16,27 +12,30 @@ FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
 for more details.
 
 You should have received a copy of the GNU General Public License along
-with this program; if not, write to the Free Software Foundation, Inc.,
-59 Temple Place - Suite 330, Boston, MA  02111-1307, USA. */
+with this program.  If not, see http://www.gnu.org/licenses/. */
+using Db4oUnit;
+using Db4objects.Db4o.Internal;
+using Db4objects.Db4o.Internal.Btree;
+using Db4objects.Db4o.Tests.Common.Btree;
+
 namespace Db4objects.Db4o.Tests.Common.Btree
 {
-	public class BTreeAddRemoveTestCase : Db4objects.Db4o.Tests.Common.Btree.BTreeTestCaseBase
+	public class BTreeAddRemoveTestCase : BTreeTestCaseBase
 	{
 		public virtual void TestFirstPointerMultiTransactional()
 		{
-			int count = BTREE_NODE_SIZE + 1;
+			int count = BtreeNodeSize + 1;
 			for (int i = 0; i < count; i++)
 			{
 				Add(count + i + 1);
 			}
 			int smallest = count + 1;
-			Db4objects.Db4o.Internal.Transaction trans = NewTransaction();
+			Transaction trans = NewTransaction();
 			for (int i = 0; i < count; i++)
 			{
 				Add(trans, i);
 			}
-			Db4objects.Db4o.Internal.Btree.BTreePointer firstPointer = _btree.FirstPointer(Trans
-				());
+			BTreePointer firstPointer = _btree.FirstPointer(Trans());
 			AssertPointerKey(smallest, firstPointer);
 		}
 
@@ -56,11 +55,10 @@ namespace Db4objects.Db4o.Tests.Common.Btree
 			int[] keys = new int[] { 3, 4, 7, 9 };
 			Add(keys);
 			Remove(4);
-			Db4objects.Db4o.Internal.Btree.IBTreeRange result = Search(4);
-			Db4oUnit.Assert.IsTrue(result.IsEmpty());
-			Db4objects.Db4o.Internal.Btree.IBTreeRange range = result.Greater();
-			Db4objects.Db4o.Tests.Common.Btree.BTreeAssert.AssertRange(new int[] { 7, 9 }, range
-				);
+			IBTreeRange result = Search(4);
+			Assert.IsTrue(result.IsEmpty());
+			IBTreeRange range = result.Greater();
+			BTreeAssert.AssertRange(new int[] { 7, 9 }, range);
 		}
 
 		public virtual void TestMultipleRemoveAdds()
@@ -78,8 +76,8 @@ namespace Db4objects.Db4o.Tests.Common.Btree
 			int element = 1;
 			Add(element);
 			Commit();
-			Db4objects.Db4o.Internal.Transaction trans1 = NewTransaction();
-			Db4objects.Db4o.Internal.Transaction trans2 = NewTransaction();
+			Transaction trans1 = NewTransaction();
+			Transaction trans2 = NewTransaction();
 			Remove(trans1, element);
 			AssertSingleElement(trans2, element);
 			Add(trans1, element);
@@ -99,13 +97,12 @@ namespace Db4objects.Db4o.Tests.Common.Btree
 			AssertKeys(keys);
 			Remove(SystemTrans(), assorted);
 			AssertKeys(keys);
-			Db4objects.Db4o.Tests.Common.Btree.BTreeAssert.AssertRange(new int[] { 7, 9 }, Search
-				(Trans(), 4).Greater());
+			BTreeAssert.AssertRange(new int[] { 7, 9 }, Search(Trans(), 4).Greater());
 		}
 
 		private void AssertKeys(int[] keys)
 		{
-			Db4objects.Db4o.Tests.Common.Btree.BTreeAssert.AssertKeys(Trans(), _btree, keys);
+			BTreeAssert.AssertKeys(Trans(), _btree, keys);
 		}
 
 		public virtual void TestAddRemoveInDifferentTransactions()
@@ -117,6 +114,25 @@ namespace Db4objects.Db4o.Tests.Common.Btree
 			Remove(Trans(), element);
 			AssertEmpty(SystemTrans());
 			AssertEmpty(Trans());
+			_btree.Commit(SystemTrans());
+			_btree.Commit(Trans());
+			AssertEmpty(SystemTrans());
+			AssertEmpty(Trans());
+		}
+
+		public virtual void TestRemoveCommitInDifferentTransactions()
+		{
+			int element = 1;
+			Add(Trans(), element);
+			_btree.Commit(Trans());
+			Remove(SystemTrans(), element);
+			Remove(Trans(), element);
+			AssertEmpty(SystemTrans());
+			AssertEmpty(Trans());
+			_btree.Commit(SystemTrans());
+			_btree.Commit(Trans());
+			AssertEmpty(SystemTrans());
+			AssertEmpty(Trans());
 		}
 
 		public virtual void TestRemoveAddInDifferentTransactions()
@@ -146,9 +162,34 @@ namespace Db4objects.Db4o.Tests.Common.Btree
 			AssertSingleElement(SystemTrans(), element);
 		}
 
+		public virtual void TestMultipleConcurrentRemoves()
+		{
+			int count = 100;
+			for (int i = 0; i < count; i++)
+			{
+				Add(Trans(), i);
+			}
+			Db().Commit();
+			Transaction secondTransaction = NewTransaction();
+			for (int i = 1; i < count; i++)
+			{
+				if (i % 2 == 0)
+				{
+					Remove(Trans(), i);
+				}
+				else
+				{
+					Remove(secondTransaction, i);
+				}
+			}
+			secondTransaction.Commit();
+			Db().Commit();
+			AssertSize(1);
+		}
+
 		public static void Main(string[] args)
 		{
-			new Db4objects.Db4o.Tests.Common.Btree.BTreeAddRemoveTestCase().RunSolo();
+			new BTreeAddRemoveTestCase().RunSolo();
 		}
 	}
 }
