@@ -1,14 +1,10 @@
-/* Copyright (C) 2004 - 2007  db4objects Inc.  http://www.db4o.com
+/* This file is part of the db4o object database http://www.db4o.com
 
-This file is part of the db4o open source object database.
+Copyright (C) 2004 - 2009  Versant Corporation http://www.versant.com
 
 db4o is free software; you can redistribute it and/or modify it under
-the terms of version 2 of the GNU General Public License as published
-by the Free Software Foundation and as clarified by db4objects' GPL 
-interpretation policy, available at
-http://www.db4o.com/about/company/legalpolicies/gplinterpretation/
-Alternatively you can write to db4objects, Inc., 1900 S Norfolk Street,
-Suite 350, San Mateo, CA 94403, USA.
+the terms of version 3 of the GNU General Public License as published
+by the Free Software Foundation.
 
 db4o is distributed in the hope that it will be useful, but WITHOUT ANY
 WARRANTY; without even the implied warranty of MERCHANTABILITY or
@@ -16,30 +12,35 @@ FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
 for more details.
 
 You should have received a copy of the GNU General Public License along
-with this program; if not, write to the Free Software Foundation, Inc.,
-59 Temple Place - Suite 330, Boston, MA  02111-1307, USA. */
+with this program.  If not, see http://www.gnu.org/licenses/. */
+using Db4oUnit.Extensions;
+using Db4oUnit.Extensions.Fixtures;
+using Db4objects.Db4o.Internal;
+using Db4objects.Db4o.Internal.Btree;
+using Db4objects.Db4o.Tests.Common.Btree;
+
 namespace Db4objects.Db4o.Tests.Common.Btree
 {
-	public class BTreeSimpleTestCase : Db4oUnit.Extensions.AbstractDb4oTestCase, Db4oUnit.Extensions.Fixtures.IOptOutDefragSolo
-		, Db4oUnit.Extensions.Fixtures.IOptOutCS
+	public class BTreeSimpleTestCase : AbstractDb4oTestCase, IOptOutDefragSolo, IOptOutCS
 	{
-		protected const int BTREE_NODE_SIZE = 4;
+		protected const int BtreeNodeSize = 4;
 
-		internal int[] _keys = { 3, 234, 55, 87, 2, 1, 101, 59, 70, 300, 288 };
+		internal int[] _keys = new int[] { 3, 234, 55, 87, 2, 1, 101, 59, 70, 300, 288 };
 
 		internal int[] _values;
 
-		internal int[] _sortedKeys = { 1, 2, 3, 55, 59, 70, 87, 101, 234, 288, 300 };
+		internal int[] _sortedKeys = new int[] { 1, 2, 3, 55, 59, 70, 87, 101, 234, 288, 
+			300 };
 
 		internal int[] _sortedValues;
 
-		internal int[] _keysOnRemoval = { 1, 2, 55, 59, 70, 87, 234, 288, 300 };
+		internal int[] _keysOnRemoval = new int[] { 1, 2, 55, 59, 70, 87, 234, 288, 300 };
 
 		internal int[] _valuesOnRemoval;
 
-		internal int[] _one = { 1 };
+		internal int[] _one = new int[] { 1 };
 
-		internal int[] _none = {  };
+		internal int[] _none = new int[] {  };
 
 		public BTreeSimpleTestCase() : base()
 		{
@@ -60,18 +61,18 @@ namespace Db4objects.Db4o.Tests.Common.Btree
 			}
 		}
 
+		/// <exception cref="System.Exception"></exception>
 		public virtual void TestIntKeys()
 		{
-			Db4objects.Db4o.Internal.Btree.BTree btree = Db4objects.Db4o.Tests.Common.Btree.BTreeAssert
-				.CreateIntKeyBTree(Stream(), 0, BTREE_NODE_SIZE);
+			BTree btree = BTreeAssert.CreateIntKeyBTree(Container(), 0, BtreeNodeSize);
 			for (int i = 0; i < 5; i++)
 			{
 				btree = CycleIntKeys(btree);
 			}
 		}
 
-		private Db4objects.Db4o.Internal.Btree.BTree CycleIntKeys(Db4objects.Db4o.Internal.Btree.BTree
-			 btree)
+		/// <exception cref="System.Exception"></exception>
+		private BTree CycleIntKeys(BTree btree)
 		{
 			AddKeys(btree);
 			ExpectKeys(btree, _sortedKeys);
@@ -83,13 +84,13 @@ namespace Db4objects.Db4o.Tests.Common.Btree
 			ExpectKeys(btree, _sortedKeys);
 			int id = btree.GetID();
 			Reopen();
-			btree = Db4objects.Db4o.Tests.Common.Btree.BTreeAssert.CreateIntKeyBTree(Stream()
-				, id, BTREE_NODE_SIZE);
+			btree = BTreeAssert.CreateIntKeyBTree(Container(), id, BtreeNodeSize);
 			ExpectKeys(btree, _sortedKeys);
 			RemoveKeys(btree);
 			ExpectKeys(btree, _keysOnRemoval);
 			btree.Commit(Trans());
 			ExpectKeys(btree, _keysOnRemoval);
+			// remove all but 1
 			for (int i = 1; i < _keysOnRemoval.Length; i++)
 			{
 				btree.Remove(Trans(), _keysOnRemoval[i]);
@@ -106,24 +107,24 @@ namespace Db4objects.Db4o.Tests.Common.Btree
 			return btree;
 		}
 
-		private void RemoveKeys(Db4objects.Db4o.Internal.Btree.BTree btree)
+		private void RemoveKeys(BTree btree)
 		{
 			btree.Remove(Trans(), 3);
 			btree.Remove(Trans(), 101);
 		}
 
-		private void AddKeys(Db4objects.Db4o.Internal.Btree.BTree btree)
+		private void AddKeys(BTree btree)
 		{
-			Db4objects.Db4o.Internal.Transaction trans = Trans();
+			Transaction trans = Trans();
 			for (int i = 0; i < _keys.Length; i++)
 			{
 				btree.Add(trans, _keys[i]);
 			}
 		}
 
-		private void ExpectKeys(Db4objects.Db4o.Internal.Btree.BTree btree, int[] keys)
+		private void ExpectKeys(BTree btree, int[] keys)
 		{
-			Db4objects.Db4o.Tests.Common.Btree.BTreeAssert.AssertKeys(Trans(), btree, keys);
+			BTreeAssert.AssertKeys(Trans(), btree, keys);
 		}
 	}
 }
