@@ -1,14 +1,10 @@
-/* Copyright (C) 2004 - 2007  db4objects Inc.  http://www.db4o.com
+/* This file is part of the db4o object database http://www.db4o.com
 
-This file is part of the db4o open source object database.
+Copyright (C) 2004 - 2009  Versant Corporation http://www.versant.com
 
 db4o is free software; you can redistribute it and/or modify it under
-the terms of version 2 of the GNU General Public License as published
-by the Free Software Foundation and as clarified by db4objects' GPL 
-interpretation policy, available at
-http://www.db4o.com/about/company/legalpolicies/gplinterpretation/
-Alternatively you can write to db4objects, Inc., 1900 S Norfolk Street,
-Suite 350, San Mateo, CA 94403, USA.
+the terms of version 3 of the GNU General Public License as published
+by the Free Software Foundation.
 
 db4o is distributed in the hope that it will be useful, but WITHOUT ANY
 WARRANTY; without even the implied warranty of MERCHANTABILITY or
@@ -16,28 +12,30 @@ FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
 for more details.
 
 You should have received a copy of the GNU General Public License along
-with this program; if not, write to the Free Software Foundation, Inc.,
-59 Temple Place - Suite 330, Boston, MA  02111-1307, USA. */
+with this program.  If not, see http://www.gnu.org/licenses/. */
+using Db4oUnit;
+using Db4objects.Db4o.Foundation;
+using Sharpen;
+
 namespace Db4objects.Db4o.Tests.Common.Btree
 {
-	public class ExpectingVisitor : Db4objects.Db4o.Foundation.IVisitor4
+	public class ExpectingVisitor : IVisitor4
 	{
-		private const bool DEBUG = false;
+		private const bool Debug = false;
 
 		private readonly object[] _expected;
 
 		private readonly bool _obeyOrder;
 
-		private readonly Db4objects.Db4o.Foundation.Collection4 _unexpected = new Db4objects.Db4o.Foundation.Collection4
-			();
+		private readonly Collection4 _unexpected = new Collection4();
 
 		private bool _ignoreUnexpected;
 
 		private int _cursor;
 
-		private sealed class _AnonymousInnerClass24 : object
+		private sealed class _object_24 : object
 		{
-			public _AnonymousInnerClass24()
+			public _object_24()
 			{
 			}
 
@@ -47,7 +45,7 @@ namespace Db4objects.Db4o.Tests.Common.Btree
 			}
 		}
 
-		private static readonly object FOUND = new _AnonymousInnerClass24();
+		private static readonly object Found = new _object_24();
 
 		public ExpectingVisitor(object[] results, bool obeyOrder, bool ignoreUnexpected)
 		{
@@ -66,6 +64,7 @@ namespace Db4objects.Db4o.Tests.Common.Btree
 		{
 		}
 
+		/// <summary>Expect empty</summary>
 		public ExpectingVisitor() : this(new object[0])
 		{
 		}
@@ -89,7 +88,7 @@ namespace Db4objects.Db4o.Tests.Common.Btree
 				if (AreEqual(_expected[_cursor], obj))
 				{
 					Ods("Expected OK: " + obj.ToString());
-					_expected[_cursor] = FOUND;
+					_expected[_cursor] = Found;
 					_cursor++;
 					return;
 				}
@@ -115,7 +114,7 @@ namespace Db4objects.Db4o.Tests.Common.Btree
 				if (AreEqual(obj, expectedItem))
 				{
 					Ods("Expected OK: " + obj);
-					_expected[i] = FOUND;
+					_expected[i] = Found;
 					return;
 				}
 			}
@@ -136,11 +135,11 @@ namespace Db4objects.Db4o.Tests.Common.Btree
 		{
 			if (_unexpected.Size() > 0)
 			{
-				Db4oUnit.Assert.Fail("UNEXPECTED: " + _unexpected.ToString());
+				Assert.Fail("UNEXPECTED: " + _unexpected.ToString());
 			}
 			for (int i = 0; i < _expected.Length; i++)
 			{
-				Db4oUnit.Assert.AreSame(FOUND, _expected[i]);
+				Assert.AreSame(Found, _expected[i]);
 			}
 		}
 	}
