@@ -1,14 +1,10 @@
-/* Copyright (C) 2004 - 2007  db4objects Inc.  http://www.db4o.com
+/* This file is part of the db4o object database http://www.db4o.com
 
-This file is part of the db4o open source object database.
+Copyright (C) 2004 - 2009  Versant Corporation http://www.versant.com
 
 db4o is free software; you can redistribute it and/or modify it under
-the terms of version 2 of the GNU General Public License as published
-by the Free Software Foundation and as clarified by db4objects' GPL 
-interpretation policy, available at
-http://www.db4o.com/about/company/legalpolicies/gplinterpretation/
-Alternatively you can write to db4objects, Inc., 1900 S Norfolk Street,
-Suite 350, San Mateo, CA 94403, USA.
+the terms of version 3 of the GNU General Public License as published
+by the Free Software Foundation.
 
 db4o is distributed in the hope that it will be useful, but WITHOUT ANY
 WARRANTY; without even the implied warranty of MERCHANTABILITY or
@@ -16,17 +12,21 @@ FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
 for more details.
 
 You should have received a copy of the GNU General Public License along
-with this program; if not, write to the Free Software Foundation, Inc.,
-59 Temple Place - Suite 330, Boston, MA  02111-1307, USA. */
+with this program.  If not, see http://www.gnu.org/licenses/. */
+using Db4oUnit;
+using Db4oUnit.Extensions.Fixtures;
+using Db4objects.Db4o.Internal;
+using Db4objects.Db4o.Query;
+using Db4objects.Db4o.Tests.Common.Fieldindex;
+
 namespace Db4objects.Db4o.Tests.Common.Fieldindex
 {
 	/// <exclude></exclude>
-	public class StringIndexTestCase : Db4objects.Db4o.Tests.Common.Fieldindex.StringIndexTestCaseBase
-		, Db4oUnit.Extensions.Fixtures.IOptOutCS
+	public class StringIndexTestCase : StringIndexTestCaseBase, IOptOutCS
 	{
 		public static void Main(string[] args)
 		{
-			new Db4objects.Db4o.Tests.Common.Fieldindex.StringIndexTestCase().RunSolo();
+			new StringIndexTestCase().RunSolo();
 		}
 
 		public virtual void TestNotEquals()
@@ -35,12 +35,12 @@ namespace Db4objects.Db4o.Tests.Common.Fieldindex
 			Add("bar");
 			Add("baz");
 			Add(null);
-			Db4objects.Db4o.Query.IQuery query = NewQuery(typeof(Db4objects.Db4o.Tests.Common.Fieldindex.StringIndexTestCaseBase.Item)
-				);
+			IQuery query = NewQuery(typeof(StringIndexTestCaseBase.Item));
 			query.Descend("name").Constrain("bar").Not();
 			AssertItems(new string[] { "foo", "baz", null }, query.Execute());
 		}
 
+		/// <exception cref="System.Exception"></exception>
 		public virtual void TestCancelRemovalRollback()
 		{
 			PrepareCancelRemoval(Trans(), "original");
@@ -51,10 +51,11 @@ namespace Db4objects.Db4o.Tests.Common.Fieldindex
 			AssertExists("original");
 		}
 
+		/// <exception cref="System.Exception"></exception>
 		public virtual void TestCancelRemovalRollbackForMultipleTransactions()
 		{
-			Db4objects.Db4o.Internal.Transaction trans1 = NewTransaction();
-			Db4objects.Db4o.Internal.Transaction trans2 = NewTransaction();
+			Transaction trans1 = NewTransaction();
+			Transaction trans2 = NewTransaction();
 			PrepareCancelRemoval(trans1, "original");
 			AssertExists(trans2, "original");
 			trans1.Rollback();
@@ -68,6 +69,7 @@ namespace Db4objects.Db4o.Tests.Common.Fieldindex
 			AssertExists("original");
 		}
 
+		/// <exception cref="System.Exception"></exception>
 		public virtual void TestCancelRemoval()
 		{
 			PrepareCancelRemoval(Trans(), "original");
@@ -77,8 +79,7 @@ namespace Db4objects.Db4o.Tests.Common.Fieldindex
 			AssertExists("original");
 		}
 
-		private void PrepareCancelRemoval(Db4objects.Db4o.Internal.Transaction transaction
-			, string itemName)
+		private void PrepareCancelRemoval(Transaction transaction, string itemName)
 		{
 			Add(itemName);
 			Db().Commit();
@@ -88,10 +89,11 @@ namespace Db4objects.Db4o.Tests.Common.Fieldindex
 			AssertExists(transaction, itemName);
 		}
 
+		/// <exception cref="System.Exception"></exception>
 		public virtual void TestCancelRemovalForMultipleTransactions()
 		{
-			Db4objects.Db4o.Internal.Transaction trans1 = NewTransaction();
-			Db4objects.Db4o.Internal.Transaction trans2 = NewTransaction();
+			Transaction trans1 = NewTransaction();
+			Transaction trans2 = NewTransaction();
 			PrepareCancelRemoval(trans1, "original");
 			Rename(trans2, "original", "updated");
 			trans1.Commit();
@@ -100,16 +102,17 @@ namespace Db4objects.Db4o.Tests.Common.Fieldindex
 			AssertExists("original");
 		}
 
+		/// <exception cref="System.Exception"></exception>
 		public virtual void TestDeletingAndReaddingMember()
 		{
 			Add("original");
 			AssertExists("original");
 			Rename("original", "updated");
 			AssertExists("updated");
-			Db4oUnit.Assert.IsNull(Query("original"));
+			Assert.IsNull(Query("original"));
 			Reopen();
 			AssertExists("updated");
-			Db4oUnit.Assert.IsNull(Query("original"));
+			Assert.IsNull(Query("original"));
 		}
 	}
 }
