@@ -1,14 +1,10 @@
-/* Copyright (C) 2004 - 2007  db4objects Inc.  http://www.db4o.com
+/* This file is part of the db4o object database http://www.db4o.com
 
-This file is part of the db4o open source object database.
+Copyright (C) 2004 - 2009  Versant Corporation http://www.versant.com
 
 db4o is free software; you can redistribute it and/or modify it under
-the terms of version 2 of the GNU General Public License as published
-by the Free Software Foundation and as clarified by db4objects' GPL 
-interpretation policy, available at
-http://www.db4o.com/about/company/legalpolicies/gplinterpretation/
-Alternatively you can write to db4objects, Inc., 1900 S Norfolk Street,
-Suite 350, San Mateo, CA 94403, USA.
+the terms of version 3 of the GNU General Public License as published
+by the Free Software Foundation.
 
 db4o is distributed in the hope that it will be useful, but WITHOUT ANY
 WARRANTY; without even the implied warranty of MERCHANTABILITY or
@@ -16,13 +12,16 @@ FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
 for more details.
 
 You should have received a copy of the GNU General Public License along
-with this program; if not, write to the Free Software Foundation, Inc.,
-59 Temple Place - Suite 330, Boston, MA  02111-1307, USA. */
+with this program.  If not, see http://www.gnu.org/licenses/. */
+using Db4oUnit;
+using Db4objects.Db4o.Foundation;
+using Db4objects.Db4o.Tests.Common.Foundation;
+
 namespace Db4objects.Db4o.Tests.Common.Foundation
 {
-	public class Algorithms4TestCase : Db4oUnit.ITestCase
+	public class Algorithms4TestCase : ITestCase
 	{
-		public class QuickSortableIntArray : Db4objects.Db4o.Foundation.IQuickSortable4
+		public class QuickSortableIntArray : IQuickSortable4
 		{
 			private int[] ints;
 
@@ -52,7 +51,7 @@ namespace Db4objects.Db4o.Tests.Common.Foundation
 			{
 				for (int i = 0; i < ints.Length; i++)
 				{
-					Db4oUnit.Assert.AreEqual(i + 1, ints[i]);
+					Assert.AreEqual(i + 1, ints[i]);
 				}
 			}
 		}
@@ -75,10 +74,9 @@ namespace Db4objects.Db4o.Tests.Common.Foundation
 
 		private void AssertQSort(int[] ints)
 		{
-			Db4objects.Db4o.Tests.Common.Foundation.Algorithms4TestCase.QuickSortableIntArray
-				 sample = new Db4objects.Db4o.Tests.Common.Foundation.Algorithms4TestCase.QuickSortableIntArray
+			Algorithms4TestCase.QuickSortableIntArray sample = new Algorithms4TestCase.QuickSortableIntArray
 				(ints);
-			Db4objects.Db4o.Foundation.Algorithms4.Qsort(sample);
+			Algorithms4.Qsort(sample);
 			sample.AssertSorted();
 		}
 	}
