@@ -1,14 +1,10 @@
-/* Copyright (C) 2004 - 2007  db4objects Inc.  http://www.db4o.com
+/* This file is part of the db4o object database http://www.db4o.com
 
-This file is part of the db4o open source object database.
+Copyright (C) 2004 - 2009  Versant Corporation http://www.versant.com
 
 db4o is free software; you can redistribute it and/or modify it under
-the terms of version 2 of the GNU General Public License as published
-by the Free Software Foundation and as clarified by db4objects' GPL 
-interpretation policy, available at
-http://www.db4o.com/about/company/legalpolicies/gplinterpretation/
-Alternatively you can write to db4objects, Inc., 1900 S Norfolk Street,
-Suite 350, San Mateo, CA 94403, USA.
+the terms of version 3 of the GNU General Public License as published
+by the Free Software Foundation.
 
 db4o is distributed in the hope that it will be useful, but WITHOUT ANY
 WARRANTY; without even the implied warranty of MERCHANTABILITY or
@@ -16,14 +12,22 @@ FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
 for more details.
 
 You should have received a copy of the GNU General Public License along
-with this program; if not, write to the Free Software Foundation, Inc.,
-59 Temple Place - Suite 330, Boston, MA  02111-1307, USA. */
+with this program.  If not, see http://www.gnu.org/licenses/. */
+using Db4objects.Db4o.Query;
+using Db4objects.Db4o.Tests.Common.Soda.Util;
+
 namespace Db4objects.Db4o.Tests.Common.Soda.Arrays.Typed
 {
-	public class STArrIntegerTTestCase : Db4objects.Db4o.Tests.Common.Soda.Util.SodaBaseTestCase
+	public class STArrIntegerTTestCase : SodaBaseTestCase
 	{
 		public int[] intArr;
 
+		public static void Main(string[] args)
+		{
+			new Db4objects.Db4o.Tests.Common.Soda.Arrays.Typed.STArrIntegerTTestCase().RunSolo
+				();
+		}
+
 		public STArrIntegerTTestCase()
 		{
 		}
@@ -43,17 +47,17 @@ namespace Db4objects.Db4o.Tests.Common.Soda.Arrays.Typed
 				(new int[] { 3, 17, 25, int.MaxValue - 2 }) };
 		}
 
-		public virtual void TestDefaultContainsOne()
+		public virtual void _testDefaultContainsOne()
 		{
-			Db4objects.Db4o.Query.IQuery q = NewQuery();
+			IQuery q = NewQuery();
 			q.Constrain(new Db4objects.Db4o.Tests.Common.Soda.Arrays.Typed.STArrIntegerTTestCase
 				(new int[] { 17 }));
 			Expect(q, new int[] { 3, 4 });
 		}
 
-		public virtual void TestDefaultContainsTwo()
+		public virtual void _testDefaultContainsTwo()
 		{
-			Db4objects.Db4o.Query.IQuery q = NewQuery();
+			IQuery q = NewQuery();
 			q.Constrain(new Db4objects.Db4o.Tests.Common.Soda.Arrays.Typed.STArrIntegerTTestCase
 				(new int[] { 17, 25 }));
 			Expect(q, new int[] { 4 });
@@ -61,19 +65,19 @@ namespace Db4objects.Db4o.Tests.Common.Soda.Arrays.Typed
 
 		public virtual void TestDescendOne()
 		{
-			Db4objects.Db4o.Query.IQuery q = NewQuery();
-			q.Constrain(typeof(Db4objects.Db4o.Tests.Common.Soda.Arrays.Typed.STArrIntegerTTestCase)
-				);
+			IQuery q = NewQuery();
+			q.Constrain(typeof(Db4objects.Db4o.Tests.Common.Soda.Arrays.Typed.STArrIntegerTTestCase
+				));
 			q.Descend("intArr").Constrain(17);
 			Expect(q, new int[] { 3, 4 });
 		}
 
 		public virtual void TestDescendTwo()
 		{
-			Db4objects.Db4o.Query.IQuery q = NewQuery();
-			q.Constrain(typeof(Db4objects.Db4o.Tests.Common.Soda.Arrays.Typed.STArrIntegerTTestCase)
-				);
-			Db4objects.Db4o.Query.IQuery qElements = q.Descend("intArr");
+			IQuery q = NewQuery();
+			q.Constrain(typeof(Db4objects.Db4o.Tests.Common.Soda.Arrays.Typed.STArrIntegerTTestCase
+				));
+			IQuery qElements = q.Descend("intArr");
 			qElements.Constrain(17);
 			qElements.Constrain(25);
 			Expect(q, new int[] { 4 });
@@ -81,20 +85,20 @@ namespace Db4objects.Db4o.Tests.Common.Soda.Arrays.Typed
 
 		public virtual void TestDescendSmaller()
 		{
-			Db4objects.Db4o.Query.IQuery q = NewQuery();
-			q.Constrain(typeof(Db4objects.Db4o.Tests.Common.Soda.Arrays.Typed.STArrIntegerTTestCase)
-				);
-			Db4objects.Db4o.Query.IQuery qElements = q.Descend("intArr");
+			IQuery q = NewQuery();
+			q.Constrain(typeof(Db4objects.Db4o.Tests.Common.Soda.Arrays.Typed.STArrIntegerTTestCase
+				));
+			IQuery qElements = q.Descend("intArr");
 			qElements.Constrain(3).Smaller();
 			Expect(q, new int[] { 2, 3 });
 		}
 
 		public virtual void TestDescendNotSmaller()
 		{
-			Db4objects.Db4o.Query.IQuery q = NewQuery();
-			q.Constrain(typeof(Db4objects.Db4o.Tests.Common.Soda.Arrays.Typed.STArrIntegerTTestCase)
-				);
-			Db4objects.Db4o.Query.IQuery qElements = q.Descend("intArr");
+			IQuery q = NewQuery();
+			q.Constrain(typeof(Db4objects.Db4o.Tests.Common.Soda.Arrays.Typed.STArrIntegerTTestCase
+				));
+			IQuery qElements = q.Descend("intArr");
 			qElements.Constrain(3).Smaller();
 			Expect(q, new int[] { 2, 3 });
 		}
