@@ -1,14 +1,10 @@
-/* Copyright (C) 2004 - 2007  db4objects Inc.  http://www.db4o.com
+/* This file is part of the db4o object database http://www.db4o.com
 
-This file is part of the db4o open source object database.
+Copyright (C) 2004 - 2009  Versant Corporation http://www.versant.com
 
 db4o is free software; you can redistribute it and/or modify it under
-the terms of version 2 of the GNU General Public License as published
-by the Free Software Foundation and as clarified by db4objects' GPL 
-interpretation policy, available at
-http://www.db4o.com/about/company/legalpolicies/gplinterpretation/
-Alternatively you can write to db4objects, Inc., 1900 S Norfolk Street,
-Suite 350, San Mateo, CA 94403, USA.
+the terms of version 3 of the GNU General Public License as published
+by the Free Software Foundation.
 
 db4o is distributed in the hope that it will be useful, but WITHOUT ANY
 WARRANTY; without even the implied warranty of MERCHANTABILITY or
@@ -16,11 +12,14 @@ FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
 for more details.
 
 You should have received a copy of the GNU General Public License along
-with this program; if not, write to the Free Software Foundation, Inc.,
-59 Temple Place - Suite 330, Boston, MA  02111-1307, USA. */
+with this program.  If not, see http://www.gnu.org/licenses/. */
+using Db4objects.Db4o.Query;
+using Db4objects.Db4o.Tests.Common.Soda.Util;
+using Sharpen;
+
 namespace Db4objects.Db4o.Tests.Common.Soda.Arrays.Untyped
 {
-	public class STArrMixedNTestCase : Db4objects.Db4o.Tests.Common.Soda.Util.SodaBaseTestCase
+	public class STArrMixedNTestCase : SodaBaseTestCase
 	{
 		public object[][][] arr;
 
@@ -69,7 +68,7 @@ namespace Db4objects.Db4o.Tests.Common.Soda.Arrays.Untyped
 
 		public virtual void TestDefaultContainsString()
 		{
-			Db4objects.Db4o.Query.IQuery q = NewQuery();
+			IQuery q = NewQuery();
 			object[][][] content = new object[][][] { new object[][] { new object[1] } };
 			content[0][0][0] = "bar";
 			q.Constrain(new Db4objects.Db4o.Tests.Common.Soda.Arrays.Untyped.STArrMixedNTestCase
@@ -79,7 +78,7 @@ namespace Db4objects.Db4o.Tests.Common.Soda.Arrays.Untyped
 
 		public virtual void TestDefaultContainsInteger()
 		{
-			Db4objects.Db4o.Query.IQuery q = NewQuery();
+			IQuery q = NewQuery();
 			object[][][] content = new object[][][] { new object[][] { new object[1] } };
 			content[0][0][0] = 12;
 			q.Constrain(new Db4objects.Db4o.Tests.Common.Soda.Arrays.Untyped.STArrMixedNTestCase
@@ -89,7 +88,7 @@ namespace Db4objects.Db4o.Tests.Common.Soda.Arrays.Untyped
 
 		public virtual void TestDefaultContainsBoolean()
 		{
-			Db4objects.Db4o.Query.IQuery q = NewQuery();
+			IQuery q = NewQuery();
 			object[][][] content = new object[][][] { new object[][] { new object[1] } };
 			content[0][0][0] = false;
 			q.Constrain(new Db4objects.Db4o.Tests.Common.Soda.Arrays.Untyped.STArrMixedNTestCase
@@ -99,9 +98,9 @@ namespace Db4objects.Db4o.Tests.Common.Soda.Arrays.Untyped
 
 		public virtual void TestDefaultContainsTwo()
 		{
-			Db4objects.Db4o.Query.IQuery q = NewQuery();
-			object[][][] content = new object[][][] { new object[][] { new object[1] }, new object[]
-				[] { new object[1] } };
+			IQuery q = NewQuery();
+			object[][][] content = new object[][][] { new object[][] { new object[1] }, new object
+				[][] { new object[1] } };
 			content[0][0][0] = "bar";
 			content[1][0][0] = 12;
 			q.Constrain(new Db4objects.Db4o.Tests.Common.Soda.Arrays.Untyped.STArrMixedNTestCase
@@ -111,19 +110,19 @@ namespace Db4objects.Db4o.Tests.Common.Soda.Arrays.Untyped
 
 		public virtual void TestDescendOne()
 		{
-			Db4objects.Db4o.Query.IQuery q = NewQuery();
-			q.Constrain(typeof(Db4objects.Db4o.Tests.Common.Soda.Arrays.Untyped.STArrMixedNTestCase)
-				);
+			IQuery q = NewQuery();
+			q.Constrain(typeof(Db4objects.Db4o.Tests.Common.Soda.Arrays.Untyped.STArrMixedNTestCase
+				));
 			q.Descend("arr").Constrain("bar");
 			Expect(q, new int[] { 3, 4 });
 		}
 
 		public virtual void TestDescendTwo()
 		{
-			Db4objects.Db4o.Query.IQuery q = NewQuery();
-			q.Constrain(typeof(Db4objects.Db4o.Tests.Common.Soda.Arrays.Untyped.STArrMixedNTestCase)
-				);
-			Db4objects.Db4o.Query.IQuery qElements = q.Descend("arr");
+			IQuery q = NewQuery();
+			q.Constrain(typeof(Db4objects.Db4o.Tests.Common.Soda.Arrays.Untyped.STArrMixedNTestCase
+				));
+			IQuery qElements = q.Descend("arr");
 			qElements.Constrain("foo");
 			qElements.Constrain("bar");
 			Expect(q, new int[] { 3 });
@@ -131,19 +130,19 @@ namespace Db4objects.Db4o.Tests.Common.Soda.Arrays.Untyped
 
 		public virtual void TestDescendOneNot()
 		{
-			Db4objects.Db4o.Query.IQuery q = NewQuery();
-			q.Constrain(typeof(Db4objects.Db4o.Tests.Common.Soda.Arrays.Untyped.STArrMixedNTestCase)
-				);
+			IQuery q = NewQuery();
+			q.Constrain(typeof(Db4objects.Db4o.Tests.Common.Soda.Arrays.Untyped.STArrMixedNTestCase
+				));
 			q.Descend("arr").Constrain("bar").Not();
 			Expect(q, new int[] { 0, 1, 2 });
 		}
 
 		public virtual void TestDescendTwoNot()
 		{
-			Db4objects.Db4o.Query.IQuery q = NewQuery();
-			q.Constrain(typeof(Db4objects.Db4o.Tests.Common.Soda.Arrays.Untyped.STArrMixedNTestCase)
-				);
-			Db4objects.Db4o.Query.IQuery qElements = q.Descend("arr");
+			IQuery q = NewQuery();
+			q.Constrain(typeof(Db4objects.Db4o.Tests.Common.Soda.Arrays.Untyped.STArrMixedNTestCase
+				));
+			IQuery qElements = q.Descend("arr");
 			qElements.Constrain("foo").Not();
 			qElements.Constrain("bar").Not();
 			Expect(q, new int[] { 0, 1, 2 });
