@@ -1,14 +1,10 @@
-/* Copyright (C) 2004 - 2007  db4objects Inc.  http://www.db4o.com
+/* This file is part of the db4o object database http://www.db4o.com
 
-This file is part of the db4o open source object database.
+Copyright (C) 2004 - 2009  Versant Corporation http://www.versant.com
 
 db4o is free software; you can redistribute it and/or modify it under
-the terms of version 2 of the GNU General Public License as published
-by the Free Software Foundation and as clarified by db4objects' GPL 
-interpretation policy, available at
-http://www.db4o.com/about/company/legalpolicies/gplinterpretation/
-Alternatively you can write to db4objects, Inc., 1900 S Norfolk Street,
-Suite 350, San Mateo, CA 94403, USA.
+the terms of version 3 of the GNU General Public License as published
+by the Free Software Foundation.
 
 db4o is distributed in the hope that it will be useful, but WITHOUT ANY
 WARRANTY; without even the implied warranty of MERCHANTABILITY or
@@ -16,13 +12,17 @@ FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
 for more details.
 
 You should have received a copy of the GNU General Public License along
-with this program; if not, write to the Free Software Foundation, Inc.,
-59 Temple Place - Suite 330, Boston, MA  02111-1307, USA. */
+with this program.  If not, see http://www.gnu.org/licenses/. */
+using Db4oUnit;
+using Db4objects.Db4o;
+using Db4objects.Db4o.Query;
+using Db4objects.Db4o.Tests.Common.Soda.Util;
+
 namespace Db4objects.Db4o.Tests.Common.Soda.Classes.Simple
 {
-	public class STCharTestCase : Db4objects.Db4o.Tests.Common.Soda.Util.SodaBaseTestCase
+	public class STCharTestCase : SodaBaseTestCase
 	{
-		internal static readonly string DESCENDANT = "i_char";
+		internal static readonly string Descendant = "i_char";
 
 		public char i_char;
 
@@ -46,60 +46,62 @@ namespace Db4objects.Db4o.Tests.Common.Soda.Classes.Simple
 
 		public virtual void TestEquals()
 		{
-			Db4objects.Db4o.Query.IQuery q = NewQuery();
+			IQuery q = NewQuery();
 			q.Constrain(new Db4objects.Db4o.Tests.Common.Soda.Classes.Simple.STCharTestCase((
 				char)0));
-			q.Descend(DESCENDANT).Constrain((char)0);
-			Db4objects.Db4o.Tests.Common.Soda.Util.SodaTestUtil.ExpectOne(q, _array[0]);
+			// Primitive default values are ignored, so we need an 
+			// additional constraint:
+			q.Descend(Descendant).Constrain((char)0);
+			SodaTestUtil.ExpectOne(q, _array[0]);
 		}
 
 		public virtual void TestNotEquals()
 		{
-			Db4objects.Db4o.Query.IQuery q = NewQuery();
+			IQuery q = NewQuery();
 			q.Constrain(_array[0]);
-			q.Descend(DESCENDANT).Constrain((char)0).Not();
+			q.Descend(Descendant).Constrain((char)0).Not();
 			Expect(q, new int[] { 1, 2, 3 });
 		}
 
 		public virtual void TestGreater()
 		{
-			Db4objects.Db4o.Query.IQuery q = NewQuery();
+			IQuery q = NewQuery();
 			q.Constrain(new Db4objects.Db4o.Tests.Common.Soda.Classes.Simple.STCharTestCase((
 				char)9));
-			q.Descend(DESCENDANT).Constraints().Greater();
+			q.Descend(Descendant).Constraints().Greater();
 			Expect(q, new int[] { 2, 3 });
 		}
 
 		public virtual void TestSmaller()
 		{
-			Db4objects.Db4o.Query.IQuery q = NewQuery();
+			IQuery q = NewQuery();
 			q.Constrain(new Db4objects.Db4o.Tests.Common.Soda.Classes.Simple.STCharTestCase((
 				char)1));
-			q.Descend(DESCENDANT).Constraints().Smaller();
-			Db4objects.Db4o.Tests.Common.Soda.Util.SodaTestUtil.ExpectOne(q, _array[0]);
+			q.Descend(Descendant).Constraints().Smaller();
+			SodaTestUtil.ExpectOne(q, _array[0]);
 		}
 
 		public virtual void TestIdentity()
 		{
-			Db4objects.Db4o.Query.IQuery q = NewQuery();
+			IQuery q = NewQuery();
 			q.Constrain(new Db4objects.Db4o.Tests.Common.Soda.Classes.Simple.STCharTestCase((
 				char)1));
-			Db4objects.Db4o.IObjectSet set = q.Execute();
+			IObjectSet set = q.Execute();
 			Db4objects.Db4o.Tests.Common.Soda.Classes.Simple.STCharTestCase identityConstraint
 				 = (Db4objects.Db4o.Tests.Common.Soda.Classes.Simple.STCharTestCase)set.Next();
 			identityConstraint.i_char = (char)9999;
 			q = NewQuery();
 			q.Constrain(identityConstraint).Identity();
 			identityConstraint.i_char = (char)1;
-			Db4objects.Db4o.Tests.Common.Soda.Util.SodaTestUtil.ExpectOne(q, _array[1]);
+			SodaTestUtil.ExpectOne(q, _array[1]);
 		}
 
 		public virtual void TestNotIdentity()
 		{
-			Db4objects.Db4o.Query.IQuery q = NewQuery();
+			IQuery q = NewQuery();
 			q.Constrain(new Db4objects.Db4o.Tests.Common.Soda.Classes.Simple.STCharTestCase((
 				char)1));
-			Db4objects.Db4o.IObjectSet set = q.Execute();
+			IObjectSet set = q.Execute();
 			Db4objects.Db4o.Tests.Common.Soda.Classes.Simple.STCharTestCase identityConstraint
 				 = (Db4objects.Db4o.Tests.Common.Soda.Classes.Simple.STCharTestCase)set.Next();
 			identityConstraint.i_char = (char)9080;
@@ -111,16 +113,16 @@ namespace Db4objects.Db4o.Tests.Common.Soda.Classes.Simple
 
 		public virtual void TestConstraints()
 		{
-			Db4objects.Db4o.Query.IQuery q = NewQuery();
+			IQuery q = NewQuery();
 			q.Constrain(new Db4objects.Db4o.Tests.Common.Soda.Classes.Simple.STCharTestCase((
 				char)1));
 			q.Constrain(new Db4objects.Db4o.Tests.Common.Soda.Classes.Simple.STCharTestCase((
 				char)0));
-			Db4objects.Db4o.Query.IConstraints cs = q.Constraints();
-			Db4objects.Db4o.Query.IConstraint[] csa = cs.ToArray();
+			IConstraints cs = q.Constraints();
+			IConstraint[] csa = cs.ToArray();
 			if (csa.Length != 2)
 			{
-				Db4oUnit.Assert.Fail("Constraints not returned");
+				Assert.Fail("Constraints not returned");
 			}
 		}
 	}
