@@ -1,14 +1,10 @@
-/* Copyright (C) 2004 - 2007  db4objects Inc.  http://www.db4o.com
+/* This file is part of the db4o object database http://www.db4o.com
 
-This file is part of the db4o open source object database.
+Copyright (C) 2004 - 2009  Versant Corporation http://www.versant.com
 
 db4o is free software; you can redistribute it and/or modify it under
-the terms of version 2 of the GNU General Public License as published
-by the Free Software Foundation and as clarified by db4objects' GPL 
-interpretation policy, available at
-http://www.db4o.com/about/company/legalpolicies/gplinterpretation/
-Alternatively you can write to db4objects, Inc., 1900 S Norfolk Street,
-Suite 350, San Mateo, CA 94403, USA.
+the terms of version 3 of the GNU General Public License as published
+by the Free Software Foundation.
 
 db4o is distributed in the hope that it will be useful, but WITHOUT ANY
 WARRANTY; without even the implied warranty of MERCHANTABILITY or
@@ -16,14 +12,20 @@ FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
 for more details.
 
 You should have received a copy of the GNU General Public License along
-with this program; if not, write to the Free Software Foundation, Inc.,
-59 Temple Place - Suite 330, Boston, MA  02111-1307, USA. */
+with this program.  If not, see http://www.gnu.org/licenses/. */
+using Db4oUnit;
+using Db4objects.Db4o;
+using Db4objects.Db4o.Ext;
+using Db4objects.Db4o.Query;
+using Db4objects.Db4o.Tests.Common.Soda.Classes.Typedhierarchy;
+using Db4objects.Db4o.Tests.Common.Soda.Util;
+
 namespace Db4objects.Db4o.Tests.Common.Soda.Classes.Typedhierarchy
 {
 	/// <summary>RTH: Roundtrip Typed Hierarchy</summary>
-	public class STRTH1TestCase : Db4objects.Db4o.Tests.Common.Soda.Util.SodaBaseTestCase
+	public class STRTH1TestCase : SodaBaseTestCase
 	{
-		public Db4objects.Db4o.Tests.Common.Soda.Classes.Typedhierarchy.STRTH2 h2;
+		public STRTH2 h2;
 
 		public string foo1;
 
@@ -31,8 +33,7 @@ namespace Db4objects.Db4o.Tests.Common.Soda.Classes.Typedhierarchy
 		{
 		}
 
-		public STRTH1TestCase(Db4objects.Db4o.Tests.Common.Soda.Classes.Typedhierarchy.STRTH2
-			 a2)
+		public STRTH1TestCase(STRTH2 a2)
 		{
 			h2 = a2;
 		}
@@ -42,8 +43,7 @@ namespace Db4objects.Db4o.Tests.Common.Soda.Classes.Typedhierarchy
 			foo1 = str;
 		}
 
-		public STRTH1TestCase(Db4objects.Db4o.Tests.Common.Soda.Classes.Typedhierarchy.STRTH2
-			 a2, string str)
+		public STRTH1TestCase(STRTH2 a2, string str)
 		{
 			h2 = a2;
 			foo1 = str;
@@ -52,16 +52,14 @@ namespace Db4objects.Db4o.Tests.Common.Soda.Classes.Typedhierarchy
 		public override object[] CreateData()
 		{
 			Db4objects.Db4o.Tests.Common.Soda.Classes.Typedhierarchy.STRTH1TestCase[] objects
-				 = { new Db4objects.Db4o.Tests.Common.Soda.Classes.Typedhierarchy.STRTH1TestCase
-				(), new Db4objects.Db4o.Tests.Common.Soda.Classes.Typedhierarchy.STRTH1TestCase(
-				"str1"), new Db4objects.Db4o.Tests.Common.Soda.Classes.Typedhierarchy.STRTH1TestCase
-				(new Db4objects.Db4o.Tests.Common.Soda.Classes.Typedhierarchy.STRTH2()), new Db4objects.Db4o.Tests.Common.Soda.Classes.Typedhierarchy.STRTH1TestCase
-				(new Db4objects.Db4o.Tests.Common.Soda.Classes.Typedhierarchy.STRTH2("str2")), new 
-				Db4objects.Db4o.Tests.Common.Soda.Classes.Typedhierarchy.STRTH1TestCase(new Db4objects.Db4o.Tests.Common.Soda.Classes.Typedhierarchy.STRTH2
-				(new Db4objects.Db4o.Tests.Common.Soda.Classes.Typedhierarchy.STRTH3("str3"))), 
-				new Db4objects.Db4o.Tests.Common.Soda.Classes.Typedhierarchy.STRTH1TestCase(new 
-				Db4objects.Db4o.Tests.Common.Soda.Classes.Typedhierarchy.STRTH2(new Db4objects.Db4o.Tests.Common.Soda.Classes.Typedhierarchy.STRTH3
-				("str3"), "str2")) };
+				 = new Db4objects.Db4o.Tests.Common.Soda.Classes.Typedhierarchy.STRTH1TestCase[]
+				 { new Db4objects.Db4o.Tests.Common.Soda.Classes.Typedhierarchy.STRTH1TestCase()
+				, new Db4objects.Db4o.Tests.Common.Soda.Classes.Typedhierarchy.STRTH1TestCase("str1"
+				), new Db4objects.Db4o.Tests.Common.Soda.Classes.Typedhierarchy.STRTH1TestCase(new 
+				STRTH2()), new Db4objects.Db4o.Tests.Common.Soda.Classes.Typedhierarchy.STRTH1TestCase
+				(new STRTH2("str2")), new Db4objects.Db4o.Tests.Common.Soda.Classes.Typedhierarchy.STRTH1TestCase
+				(new STRTH2(new STRTH3("str3"))), new Db4objects.Db4o.Tests.Common.Soda.Classes.Typedhierarchy.STRTH1TestCase
+				(new STRTH2(new STRTH3("str3"), "str2")) };
 			for (int i = 0; i < objects.Length; i++)
 			{
 				objects[i].AdjustParents();
@@ -85,7 +83,7 @@ namespace Db4objects.Db4o.Tests.Common.Soda.Classes.Typedhierarchy
 
 		public virtual void TestStrNull()
 		{
-			Db4objects.Db4o.Query.IQuery q = NewQuery();
+			IQuery q = NewQuery();
 			q.Constrain(new Db4objects.Db4o.Tests.Common.Soda.Classes.Typedhierarchy.STRTH1TestCase
 				());
 			q.Descend("foo1").Constrain(null);
@@ -94,17 +92,17 @@ namespace Db4objects.Db4o.Tests.Common.Soda.Classes.Typedhierarchy
 
 		public virtual void TestBothNull()
 		{
-			Db4objects.Db4o.Query.IQuery q = NewQuery();
+			IQuery q = NewQuery();
 			q.Constrain(new Db4objects.Db4o.Tests.Common.Soda.Classes.Typedhierarchy.STRTH1TestCase
 				());
 			q.Descend("foo1").Constrain(null);
 			q.Descend("h2").Constrain(null);
-			Db4objects.Db4o.Tests.Common.Soda.Util.SodaTestUtil.ExpectOne(q, _array[0]);
+			SodaTestUtil.ExpectOne(q, _array[0]);
 		}
 
 		public virtual void TestDescendantNotNull()
 		{
-			Db4objects.Db4o.Query.IQuery q = NewQuery();
+			IQuery q = NewQuery();
 			q.Constrain(new Db4objects.Db4o.Tests.Common.Soda.Classes.Typedhierarchy.STRTH1TestCase
 				());
 			q.Descend("h2").Constrain(null).Not();
@@ -113,7 +111,7 @@ namespace Db4objects.Db4o.Tests.Common.Soda.Classes.Typedhierarchy
 
 		public virtual void TestDescendantDescendantNotNull()
 		{
-			Db4objects.Db4o.Query.IQuery q = NewQuery();
+			IQuery q = NewQuery();
 			q.Constrain(new Db4objects.Db4o.Tests.Common.Soda.Classes.Typedhierarchy.STRTH1TestCase
 				());
 			q.Descend("h2").Descend("h3").Constrain(null).Not();
@@ -122,39 +120,37 @@ namespace Db4objects.Db4o.Tests.Common.Soda.Classes.Typedhierarchy
 
 		public virtual void TestDescendantExists()
 		{
-			Db4objects.Db4o.Query.IQuery q = NewQuery();
+			IQuery q = NewQuery();
 			q.Constrain(_array[2]);
 			Expect(q, new int[] { 2, 3, 4, 5 });
 		}
 
 		public virtual void TestDescendantValue()
 		{
-			Db4objects.Db4o.Query.IQuery q = NewQuery();
+			IQuery q = NewQuery();
 			q.Constrain(_array[3]);
 			Expect(q, new int[] { 3, 5 });
 		}
 
 		public virtual void TestDescendantDescendantExists()
 		{
-			Db4objects.Db4o.Query.IQuery q = NewQuery();
+			IQuery q = NewQuery();
 			q.Constrain(new Db4objects.Db4o.Tests.Common.Soda.Classes.Typedhierarchy.STRTH1TestCase
-				(new Db4objects.Db4o.Tests.Common.Soda.Classes.Typedhierarchy.STRTH2(new Db4objects.Db4o.Tests.Common.Soda.Classes.Typedhierarchy.STRTH3
-				())));
+				(new STRTH2(new STRTH3())));
 			Expect(q, new int[] { 4, 5 });
 		}
 
 		public virtual void TestDescendantDescendantValue()
 		{
-			Db4objects.Db4o.Query.IQuery q = NewQuery();
+			IQuery q = NewQuery();
 			q.Constrain(new Db4objects.Db4o.Tests.Common.Soda.Classes.Typedhierarchy.STRTH1TestCase
-				(new Db4objects.Db4o.Tests.Common.Soda.Classes.Typedhierarchy.STRTH2(new Db4objects.Db4o.Tests.Common.Soda.Classes.Typedhierarchy.STRTH3
-				("str3"))));
+				(new STRTH2(new STRTH3("str3"))));
 			Expect(q, new int[] { 4, 5 });
 		}
 
 		public virtual void TestDescendantDescendantStringPath()
 		{
-			Db4objects.Db4o.Query.IQuery q = NewQuery();
+			IQuery q = NewQuery();
 			q.Constrain(new Db4objects.Db4o.Tests.Common.Soda.Classes.Typedhierarchy.STRTH1TestCase
 				());
 			q.Descend("h2").Descend("h3").Descend("foo3").Constrain("str3");
@@ -163,23 +159,21 @@ namespace Db4objects.Db4o.Tests.Common.Soda.Classes.Typedhierarchy
 
 		public virtual void TestSequentialAddition()
 		{
-			Db4objects.Db4o.Query.IQuery q = NewQuery();
+			IQuery q = NewQuery();
 			q.Constrain(new Db4objects.Db4o.Tests.Common.Soda.Classes.Typedhierarchy.STRTH1TestCase
 				());
-			Db4objects.Db4o.Query.IQuery cur = q.Descend("h2");
-			cur.Constrain(new Db4objects.Db4o.Tests.Common.Soda.Classes.Typedhierarchy.STRTH2
-				());
+			IQuery cur = q.Descend("h2");
+			cur.Constrain(new STRTH2());
 			cur.Descend("foo2").Constrain("str2");
 			cur = cur.Descend("h3");
-			cur.Constrain(new Db4objects.Db4o.Tests.Common.Soda.Classes.Typedhierarchy.STRTH3
-				());
+			cur.Constrain(new STRTH3());
 			cur.Descend("foo3").Constrain("str3");
-			Db4objects.Db4o.Tests.Common.Soda.Util.SodaTestUtil.ExpectOne(q, _array[5]);
+			SodaTestUtil.ExpectOne(q, _array[5]);
 		}
 
 		public virtual void TestTwoLevelOr()
 		{
-			Db4objects.Db4o.Query.IQuery q = NewQuery();
+			IQuery q = NewQuery();
 			q.Constrain(new Db4objects.Db4o.Tests.Common.Soda.Classes.Typedhierarchy.STRTH1TestCase
 				("str1"));
 			q.Descend("foo1").Constraints().Or(q.Descend("h2").Descend("h3").Descend("foo3").
@@ -189,7 +183,7 @@ namespace Db4objects.Db4o.Tests.Common.Soda.Classes.Typedhierarchy
 
 		public virtual void TestThreeLevelOr()
 		{
-			Db4objects.Db4o.Query.IQuery q = NewQuery();
+			IQuery q = NewQuery();
 			q.Constrain(new Db4objects.Db4o.Tests.Common.Soda.Classes.Typedhierarchy.STRTH1TestCase
 				("str1"));
 			q.Descend("foo1").Constraints().Or(q.Descend("h2").Descend("foo2").Constrain("str2"
@@ -197,19 +191,20 @@ namespace Db4objects.Db4o.Tests.Common.Soda.Classes.Typedhierarchy
 			Expect(q, new int[] { 1, 3, 4, 5 });
 		}
 
+		/// <exception cref="System.Exception"></exception>
 		public virtual void TestDeleteAll()
 		{
-			Db4objects.Db4o.Ext.IExtObjectContainer oc = Fixture().Db();
-			Db4objects.Db4o.IObjectSet os = oc.Get(null);
+			IExtObjectContainer oc = Fixture().Db();
+			IObjectSet os = oc.QueryByExample(null);
 			while (os.HasNext())
 			{
 				oc.Delete(os.Next());
 			}
 			Db().Commit();
-			Fixture().Reopen();
+			Fixture().Reopen(GetType());
 			oc = Fixture().Db();
-			os = oc.Get(null);
-			Db4oUnit.Assert.AreEqual(0, os.Size());
+			os = oc.QueryByExample(null);
+			Assert.AreEqual(0, os.Size());
 		}
 
 		public static void Main(string[] arguments)
