@@ -1,14 +1,10 @@
-/* Copyright (C) 2004 - 2007  db4objects Inc.  http://www.db4o.com
+/* This file is part of the db4o object database http://www.db4o.com
 
-This file is part of the db4o open source object database.
+Copyright (C) 2004 - 2009  Versant Corporation http://www.versant.com
 
 db4o is free software; you can redistribute it and/or modify it under
-the terms of version 2 of the GNU General Public License as published
-by the Free Software Foundation and as clarified by db4objects' GPL 
-interpretation policy, available at
-http://www.db4o.com/about/company/legalpolicies/gplinterpretation/
-Alternatively you can write to db4objects, Inc., 1900 S Norfolk Street,
-Suite 350, San Mateo, CA 94403, USA.
+the terms of version 3 of the GNU General Public License as published
+by the Free Software Foundation.
 
 db4o is distributed in the hope that it will be useful, but WITHOUT ANY
 WARRANTY; without even the implied warranty of MERCHANTABILITY or
@@ -16,8 +12,11 @@ FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
 for more details.
 
 You should have received a copy of the GNU General Public License along
-with this program; if not, write to the Free Software Foundation, Inc.,
-59 Temple Place - Suite 330, Boston, MA  02111-1307, USA. */
+with this program.  If not, see http://www.gnu.org/licenses/. */
+using Db4objects.Db4o.Query;
+using Db4objects.Db4o.Tests.Common.Soda.Classes.Untypedhierarchy;
+using Db4objects.Db4o.Tests.Common.Soda.Util;
+
 namespace Db4objects.Db4o.Tests.Common.Soda.Classes.Untypedhierarchy
 {
 	/// <summary>
@@ -36,7 +35,7 @@ namespace Db4objects.Db4o.Tests.Common.Soda.Classes.Untypedhierarchy
 	/// </remarks>
 	/// <author><a href="mailto:Paul-Ebermann@gmx.de">Paul Ebermann</a></author>
 	/// <version>0.1</version>
-	public class STInnerClassesTestCase : Db4objects.Db4o.Tests.Common.Soda.Util.SodaBaseTestCase
+	public class STInnerClassesTestCase : SodaBaseTestCase
 	{
 		public class Parent
 		{
@@ -45,6 +44,7 @@ namespace Db4objects.Db4o.Tests.Common.Soda.Classes.Untypedhierarchy
 			public Parent(STInnerClassesTestCase _enclosing, object o)
 			{
 				this._enclosing = _enclosing;
+				// Generierter package-Name
 				this.child = o;
 			}
 
@@ -90,19 +90,19 @@ namespace Db4objects.Db4o.Tests.Common.Soda.Classes.Untypedhierarchy
 
 		public override object[] CreateData()
 		{
-			return new object[] { new Db4objects.Db4o.Tests.Common.Soda.Classes.Untypedhierarchy.STInnerClassesTestCase.Parent
-				(this, new Db4objects.Db4o.Tests.Common.Soda.Classes.Untypedhierarchy.STInnerClassesTestCase.FirstClass
-				(this, "Example")), new Db4objects.Db4o.Tests.Common.Soda.Classes.Untypedhierarchy.STInnerClassesTestCase.Parent
-				(this, new Db4objects.Db4o.Tests.Common.Soda.Classes.Untypedhierarchy.STInnerClassesTestCase.FirstClass
+			return new object[] { new STInnerClassesTestCase.Parent(this, new STInnerClassesTestCase.FirstClass
+				(this, "Example")), new STInnerClassesTestCase.Parent(this, new STInnerClassesTestCase.FirstClass
 				(this, "no Example")) };
 		}
 
 		/// <summary>Only</summary>
 		public virtual void TestNothing()
 		{
-			Db4objects.Db4o.Query.IQuery q = NewQuery();
+			IQuery q = NewQuery();
 			q.Descend("child");
-			Db4objects.Db4o.Tests.Common.Soda.Util.SodaTestUtil.Expect(q, _array);
+			SodaTestUtil.Expect(q, _array);
 		}
+		//SodaTest.log(q);
+		// STSomeClasses
 	}
 }
