@@ -1,14 +1,10 @@
-/* Copyright (C) 2004 - 2007  db4objects Inc.  http://www.db4o.com
+/* This file is part of the db4o object database http://www.db4o.com
 
-This file is part of the db4o open source object database.
+Copyright (C) 2004 - 2009  Versant Corporation http://www.versant.com
 
 db4o is free software; you can redistribute it and/or modify it under
-the terms of version 2 of the GNU General Public License as published
-by the Free Software Foundation and as clarified by db4objects' GPL 
-interpretation policy, available at
-http://www.db4o.com/about/company/legalpolicies/gplinterpretation/
-Alternatively you can write to db4objects, Inc., 1900 S Norfolk Street,
-Suite 350, San Mateo, CA 94403, USA.
+the terms of version 3 of the GNU General Public License as published
+by the Free Software Foundation.
 
 db4o is distributed in the hope that it will be useful, but WITHOUT ANY
 WARRANTY; without even the implied warranty of MERCHANTABILITY or
@@ -16,12 +12,15 @@ FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
 for more details.
 
 You should have received a copy of the GNU General Public License along
-with this program; if not, write to the Free Software Foundation, Inc.,
-59 Temple Place - Suite 330, Boston, MA  02111-1307, USA. */
+with this program.  If not, see http://www.gnu.org/licenses/. */
+using Db4objects.Db4o.Query;
+using Db4objects.Db4o.Tests.Common.Soda.Classes.Untypedhierarchy;
+using Db4objects.Db4o.Tests.Common.Soda.Util;
+
 namespace Db4objects.Db4o.Tests.Common.Soda.Classes.Untypedhierarchy
 {
 	/// <summary>RUH: RoundTrip Untyped Hierarchy</summary>
-	public class STRUH1TestCase : Db4objects.Db4o.Tests.Common.Soda.Util.SodaBaseTestCase
+	public class STRUH1TestCase : SodaBaseTestCase
 	{
 		public object h2;
 
@@ -31,8 +30,7 @@ namespace Db4objects.Db4o.Tests.Common.Soda.Classes.Untypedhierarchy
 		{
 		}
 
-		public STRUH1TestCase(Db4objects.Db4o.Tests.Common.Soda.Classes.Untypedhierarchy.STRUH2
-			 a2)
+		public STRUH1TestCase(STRUH2 a2)
 		{
 			h2 = a2;
 		}
@@ -42,8 +40,7 @@ namespace Db4objects.Db4o.Tests.Common.Soda.Classes.Untypedhierarchy
 			foo1 = str;
 		}
 
-		public STRUH1TestCase(Db4objects.Db4o.Tests.Common.Soda.Classes.Untypedhierarchy.STRUH2
-			 a2, string str)
+		public STRUH1TestCase(STRUH2 a2, string str)
 		{
 			h2 = a2;
 			foo1 = str;
@@ -52,16 +49,14 @@ namespace Db4objects.Db4o.Tests.Common.Soda.Classes.Untypedhierarchy
 		public override object[] CreateData()
 		{
 			Db4objects.Db4o.Tests.Common.Soda.Classes.Untypedhierarchy.STRUH1TestCase[] objects
-				 = { new Db4objects.Db4o.Tests.Common.Soda.Classes.Untypedhierarchy.STRUH1TestCase
+				 = new Db4objects.Db4o.Tests.Common.Soda.Classes.Untypedhierarchy.STRUH1TestCase
+				[] { new Db4objects.Db4o.Tests.Common.Soda.Classes.Untypedhierarchy.STRUH1TestCase
 				(), new Db4objects.Db4o.Tests.Common.Soda.Classes.Untypedhierarchy.STRUH1TestCase
 				("str1"), new Db4objects.Db4o.Tests.Common.Soda.Classes.Untypedhierarchy.STRUH1TestCase
-				(new Db4objects.Db4o.Tests.Common.Soda.Classes.Untypedhierarchy.STRUH2()), new Db4objects.Db4o.Tests.Common.Soda.Classes.Untypedhierarchy.STRUH1TestCase
-				(new Db4objects.Db4o.Tests.Common.Soda.Classes.Untypedhierarchy.STRUH2("str2")), 
-				new Db4objects.Db4o.Tests.Common.Soda.Classes.Untypedhierarchy.STRUH1TestCase(new 
-				Db4objects.Db4o.Tests.Common.Soda.Classes.Untypedhierarchy.STRUH2(new Db4objects.Db4o.Tests.Common.Soda.Classes.Untypedhierarchy.STRUH3
-				("str3"))), new Db4objects.Db4o.Tests.Common.Soda.Classes.Untypedhierarchy.STRUH1TestCase
-				(new Db4objects.Db4o.Tests.Common.Soda.Classes.Untypedhierarchy.STRUH2(new Db4objects.Db4o.Tests.Common.Soda.Classes.Untypedhierarchy.STRUH3
-				("str3"), "str2")) };
+				(new STRUH2()), new Db4objects.Db4o.Tests.Common.Soda.Classes.Untypedhierarchy.STRUH1TestCase
+				(new STRUH2("str2")), new Db4objects.Db4o.Tests.Common.Soda.Classes.Untypedhierarchy.STRUH1TestCase
+				(new STRUH2(new STRUH3("str3"))), new Db4objects.Db4o.Tests.Common.Soda.Classes.Untypedhierarchy.STRUH1TestCase
+				(new STRUH2(new STRUH3("str3"), "str2")) };
 			for (int i = 0; i < objects.Length; i++)
 			{
 				objects[i].AdjustParents();
@@ -74,13 +69,11 @@ namespace Db4objects.Db4o.Tests.Common.Soda.Classes.Untypedhierarchy
 		{
 			if (h2 != null)
 			{
-				Db4objects.Db4o.Tests.Common.Soda.Classes.Untypedhierarchy.STRUH2 th2 = (Db4objects.Db4o.Tests.Common.Soda.Classes.Untypedhierarchy.STRUH2
-					)h2;
+				STRUH2 th2 = (STRUH2)h2;
 				th2.parent = this;
 				if (th2.h3 != null)
 				{
-					Db4objects.Db4o.Tests.Common.Soda.Classes.Untypedhierarchy.STRUH3 th3 = (Db4objects.Db4o.Tests.Common.Soda.Classes.Untypedhierarchy.STRUH3
-						)th2.h3;
+					STRUH3 th3 = (STRUH3)th2.h3;
 					th3.parent = th2;
 					th3.grandParent = this;
 				}
@@ -89,7 +82,7 @@ namespace Db4objects.Db4o.Tests.Common.Soda.Classes.Untypedhierarchy
 
 		public virtual void TestStrNull()
 		{
-			Db4objects.Db4o.Query.IQuery q = NewQuery();
+			IQuery q = NewQuery();
 			q.Constrain(new Db4objects.Db4o.Tests.Common.Soda.Classes.Untypedhierarchy.STRUH1TestCase
 				());
 			q.Descend("foo1").Constrain(null);
@@ -98,17 +91,17 @@ namespace Db4objects.Db4o.Tests.Common.Soda.Classes.Untypedhierarchy
 
 		public virtual void TestBothNull()
 		{
-			Db4objects.Db4o.Query.IQuery q = NewQuery();
+			IQuery q = NewQuery();
 			q.Constrain(new Db4objects.Db4o.Tests.Common.Soda.Classes.Untypedhierarchy.STRUH1TestCase
 				());
 			q.Descend("foo1").Constrain(null);
 			q.Descend("h2").Constrain(null);
-			Db4objects.Db4o.Tests.Common.Soda.Util.SodaTestUtil.ExpectOne(q, _array[0]);
+			SodaTestUtil.ExpectOne(q, _array[0]);
 		}
 
 		public virtual void TestDescendantNotNull()
 		{
-			Db4objects.Db4o.Query.IQuery q = NewQuery();
+			IQuery q = NewQuery();
 			q.Constrain(new Db4objects.Db4o.Tests.Common.Soda.Classes.Untypedhierarchy.STRUH1TestCase
 				());
 			q.Descend("h2").Constrain(null).Not();
@@ -117,7 +110,7 @@ namespace Db4objects.Db4o.Tests.Common.Soda.Classes.Untypedhierarchy
 
 		public virtual void TestDescendantDescendantNotNull()
 		{
-			Db4objects.Db4o.Query.IQuery q = NewQuery();
+			IQuery q = NewQuery();
 			q.Constrain(new Db4objects.Db4o.Tests.Common.Soda.Classes.Untypedhierarchy.STRUH1TestCase
 				());
 			q.Descend("h2").Descend("h3").Constrain(null).Not();
@@ -126,39 +119,37 @@ namespace Db4objects.Db4o.Tests.Common.Soda.Classes.Untypedhierarchy
 
 		public virtual void TestDescendantExists()
 		{
-			Db4objects.Db4o.Query.IQuery q = NewQuery();
+			IQuery q = NewQuery();
 			q.Constrain(_array[2]);
 			Expect(q, new int[] { 2, 3, 4, 5 });
 		}
 
 		public virtual void TestDescendantValue()
 		{
-			Db4objects.Db4o.Query.IQuery q = NewQuery();
+			IQuery q = NewQuery();
 			q.Constrain(_array[3]);
 			Expect(q, new int[] { 3, 5 });
 		}
 
 		public virtual void TestDescendantDescendantExists()
 		{
-			Db4objects.Db4o.Query.IQuery q = NewQuery();
+			IQuery q = NewQuery();
 			q.Constrain(new Db4objects.Db4o.Tests.Common.Soda.Classes.Untypedhierarchy.STRUH1TestCase
-				(new Db4objects.Db4o.Tests.Common.Soda.Classes.Untypedhierarchy.STRUH2(new Db4objects.Db4o.Tests.Common.Soda.Classes.Untypedhierarchy.STRUH3
-				())));
+				(new STRUH2(new STRUH3())));
 			Expect(q, new int[] { 4, 5 });
 		}
 
 		public virtual void TestDescendantDescendantValue()
 		{
-			Db4objects.Db4o.Query.IQuery q = NewQuery();
+			IQuery q = NewQuery();
 			q.Constrain(new Db4objects.Db4o.Tests.Common.Soda.Classes.Untypedhierarchy.STRUH1TestCase
-				(new Db4objects.Db4o.Tests.Common.Soda.Classes.Untypedhierarchy.STRUH2(new Db4objects.Db4o.Tests.Common.Soda.Classes.Untypedhierarchy.STRUH3
-				("str3"))));
+				(new STRUH2(new STRUH3("str3"))));
 			Expect(q, new int[] { 4, 5 });
 		}
 
 		public virtual void TestDescendantDescendantStringPath()
 		{
-			Db4objects.Db4o.Query.IQuery q = NewQuery();
+			IQuery q = NewQuery();
 			q.Constrain(new Db4objects.Db4o.Tests.Common.Soda.Classes.Untypedhierarchy.STRUH1TestCase
 				());
 			q.Descend("h2").Descend("h3").Descend("foo3").Constrain("str3");
@@ -167,23 +158,21 @@ namespace Db4objects.Db4o.Tests.Common.Soda.Classes.Untypedhierarchy
 
 		public virtual void TestSequentialAddition()
 		{
-			Db4objects.Db4o.Query.IQuery q = NewQuery();
+			IQuery q = NewQuery();
 			q.Constrain(new Db4objects.Db4o.Tests.Common.Soda.Classes.Untypedhierarchy.STRUH1TestCase
 				());
-			Db4objects.Db4o.Query.IQuery cur = q.Descend("h2");
-			cur.Constrain(new Db4objects.Db4o.Tests.Common.Soda.Classes.Untypedhierarchy.STRUH2
-				());
+			IQuery cur = q.Descend("h2");
+			cur.Constrain(new STRUH2());
 			cur.Descend("foo2").Constrain("str2");
 			cur = cur.Descend("h3");
-			cur.Constrain(new Db4objects.Db4o.Tests.Common.Soda.Classes.Untypedhierarchy.STRUH3
-				());
+			cur.Constrain(new STRUH3());
 			cur.Descend("foo3").Constrain("str3");
-			Db4objects.Db4o.Tests.Common.Soda.Util.SodaTestUtil.ExpectOne(q, _array[5]);
+			SodaTestUtil.ExpectOne(q, _array[5]);
 		}
 
 		public virtual void TestTwoLevelOr()
 		{
-			Db4objects.Db4o.Query.IQuery q = NewQuery();
+			IQuery q = NewQuery();
 			q.Constrain(new Db4objects.Db4o.Tests.Common.Soda.Classes.Untypedhierarchy.STRUH1TestCase
 				("str1"));
 			q.Descend("foo1").Constraints().Or(q.Descend("h2").Descend("h3").Descend("foo3").
@@ -193,7 +182,7 @@ namespace Db4objects.Db4o.Tests.Common.Soda.Classes.Untypedhierarchy
 
 		public virtual void TestThreeLevelOr()
 		{
-			Db4objects.Db4o.Query.IQuery q = NewQuery();
+			IQuery q = NewQuery();
 			q.Constrain(new Db4objects.Db4o.Tests.Common.Soda.Classes.Untypedhierarchy.STRUH1TestCase
 				("str1"));
 			q.Descend("foo1").Constraints().Or(q.Descend("h2").Descend("foo2").Constrain("str2"
