@@ -1,14 +1,10 @@
-/* Copyright (C) 2004 - 2007  db4objects Inc.  http://www.db4o.com
+/* This file is part of the db4o object database http://www.db4o.com
 
-This file is part of the db4o open source object database.
+Copyright (C) 2004 - 2009  Versant Corporation http://www.versant.com
 
 db4o is free software; you can redistribute it and/or modify it under
-the terms of version 2 of the GNU General Public License as published
-by the Free Software Foundation and as clarified by db4objects' GPL 
-interpretation policy, available at
-http://www.db4o.com/about/company/legalpolicies/gplinterpretation/
-Alternatively you can write to db4objects, Inc., 1900 S Norfolk Street,
-Suite 350, San Mateo, CA 94403, USA.
+the terms of version 3 of the GNU General Public License as published
+by the Free Software Foundation.
 
 db4o is distributed in the hope that it will be useful, but WITHOUT ANY
 WARRANTY; without even the implied warranty of MERCHANTABILITY or
@@ -16,12 +12,19 @@ FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
 for more details.
 
 You should have received a copy of the GNU General Public License along
-with this program; if not, write to the Free Software Foundation, Inc.,
-59 Temple Place - Suite 330, Boston, MA  02111-1307, USA. */
+with this program.  If not, see http://www.gnu.org/licenses/. */
+using Db4objects.Db4o.Query;
+using Db4objects.Db4o.Tests.Common.Soda.Util;
+
 namespace Db4objects.Db4o.Tests.Common.Soda.Joins.Untyped
 {
-	public class STOrUTestCase : Db4objects.Db4o.Tests.Common.Soda.Util.SodaBaseTestCase
+	public class STOrUTestCase : SodaBaseTestCase
 	{
+		public static void Main(string[] arguments)
+		{
+			new Db4objects.Db4o.Tests.Common.Soda.Joins.Untyped.STOrUTestCase().RunAll();
+		}
+
 		public object orInt;
 
 		public object orString;
@@ -59,34 +62,34 @@ namespace Db4objects.Db4o.Tests.Common.Soda.Joins.Untyped
 
 		public virtual void TestSmallerGreater()
 		{
-			Db4objects.Db4o.Query.IQuery q = NewQuery();
+			IQuery q = NewQuery();
 			q.Constrain(new Db4objects.Db4o.Tests.Common.Soda.Joins.Untyped.STOrUTestCase());
-			Db4objects.Db4o.Query.IQuery sub = q.Descend("orInt");
+			IQuery sub = q.Descend("orInt");
 			sub.Constrain(30000).Greater().Or(sub.Constrain(5).Smaller());
 			Expect(q, new int[] { 0, 4 });
 		}
 
 		public virtual void TestGreaterGreater()
 		{
-			Db4objects.Db4o.Query.IQuery q = NewQuery();
+			IQuery q = NewQuery();
 			q.Constrain(new Db4objects.Db4o.Tests.Common.Soda.Joins.Untyped.STOrUTestCase());
-			Db4objects.Db4o.Query.IQuery sub = q.Descend("orInt");
+			IQuery sub = q.Descend("orInt");
 			sub.Constrain(30000).Greater().Or(sub.Constrain(5).Greater());
 			Expect(q, new int[] { 2, 3, 4 });
 		}
 
 		public virtual void TestGreaterEquals()
 		{
-			Db4objects.Db4o.Query.IQuery q = NewQuery();
+			IQuery q = NewQuery();
 			q.Constrain(new Db4objects.Db4o.Tests.Common.Soda.Joins.Untyped.STOrUTestCase());
-			Db4objects.Db4o.Query.IQuery sub = q.Descend("orInt");
+			IQuery sub = q.Descend("orInt");
 			sub.Constrain(1000).Greater().Or(sub.Constrain(0));
 			Expect(q, new int[] { 0, 3, 4 });
 		}
 
 		public virtual void TestEqualsNull()
 		{
-			Db4objects.Db4o.Query.IQuery q = NewQuery();
+			IQuery q = NewQuery();
 			q.Constrain(new Db4objects.Db4o.Tests.Common.Soda.Joins.Untyped.STOrUTestCase(1000
 				, null));
 			q.Descend("orInt").Constraints().Or(q.Descend("orString").Constrain(null));
@@ -95,7 +98,7 @@ namespace Db4objects.Db4o.Tests.Common.Soda.Joins.Untyped
 
 		public virtual void TestAndOrAnd()
 		{
-			Db4objects.Db4o.Query.IQuery q = NewQuery();
+			IQuery q = NewQuery();
 			q.Constrain(new Db4objects.Db4o.Tests.Common.Soda.Joins.Untyped.STOrUTestCase(null
 				, null));
 			(q.Descend("orInt").Constrain(5).And(q.Descend("orString").Constrain(null))).Or(q
@@ -105,18 +108,18 @@ namespace Db4objects.Db4o.Tests.Common.Soda.Joins.Untyped
 
 		public virtual void TestOrAndOr()
 		{
-			Db4objects.Db4o.Query.IQuery q = NewQuery();
+			IQuery q = NewQuery();
 			q.Constrain(new Db4objects.Db4o.Tests.Common.Soda.Joins.Untyped.STOrUTestCase(null
 				, null));
 			(q.Descend("orInt").Constrain(5).Or(q.Descend("orString").Constrain(null))).And(q
 				.Descend("orInt").Constrain(int.MaxValue - 1).Or(q.Descend("orString").Constrain
 				("joho")));
-			Db4objects.Db4o.Tests.Common.Soda.Util.SodaTestUtil.ExpectOne(q, _array[4]);
+			SodaTestUtil.ExpectOne(q, _array[4]);
 		}
 
 		public virtual void TestOrOrAnd()
 		{
-			Db4objects.Db4o.Query.IQuery q = NewQuery();
+			IQuery q = NewQuery();
 			q.Constrain(new Db4objects.Db4o.Tests.Common.Soda.Joins.Untyped.STOrUTestCase());
 			(q.Descend("orInt").Constrain(int.MaxValue - 1).Or(q.Descend("orString").Constrain
 				("joho"))).Or(q.Descend("orInt").Constrain(5).And(q.Descend("orString").Constrain
@@ -126,7 +129,7 @@ namespace Db4objects.Db4o.Tests.Common.Soda.Joins.Untyped
 
 		public virtual void TestMultiOrAnd()
 		{
-			Db4objects.Db4o.Query.IQuery q = NewQuery();
+			IQuery q = NewQuery();
 			q.Constrain(new Db4objects.Db4o.Tests.Common.Soda.Joins.Untyped.STOrUTestCase());
 			((q.Descend("orInt").Constrain(int.MaxValue - 1).Or(q.Descend("orString").Constrain
 				("joho"))).Or(q.Descend("orInt").Constrain(5).And(q.Descend("orString").Constrain
@@ -138,34 +141,34 @@ namespace Db4objects.Db4o.Tests.Common.Soda.Joins.Untyped
 
 		public virtual void TestNotSmallerGreater()
 		{
-			Db4objects.Db4o.Query.IQuery q = NewQuery();
+			IQuery q = NewQuery();
 			q.Constrain(new Db4objects.Db4o.Tests.Common.Soda.Joins.Untyped.STOrUTestCase());
-			Db4objects.Db4o.Query.IQuery sub = q.Descend("orInt");
+			IQuery sub = q.Descend("orInt");
 			(sub.Constrain(30000).Greater().Or(sub.Constrain(5).Smaller())).Not();
 			Expect(q, new int[] { 1, 2, 3 });
 		}
 
 		public virtual void TestNotGreaterGreater()
 		{
-			Db4objects.Db4o.Query.IQuery q = NewQuery();
+			IQuery q = NewQuery();
 			q.Constrain(new Db4objects.Db4o.Tests.Common.Soda.Joins.Untyped.STOrUTestCase());
-			Db4objects.Db4o.Query.IQuery sub = q.Descend("orInt");
+			IQuery sub = q.Descend("orInt");
 			(sub.Constrain(30000).Greater().Or(sub.Constrain(5).Greater())).Not();
 			Expect(q, new int[] { 0, 1 });
 		}
 
 		public virtual void TestNotGreaterEquals()
 		{
-			Db4objects.Db4o.Query.IQuery q = NewQuery();
+			IQuery q = NewQuery();
 			q.Constrain(new Db4objects.Db4o.Tests.Common.Soda.Joins.Untyped.STOrUTestCase());
-			Db4objects.Db4o.Query.IQuery sub = q.Descend("orInt");
+			IQuery sub = q.Descend("orInt");
 			(sub.Constrain(1000).Greater().Or(sub.Constrain(0))).Not();
 			Expect(q, new int[] { 1, 2 });
 		}
 
 		public virtual void TestNotEqualsNull()
 		{
-			Db4objects.Db4o.Query.IQuery q = NewQuery();
+			IQuery q = NewQuery();
 			q.Constrain(new Db4objects.Db4o.Tests.Common.Soda.Joins.Untyped.STOrUTestCase(1000
 				, null));
 			(q.Descend("orInt").Constraints().Or(q.Descend("orString").Constrain(null))).Not(
@@ -175,7 +178,7 @@ namespace Db4objects.Db4o.Tests.Common.Soda.Joins.Untyped
 
 		public virtual void TestNotAndOrAnd()
 		{
-			Db4objects.Db4o.Query.IQuery q = NewQuery();
+			IQuery q = NewQuery();
 			q.Constrain(new Db4objects.Db4o.Tests.Common.Soda.Joins.Untyped.STOrUTestCase());
 			(q.Descend("orInt").Constrain(5).And(q.Descend("orString").Constrain(null))).Or(q
 				.Descend("orInt").Constrain(1000).And(q.Descend("orString").Constrain("joho"))).
@@ -185,7 +188,7 @@ namespace Db4objects.Db4o.Tests.Common.Soda.Joins.Untyped
 
 		public virtual void TestNotOrAndOr()
 		{
-			Db4objects.Db4o.Query.IQuery q = NewQuery();
+			IQuery q = NewQuery();
 			q.Constrain(new Db4objects.Db4o.Tests.Common.Soda.Joins.Untyped.STOrUTestCase());
 			(q.Descend("orInt").Constrain(5).Or(q.Descend("orString").Constrain(null))).And(q
 				.Descend("orInt").Constrain(int.MaxValue - 1).Or(q.Descend("orString").Constrain
@@ -195,7 +198,7 @@ namespace Db4objects.Db4o.Tests.Common.Soda.Joins.Untyped
 
 		public virtual void TestNotOrOrAnd()
 		{
-			Db4objects.Db4o.Query.IQuery q = NewQuery();
+			IQuery q = NewQuery();
 			q.Constrain(new Db4objects.Db4o.Tests.Common.Soda.Joins.Untyped.STOrUTestCase());
 			(q.Descend("orInt").Constrain(int.MaxValue - 1).Or(q.Descend("orString").Constrain
 				("joho"))).Or(q.Descend("orInt").Constrain(5).And(q.Descend("orString").Constrain
@@ -205,7 +208,7 @@ namespace Db4objects.Db4o.Tests.Common.Soda.Joins.Untyped
 
 		public virtual void TestNotMultiOrAnd()
 		{
-			Db4objects.Db4o.Query.IQuery q = NewQuery();
+			IQuery q = NewQuery();
 			q.Constrain(new Db4objects.Db4o.Tests.Common.Soda.Joins.Untyped.STOrUTestCase());
 			((q.Descend("orInt").Constrain(int.MaxValue - 1).Or(q.Descend("orString").Constrain
 				("joho"))).Or(q.Descend("orInt").Constrain(5).And(q.Descend("orString").Constrain
@@ -217,7 +220,7 @@ namespace Db4objects.Db4o.Tests.Common.Soda.Joins.Untyped
 
 		public virtual void TestOrNotAndOr()
 		{
-			Db4objects.Db4o.Query.IQuery q = NewQuery();
+			IQuery q = NewQuery();
 			q.Constrain(new Db4objects.Db4o.Tests.Common.Soda.Joins.Untyped.STOrUTestCase());
 			(q.Descend("orInt").Constrain(int.MaxValue - 1).Or(q.Descend("orString").Constrain
 				("joho"))).Not().And(q.Descend("orInt").Constrain(5).Or(q.Descend("orString").Constrain
@@ -227,7 +230,7 @@ namespace Db4objects.Db4o.Tests.Common.Soda.Joins.Untyped
 
 		public virtual void TestAndNotAndAnd()
 		{
-			Db4objects.Db4o.Query.IQuery q = NewQuery();
+			IQuery q = NewQuery();
 			q.Constrain(new Db4objects.Db4o.Tests.Common.Soda.Joins.Untyped.STOrUTestCase());
 			(q.Descend("orInt").Constrain(int.MaxValue - 1).And(q.Descend("orString").Constrain
 				(null))).Not().And(q.Descend("orInt").Constrain(5).Or(q.Descend("orString").Constrain
