@@ -1,14 +1,10 @@
-/* Copyright (C) 2004 - 2007  db4objects Inc.  http://www.db4o.com
+/* This file is part of the db4o object database http://www.db4o.com
 
-This file is part of the db4o open source object database.
+Copyright (C) 2004 - 2009  Versant Corporation http://www.versant.com
 
 db4o is free software; you can redistribute it and/or modify it under
-the terms of version 2 of the GNU General Public License as published
-by the Free Software Foundation and as clarified by db4objects' GPL 
-interpretation policy, available at
-http://www.db4o.com/about/company/legalpolicies/gplinterpretation/
-Alternatively you can write to db4objects, Inc., 1900 S Norfolk Street,
-Suite 350, San Mateo, CA 94403, USA.
+the terms of version 3 of the GNU General Public License as published
+by the Free Software Foundation.
 
 db4o is distributed in the hope that it will be useful, but WITHOUT ANY
 WARRANTY; without even the implied warranty of MERCHANTABILITY or
@@ -16,11 +12,13 @@ FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
 for more details.
 
 You should have received a copy of the GNU General Public License along
-with this program; if not, write to the Free Software Foundation, Inc.,
-59 Temple Place - Suite 330, Boston, MA  02111-1307, USA. */
+with this program.  If not, see http://www.gnu.org/licenses/. */
+using Db4objects.Db4o.Query;
+using Db4objects.Db4o.Tests.Common.Soda.Util;
+
 namespace Db4objects.Db4o.Tests.Common.Soda.Ordered
 {
-	public class STOIntegerTestCase : Db4objects.Db4o.Tests.Common.Soda.Util.SodaBaseTestCase
+	public class STOIntegerTestCase : SodaBaseTestCase
 	{
 		public int i_int;
 
@@ -50,7 +48,7 @@ namespace Db4objects.Db4o.Tests.Common.Soda.Ordered
 
 		public virtual void TestAscending()
 		{
-			Db4objects.Db4o.Query.IQuery q = NewQuery();
+			IQuery q = NewQuery();
 			q.Constrain(typeof(Db4objects.Db4o.Tests.Common.Soda.Ordered.STOIntegerTestCase));
 			q.Descend("i_int").OrderAscending();
 			ExpectOrdered(q, new int[] { 5, 2, 1, 3, 0, 4, 6 });
@@ -58,7 +56,7 @@ namespace Db4objects.Db4o.Tests.Common.Soda.Ordered
 
 		public virtual void TestDescending()
 		{
-			Db4objects.Db4o.Query.IQuery q = NewQuery();
+			IQuery q = NewQuery();
 			q.Constrain(typeof(Db4objects.Db4o.Tests.Common.Soda.Ordered.STOIntegerTestCase));
 			q.Descend("i_int").OrderDescending();
 			ExpectOrdered(q, new int[] { 6, 4, 0, 3, 1, 2, 5 });
@@ -66,9 +64,9 @@ namespace Db4objects.Db4o.Tests.Common.Soda.Ordered
 
 		public virtual void TestAscendingGreater()
 		{
-			Db4objects.Db4o.Query.IQuery q = NewQuery();
+			IQuery q = NewQuery();
 			q.Constrain(typeof(Db4objects.Db4o.Tests.Common.Soda.Ordered.STOIntegerTestCase));
-			Db4objects.Db4o.Query.IQuery qInt = q.Descend("i_int");
+			IQuery qInt = q.Descend("i_int");
 			qInt.Constrain(100).Greater();
 			qInt.OrderAscending();
 			ExpectOrdered(q, new int[] { 3, 0, 4, 6 });
