@@ -1,14 +1,10 @@
-/* Copyright (C) 2004 - 2007  db4objects Inc.  http://www.db4o.com
+/* This file is part of the db4o object database http://www.db4o.com
 
-This file is part of the db4o open source object database.
+Copyright (C) 2004 - 2009  Versant Corporation http://www.versant.com
 
 db4o is free software; you can redistribute it and/or modify it under
-the terms of version 2 of the GNU General Public License as published
-by the Free Software Foundation and as clarified by db4objects' GPL 
-interpretation policy, available at
-http://www.db4o.com/about/company/legalpolicies/gplinterpretation/
-Alternatively you can write to db4objects, Inc., 1900 S Norfolk Street,
-Suite 350, San Mateo, CA 94403, USA.
+the terms of version 3 of the GNU General Public License as published
+by the Free Software Foundation.
 
 db4o is distributed in the hope that it will be useful, but WITHOUT ANY
 WARRANTY; without even the implied warranty of MERCHANTABILITY or
@@ -16,11 +12,13 @@ FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
 for more details.
 
 You should have received a copy of the GNU General Public License along
-with this program; if not, write to the Free Software Foundation, Inc.,
-59 Temple Place - Suite 330, Boston, MA  02111-1307, USA. */
+with this program.  If not, see http://www.gnu.org/licenses/. */
+using Db4objects.Db4o.Query;
+using Db4objects.Db4o.Tests.Common.Soda.Util;
+
 namespace Db4objects.Db4o.Tests.Common.Soda.Ordered
 {
-	public class STOStringTestCase : Db4objects.Db4o.Tests.Common.Soda.Util.SodaBaseTestCase
+	public class STOStringTestCase : SodaBaseTestCase
 	{
 		public string foo;
 
@@ -45,7 +43,7 @@ namespace Db4objects.Db4o.Tests.Common.Soda.Ordered
 
 		public virtual void TestAscending()
 		{
-			Db4objects.Db4o.Query.IQuery q = NewQuery();
+			IQuery q = NewQuery();
 			q.Constrain(typeof(Db4objects.Db4o.Tests.Common.Soda.Ordered.STOStringTestCase));
 			q.Descend("foo").OrderAscending();
 			ExpectOrdered(q, new int[] { 5, 4, 1, 2, 6, 3, 0 });
@@ -53,7 +51,7 @@ namespace Db4objects.Db4o.Tests.Common.Soda.Ordered
 
 		public virtual void TestDescending()
 		{
-			Db4objects.Db4o.Query.IQuery q = NewQuery();
+			IQuery q = NewQuery();
 			q.Constrain(typeof(Db4objects.Db4o.Tests.Common.Soda.Ordered.STOStringTestCase));
 			q.Descend("foo").OrderDescending();
 			ExpectOrdered(q, new int[] { 3, 6, 2, 1, 4, 5, 0 });
@@ -61,9 +59,9 @@ namespace Db4objects.Db4o.Tests.Common.Soda.Ordered
 
 		public virtual void TestAscendingLike()
 		{
-			Db4objects.Db4o.Query.IQuery q = NewQuery();
+			IQuery q = NewQuery();
 			q.Constrain(typeof(Db4objects.Db4o.Tests.Common.Soda.Ordered.STOStringTestCase));
-			Db4objects.Db4o.Query.IQuery qStr = q.Descend("foo");
+			IQuery qStr = q.Descend("foo");
 			qStr.Constrain("b").Like();
 			qStr.OrderAscending();
 			ExpectOrdered(q, new int[] { 5, 1, 2, 6 });
@@ -71,9 +69,9 @@ namespace Db4objects.Db4o.Tests.Common.Soda.Ordered
 
 		public virtual void TestDescendingContains()
 		{
-			Db4objects.Db4o.Query.IQuery q = NewQuery();
+			IQuery q = NewQuery();
 			q.Constrain(typeof(Db4objects.Db4o.Tests.Common.Soda.Ordered.STOStringTestCase));
-			Db4objects.Db4o.Query.IQuery qStr = q.Descend("foo");
+			IQuery qStr = q.Descend("foo");
 			qStr.Constrain("b").Contains();
 			qStr.OrderDescending();
 			ExpectOrdered(q, new int[] { 6, 2, 1, 5 });
