@@ -1,14 +1,10 @@
-/* Copyright (C) 2004 - 2007  db4objects Inc.  http://www.db4o.com
+/* This file is part of the db4o object database http://www.db4o.com
 
-This file is part of the db4o open source object database.
+Copyright (C) 2004 - 2009  Versant Corporation http://www.versant.com
 
 db4o is free software; you can redistribute it and/or modify it under
-the terms of version 2 of the GNU General Public License as published
-by the Free Software Foundation and as clarified by db4objects' GPL 
-interpretation policy, available at
-http://www.db4o.com/about/company/legalpolicies/gplinterpretation/
-Alternatively you can write to db4objects, Inc., 1900 S Norfolk Street,
-Suite 350, San Mateo, CA 94403, USA.
+the terms of version 3 of the GNU General Public License as published
+by the Free Software Foundation.
 
 db4o is distributed in the hope that it will be useful, but WITHOUT ANY
 WARRANTY; without even the implied warranty of MERCHANTABILITY or
@@ -16,15 +12,21 @@ FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
 for more details.
 
 You should have received a copy of the GNU General Public License along
-with this program; if not, write to the Free Software Foundation, Inc.,
-59 Temple Place - Suite 330, Boston, MA  02111-1307, USA. */
+with this program.  If not, see http://www.gnu.org/licenses/. */
+using Db4oUnit;
+using Db4oUnit.Extensions;
+using Db4objects.Db4o;
+using Db4objects.Db4o.Query;
+using Db4objects.Db4o.Tests.Common.Soda;
+
 namespace Db4objects.Db4o.Tests.Common.Soda
 {
-	public class SortMultipleTestCase : Db4oUnit.Extensions.AbstractDb4oTestCase
+	public class SortMultipleTestCase : AbstractDb4oTestCase
 	{
+		// COR-18
 		public static void Main(string[] arguments)
 		{
-			new Db4objects.Db4o.Tests.Common.Soda.SortMultipleTestCase().RunSolo();
+			new SortMultipleTestCase().RunSolo();
 		}
 
 		public class IntHolder
@@ -46,8 +48,7 @@ namespace Db4objects.Db4o.Tests.Common.Soda
 				{
 					return false;
 				}
-				Db4objects.Db4o.Tests.Common.Soda.SortMultipleTestCase.IntHolder intHolder = (Db4objects.Db4o.Tests.Common.Soda.SortMultipleTestCase.IntHolder
-					)obj;
+				SortMultipleTestCase.IntHolder intHolder = (SortMultipleTestCase.IntHolder)obj;
 				return _value == intHolder._value;
 			}
 
@@ -68,14 +69,13 @@ namespace Db4objects.Db4o.Tests.Common.Soda
 
 			public int _second;
 
-			public Db4objects.Db4o.Tests.Common.Soda.SortMultipleTestCase.IntHolder _third;
+			public SortMultipleTestCase.IntHolder _third;
 
 			public Data(int first, int second, int third)
 			{
 				this._first = first;
 				this._second = second;
-				this._third = new Db4objects.Db4o.Tests.Common.Soda.SortMultipleTestCase.IntHolder
-					(third);
+				this._third = new SortMultipleTestCase.IntHolder(third);
 			}
 
 			public override bool Equals(object obj)
@@ -88,8 +88,7 @@ namespace Db4objects.Db4o.Tests.Common.Soda
 				{
 					return false;
 				}
-				Db4objects.Db4o.Tests.Common.Soda.SortMultipleTestCase.Data data = (Db4objects.Db4o.Tests.Common.Soda.SortMultipleTestCase.Data
-					)obj;
+				SortMultipleTestCase.Data data = (SortMultipleTestCase.Data)obj;
 				return _first == data._first && _second == data._second && _third.Equals(data._third
 					);
 			}
@@ -108,25 +107,30 @@ namespace Db4objects.Db4o.Tests.Common.Soda
 			}
 		}
 
-		private static readonly Db4objects.Db4o.Tests.Common.Soda.SortMultipleTestCase.Data[]
-			 DATA = { new Db4objects.Db4o.Tests.Common.Soda.SortMultipleTestCase.Data(1, 2, 
-			4), new Db4objects.Db4o.Tests.Common.Soda.SortMultipleTestCase.Data(1, 4, 3), new 
-			Db4objects.Db4o.Tests.Common.Soda.SortMultipleTestCase.Data(2, 4, 2), new Db4objects.Db4o.Tests.Common.Soda.SortMultipleTestCase.Data
-			(3, 1, 4), new Db4objects.Db4o.Tests.Common.Soda.SortMultipleTestCase.Data(4, 3, 
-			1), new Db4objects.Db4o.Tests.Common.Soda.SortMultipleTestCase.Data(4, 1, 3) };
+		private static readonly SortMultipleTestCase.Data[] TestData = new SortMultipleTestCase.Data
+			[] { new SortMultipleTestCase.Data(1, 2, 4), new SortMultipleTestCase.Data(1, 4, 
+			3), new SortMultipleTestCase.Data(2, 4, 2), new SortMultipleTestCase.Data(3, 1, 
+			4), new SortMultipleTestCase.Data(4, 3, 1), new SortMultipleTestCase.Data(4, 1, 
+			3) };
 
+		// 0
+		// 1
+		// 2
+		// 3
+		// 4
+		// 5
+		/// <exception cref="System.Exception"></exception>
 		protected override void Store()
 		{
-			for (int dataIdx = 0; dataIdx < DATA.Length; dataIdx++)
+			for (int dataIdx = 0; dataIdx < TestData.Length; dataIdx++)
 			{
-				Store(DATA[dataIdx]);
+				Store(TestData[dataIdx]);
 			}
 		}
 
 		public virtual void TestSortFirstThenSecond()
 		{
-			Db4objects.Db4o.Query.IQuery query = NewQuery(typeof(Db4objects.Db4o.Tests.Common.Soda.SortMultipleTestCase.Data)
-				);
+			IQuery query = NewQuery(typeof(SortMultipleTestCase.Data));
 			query.Descend("_first").OrderAscending();
 			query.Descend("_second").OrderAscending();
 			AssertSortOrder(query, new int[] { 0, 1, 2, 3, 5, 4 });
@@ -134,8 +138,7 @@ namespace Db4objects.Db4o.Tests.Common.Soda
 
 		public virtual void TestSortSecondThenFirst()
 		{
-			Db4objects.Db4o.Query.IQuery query = NewQuery(typeof(Db4objects.Db4o.Tests.Common.Soda.SortMultipleTestCase.Data)
-				);
+			IQuery query = NewQuery(typeof(SortMultipleTestCase.Data));
 			query.Descend("_second").OrderAscending();
 			query.Descend("_first").OrderAscending();
 			AssertSortOrder(query, new int[] { 3, 5, 0, 4, 1, 2 });
@@ -143,8 +146,7 @@ namespace Db4objects.Db4o.Tests.Common.Soda
 
 		public virtual void TestSortThirdThenFirst()
 		{
-			Db4objects.Db4o.Query.IQuery query = NewQuery(typeof(Db4objects.Db4o.Tests.Common.Soda.SortMultipleTestCase.Data)
-				);
+			IQuery query = NewQuery(typeof(SortMultipleTestCase.Data));
 			query.Descend("_third").Descend("_value").OrderAscending();
 			query.Descend("_first").OrderAscending();
 			AssertSortOrder(query, new int[] { 4, 2, 1, 5, 0, 3 });
@@ -152,8 +154,7 @@ namespace Db4objects.Db4o.Tests.Common.Soda
 
 		public virtual void TestSortThirdThenSecond()
 		{
-			Db4objects.Db4o.Query.IQuery query = NewQuery(typeof(Db4objects.Db4o.Tests.Common.Soda.SortMultipleTestCase.Data)
-				);
+			IQuery query = NewQuery(typeof(SortMultipleTestCase.Data));
 			query.Descend("_third").Descend("_value").OrderAscending();
 			query.Descend("_second").OrderAscending();
 			AssertSortOrder(query, new int[] { 4, 2, 5, 1, 3, 0 });
@@ -161,21 +162,19 @@ namespace Db4objects.Db4o.Tests.Common.Soda
 
 		public virtual void TestSortSecondThenThird()
 		{
-			Db4objects.Db4o.Query.IQuery query = NewQuery(typeof(Db4objects.Db4o.Tests.Common.Soda.SortMultipleTestCase.Data)
-				);
+			IQuery query = NewQuery(typeof(SortMultipleTestCase.Data));
 			query.Descend("_second").OrderAscending();
 			query.Descend("_third").Descend("_value").OrderAscending();
 			AssertSortOrder(query, new int[] { 5, 3, 0, 4, 2, 1 });
 		}
 
-		private void AssertSortOrder(Db4objects.Db4o.Query.IQuery query, int[] expectedIndexes
-			)
+		private void AssertSortOrder(IQuery query, int[] expectedIndexes)
 		{
-			Db4objects.Db4o.IObjectSet result = query.Execute();
-			Db4oUnit.Assert.AreEqual(expectedIndexes.Length, result.Size());
+			IObjectSet result = query.Execute();
+			Assert.AreEqual(expectedIndexes.Length, result.Size());
 			for (int i = 0; i < expectedIndexes.Length; i++)
 			{
-				Db4oUnit.Assert.AreEqual(DATA[expectedIndexes[i]], result.Next());
+				Assert.AreEqual(TestData[expectedIndexes[i]], result.Next());
 			}
 		}
 	}
