@@ -1,14 +1,10 @@
-/* Copyright (C) 2004 - 2007  db4objects Inc.  http://www.db4o.com
+/* This file is part of the db4o object database http://www.db4o.com
 
-This file is part of the db4o open source object database.
+Copyright (C) 2004 - 2009  Versant Corporation http://www.versant.com
 
 db4o is free software; you can redistribute it and/or modify it under
-the terms of version 2 of the GNU General Public License as published
-by the Free Software Foundation and as clarified by db4objects' GPL 
-interpretation policy, available at
-http://www.db4o.com/about/company/legalpolicies/gplinterpretation/
-Alternatively you can write to db4objects, Inc., 1900 S Norfolk Street,
-Suite 350, San Mateo, CA 94403, USA.
+the terms of version 3 of the GNU General Public License as published
+by the Free Software Foundation.
 
 db4o is distributed in the hope that it will be useful, but WITHOUT ANY
 WARRANTY; without even the implied warranty of MERCHANTABILITY or
@@ -16,18 +12,23 @@ FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
 for more details.
 
 You should have received a copy of the GNU General Public License along
-with this program; if not, write to the Free Software Foundation, Inc.,
-59 Temple Place - Suite 330, Boston, MA  02111-1307, USA. */
+with this program.  If not, see http://www.gnu.org/licenses/. */
+using System;
+using System.Collections;
+using System.Reflection;
+using Db4oUnit.Extensions;
+using Db4objects.Db4o.Internal;
+
 namespace Db4objects.Db4o.Tests.Common.Soda.Util
 {
 	public class TCompare
 	{
 		public static bool IsEqual(object a_compare, object a_with)
 		{
-			return IsEqual(a_compare, a_with, null, new System.Collections.ArrayList());
+			return IsEqual(a_compare, a_with, null, new ArrayList());
 		}
 
-		private static bool IsEqual(object a_compare, object a_with, string a_path, System.Collections.ArrayList
+		private static bool IsEqual(object a_compare, object a_with, string a_path, ArrayList
 			 a_list)
 		{
 			if (a_compare == null)
@@ -38,15 +39,16 @@ namespace Db4objects.Db4o.Tests.Common.Soda.Util
 			{
 				return false;
 			}
-			System.Type clazz = a_compare.GetType();
+			Type clazz = a_compare.GetType();
 			if (clazz != a_with.GetType())
 			{
 				return false;
 			}
-			if (Db4objects.Db4o.Internal.Platform4.IsSimple(clazz))
+			if (Platform4.IsSimple(clazz))
 			{
 				return a_compare.Equals(a_with);
 			}
+			// takes care of repeating calls to the same object
 			if (a_list.Contains(a_compare))
 			{
 				return true;
@@ -65,17 +67,16 @@ namespace Db4objects.Db4o.Tests.Common.Soda.Util
 		}
 
 		private static bool AreFieldsEqual(object a_compare, object a_with, string a_path
-			, System.Collections.ArrayList a_list)
+			, ArrayList a_list)
 		{
 			string path = GetPath(a_compare, a_with, a_path);
-			System.Reflection.FieldInfo[] fields = Sharpen.Runtime.GetDeclaredFields(a_compare
-				.GetType());
+			FieldInfo[] fields = Sharpen.Runtime.GetDeclaredFields(a_compare.GetType());
 			for (int i = 0; i < fields.Length; i++)
 			{
-				System.Reflection.FieldInfo field = fields[i];
-				if (Db4oUnit.Extensions.Db4oUnitPlatform.IsStoreableField(field))
+				FieldInfo field = fields[i];
+				if (Db4oUnitPlatform.IsUserField(field))
 				{
-					Db4objects.Db4o.Internal.Platform4.SetAccessible(field);
+					Platform4.SetAccessible(field);
 					try
 					{
 						if (!IsFieldEqual(field, a_compare, a_with, path, a_list))
@@ -83,7 +84,7 @@ namespace Db4objects.Db4o.Tests.Common.Soda.Util
 							return false;
 						}
 					}
-					catch (System.Exception e)
+					catch (Exception e)
 					{
 						Sharpen.Runtime.Err.WriteLine("TCompare failure executing path:" + path);
 						Sharpen.Runtime.PrintStackTrace(e);
@@ -94,28 +95,29 @@ namespace Db4objects.Db4o.Tests.Common.Soda.Util
 			return true;
 		}
 
-		private static bool IsFieldEqual(System.Reflection.FieldInfo field, object a_compare
-			, object a_with, string path, System.Collections.ArrayList a_list)
+		private static bool IsFieldEqual(FieldInfo field, object a_compare, object a_with
+			, string path, ArrayList a_list)
 		{
 			object compare = GetFieldValue(field, a_compare);
 			object with = GetFieldValue(field, a_with);
 			return IsEqual(compare, with, path + field.Name + ":", a_list);
 		}
 
-		private static object GetFieldValue(System.Reflection.FieldInfo field, object obj
-			)
+		private static object GetFieldValue(FieldInfo field, object obj)
 		{
 			try
 			{
 				return field.GetValue(obj);
 			}
-			catch (System.MemberAccessException)
+			catch (MemberAccessException)
 			{
+				// probably JDK 1
+				// never mind this field
 				return null;
 			}
 		}
 
-		private static bool AreArraysEqual(object compare, object with, string path, System.Collections.ArrayList
+		private static bool AreArraysEqual(object compare, object with, string path, ArrayList
 			 a_list)
 		{
 			int len = Sharpen.Runtime.GetArrayLength(compare);
@@ -155,7 +157,7 @@ namespace Db4objects.Db4o.Tests.Common.Soda.Util
 			return a_path;
 		}
 
-		internal static bool HasPublicConstructor(System.Type a_class)
+		internal static bool HasPublicConstructor(Type a_class)
 		{
 			if (a_class != typeof(string))
 			{
@@ -186,8 +188,8 @@ namespace Db4objects.Db4o.Tests.Common.Soda.Util
 			return a_object;
 		}
 
-		internal static int NormalizeNArray1(object a_object, object a_all, int a_next, int[]
-			 a_dim, int a_index)
+		internal static int NormalizeNArray1(object a_object, object a_all, int a_next, int
+			[] a_dim, int a_index)
 		{
 			if (a_index == a_dim.Length - 1)
 			{
@@ -211,7 +213,7 @@ namespace Db4objects.Db4o.Tests.Common.Soda.Util
 		internal static int[] ArrayDimensions(object a_object)
 		{
 			int count = 0;
-			for (System.Type clazz = a_object.GetType(); clazz.IsArray; clazz = clazz.GetElementType
+			for (Type clazz = a_object.GetType(); clazz.IsArray; clazz = clazz.GetElementType
 				())
 			{
 				count++;
