@@ -1,14 +1,10 @@
-/* Copyright (C) 2004 - 2007  db4objects Inc.  http://www.db4o.com
+/* This file is part of the db4o object database http://www.db4o.com
 
-This file is part of the db4o open source object database.
+Copyright (C) 2004 - 2009  Versant Corporation http://www.versant.com
 
 db4o is free software; you can redistribute it and/or modify it under
-the terms of version 2 of the GNU General Public License as published
-by the Free Software Foundation and as clarified by db4objects' GPL 
-interpretation policy, available at
-http://www.db4o.com/about/company/legalpolicies/gplinterpretation/
-Alternatively you can write to db4objects, Inc., 1900 S Norfolk Street,
-Suite 350, San Mateo, CA 94403, USA.
+the terms of version 3 of the GNU General Public License as published
+by the Free Software Foundation.
 
 db4o is distributed in the hope that it will be useful, but WITHOUT ANY
 WARRANTY; without even the implied warranty of MERCHANTABILITY or
@@ -16,12 +12,16 @@ FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
 for more details.
 
 You should have received a copy of the GNU General Public License along
-with this program; if not, write to the Free Software Foundation, Inc.,
-59 Temple Place - Suite 330, Boston, MA  02111-1307, USA. */
+with this program.  If not, see http://www.gnu.org/licenses/. */
+using Db4oUnit;
+using Db4objects.Db4o;
+using Db4objects.Db4o.Query;
+using Db4objects.Db4o.Tests.Common.Soda.Util;
+
 namespace Db4objects.Db4o.Tests.Common.Soda.Wrapper.Untyped
 {
 	[System.Serializable]
-	public class STIntegerWUTestCase : Db4objects.Db4o.Tests.Common.Soda.Util.SodaBaseTestCase
+	public class STIntegerWUTestCase : SodaBaseTestCase
 	{
 		public object i_int;
 
@@ -45,16 +45,18 @@ namespace Db4objects.Db4o.Tests.Common.Soda.Wrapper.Untyped
 
 		public virtual void TestEquals()
 		{
-			Db4objects.Db4o.Query.IQuery q = NewQuery();
+			IQuery q = NewQuery();
 			q.Constrain(new Db4objects.Db4o.Tests.Common.Soda.Wrapper.Untyped.STIntegerWUTestCase
 				(0));
+			// Primitive default values are ignored, so we need an 
+			// additional constraint:
 			q.Descend("i_int").Constrain(0);
-			Db4objects.Db4o.Tests.Common.Soda.Util.SodaTestUtil.ExpectOne(q, _array[0]);
+			SodaTestUtil.ExpectOne(q, _array[0]);
 		}
 
 		public virtual void TestNotEquals()
 		{
-			Db4objects.Db4o.Query.IQuery q = NewQuery();
+			IQuery q = NewQuery();
 			q.Constrain(new Db4objects.Db4o.Tests.Common.Soda.Wrapper.Untyped.STIntegerWUTestCase
 				());
 			q.Descend("i_int").Constrain(0).Not();
@@ -63,7 +65,7 @@ namespace Db4objects.Db4o.Tests.Common.Soda.Wrapper.Untyped
 
 		public virtual void TestGreater()
 		{
-			Db4objects.Db4o.Query.IQuery q = NewQuery();
+			IQuery q = NewQuery();
 			q.Constrain(new Db4objects.Db4o.Tests.Common.Soda.Wrapper.Untyped.STIntegerWUTestCase
 				(9));
 			q.Descend("i_int").Constraints().Greater();
@@ -72,16 +74,16 @@ namespace Db4objects.Db4o.Tests.Common.Soda.Wrapper.Untyped
 
 		public virtual void TestSmaller()
 		{
-			Db4objects.Db4o.Query.IQuery q = NewQuery();
+			IQuery q = NewQuery();
 			q.Constrain(new Db4objects.Db4o.Tests.Common.Soda.Wrapper.Untyped.STIntegerWUTestCase
 				(1));
 			q.Descend("i_int").Constraints().Smaller();
-			Db4objects.Db4o.Tests.Common.Soda.Util.SodaTestUtil.ExpectOne(q, _array[0]);
+			SodaTestUtil.ExpectOne(q, _array[0]);
 		}
 
 		public virtual void TestContains()
 		{
-			Db4objects.Db4o.Query.IQuery q = NewQuery();
+			IQuery q = NewQuery();
 			q.Constrain(new Db4objects.Db4o.Tests.Common.Soda.Wrapper.Untyped.STIntegerWUTestCase
 				(9));
 			q.Descend("i_int").Constraints().Contains();
@@ -90,7 +92,7 @@ namespace Db4objects.Db4o.Tests.Common.Soda.Wrapper.Untyped
 
 		public virtual void TestNotContains()
 		{
-			Db4objects.Db4o.Query.IQuery q = NewQuery();
+			IQuery q = NewQuery();
 			q.Constrain(new Db4objects.Db4o.Tests.Common.Soda.Wrapper.Untyped.STIntegerWUTestCase
 				());
 			q.Descend("i_int").Constrain(0).Contains().Not();
@@ -99,11 +101,11 @@ namespace Db4objects.Db4o.Tests.Common.Soda.Wrapper.Untyped
 
 		public virtual void TestLike()
 		{
-			Db4objects.Db4o.Query.IQuery q = NewQuery();
+			IQuery q = NewQuery();
 			q.Constrain(new Db4objects.Db4o.Tests.Common.Soda.Wrapper.Untyped.STIntegerWUTestCase
 				(90));
 			q.Descend("i_int").Constraints().Like();
-			Db4objects.Db4o.Tests.Common.Soda.Util.SodaTestUtil.ExpectOne(q, new Db4objects.Db4o.Tests.Common.Soda.Wrapper.Untyped.STIntegerWUTestCase
+			SodaTestUtil.ExpectOne(q, new Db4objects.Db4o.Tests.Common.Soda.Wrapper.Untyped.STIntegerWUTestCase
 				(909));
 			q = NewQuery();
 			q.Constrain(new Db4objects.Db4o.Tests.Common.Soda.Wrapper.Untyped.STIntegerWUTestCase
@@ -114,7 +116,7 @@ namespace Db4objects.Db4o.Tests.Common.Soda.Wrapper.Untyped
 
 		public virtual void TestNotLike()
 		{
-			Db4objects.Db4o.Query.IQuery q = NewQuery();
+			IQuery q = NewQuery();
 			q.Constrain(new Db4objects.Db4o.Tests.Common.Soda.Wrapper.Untyped.STIntegerWUTestCase
 				(1));
 			q.Descend("i_int").Constraints().Like().Not();
@@ -123,10 +125,10 @@ namespace Db4objects.Db4o.Tests.Common.Soda.Wrapper.Untyped
 
 		public virtual void TestIdentity()
 		{
-			Db4objects.Db4o.Query.IQuery q = NewQuery();
+			IQuery q = NewQuery();
 			q.Constrain(new Db4objects.Db4o.Tests.Common.Soda.Wrapper.Untyped.STIntegerWUTestCase
 				(1));
-			Db4objects.Db4o.IObjectSet set = q.Execute();
+			IObjectSet set = q.Execute();
 			Db4objects.Db4o.Tests.Common.Soda.Wrapper.Untyped.STIntegerWUTestCase identityConstraint
 				 = (Db4objects.Db4o.Tests.Common.Soda.Wrapper.Untyped.STIntegerWUTestCase)set.Next
 				();
@@ -134,15 +136,15 @@ namespace Db4objects.Db4o.Tests.Common.Soda.Wrapper.Untyped
 			q = NewQuery();
 			q.Constrain(identityConstraint).Identity();
 			identityConstraint.i_int = 1;
-			Db4objects.Db4o.Tests.Common.Soda.Util.SodaTestUtil.ExpectOne(q, _array[1]);
+			SodaTestUtil.ExpectOne(q, _array[1]);
 		}
 
 		public virtual void TestNotIdentity()
 		{
-			Db4objects.Db4o.Query.IQuery q = NewQuery();
+			IQuery q = NewQuery();
 			q.Constrain(new Db4objects.Db4o.Tests.Common.Soda.Wrapper.Untyped.STIntegerWUTestCase
 				(1));
-			Db4objects.Db4o.IObjectSet set = q.Execute();
+			IObjectSet set = q.Execute();
 			Db4objects.Db4o.Tests.Common.Soda.Wrapper.Untyped.STIntegerWUTestCase identityConstraint
 				 = (Db4objects.Db4o.Tests.Common.Soda.Wrapper.Untyped.STIntegerWUTestCase)set.Next
 				();
@@ -155,43 +157,40 @@ namespace Db4objects.Db4o.Tests.Common.Soda.Wrapper.Untyped
 
 		public virtual void TestConstraints()
 		{
-			Db4objects.Db4o.Query.IQuery q = NewQuery();
+			IQuery q = NewQuery();
 			q.Constrain(new Db4objects.Db4o.Tests.Common.Soda.Wrapper.Untyped.STIntegerWUTestCase
 				(1));
 			q.Constrain(new Db4objects.Db4o.Tests.Common.Soda.Wrapper.Untyped.STIntegerWUTestCase
 				(0));
-			Db4objects.Db4o.Query.IConstraints cs = q.Constraints();
-			Db4objects.Db4o.Query.IConstraint[] csa = cs.ToArray();
+			IConstraints cs = q.Constraints();
+			IConstraint[] csa = cs.ToArray();
 			if (csa.Length != 2)
 			{
-				Db4oUnit.Assert.Fail("Constraints not returned");
+				Assert.Fail("Constraints not returned");
 			}
 		}
 
 		public virtual void TestEvaluation()
 		{
-			Db4objects.Db4o.Query.IQuery q = NewQuery();
+			IQuery q = NewQuery();
 			q.Constrain(new Db4objects.Db4o.Tests.Common.Soda.Wrapper.Untyped.STIntegerWUTestCase
 				());
-			q.Constrain(new _AnonymousInnerClass137(this));
+			q.Constrain(new _IEvaluation_137());
 			Expect(q, new int[] { 2, 3 });
 		}
 
-		private sealed class _AnonymousInnerClass137 : Db4objects.Db4o.Query.IEvaluation
+		private sealed class _IEvaluation_137 : IEvaluation
 		{
-			public _AnonymousInnerClass137(STIntegerWUTestCase _enclosing)
+			public _IEvaluation_137()
 			{
-				this._enclosing = _enclosing;
 			}
 
-			public void Evaluate(Db4objects.Db4o.Query.ICandidate candidate)
+			public void Evaluate(ICandidate candidate)
 			{
 				Db4objects.Db4o.Tests.Common.Soda.Wrapper.Untyped.STIntegerWUTestCase sti = (Db4objects.Db4o.Tests.Common.Soda.Wrapper.Untyped.STIntegerWUTestCase
 					)candidate.GetObject();
 				candidate.Include((((int)sti.i_int) + 2) > 100);
 			}
-
-			private readonly STIntegerWUTestCase _enclosing;
 		}
 	}
 }
