@@ -1,14 +1,10 @@
-/* Copyright (C) 2004 - 2007  db4objects Inc.  http://www.db4o.com
+/* This file is part of the db4o object database http://www.db4o.com
 
-This file is part of the db4o open source object database.
+Copyright (C) 2004 - 2009  Versant Corporation http://www.versant.com
 
 db4o is free software; you can redistribute it and/or modify it under
-the terms of version 2 of the GNU General Public License as published
-by the Free Software Foundation and as clarified by db4objects' GPL 
-interpretation policy, available at
-http://www.db4o.com/about/company/legalpolicies/gplinterpretation/
-Alternatively you can write to db4objects, Inc., 1900 S Norfolk Street,
-Suite 350, San Mateo, CA 94403, USA.
+the terms of version 3 of the GNU General Public License as published
+by the Free Software Foundation.
 
 db4o is distributed in the hope that it will be useful, but WITHOUT ANY
 WARRANTY; without even the implied warranty of MERCHANTABILITY or
@@ -16,8 +12,7 @@ FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
 for more details.
 
 You should have received a copy of the GNU General Public License along
-with this program; if not, write to the Free Software Foundation, Inc.,
-59 Temple Place - Suite 330, Boston, MA  02111-1307, USA. */
+with this program.  If not, see http://www.gnu.org/licenses/. */
 using System;
 using System.IO;
 using System.Reflection;
@@ -26,7 +21,7 @@ using Db4oUnit;
 
 namespace Db4objects.Db4o.Tests.CLI1
 {
-#if !CF_1_0 && !CF_2_0
+#if !CF
     /// <summary>
     /// This test emits an assembly with a version in one app domain
     /// and then unloads it.
@@ -36,7 +31,7 @@ namespace Db4objects.Db4o.Tests.CLI1
     /// </summary>
     public class CsAssemblyVersionChange : ITestCase
     {
-        const string TestAssemblyName = "test.exe";
+        const string TestAssemblyName = "test.dll";
 
         protected static readonly string DataFile = Path.Combine(Path.GetTempPath(), "test.yap");
 
@@ -108,24 +103,22 @@ namespace Db4objects.Db4o.Tests.CLI1
             }
         }
 
-        void CopyNecessaryAssembliesTo(string basePath)
+        static void CopyNecessaryAssembliesTo(string basePath)
         {
-            CopyToDir(typeof(Db4oFactory).Assembly.Location, basePath);
-            CopyToDir(typeof(Db4oUnit.Assert).Assembly.Location, basePath);
-            CopyToDir(Assembly.GetExecutingAssembly().Location, basePath);
+        	IOServices.CopyEnclosingAssemblyTo(typeof(Db4oFactory), basePath);
+			IOServices.CopyEnclosingAssemblyTo(typeof(Db4oUnit.Assert), basePath);
+            CopyTo(Assembly.GetExecutingAssembly().Location, basePath);
         }
 
-        void CopyToDir(string fname, string dir)
+    	static void CopyTo(string fname, string dir)
         {
-            File.Copy(fname, Path.Combine(dir, Path.GetFileName(fname)), true);
+            IOServices.CopyTo(fname, dir);
         }
 
         string BaseCode
         {
             get
             {
-#if NET_2_0
-                #region .NET 2.0 version
                 return @"
 using System;
 using System.IO;
@@ -173,54 +166,6 @@ public class Tester
 	}
 }
             ";
-                #endregion
-#else
-                #region .NET 1.1 version
-				return @"
-using System;
-using System.IO;
-using Db4objects.Db4o;
-
-public class ST
-{
-	public int value;
-
-	public ST(int value)
-	{
-		this.value = value;
-	}
-}
-
-public class Tester
-{
-	public static void Store(string fname)
-	{
-		using (IObjectContainer container = Db4oFactory.OpenFile(fname))
-		{
-			container.Set(new ST(42));
-		}
-	}
-	
-	public static void Load(string fname)
-	{
-		using (IObjectContainer container = Db4oFactory.OpenFile(fname))
-		{
-			IObjectSet os = container.Get(typeof(ST));
-			AssertEquals(1, os.Size());
-		}
-	}
-	
-	static void AssertEquals(object expected, object actual)
-	{
-		if (!Object.Equals(expected, actual))
-		{
-			throw new ApplicationException();
-		}
-	}
-}
-            ";
-                #endregion
-#endif
 
             }
         }
