@@ -1,14 +1,10 @@
-/* Copyright (C) 2004 - 2007  db4objects Inc.  http://www.db4o.com
+/* This file is part of the db4o object database http://www.db4o.com
 
-This file is part of the db4o open source object database.
+Copyright (C) 2004 - 2009  Versant Corporation http://www.versant.com
 
 db4o is free software; you can redistribute it and/or modify it under
-the terms of version 2 of the GNU General Public License as published
-by the Free Software Foundation and as clarified by db4objects' GPL 
-interpretation policy, available at
-http://www.db4o.com/about/company/legalpolicies/gplinterpretation/
-Alternatively you can write to db4objects, Inc., 1900 S Norfolk Street,
-Suite 350, San Mateo, CA 94403, USA.
+the terms of version 3 of the GNU General Public License as published
+by the Free Software Foundation.
 
 db4o is distributed in the hope that it will be useful, but WITHOUT ANY
 WARRANTY; without even the implied warranty of MERCHANTABILITY or
@@ -16,15 +12,16 @@ FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
 for more details.
 
 You should have received a copy of the GNU General Public License along
-with this program; if not, write to the Free Software Foundation, Inc.,
-59 Temple Place - Suite 330, Boston, MA  02111-1307, USA. */
+with this program.  If not, see http://www.gnu.org/licenses/. */
 using System.Collections;
 using System.Reflection;
 using System.Text;
-using Db4objects.Db4o.Nativequery.Expr;
-using Db4objects.Db4o.Nativequery.Optimization;
+using Db4objects.Db4o.Foundation;
+using Db4objects.Db4o.Instrumentation.Cecil;
+using Db4objects.Db4o.NativeQueries.Expr;
+using Db4objects.Db4o.NativeQueries.Optimization;
 using Db4objects.Db4o.Query;
-using Db4objects.Db4o.Tools.NativeQueries;
+using Db4objects.Db4o.NativeQueries;
 using Db4oUnit;
 using Db4oUnit.Extensions;
 
@@ -45,16 +42,8 @@ namespace Db4objects.Db4o.Tests.CLI1.NativeQueries
 		}
 
 		private string ToString(IEnumerable os)
-		{	
-			StringBuilder buffer = new StringBuilder();
-			buffer.Append('[');
-			foreach (object item in os)
-			{
-				if (buffer.Length > 1) buffer.Append(", ");
-				buffer.Append(item.ToString());
-			}
-			buffer.Append(']');
-			return buffer.ToString();
+		{
+			return Iterators.ToString(os.GetEnumerator());
 		}
 
 		private IQuery QueryFromPredicate(object predicate)
@@ -62,7 +51,7 @@ namespace Db4objects.Db4o.Tests.CLI1.NativeQueries
 			MethodInfo match = predicate.GetType().GetMethod("Match");
 			IExpression expression = (new QueryExpressionBuilder ()).FromMethod(match);
 			IQuery q = NewQuery(match.GetParameters()[0].ParameterType);
-			new SODAQueryBuilder().OptimizeQuery(expression, q, predicate);
+			new SODAQueryBuilder().OptimizeQuery(expression, q, predicate, new Db4objects.Db4o.Instrumentation.Core.DefaultNativeClassFactory(), new CecilReferenceResolver());
 			return q;
 		}
 	}
