@@ -1,14 +1,10 @@
-/* Copyright (C) 2004 - 2007  db4objects Inc.  http://www.db4o.com
+/* This file is part of the db4o object database http://www.db4o.com
 
-This file is part of the db4o open source object database.
+Copyright (C) 2004 - 2009  Versant Corporation http://www.versant.com
 
 db4o is free software; you can redistribute it and/or modify it under
-the terms of version 2 of the GNU General Public License as published
-by the Free Software Foundation and as clarified by db4objects' GPL 
-interpretation policy, available at
-http://www.db4o.com/about/company/legalpolicies/gplinterpretation/
-Alternatively you can write to db4objects, Inc., 1900 S Norfolk Street,
-Suite 350, San Mateo, CA 94403, USA.
+the terms of version 3 of the GNU General Public License as published
+by the Free Software Foundation.
 
 db4o is distributed in the hope that it will be useful, but WITHOUT ANY
 WARRANTY; without even the implied warranty of MERCHANTABILITY or
@@ -16,8 +12,7 @@ FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
 for more details.
 
 You should have received a copy of the GNU General Public License along
-with this program; if not, write to the Free Software Foundation, Inc.,
-59 Temple Place - Suite 330, Boston, MA  02111-1307, USA. */
+with this program.  If not, see http://www.gnu.org/licenses/. */
 using System.Collections;
 using Db4objects.Db4o.Query;
 using Db4oUnit;
@@ -133,17 +128,17 @@ namespace Db4objects.Db4o.Tests.CLI1.NativeQueries.Cats
 		public void RunTests()
 		{
 			Expect(new NoneFound());
-			Expect(new AgeOne(), "Occam", "Vahiné");
+			Expect(new AgeOne(), "Occam", "Vahin\u00E9");
 			Expect(new FatherAgeOne(), "Achat", "Acrobat");
 			Expect(new GrandFatherName(), "Achat", "Acrobat");
 			Expect(new OrFatherName(), "Achat", "Acrobat", "Occam");
-			Expect(new AddToAge(), "Occam", "Vahiné");
+			Expect(new AddToAge(), "Occam", "Vahin\u00E9");
 			Expect(new TwoGetters(), "Occam");
 			Expect(new CalculatedGetter(), "Achat");
 			Expect(new GetterNull());
 			Expect(new StartsWith(), "Achat", "Acrobat");
 
-#if NET_2_0
+#if !CF
 
 			Expect<Cat>(delegate(Cat cat)
 			{
@@ -152,7 +147,7 @@ namespace Db4objects.Db4o.Tests.CLI1.NativeQueries.Cats
 			Expect<Cat>(delegate(Cat cat)
 			{
 				return cat._age == 1;
-			}, "Occam", "Vahiné");
+			}, "Occam", "Vahin\u00E9");
 			Expect<Cat>(delegate(Cat cat)
 			{
 				return cat._father._age == 1;
@@ -170,7 +165,7 @@ namespace Db4objects.Db4o.Tests.CLI1.NativeQueries.Cats
 			Expect<Cat>(delegate(Cat cat)
 			{
 				return cat._age + 1 == 2;
-			}, "Occam", "Vahiné");
+			}, "Occam", "Vahin\u00E9");
 			Expect<Cat>(delegate(Cat cat)
 			{
 				return cat.GetFirstName() == "Occam"
@@ -204,20 +199,20 @@ namespace Db4objects.Db4o.Tests.CLI1.NativeQueries.Cats
 			Cat bachi = new Cat();
 			bachi._sex = Animal.FEMALE;
 			bachi._firstName = "Frau Bachmann";
-			bachi._lastName = "von der Bärenhöhle";
+			bachi._lastName = "von der B\u00E4renh\u00F6hle";
 			bachi._age = 10;
 
 			Cat occam = new Cat();
 			occam._sex = Animal.MALE;
 			occam._firstName = "Occam";
-			occam._lastName = "von der Bärenhöhle";
+			occam._lastName = "von der B\u00E4renh\u00F6hle";
 			occam._age = 1;
 			occam._father = winni;
 			occam._mother = bachi;
 
 			Cat zora = new Cat();
 			zora._sex = Animal.FEMALE;
-			zora._firstName = "Vahiné";
+			zora._firstName = "Vahin\u00E9";
 			zora._lastName = "des Fauves et Or";
 			zora._age = 1;
 
@@ -248,7 +243,7 @@ namespace Db4objects.Db4o.Tests.CLI1.NativeQueries.Cats
 			Expect(Db().Query(predicate), names);
 		}
 
-#if NET_2_0
+#if !CF
 		private void Expect<Extent>(System.Predicate<Extent> match, params string[] names)
 		{
 			System.Collections.Generic.IList<Extent> list = Db().Query(match);
