@@ -1,14 +1,10 @@
-/* Copyright (C) 2004 - 2007  db4objects Inc.  http://www.db4o.com
+/* This file is part of the db4o object database http://www.db4o.com
 
-This file is part of the db4o open source object database.
+Copyright (C) 2004 - 2009  Versant Corporation http://www.versant.com
 
 db4o is free software; you can redistribute it and/or modify it under
-the terms of version 2 of the GNU General Public License as published
-by the Free Software Foundation and as clarified by db4objects' GPL 
-interpretation policy, available at
-http://www.db4o.com/about/company/legalpolicies/gplinterpretation/
-Alternatively you can write to db4objects, Inc., 1900 S Norfolk Street,
-Suite 350, San Mateo, CA 94403, USA.
+the terms of version 3 of the GNU General Public License as published
+by the Free Software Foundation.
 
 db4o is distributed in the hope that it will be useful, but WITHOUT ANY
 WARRANTY; without even the implied warranty of MERCHANTABILITY or
@@ -16,8 +12,7 @@ FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
 for more details.
 
 You should have received a copy of the GNU General Public License along
-with this program; if not, write to the Free Software Foundation, Inc.,
-59 Temple Place - Suite 330, Boston, MA  02111-1307, USA. */
+with this program.  If not, see http://www.gnu.org/licenses/. */
 namespace Db4objects.Db4o.Tests.CLI2.Assorted
 {
 	using System;
@@ -28,7 +23,6 @@ namespace Db4objects.Db4o.Tests.CLI2.Assorted
 	using Db4oUnit;
 	using Db4oUnit.Extensions;
 
-#if NET_2_0 || CF_2_0
 	class NullableContainer
 	{
 		public int? intValue = null;
@@ -44,17 +38,15 @@ namespace Db4objects.Db4o.Tests.CLI2.Assorted
 			dateValue = value;
 		}
 	}
-#endif
 
 	class NullableTypes : AbstractDb4oTestCase
 	{
-#if NET_2_0 || CF_2_0
 		static readonly DateTime TheDate = new DateTime(1983, 3, 7);
 
 		protected override void Store()
 		{
-			Db().Set(new NullableContainer(42));
-			Db().Set(new NullableContainer(TheDate));
+			Db().Store(new NullableContainer(42));
+			Db().Store(new NullableContainer(TheDate));
 		}
 
 		public void TestGlobalQuery()
@@ -76,7 +68,7 @@ namespace Db4objects.Db4o.Tests.CLI2.Assorted
 					Assert.IsFalse(item.dateValue.HasValue);
 					foundInt = true;
 				}
-				else
+				else if (item.dateValue.HasValue)
 				{
 					Assert.AreEqual(TheDate, item.dateValue.Value);
 					Assert.IsFalse(item.intValue.HasValue);
@@ -134,6 +126,5 @@ namespace Db4objects.Db4o.Tests.CLI2.Assorted
 		{
 			Assert.IsFalse(value.HasValue, "!nullable.HasValue");
 		}
-#endif
 	}
 }
