@@ -1,14 +1,10 @@
-/* Copyright (C) 2004 - 2007  db4objects Inc.  http://www.db4o.com
+/* This file is part of the db4o object database http://www.db4o.com
 
-This file is part of the db4o open source object database.
+Copyright (C) 2004 - 2009  Versant Corporation http://www.versant.com
 
 db4o is free software; you can redistribute it and/or modify it under
-the terms of version 2 of the GNU General Public License as published
-by the Free Software Foundation and as clarified by db4objects' GPL 
-interpretation policy, available at
-http://www.db4o.com/about/company/legalpolicies/gplinterpretation/
-Alternatively you can write to db4objects, Inc., 1900 S Norfolk Street,
-Suite 350, San Mateo, CA 94403, USA.
+the terms of version 3 of the GNU General Public License as published
+by the Free Software Foundation.
 
 db4o is distributed in the hope that it will be useful, but WITHOUT ANY
 WARRANTY; without even the implied warranty of MERCHANTABILITY or
@@ -16,15 +12,13 @@ FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
 for more details.
 
 You should have received a copy of the GNU General Public License along
-with this program; if not, write to the Free Software Foundation, Inc.,
-59 Temple Place - Suite 330, Boston, MA  02111-1307, USA. */
+with this program.  If not, see http://www.gnu.org/licenses/. */
 using Db4objects.Db4o.Query;
 using Db4oUnit;
 using Db4oUnit.Extensions;
 
 namespace Db4objects.Db4o.Tests.CLI2.Assorted
 {
-#if NET_2_0 || CF_2_0
 	class SimpleGenericType<T>
 	{
 		public T value;
@@ -34,11 +28,9 @@ namespace Db4objects.Db4o.Tests.CLI2.Assorted
 			this.value = value;
 		}
 	}
-#endif
 
 	class SimpleGenericTypeTestCase : AbstractDb4oTestCase
 	{
-#if NET_2_0 || CF_2_0
 		override protected void Store()
 		{
 			Store(new SimpleGenericType<string>("Will it work?"));
@@ -55,11 +47,11 @@ namespace Db4objects.Db4o.Tests.CLI2.Assorted
 		{
 			IQuery query = NewQuery(typeof(SimpleGenericType<T>));
 
-			EnsureGenericItem<T>(expectedValue, query.Execute());
+			EnsureGenericItem(expectedValue, query.Execute());
 
 			query = NewQuery(typeof(SimpleGenericType<T>));
 			query.Descend("value").Constrain(expectedValue);
-			EnsureGenericItem<T>(expectedValue, query.Execute());
+			EnsureGenericItem(expectedValue, query.Execute());
 		}
 
 		private static void EnsureGenericItem<T>(T expectedValue, IObjectSet os)
@@ -69,6 +61,5 @@ namespace Db4objects.Db4o.Tests.CLI2.Assorted
 			SimpleGenericType<T> item = (SimpleGenericType<T>)os.Next();
 			Assert.AreEqual(expectedValue, item.value);
 		}
-#endif
 	}
 }
