@@ -1,14 +1,10 @@
-/* Copyright (C) 2004 - 2007  db4objects Inc.  http://www.db4o.com
+/* This file is part of the db4o object database http://www.db4o.com
 
-This file is part of the db4o open source object database.
+Copyright (C) 2004 - 2009  Versant Corporation http://www.versant.com
 
 db4o is free software; you can redistribute it and/or modify it under
-the terms of version 2 of the GNU General Public License as published
-by the Free Software Foundation and as clarified by db4objects' GPL 
-interpretation policy, available at
-http://www.db4o.com/about/company/legalpolicies/gplinterpretation/
-Alternatively you can write to db4objects, Inc., 1900 S Norfolk Street,
-Suite 350, San Mateo, CA 94403, USA.
+the terms of version 3 of the GNU General Public License as published
+by the Free Software Foundation.
 
 db4o is distributed in the hope that it will be useful, but WITHOUT ANY
 WARRANTY; without even the implied warranty of MERCHANTABILITY or
@@ -16,11 +12,9 @@ FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
 for more details.
 
 You should have received a copy of the GNU General Public License along
-with this program; if not, write to the Free Software Foundation, Inc.,
-59 Temple Place - Suite 330, Boston, MA  02111-1307, USA. */
+with this program.  If not, see http://www.gnu.org/licenses/. */
 namespace Db4objects.Db4o.Tests.CLI2.Collections
 {
-#if NET_2_0 || CF_2_0
     using System;
     using System.Collections;
     using System.Collections.Generic;
@@ -54,10 +48,10 @@ namespace Db4objects.Db4o.Tests.CLI2.Collections
 			dh3._name = "identity";
 			dh3.CreateDicts();
         	
-        	Db().Set(dh1);
-			Db().Set(dh2);
-			Db().Set(dh1_2);
-			Db().Set(dh3);
+        	Db().Store(dh1);
+			Db().Store(dh2);
+			Db().Store(dh1_2);
+			Db().Store(dh3);
         }
     	
     	public void TestQuery()
@@ -150,10 +144,10 @@ namespace Db4objects.Db4o.Tests.CLI2.Collections
 
         public void StoreDicts(IObjectContainer oc)
         {
-            oc.Set(nDict1);
-            oc.Set(nDict2);
-            oc.Set(gDict1);
-            oc.Set(gDict2);
+            oc.Store(nDict1);
+            oc.Store(nDict2);
+            oc.Store(gDict1);
+            oc.Store(gDict2);
         }
 
         public void CheckDictsBeforeUpdate()
@@ -361,6 +355,4 @@ namespace Db4objects.Db4o.Tests.CLI2.Collections
     {
         string Name();
     }
-
-#endif
 }
