@@ -1,14 +1,10 @@
-/* Copyright (C) 2004 - 2007  db4objects Inc.  http://www.db4o.com
+/* This file is part of the db4o object database http://www.db4o.com
 
-This file is part of the db4o open source object database.
+Copyright (C) 2004 - 2009  Versant Corporation http://www.versant.com
 
 db4o is free software; you can redistribute it and/or modify it under
-the terms of version 2 of the GNU General Public License as published
-by the Free Software Foundation and as clarified by db4objects' GPL 
-interpretation policy, available at
-http://www.db4o.com/about/company/legalpolicies/gplinterpretation/
-Alternatively you can write to db4objects, Inc., 1900 S Norfolk Street,
-Suite 350, San Mateo, CA 94403, USA.
+the terms of version 3 of the GNU General Public License as published
+by the Free Software Foundation.
 
 db4o is distributed in the hope that it will be useful, but WITHOUT ANY
 WARRANTY; without even the implied warranty of MERCHANTABILITY or
@@ -16,8 +12,7 @@ FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
 for more details.
 
 You should have received a copy of the GNU General Public License along
-with this program; if not, write to the Free Software Foundation, Inc.,
-59 Temple Place - Suite 330, Boston, MA  02111-1307, USA. */
+with this program.  If not, see http://www.gnu.org/licenses/. */
 namespace Db4objects.Db4o.Tests.SharpenLang
 {
     using System;
@@ -25,9 +20,6 @@ namespace Db4objects.Db4o.Tests.SharpenLang
     using System.Reflection;
     using Db4oUnit;
     using Sharpen.Lang;
-
-#if NET_2_0
-
     using System.Collections.Generic;
 
     class SimpleGenericType<T>
@@ -50,7 +42,6 @@ namespace Db4objects.Db4o.Tests.SharpenLang
             this.Second = second;
         }
     }
-#endif
 
     class TypeReferenceTestCase : ITestCase
     {
@@ -80,9 +71,7 @@ namespace Db4objects.Db4o.Tests.SharpenLang
 			TypeReference voidPointer = TypeReference.FromString("System.Void*");
 			Assert.AreEqual("System.Void", voidPointer.SimpleName);
 			Assert.IsTrue(voidPointer is PointerTypeReference);
-#if !CF_1_0
             Assert.AreEqual(Type.GetType("System.Void*", true), voidPointer.Resolve());
-#endif
         }
 
         public void TestNestedType()
@@ -149,7 +138,7 @@ namespace Db4objects.Db4o.Tests.SharpenLang
             EnsureRoundtrip(typeof(byte[][]));
         }
 
-#if (MONO || CF_1_0)
+#if MONO
         public void _TestJaggedXDArray() { 
 #else
 		public void TestJaggedXDArray() 
@@ -158,14 +147,15 @@ namespace Db4objects.Db4o.Tests.SharpenLang
             EnsureRoundtrip(typeof(byte[][][,]));
         }
 
-
-
-#if NET_2_0
         class NestedGeneric<Key, Value>
         {
         }
 
+#if CF
+		public void _TestDeepGenericTypeName()
+#else
         public void TestDeepGenericTypeName()
+#endif
         {
             EnsureRoundtrip(typeof(Dictionary<string, List<string>>));
             EnsureRoundtrip(typeof(Dictionary<string, List<List<string>>>));
@@ -242,6 +232,5 @@ namespace Db4objects.Db4o.Tests.SharpenLang
     	{
     		return Assembly.GetExecutingAssembly().GetName().Name;
     	}
-#endif
     }
 }
\ No newline at end of file
