@@ -1,14 +1,10 @@
-/* Copyright (C) 2004 - 2007  db4objects Inc.  http://www.db4o.com
+/* This file is part of the db4o object database http://www.db4o.com
 
-This file is part of the db4o open source object database.
+Copyright (C) 2004 - 2009  Versant Corporation http://www.versant.com
 
 db4o is free software; you can redistribute it and/or modify it under
-the terms of version 2 of the GNU General Public License as published
-by the Free Software Foundation and as clarified by db4objects' GPL 
-interpretation policy, available at
-http://www.db4o.com/about/company/legalpolicies/gplinterpretation/
-Alternatively you can write to db4objects, Inc., 1900 S Norfolk Street,
-Suite 350, San Mateo, CA 94403, USA.
+the terms of version 3 of the GNU General Public License as published
+by the Free Software Foundation.
 
 db4o is distributed in the hope that it will be useful, but WITHOUT ANY
 WARRANTY; without even the implied warranty of MERCHANTABILITY or
@@ -16,11 +12,10 @@ FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
 for more details.
 
 You should have received a copy of the GNU General Public License along
-with this program; if not, write to the Free Software Foundation, Inc.,
-59 Temple Place - Suite 330, Boston, MA  02111-1307, USA. */
+with this program.  If not, see http://www.gnu.org/licenses/. */
 namespace Db4objects.Db4o.Tests.Util
 {
-#if !CF_1_0 && !CF_2_0
+#if !CF
 	using System;
 	using System.CodeDom.Compiler;
 	using System.IO;
@@ -33,12 +28,21 @@ namespace Db4objects.Db4o.Tests.Util
 	public class CompilationServices
 	{
 		public static void EmitAssembly(string assemblyFileName, params string[] code)
+		{
+			string[] references = {
+				typeof(Db4oFactory).Module.FullyQualifiedName,
+				typeof(CompilationServices).Module.FullyQualifiedName 
+			};
+			EmitAssembly(assemblyFileName, references, code);
+		}
+
+		public static void EmitAssembly(string assemblyFileName, string[] references, params string[] code)
 		{
 			string basePath = Path.GetDirectoryName(assemblyFileName);
 			CreateDirectoryIfNeeded(basePath);
 
 			string[] sourceFiles = WriteSourceFiles(Path.GetTempPath(), code);
-			CompileFiles(assemblyFileName, sourceFiles);
+			CompileFiles(assemblyFileName, references, sourceFiles);
 		}
 
 		public static void CreateDirectoryIfNeeded(string directory)
@@ -69,7 +73,7 @@ namespace Db4objects.Db4o.Tests.Util
 			}
 		}
 
-#if NET_2_0
+#if !CF
 		static CompilerInfo GetCSharpCompilerInfo()
 		{
 			return CodeDomProvider.GetCompilerInfo(CodeDomProvider.GetLanguageFromExtension(".cs"));
@@ -78,7 +82,7 @@ namespace Db4objects.Db4o.Tests.Util
 
 		static CodeDomProvider GetCSharpCodeDomProvider()
 		{
-#if NET_2_0 && !MONO
+#if !CF && !MONO
 			return GetCSharpCompilerInfo().CreateProvider();
 #else
 			Type provider = typeof(System.Uri).Assembly.GetType("Microsoft.CSharp.CSharpCodeProvider");
@@ -88,32 +92,43 @@ namespace Db4objects.Db4o.Tests.Util
 
 		static CompilerParameters CreateDefaultCompilerParameters()
 		{
-#if NET_2_0 && !MONO
+#if !CF && !MONO
 			return GetCSharpCompilerInfo().CreateDefaultCompilerParameters();
 #else
 			return new CompilerParameters();
 #endif
 		}
 
-		public static void CompileFiles(string assemblyFName, string[] files)
-		{	
+		public static void CompileFiles(string assemblyFName, string[] references, string[] files)
+		{
 			using (CodeDomProvider provider = GetCSharpCodeDomProvider())
 			{
 				CompilerParameters parameters = CreateDefaultCompilerParameters();
 				parameters.IncludeDebugInformation = false;
 				parameters.OutputAssembly = assemblyFName;
-				parameters.ReferencedAssemblies.Add(typeof(Db4oFactory).Module.FullyQualifiedName);
-				parameters.ReferencedAssemblies.Add(typeof(CompilationServices).Module.FullyQualifiedName);
+				parameters.ReferencedAssemblies.AddRange(references);
 
 				ICodeCompiler compiler = provider.CreateCompiler();
 				CompilerResults results = compiler.CompileAssemblyFromFileBatch(parameters, files);
-				if (results.Errors.Count > 0)
-				{
-					throw new ApplicationException(GetErrorString(results.Errors));
-				}
+                if(ContainsErrors(results.Errors))
+                {
+                    throw new ApplicationException(GetErrorString(results.Errors));
+                }
 			}
 		}
 
+        private static Boolean ContainsErrors(CompilerErrorCollection errors)
+        {
+            foreach (CompilerError error in errors)
+            {
+                if (! error.IsWarning)
+                {
+                    return true;
+                }
+            }
+            return false;
+        }
+
 		static string GetErrorString(CompilerErrorCollection errors)
 		{
 			StringBuilder builder = new StringBuilder();
