@@ -1,14 +1,10 @@
-/* Copyright (C) 2004 - 2007  db4objects Inc.  http://www.db4o.com
+/* This file is part of the db4o object database http://www.db4o.com
 
-This file is part of the db4o open source object database.
+Copyright (C) 2004 - 2009  Versant Corporation http://www.versant.com
 
 db4o is free software; you can redistribute it and/or modify it under
-the terms of version 2 of the GNU General Public License as published
-by the Free Software Foundation and as clarified by db4objects' GPL 
-interpretation policy, available at
-http://www.db4o.com/about/company/legalpolicies/gplinterpretation/
-Alternatively you can write to db4objects, Inc., 1900 S Norfolk Street,
-Suite 350, San Mateo, CA 94403, USA.
+the terms of version 3 of the GNU General Public License as published
+by the Free Software Foundation.
 
 db4o is distributed in the hope that it will be useful, but WITHOUT ANY
 WARRANTY; without even the implied warranty of MERCHANTABILITY or
@@ -16,8 +12,7 @@ FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
 for more details.
 
 You should have received a copy of the GNU General Public License along
-with this program; if not, write to the Free Software Foundation, Inc.,
-59 Temple Place - Suite 330, Boston, MA  02111-1307, USA. */
+with this program.  If not, see http://www.gnu.org/licenses/. */
 using System;
 using System.IO;
 using Db4oUnit;
@@ -28,12 +23,40 @@ namespace Db4objects.Db4o.Tests.Util
 	{
 		public static string JavacPath()
 		{
-			string path = ReadProperty(MachinePropertiesPath(), "file.compiler.jdk1.3");
-			Assert.IsTrue(File.Exists(path));
+            return ReadMachinePathProperty("file.compiler.jdk1.3");
+		}
+		
+		public static string JavaPath()
+		{
+			return ReadMachinePathProperty("file.jvm.jdk1.5");
+		}
+		
+		public static string ReadMachineProperty(string property)
+		{
+			return ReadProperty(MachinePropertiesPath(), property);
+		}
+		
+		public static string ReadMachinePathProperty(string property)
+		{
+			string path = ReadMachineProperty(property);
+			Assert.IsTrue(File.Exists(path), string.Format("File '{0}' could not be found ({1}).", path, property));
 			return path;
 		}
 
-		public static string ReadProperty(string fname, string property)
+		public static string ReadProperty(string fname, string property) 
+		{
+			return ReadProperty(fname, property, false);
+		}
+
+		public static string ReadProperty(string fname, string property, bool lenient)
+		{
+			string value = FindProperty(fname, property);
+			if (value != null) return value;
+			if (lenient) return null;
+			throw new ArgumentException("property '" + property + "' not found in '" + fname + "'");
+		}
+
+		private static string FindProperty(string fname, string property)
 		{
 			using (StreamReader reader = File.OpenText(fname))
 			{
@@ -46,22 +69,17 @@ namespace Db4objects.Db4o.Tests.Util
 					}
 				}
 			}
-			throw new ArgumentException("property '" + property + "' not found in '" + fname + "'");
+			return null;
 		}
 
 		public static string MachinePropertiesPath()
 		{
-			string path = WorkspacePath("db4obuild/machine.properties");
+			string fileName = Sharpen.Runtime.GetEnvironmentVariable("DB4O_MACHINE_PROPERTIES", "machine.properties");
+			string path = WorkspacePath("db4obuild/" + fileName);
 			Assert.IsTrue(File.Exists(path));
 			return path;
 		}
 
-		public static String Db4ojarPath()
-		{
-			string db4oVersion = string.Format("{0}.{1}", Db4oVersion.MAJOR, Db4oVersion.MINOR);
-			return WorkspacePath("db4obuild/dist/java/lib/db4o-" + db4oVersion + "-java1.2.jar");
-		}
-
 		public static string WorkspacePath(string fname)
 		{
 			string root = WorkspaceRoot;
@@ -70,7 +88,7 @@ namespace Db4objects.Db4o.Tests.Util
 		
 		public static string WorkspaceTestFilePath(string fname)
 		{
-			string testFolder = WorkspaceLocations.TEST_FOLDER;
+			string testFolder = WorkspaceLocations.TestFolder;
 			if (testFolder == null) return null;
 			return Path.Combine(testFolder, fname);
 		}
