@@ -1,14 +1,10 @@
-/* Copyright (C) 2004 - 2007  db4objects Inc.  http://www.db4o.com
+/* This file is part of the db4o object database http://www.db4o.com
 
-This file is part of the db4o open source object database.
+Copyright (C) 2004 - 2009  Versant Corporation http://www.versant.com
 
 db4o is free software; you can redistribute it and/or modify it under
-the terms of version 2 of the GNU General Public License as published
-by the Free Software Foundation and as clarified by db4objects' GPL 
-interpretation policy, available at
-http://www.db4o.com/about/company/legalpolicies/gplinterpretation/
-Alternatively you can write to db4objects, Inc., 1900 S Norfolk Street,
-Suite 350, San Mateo, CA 94403, USA.
+the terms of version 3 of the GNU General Public License as published
+by the Free Software Foundation.
 
 db4o is distributed in the hope that it will be useful, but WITHOUT ANY
 WARRANTY; without even the implied warranty of MERCHANTABILITY or
@@ -16,8 +12,12 @@ FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
 for more details.
 
 You should have received a copy of the GNU General Public License along
-with this program; if not, write to the Free Software Foundation, Inc.,
-59 Temple Place - Suite 330, Boston, MA  02111-1307, USA. */
+with this program.  If not, see http://www.gnu.org/licenses/. */
+using System;
+using Db4objects.Db4o;
+using Db4objects.Db4o.Internal.Cluster;
+using Db4objects.Db4o.Query;
+
 namespace Db4objects.Db4o.Cluster
 {
 	/// <summary>allows running Queries against multiple ObjectContainers.</summary>
@@ -25,23 +25,27 @@ namespace Db4objects.Db4o.Cluster
 	/// <exclude></exclude>
 	public class Cluster
 	{
-		public readonly Db4objects.Db4o.IObjectContainer[] _objectContainers;
+		public readonly IObjectContainer[] _objectContainers;
 
-		public Cluster(Db4objects.Db4o.IObjectContainer[] objectContainers)
+		/// <summary>
+		/// use this constructor to create a Cluster and call
+		/// add() to add ObjectContainers
+		/// </summary>
+		public Cluster(IObjectContainer[] objectContainers)
 		{
 			if (objectContainers == null)
 			{
-				throw new System.ArgumentNullException();
+				throw new ArgumentNullException();
 			}
 			if (objectContainers.Length < 1)
 			{
-				throw new System.ArgumentException();
+				throw new ArgumentException();
 			}
 			for (int i = 0; i < objectContainers.Length; i++)
 			{
 				if (objectContainers[i] == null)
 				{
-					throw new System.ArgumentException();
+					throw new ArgumentException();
 				}
 			}
 			_objectContainers = objectContainers;
@@ -56,17 +60,16 @@ namespace Db4objects.Db4o.Cluster
 		/// this Cluster.
 		/// </remarks>
 		/// <returns>the Query</returns>
-		public virtual Db4objects.Db4o.Query.IQuery Query()
+		public virtual IQuery Query()
 		{
 			lock (this)
 			{
-				Db4objects.Db4o.Query.IQuery[] queries = new Db4objects.Db4o.Query.IQuery[_objectContainers
-					.Length];
+				IQuery[] queries = new IQuery[_objectContainers.Length];
 				for (int i = 0; i < _objectContainers.Length; i++)
 				{
 					queries[i] = _objectContainers[i].Query();
 				}
-				return new Db4objects.Db4o.Internal.Cluster.ClusterQuery(this, queries);
+				return new ClusterQuery(this, queries);
 			}
 		}
 
@@ -77,7 +80,7 @@ namespace Db4objects.Db4o.Cluster
 		/// </summary>
 		/// <param name="obj">the object</param>
 		/// <returns>the ObjectContainer</returns>
-		public virtual Db4objects.Db4o.IObjectContainer ObjectContainerFor(object obj)
+		public virtual IObjectContainer ObjectContainerFor(object obj)
 		{
 			lock (this)
 			{
