@@ -1,14 +1,10 @@
-/* Copyright (C) 2004 - 2007  db4objects Inc.  http://www.db4o.com
+/* This file is part of the db4o object database http://www.db4o.com
 
-This file is part of the db4o open source object database.
+Copyright (C) 2004 - 2009  Versant Corporation http://www.versant.com
 
 db4o is free software; you can redistribute it and/or modify it under
-the terms of version 2 of the GNU General Public License as published
-by the Free Software Foundation and as clarified by db4objects' GPL 
-interpretation policy, available at
-http://www.db4o.com/about/company/legalpolicies/gplinterpretation/
-Alternatively you can write to db4objects, Inc., 1900 S Norfolk Street,
-Suite 350, San Mateo, CA 94403, USA.
+the terms of version 3 of the GNU General Public License as published
+by the Free Software Foundation.
 
 db4o is distributed in the hope that it will be useful, but WITHOUT ANY
 WARRANTY; without even the implied warranty of MERCHANTABILITY or
@@ -16,23 +12,24 @@ FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
 for more details.
 
 You should have received a copy of the GNU General Public License along
-with this program; if not, write to the Free Software Foundation, Inc.,
-59 Temple Place - Suite 330, Boston, MA  02111-1307, USA. */
+with this program.  If not, see http://www.gnu.org/licenses/. */
+using Db4objects.Db4o.Config;
+
 namespace Db4objects.Db4o.Config
 {
 	/// <summary>configuration interface for classes.</summary>
 	/// <remarks>
 	/// configuration interface for classes.
-	/// <br /><br /><b>Examples: ../com/db4o/samples/translators/Default.java.</b><br /><br />
+	/// <br/><br/>
 	/// Use the global Configuration object to configure db4o before opening an
-	/// <see cref="Db4objects.Db4o.IObjectContainer">ObjectContainer</see>
-	/// .<br /><br />
-	/// <b>Example:</b><br />
+	/// <see cref="IObjectContainer">IObjectContainer</see>
+	/// .<br/><br/>
+	/// <b>Example:</b><br/>
 	/// <code>
-	/// Configuration config = Db4o.configure();<br />
-	/// ObjectClass oc = config.objectClass("package.className");<br />
-	/// oc.updateDepth(3);<br />
-	/// oc.minimumActivationDepth(3);<br />
+	/// IConfiguration config = Db4oFactory.Configure();<br/>
+	/// IObjectClass oc = config.ObjectClass("Namespace.ClassName");<br/>
+	/// oc.UpdateDepth(3);<br/>
+	/// oc.MinimumActivationDepth(3);<br/>
 	/// </code>
 	/// </remarks>
 	public interface IObjectClass
@@ -56,6 +53,9 @@ namespace Db4objects.Db4o.Config
 		/// <see cref="Db4objects.Db4o.Config.IConfiguration.CallConstructors">Db4objects.Db4o.Config.IConfiguration.CallConstructors
 		/// 	</see>
 		/// .<br /><br />
+		/// In client-server environment this setting should be used on both
+		/// client and server. <br /><br />
+		/// This setting can be applied to an open object container. <br /><br />
 		/// </remarks>
 		/// <param name="flag">
 		/// - specify true, to request calling constructors, specify
@@ -73,6 +73,9 @@ namespace Db4objects.Db4o.Config
 		/// of all member objects if an instance of this class is activated.
 		/// <br /><br />
 		/// The default setting is <b>false</b>.<br /><br />
+		/// In client-server environment this setting should be used on both
+		/// client and server. <br /><br />
+		/// Can be applied to an open ObjectContainer.<br /><br />
 		/// </remarks>
 		/// <param name="flag">whether activation is to be cascaded to member objects.</param>
 		/// <seealso cref="Db4objects.Db4o.Config.IObjectField.CascadeOnActivate">Db4objects.Db4o.Config.IObjectField.CascadeOnActivate
@@ -98,7 +101,7 @@ namespace Db4objects.Db4o.Config
 		/// <b>Caution !</b><br />
 		/// This setting will also trigger deletion of old member objects, on
 		/// calls to
-		/// <see cref="Db4objects.Db4o.IObjectContainer.Set">Db4objects.Db4o.IObjectContainer.Set
+		/// <see cref="Db4objects.Db4o.IObjectContainer.Store">Db4objects.Db4o.IObjectContainer.Store
 		/// 	</see>
 		/// .<br /><br />
 		/// An example of the behaviour:<br />
@@ -115,6 +118,9 @@ namespace Db4objects.Db4o.Config
 		/// to bar1.
 		/// <br /><br />
 		/// The default setting is <b>false</b>.<br /><br />
+		/// In client-server environment this setting should be used on both
+		/// client and server. <br /><br />
+		/// This setting can be applied to an open object container. <br /><br />
 		/// </remarks>
 		/// <param name="flag">whether deletes are to be cascaded to member objects.</param>
 		/// <seealso cref="Db4objects.Db4o.Config.IObjectField.CascadeOnDelete">Db4objects.Db4o.Config.IObjectField.CascadeOnDelete
@@ -131,10 +137,13 @@ namespace Db4objects.Db4o.Config
 		/// Setting cascadeOnUpdate to true will result in the update
 		/// of all member objects if a stored instance of this class is passed
 		/// to
-		/// <see cref="Db4objects.Db4o.IObjectContainer.Set">Db4objects.Db4o.IObjectContainer.Set
+		/// <see cref="Db4objects.Db4o.IObjectContainer.Store">Db4objects.Db4o.IObjectContainer.Store
 		/// 	</see>
 		/// .<br /><br />
 		/// The default setting is <b>false</b>.<br /><br />
+		/// In client-server environment this setting should be used on both
+		/// client and server. <br /><br />
+		/// This setting can be applied to an open object container. <br /><br />
 		/// </remarks>
 		/// <param name="flag">whether updates are to be cascaded to member objects.</param>
 		/// <seealso cref="Db4objects.Db4o.Config.IObjectField.CascadeOnUpdate">Db4objects.Db4o.Config.IObjectField.CascadeOnUpdate
@@ -149,13 +158,13 @@ namespace Db4objects.Db4o.Config
 		/// registers an attribute provider for special query behavior.
 		/// <br /><br />The query processor will compare the object returned by the
 		/// attribute provider instead of the actual object, both for the constraint
-		/// and the candidate persistent object.<br /><br /> Preinstalled attribute
-		/// providers are documented
-		/// in the sourcecode of
-		/// com.db4o.samples.translators.Default.java#defaultConfiguration().<br /><br />
+		/// and the candidate persistent object.<br /><br />
+		/// In client-server environment this setting should be used on both
+		/// client and server. <br /><br />
 		/// </remarks>
 		/// <param name="attributeProvider">the attribute provider to be used</param>
-		void Compare(Db4objects.Db4o.Config.IObjectAttribute attributeProvider);
+		[System.ObsoleteAttribute(@"since version 7.0")]
+		void Compare(IObjectAttribute attributeProvider);
 
 		/// <summary>
 		/// Must be called before databases are created or opened
@@ -171,12 +180,18 @@ namespace Db4objects.Db4o.Config
 		void EnableReplication(bool setting);
 
 		/// <summary>generate UUIDs for stored objects of this class.</summary>
-		/// <remarks>generate UUIDs for stored objects of this class.</remarks>
+		/// <remarks>
+		/// generate UUIDs for stored objects of this class.
+		/// This setting should be used before the database is first created.<br /><br />
+		/// </remarks>
 		/// <param name="setting"></param>
 		void GenerateUUIDs(bool setting);
 
 		/// <summary>generate version numbers for stored objects of this class.</summary>
-		/// <remarks>generate version numbers for stored objects of this class.</remarks>
+		/// <remarks>
+		/// generate version numbers for stored objects of this class.
+		/// This setting should be used before the database is first created.<br /><br />
+		/// </remarks>
 		/// <param name="setting"></param>
 		void GenerateVersionNumbers(bool setting);
 
@@ -192,51 +207,22 @@ namespace Db4objects.Db4o.Config
 		/// - The application always works with subclasses or superclasses.<br />
 		/// - There are convenient field indexes that will always find instances
 		/// of a class.<br />
-		/// - The application always works with IDs.
+		/// - The application always works with IDs.<br /><br />
+		/// In client-server environment this setting should be used on both
+		/// client and server. <br /><br />
+		/// This setting can be applied to an open object container. <br /><br />
 		/// </remarks>
 		void Indexed(bool flag);
 
-		/// <summary>registers a custom marshaller for this class.</summary>
-		/// <remarks>
-		/// registers a custom marshaller for this class.
-		/// <br /><br />
-		/// Custom marshallers can be used for tuning the performance to store
-		/// and read objects. Instead of letting db4o do all the marshalling
-		/// by detecting the fields on a class and by using reflection, a
-		/// custom
-		/// <see cref="Db4objects.Db4o.Config.IObjectMarshaller">ObjectMarshaller</see>
-		/// allows the
-		/// application developer to write the logic how the fields of an
-		/// object are converted to a byte[] and back.
-		/// <br /><br />Downside:<br />
-		/// - Indexes and querying can not be used.
-		/// <br /><br />Upsides:<br />
-		/// - Not all fields need to be stored.<br />
-		/// - Reflection does not need to be called.<br />
-		/// <br /><br />As an alternative to using a custom marshallers you may
-		/// want to consider writing an
-		/// <see cref="Db4objects.Db4o.Config.IObjectTranslator">ObjectTranslator</see>
-		/// or your own
-		/// <see cref="Db4objects.Db4o.Reflect.IReflector">Reflector</see>
-		/// .
-		/// <br /><br />The use of an
-		/// <see cref="Db4objects.Db4o.Config.IObjectMarshaller">ObjectMarshaller</see>
-		/// is not
-		/// compatible with the use of an
-		/// <see cref="Db4objects.Db4o.Config.IObjectTranslator">ObjectTranslator</see>
-		/// .<br /><br />
-		/// </remarks>
-		/// <param name="marshaller">to be used for this class</param>
-		/// <seealso cref="Db4objects.Db4o.Config.IObjectMarshaller">Db4objects.Db4o.Config.IObjectMarshaller
-		/// 	</seealso>
-		void MarshallWith(Db4objects.Db4o.Config.IObjectMarshaller marshaller);
-
 		/// <summary>sets the maximum activation depth to the desired value.</summary>
 		/// <remarks>
 		/// sets the maximum activation depth to the desired value.
 		/// <br /><br />A class specific setting overrides the
 		/// <see cref="Db4objects.Db4o.Config.IConfiguration.ActivationDepth">global setting</see>
 		/// <br /><br />
+		/// In client-server environment this setting should be used on both
+		/// client and server. <br /><br />
+		/// This setting can be applied to an open object container. <br /><br />
 		/// </remarks>
 		/// <param name="depth">the desired maximum activation depth</param>
 		/// <seealso cref="Db4objects.Db4o.Config.IConfiguration.ActivationDepth">Why activation?
@@ -251,6 +237,9 @@ namespace Db4objects.Db4o.Config
 		/// <br /><br />A class specific setting overrides the
 		/// <see cref="Db4objects.Db4o.Config.IConfiguration.ActivationDepth">global setting</see>
 		/// <br /><br />
+		/// In client-server environment this setting should be used on both
+		/// client and server. <br /><br />
+		/// This setting can be applied to an open object container. <br /><br />
 		/// </remarks>
 		/// <param name="depth">the desired minimum activation depth</param>
 		/// <seealso cref="Db4objects.Db4o.Config.IConfiguration.ActivationDepth">Why activation?
@@ -259,9 +248,18 @@ namespace Db4objects.Db4o.Config
 		/// 	</seealso>
 		void MinimumActivationDepth(int depth);
 
+		/// <summary>gets the configured minimum activation depth.</summary>
+		/// <remarks>
+		/// gets the configured minimum activation depth.
+		/// In client-server environment this setting should be used on both
+		/// client and server. <br /><br />
+		/// </remarks>
+		/// <returns>the configured minimum activation depth.</returns>
+		int MinimumActivationDepth();
+
 		/// <summary>
 		/// returns an
-		/// <see cref="Db4objects.Db4o.Config.IObjectField">ObjectField</see>
+		/// <see cref="Db4objects.Db4o.Config.IObjectField">IObjectField</see>
 		/// object
 		/// to configure the specified field.
 		/// <br /><br />
@@ -269,10 +267,10 @@ namespace Db4objects.Db4o.Config
 		/// <param name="fieldName">the fieldname of the field to be configured.<br /><br /></param>
 		/// <returns>
 		/// an instance of an
-		/// <see cref="Db4objects.Db4o.Config.IObjectField">ObjectField</see>
+		/// <see cref="Db4objects.Db4o.Config.IObjectField">IObjectField</see>
 		/// object for configuration.
 		/// </returns>
-		Db4objects.Db4o.Config.IObjectField ObjectField(string fieldName);
+		IObjectField ObjectField(string fieldName);
 
 		/// <summary>turns on storing static field values for this class.</summary>
 		/// <remarks>
@@ -297,6 +295,9 @@ namespace Db4objects.Db4o.Config
 		/// <br /><br />Use this setting for constant static object members.
 		/// <br /><br />This option will slow down the process of opening database
 		/// files and the stored objects will occupy space in the database file.
+		/// <br /><br />In client-server environment this setting should be used on both
+		/// client and server. <br /><br />
+		/// This setting can NOT be applied to an open object container. <br /><br />
 		/// </remarks>
 		void PersistStaticFieldValues();
 
@@ -315,13 +316,16 @@ namespace Db4objects.Db4o.Config
 		/// information for clazz.
 		/// </remarks>
 		/// <param name="clazz">class name, Class object, or example object.<br /><br /></param>
+		[System.ObsoleteAttribute(@"use")]
 		void ReadAs(object clazz);
 
 		/// <summary>renames a stored class.</summary>
 		/// <remarks>
 		/// renames a stored class.
 		/// <br /><br />Use this method to refactor classes.
-		/// <br /><br /><b>Examples: ../com/db4o/samples/rename.</b><br /><br />
+		/// <br /><br />In client-server environment this setting should be used on both
+		/// client and server. <br /><br />
+		/// This setting can NOT be applied to an open object container. <br /><br />
 		/// </remarks>
 		/// <param name="newName">the new fully qualified classname.</param>
 		void Rename(string newName);
@@ -330,6 +334,9 @@ namespace Db4objects.Db4o.Config
 		/// <remarks>
 		/// allows to specify if transient fields are to be stored.
 		/// <br />The default for every class is <code>false</code>.<br /><br />
+		/// In client-server environment this setting should be used on both
+		/// client and server. <br /><br />
+		/// This setting can be applied to an open object container. <br /><br />
 		/// </remarks>
 		/// <param name="flag">whether or not transient fields are to be stored.</param>
 		void StoreTransientFields(bool flag);
@@ -338,39 +345,40 @@ namespace Db4objects.Db4o.Config
 		/// <remarks>
 		/// registers a translator for this class.
 		/// <br /><br />
-		/// Preinstalled translators are documented in the sourcecode of
-		/// com.db4o.samples.translators.Default.java#defaultConfiguration().
-		/// <br /><br />Example translators can also be found in this folder.<br /><br />
 		/// <br /><br />The use of an
-		/// <see cref="Db4objects.Db4o.Config.IObjectTranslator">ObjectTranslator</see>
+		/// <see cref="Db4objects.Db4o.Config.IObjectTranslator">IObjectTranslator</see>
 		/// is not
 		/// compatible with the use of an
-		/// <see cref="Db4objects.Db4o.Config.IObjectMarshaller">ObjectMarshaller</see>
-		/// .<br /><br />
+		/// internal class ObjectMarshaller.<br /><br />
+		/// In client-server environment this setting should be used on both
+		/// client and server. <br /><br />
+		/// This setting can be applied to an open object container. <br /><br />
 		/// </remarks>
 		/// <param name="translator">
 		/// this may be an
-		/// <see cref="Db4objects.Db4o.Config.IObjectTranslator">ObjectTranslator</see>
+		/// <see cref="Db4objects.Db4o.Config.IObjectTranslator">IObjectTranslator</see>
 		/// or an
-		/// <see cref="Db4objects.Db4o.Config.IObjectConstructor">ObjectConstructor</see>
+		/// <see cref="Db4objects.Db4o.Config.IObjectConstructor">IObjectConstructor</see>
 		/// </param>
 		/// <seealso cref="Db4objects.Db4o.Config.IObjectTranslator">Db4objects.Db4o.Config.IObjectTranslator
 		/// 	</seealso>
 		/// <seealso cref="Db4objects.Db4o.Config.IObjectConstructor">Db4objects.Db4o.Config.IObjectConstructor
 		/// 	</seealso>
-		void Translate(Db4objects.Db4o.Config.IObjectTranslator translator);
+		void Translate(IObjectTranslator translator);
 
 		/// <summary>specifies the updateDepth for this class.</summary>
 		/// <remarks>
 		/// specifies the updateDepth for this class.
 		/// <br /><br />see the documentation of
-		/// <see cref="Db4objects.Db4o.IObjectContainer.Set">Db4objects.Db4o.IObjectContainer.Set
+		/// <see cref="Db4objects.Db4o.IObjectContainer.Store">Db4objects.Db4o.IObjectContainer.Store
 		/// 	</see>
 		/// for further details.<br /><br />
 		/// The default setting is 0: Only the object passed to
-		/// <see cref="Db4objects.Db4o.IObjectContainer.Set">Db4objects.Db4o.IObjectContainer.Set
+		/// <see cref="Db4objects.Db4o.IObjectContainer.Store">Db4objects.Db4o.IObjectContainer.Store
 		/// 	</see>
 		/// will be updated.<br /><br />
+		/// In client-server environment this setting should be used on both
+		/// client and server. <br /><br />
 		/// </remarks>
 		/// <param name="depth">the depth of the desired update for this class.</param>
 		/// <seealso cref="Db4objects.Db4o.Config.IConfiguration.UpdateDepth">Db4objects.Db4o.Config.IConfiguration.UpdateDepth
