@@ -1,14 +1,10 @@
-/* Copyright (C) 2004 - 2007  db4objects Inc.  http://www.db4o.com
+/* This file is part of the db4o object database http://www.db4o.com
 
-This file is part of the db4o open source object database.
+Copyright (C) 2004 - 2009  Versant Corporation http://www.versant.com
 
 db4o is free software; you can redistribute it and/or modify it under
-the terms of version 2 of the GNU General Public License as published
-by the Free Software Foundation and as clarified by db4objects' GPL 
-interpretation policy, available at
-http://www.db4o.com/about/company/legalpolicies/gplinterpretation/
-Alternatively you can write to db4objects, Inc., 1900 S Norfolk Street,
-Suite 350, San Mateo, CA 94403, USA.
+the terms of version 3 of the GNU General Public License as published
+by the Free Software Foundation.
 
 db4o is distributed in the hope that it will be useful, but WITHOUT ANY
 WARRANTY; without even the implied warranty of MERCHANTABILITY or
@@ -16,24 +12,24 @@ FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
 for more details.
 
 You should have received a copy of the GNU General Public License along
-with this program; if not, write to the Free Software Foundation, Inc.,
-59 Temple Place - Suite 330, Boston, MA  02111-1307, USA. */
+with this program.  If not, see http://www.gnu.org/licenses/. */
 namespace Db4objects.Db4o.Config
 {
 	/// <summary>configuration interface for fields of classes.</summary>
 	/// <remarks>
 	/// configuration interface for fields of classes.
-	/// <br /><br /><b>Examples: ../com/db4o/samples/translators.</b><br /><br />
+	/// <br/><br/>
 	/// Use the global Configuration object to configure db4o before opening an
-	/// <see cref="Db4objects.Db4o.IObjectContainer">ObjectContainer</see>
-	/// .<br /><br />
-	/// <b>Example:</b><br />
+	/// <see cref="IObjectContainer">IObjectContainer</see>
+	/// .<br/><br/>
+	/// <b>Example:</b><br/>
 	/// <code>
-	/// Configuration config = Db4o.configure();<br />
-	/// ObjectClass oc = config.objectClass("package.className");<br />
-	/// ObjectField of = oc.objectField("fieldName");
-	/// of.rename("newFieldName");
-	/// of.queryEvaluation(false);
+	/// IConfiguration config = Db4oFactory.Configure();<br/>
+	/// IObjectClass oc = config.ObjectClass("Namespace.ClassName");<br/>
+	/// IObjectField of = oc.ObjectField("fieldName");
+	/// of.Rename("newFieldName");
+	/// of.QueryEvaluation(false);
+	/// 
 	/// </code>
 	/// </remarks>
 	public interface IObjectField
@@ -47,6 +43,9 @@ namespace Db4objects.Db4o.Config
 		/// is activated.
 		/// <br /><br />
 		/// The default setting is <b>false</b>.<br /><br />
+		/// In client-server environment this setting should be used on both
+		/// client and server. <br /><br />
+		/// This setting can be applied to an open object container. <br /><br />
 		/// </remarks>
 		/// <param name="flag">whether activation is to be cascaded to the member object.</param>
 		/// <seealso cref="Db4objects.Db4o.Config.IConfiguration.ActivationDepth">Why activation?
@@ -65,19 +64,23 @@ namespace Db4objects.Db4o.Config
 		/// Setting cascadeOnDelete to true will result in the deletion of
 		/// the object attribute stored in this field on the parent object
 		/// if the parent object is passed to
-		/// <see cref="Db4objects.Db4o.IObjectContainer.Delete">ObjectContainer#delete()</see>
+		/// <see cref="Db4objects.Db4o.IObjectContainer.Delete">Db4objects.Db4o.IObjectContainer.Delete
+		/// 	</see>
 		/// .
 		/// <br /><br />
 		/// <b>Caution !</b><br />
 		/// This setting will also trigger deletion of the old member object, on
 		/// calls to
-		/// <see cref="Db4objects.Db4o.IObjectContainer.Set">ObjectContainer#set()</see>
+		/// <see cref="Db4objects.Db4o.IObjectContainer.Set"></see>
 		/// .
 		/// An example of the behaviour can be found in
-		/// <see cref="Db4objects.Db4o.Config.IObjectClass.CascadeOnDelete">ObjectClass#cascadeOnDelete()
+		/// <see cref="Db4objects.Db4o.Config.IObjectClass.CascadeOnDelete">Db4objects.Db4o.Config.IObjectClass.CascadeOnDelete
 		/// 	</see>
 		/// <br /><br />
 		/// The default setting is <b>false</b>.<br /><br />
+		/// In client-server environment this setting should be used on both
+		/// client and server. <br /><br />
+		/// This setting can be applied to an open object container. <br /><br />
 		/// </remarks>
 		/// <param name="flag">whether deletes are to be cascaded to the member object.</param>
 		/// <seealso cref="Db4objects.Db4o.Config.IObjectClass.CascadeOnDelete">Db4objects.Db4o.Config.IObjectClass.CascadeOnDelete
@@ -94,10 +97,14 @@ namespace Db4objects.Db4o.Config
 		/// Setting cascadeOnUpdate to true will result in the update
 		/// of the object attribute stored in this field if the parent object
 		/// is passed to
-		/// <see cref="Db4objects.Db4o.IObjectContainer.Set">ObjectContainer#set()</see>
+		/// <see cref="Db4objects.Db4o.IObjectContainer.Set">Db4objects.Db4o.IObjectContainer.Set
+		/// 	</see>
 		/// .
 		/// <br /><br />
 		/// The default setting is <b>false</b>.<br /><br />
+		/// In client-server environment this setting should be used on both
+		/// client and server. <br /><br />
+		/// This setting can be applied to an open object container. <br /><br />
 		/// </remarks>
 		/// <param name="flag">whether updates are to be cascaded to the member object.</param>
 		/// <seealso cref="Db4objects.Db4o.IObjectContainer.Set">Db4objects.Db4o.IObjectContainer.Set
@@ -122,6 +129,10 @@ namespace Db4objects.Db4o.Config
 		/// setting is set to <code>true</code> and an index does not exist, the index will be
 		/// created. If the setting is set to <code>false</code> and an index does exist the
 		/// index will be dropped.<br /><br />
+		/// In client-server environment this setting should be used on both
+		/// client and server. <br /><br />
+		/// If this setting is applied to an open ObjectContainer it will take an effect on the next
+		/// time ObjectContainer is opened.<br /><br />
 		/// </remarks>
 		/// <param name="flag">
 		/// specify <code>true</code> or <code>false</code> to turn indexing on for
@@ -133,7 +144,10 @@ namespace Db4objects.Db4o.Config
 		/// <remarks>
 		/// renames a field of a stored class.
 		/// <br /><br />Use this method to refactor classes.
-		/// <br /><br /><b>Examples: ../com/db4o/samples/rename.</b><br /><br />
+		/// <br /><br />
+		/// In client-server environment this setting should be used on both
+		/// client and server. <br /><br />
+		/// This setting can NOT be applied to an open object container. <br /><br />
 		/// </remarks>
 		/// <param name="newName">the new fieldname.</param>
 		void Rename(string newName);
@@ -142,7 +156,9 @@ namespace Db4objects.Db4o.Config
 		/// <remarks>
 		/// toggles query evaluation.
 		/// <br /><br />All fields are evaluated by default. Use this method to turn query
-		/// evaluation of for specific fields.<br /><br />
+		/// evaluation off for specific fields.<br /><br />
+		/// In client-server environment this setting should be used on both
+		/// client and server. <br /><br />
 		/// </remarks>
 		/// <param name="flag">specify <code>false</code> to ignore this field during query evaluation.
 		/// 	</param>
