@@ -1,14 +1,10 @@
-/* Copyright (C) 2004 - 2007  db4objects Inc.  http://www.db4o.com
+/* This file is part of the db4o object database http://www.db4o.com
 
-This file is part of the db4o open source object database.
+Copyright (C) 2004 - 2009  Versant Corporation http://www.versant.com
 
 db4o is free software; you can redistribute it and/or modify it under
-the terms of version 2 of the GNU General Public License as published
-by the Free Software Foundation and as clarified by db4objects' GPL 
-interpretation policy, available at
-http://www.db4o.com/about/company/legalpolicies/gplinterpretation/
-Alternatively you can write to db4objects, Inc., 1900 S Norfolk Street,
-Suite 350, San Mateo, CA 94403, USA.
+the terms of version 3 of the GNU General Public License as published
+by the Free Software Foundation.
 
 db4o is distributed in the hope that it will be useful, but WITHOUT ANY
 WARRANTY; without even the implied warranty of MERCHANTABILITY or
@@ -16,8 +12,9 @@ FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
 for more details.
 
 You should have received a copy of the GNU General Public License along
-with this program; if not, write to the Free Software Foundation, Inc.,
-59 Temple Place - Suite 330, Boston, MA  02111-1307, USA. */
+with this program.  If not, see http://www.gnu.org/licenses/. */
+using Db4objects.Db4o.Config;
+
 namespace Db4objects.Db4o.Config
 {
 	/// <summary>interface to configure the querying settings to be used by the query processor.
@@ -132,17 +129,19 @@ namespace Db4objects.Db4o.Config
 		/// 	</see>
 		/// class to this method:<br />
 		/// -
-		/// <see cref="Db4objects.Db4o.Config.QueryEvaluationMode.IMMEDIATE">Db4objects.Db4o.Config.QueryEvaluationMode.IMMEDIATE
+		/// <see cref="Db4objects.Db4o.Config.QueryEvaluationMode.Immediate">Db4objects.Db4o.Config.QueryEvaluationMode.Immediate
 		/// 	</see>
 		/// <br />
 		/// -
-		/// <see cref="Db4objects.Db4o.Config.QueryEvaluationMode.SNAPSHOT">Db4objects.Db4o.Config.QueryEvaluationMode.SNAPSHOT
+		/// <see cref="Db4objects.Db4o.Config.QueryEvaluationMode.Snapshot">Db4objects.Db4o.Config.QueryEvaluationMode.Snapshot
 		/// 	</see>
 		/// <br />
 		/// -
-		/// <see cref="Db4objects.Db4o.Config.QueryEvaluationMode.LAZY">Db4objects.Db4o.Config.QueryEvaluationMode.LAZY
+		/// <see cref="Db4objects.Db4o.Config.QueryEvaluationMode.Lazy">Db4objects.Db4o.Config.QueryEvaluationMode.Lazy
 		/// 	</see>
+		/// <br /><br />
+		/// This setting must be issued from the client side.
 		/// </remarks>
-		void EvaluationMode(Db4objects.Db4o.Config.QueryEvaluationMode mode);
+		void EvaluationMode(QueryEvaluationMode mode);
 	}
 }
