@@ -1,14 +1,10 @@
-/* Copyright (C) 2004 - 2007  db4objects Inc.  http://www.db4o.com
+/* This file is part of the db4o object database http://www.db4o.com
 
-This file is part of the db4o open source object database.
+Copyright (C) 2004 - 2009  Versant Corporation http://www.versant.com
 
 db4o is free software; you can redistribute it and/or modify it under
-the terms of version 2 of the GNU General Public License as published
-by the Free Software Foundation and as clarified by db4objects' GPL 
-interpretation policy, available at
-http://www.db4o.com/about/company/legalpolicies/gplinterpretation/
-Alternatively you can write to db4objects, Inc., 1900 S Norfolk Street,
-Suite 350, San Mateo, CA 94403, USA.
+the terms of version 3 of the GNU General Public License as published
+by the Free Software Foundation.
 
 db4o is distributed in the hope that it will be useful, but WITHOUT ANY
 WARRANTY; without even the implied warranty of MERCHANTABILITY or
@@ -16,8 +12,9 @@ FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
 for more details.
 
 You should have received a copy of the GNU General Public License along
-with this program; if not, write to the Free Software Foundation, Inc.,
-59 Temple Place - Suite 330, Boston, MA  02111-1307, USA. */
+with this program.  If not, see http://www.gnu.org/licenses/. */
+using System;
+
 namespace Db4objects.Db4o.Config
 {
 	/// <summary>
@@ -34,8 +31,11 @@ namespace Db4objects.Db4o.Config
 	/// </remarks>
 	public class QueryEvaluationMode
 	{
-		private QueryEvaluationMode()
+		private readonly string _id;
+
+		private QueryEvaluationMode(string id)
 		{
+			_id = id;
 		}
 
 		/// <summary>Constant for immediate query evaluation.</summary>
@@ -47,8 +47,8 @@ namespace Db4objects.Db4o.Config
 		/// 	</see>
 		/// </b>
 		/// </remarks>
-		public static readonly Db4objects.Db4o.Config.QueryEvaluationMode IMMEDIATE = new 
-			Db4objects.Db4o.Config.QueryEvaluationMode();
+		public static readonly Db4objects.Db4o.Config.QueryEvaluationMode Immediate = new 
+			Db4objects.Db4o.Config.QueryEvaluationMode("IMMEDIATE");
 
 		/// <summary>Constant for snapshot query evaluation.</summary>
 		/// <remarks>
@@ -57,15 +57,15 @@ namespace Db4objects.Db4o.Config
 		/// and creates a snapshot of the index at this point in time. Non-indexed
 		/// constraints are evaluated lazily when the application iterates through
 		/// the
-		/// <see cref="ObjectSet">ObjectSet</see>
+		/// <see cref="Db4objects.Db4o.IObjectSet">Db4objects.Db4o.IObjectSet</see>
 		/// resultset of the query.
 		/// <br /><br /><b>For detailed documentation please see
 		/// <see cref="Db4objects.Db4o.Config.IQueryConfiguration.EvaluationMode">Db4objects.Db4o.Config.IQueryConfiguration.EvaluationMode
 		/// 	</see>
 		/// </b>
 		/// </remarks>
-		public static readonly Db4objects.Db4o.Config.QueryEvaluationMode SNAPSHOT = new 
-			Db4objects.Db4o.Config.QueryEvaluationMode();
+		public static readonly Db4objects.Db4o.Config.QueryEvaluationMode Snapshot = new 
+			Db4objects.Db4o.Config.QueryEvaluationMode("SNAPSHOT");
 
 		/// <summary>Constant for lazy query evaluation.</summary>
 		/// <remarks>
@@ -73,40 +73,45 @@ namespace Db4objects.Db4o.Config
 		/// query processor only chooses the best index and creates an iterator on
 		/// this index. Indexes and constraints are evaluated lazily when the
 		/// application iterates through the
-		/// <see cref="ObjectSet">ObjectSet</see>
+		/// <see cref="Db4objects.Db4o.IObjectSet">Db4objects.Db4o.IObjectSet</see>
 		/// resultset of the query.
 		/// <br /><br /><b>For detailed documentation please see
 		/// <see cref="Db4objects.Db4o.Config.IQueryConfiguration.EvaluationMode">Db4objects.Db4o.Config.IQueryConfiguration.EvaluationMode
 		/// 	</see>
 		/// </b>
 		/// </remarks>
-		public static readonly Db4objects.Db4o.Config.QueryEvaluationMode LAZY = new Db4objects.Db4o.Config.QueryEvaluationMode
-			();
+		public static readonly Db4objects.Db4o.Config.QueryEvaluationMode Lazy = new Db4objects.Db4o.Config.QueryEvaluationMode
+			("LAZY");
 
-		private static readonly Db4objects.Db4o.Config.QueryEvaluationMode[] MODES = new 
+		private static readonly Db4objects.Db4o.Config.QueryEvaluationMode[] Modes = new 
 			Db4objects.Db4o.Config.QueryEvaluationMode[] { Db4objects.Db4o.Config.QueryEvaluationMode
-			.IMMEDIATE, Db4objects.Db4o.Config.QueryEvaluationMode.SNAPSHOT, Db4objects.Db4o.Config.QueryEvaluationMode
-			.LAZY };
+			.Immediate, Db4objects.Db4o.Config.QueryEvaluationMode.Snapshot, Db4objects.Db4o.Config.QueryEvaluationMode
+			.Lazy };
 
 		/// <summary>internal method, ignore please.</summary>
 		/// <remarks>internal method, ignore please.</remarks>
 		public virtual int AsInt()
 		{
-			for (int i = 0; i < MODES.Length; i++)
+			for (int i = 0; i < Modes.Length; i++)
 			{
-				if (MODES[i] == this)
+				if (Modes[i] == this)
 				{
 					return i;
 				}
 			}
-			throw new System.InvalidOperationException();
+			throw new InvalidOperationException();
 		}
 
 		/// <summary>internal method, ignore please.</summary>
 		/// <remarks>internal method, ignore please.</remarks>
 		public static Db4objects.Db4o.Config.QueryEvaluationMode FromInt(int i)
 		{
-			return MODES[i];
+			return Modes[i];
+		}
+
+		public override string ToString()
+		{
+			return _id;
 		}
 	}
 }
