@@ -1,14 +1,10 @@
-/* Copyright (C) 2004 - 2007  db4objects Inc.  http://www.db4o.com
+/* This file is part of the db4o object database http://www.db4o.com
 
-This file is part of the db4o open source object database.
+Copyright (C) 2004 - 2009  Versant Corporation http://www.versant.com
 
 db4o is free software; you can redistribute it and/or modify it under
-the terms of version 2 of the GNU General Public License as published
-by the Free Software Foundation and as clarified by db4objects' GPL 
-interpretation policy, available at
-http://www.db4o.com/about/company/legalpolicies/gplinterpretation/
-Alternatively you can write to db4objects, Inc., 1900 S Norfolk Street,
-Suite 350, San Mateo, CA 94403, USA.
+the terms of version 3 of the GNU General Public License as published
+by the Free Software Foundation.
 
 db4o is distributed in the hope that it will be useful, but WITHOUT ANY
 WARRANTY; without even the implied warranty of MERCHANTABILITY or
@@ -16,8 +12,10 @@ FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
 for more details.
 
 You should have received a copy of the GNU General Public License along
-with this program; if not, write to the Free Software Foundation, Inc.,
-59 Temple Place - Suite 330, Boston, MA  02111-1307, USA. */
+with this program.  If not, see http://www.gnu.org/licenses/. */
+using System;
+using Db4objects.Db4o.Config;
+
 namespace Db4objects.Db4o.Config
 {
 	/// <summary>
@@ -32,40 +30,54 @@ namespace Db4objects.Db4o.Config
 	/// <see cref="Db4objects.Db4o.Config.IAlias">Db4objects.Db4o.Config.IAlias</see>
 	/// for concrete examples.
 	/// </remarks>
-	public class WildcardAlias : Db4objects.Db4o.Config.IAlias
+	public class WildcardAlias : IAlias
 	{
-		private readonly Db4objects.Db4o.Config.WildcardAlias.WildcardPattern _storedPattern;
+		private readonly WildcardAlias.WildcardPattern _storedPattern;
 
-		private readonly Db4objects.Db4o.Config.WildcardAlias.WildcardPattern _runtimePattern;
+		private readonly WildcardAlias.WildcardPattern _runtimePattern;
 
+		/// <summary>
+		/// Create a WildcardAlias with two patterns, the
+		/// stored pattern and the pattern that is to be used
+		/// at runtime.
+		/// </summary>
+		/// <remarks>
+		/// Create a WildcardAlias with two patterns, the
+		/// stored pattern and the pattern that is to be used
+		/// at runtime. One single '*' is allowed as a wildcard
+		/// character.
+		/// </remarks>
 		public WildcardAlias(string storedPattern, string runtimePattern)
 		{
 			if (null == storedPattern)
 			{
-				throw new System.ArgumentNullException("storedPattern");
+				throw new ArgumentNullException("storedPattern");
 			}
 			if (null == runtimePattern)
 			{
-				throw new System.ArgumentNullException("runtimePattern");
+				throw new ArgumentNullException("runtimePattern");
 			}
-			_storedPattern = new Db4objects.Db4o.Config.WildcardAlias.WildcardPattern(storedPattern
-				);
-			_runtimePattern = new Db4objects.Db4o.Config.WildcardAlias.WildcardPattern(runtimePattern
-				);
+			_storedPattern = new WildcardAlias.WildcardPattern(storedPattern);
+			_runtimePattern = new WildcardAlias.WildcardPattern(runtimePattern);
 		}
 
 		/// <summary>resolving is done through simple pattern matching</summary>
 		public virtual string ResolveRuntimeName(string runtimeTypeName)
 		{
-			string match = _runtimePattern.Matches(runtimeTypeName);
-			return match != null ? _storedPattern.Inject(match) : null;
+			return Resolve(_runtimePattern, _storedPattern, runtimeTypeName);
 		}
 
 		/// <summary>resolving is done through simple pattern matching</summary>
 		public virtual string ResolveStoredName(string storedTypeName)
 		{
-			string match = _storedPattern.Matches(storedTypeName);
-			return match != null ? _runtimePattern.Inject(match) : null;
+			return Resolve(_storedPattern, _runtimePattern, storedTypeName);
+		}
+
+		private string Resolve(WildcardAlias.WildcardPattern from, WildcardAlias.WildcardPattern
+			 to, string typeName)
+		{
+			string match = from.Matches(typeName);
+			return match != null ? to.Inject(match) : null;
 		}
 
 		internal class WildcardPattern
@@ -97,7 +109,7 @@ namespace Db4objects.Db4o.Config
 
 			private void InvalidPattern()
 			{
-				throw new System.ArgumentException("only one '*' character");
+				throw new ArgumentException("only one '*' character");
 			}
 
 			internal virtual string[] Split(string pattern)
