@@ -1,14 +1,10 @@
-/* Copyright (C) 2004 - 2007  db4objects Inc.  http://www.db4o.com
+/* This file is part of the db4o object database http://www.db4o.com
 
-This file is part of the db4o open source object database.
+Copyright (C) 2004 - 2009  Versant Corporation http://www.versant.com
 
 db4o is free software; you can redistribute it and/or modify it under
-the terms of version 2 of the GNU General Public License as published
-by the Free Software Foundation and as clarified by db4objects' GPL 
-interpretation policy, available at
-http://www.db4o.com/about/company/legalpolicies/gplinterpretation/
-Alternatively you can write to db4objects, Inc., 1900 S Norfolk Street,
-Suite 350, San Mateo, CA 94403, USA.
+the terms of version 3 of the GNU General Public License as published
+by the Free Software Foundation.
 
 db4o is distributed in the hope that it will be useful, but WITHOUT ANY
 WARRANTY; without even the implied warranty of MERCHANTABILITY or
@@ -16,8 +12,16 @@ FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
 for more details.
 
 You should have received a copy of the GNU General Public License along
-with this program; if not, write to the Free Software Foundation, Inc.,
-59 Temple Place - Suite 330, Boston, MA  02111-1307, USA. */
+with this program.  If not, see http://www.gnu.org/licenses/. */
+using System;
+using Db4objects.Db4o;
+using Db4objects.Db4o.Foundation;
+using Db4objects.Db4o.Internal;
+using Db4objects.Db4o.Internal.Activation;
+using Db4objects.Db4o.Query;
+using Db4objects.Db4o.Types;
+using Sharpen;
+
 namespace Db4objects.Db4o.Ext
 {
 	/// <summary>Class to identify a database by it's signature.</summary>
@@ -28,8 +32,14 @@ namespace Db4objects.Db4o.Ext
 	/// </remarks>
 	/// <persistent></persistent>
 	/// <exclude></exclude>
-	public class Db4oDatabase : Db4objects.Db4o.Types.IDb4oType, Db4objects.Db4o.IInternal4
+	public class Db4oDatabase : IDb4oType, IInternal4
 	{
+		public static readonly Db4objects.Db4o.Ext.Db4oDatabase StaticIdentity = Debug.staticIdentity
+			 ? new Db4objects.Db4o.Ext.Db4oDatabase(new byte[] { (byte)'d', (byte)'e', (byte
+			)'b', (byte)'u', (byte)'g' }, 1) : null;
+
+		public const int StaticId = -1;
+
 		/// <summary>Field is public for implementation reasons, DO NOT TOUCH!</summary>
 		public byte[] i_signature;
 
@@ -43,23 +53,27 @@ namespace Db4objects.Db4o.Ext
 		/// </remarks>
 		public long i_uuid;
 
-		private static readonly string CREATIONTIME_FIELD = "i_uuid";
+		private static readonly string CreationtimeField = "i_uuid";
 
 		/// <summary>cached ObjectContainer for getting the own ID.</summary>
 		/// <remarks>cached ObjectContainer for getting the own ID.</remarks>
 		[System.NonSerialized]
-		private Db4objects.Db4o.Internal.ObjectContainerBase i_stream;
+		private ObjectContainerBase i_stream;
 
 		/// <summary>cached ID, only valid in combination with i_objectContainer</summary>
 		[System.NonSerialized]
 		private int i_id;
 
+		/// <summary>constructor for persistence</summary>
 		public Db4oDatabase()
 		{
 		}
 
+		/// <summary>constructor for comparison and to store new ones</summary>
 		public Db4oDatabase(byte[] signature, long creationTime)
 		{
+			// TODO: change to _creationTime with PersistentFormatUpdater
+			// FIXME: make sure signature is null
 			i_signature = signature;
 			i_uuid = creationTime;
 		}
@@ -68,8 +82,10 @@ namespace Db4objects.Db4o.Ext
 		/// <remarks>generates a new Db4oDatabase object with a unique signature.</remarks>
 		public static Db4objects.Db4o.Ext.Db4oDatabase Generate()
 		{
-			return new Db4objects.Db4o.Ext.Db4oDatabase(Db4objects.Db4o.Internal.Unobfuscated
-				.GenerateSignature(), Sharpen.Runtime.CurrentTimeMillis());
+			StatefulBuffer writer = new StatefulBuffer(null, 300);
+			new LatinStringIO().Write(writer, SignatureGenerator.GenerateSignature());
+			return new Db4objects.Db4o.Ext.Db4oDatabase(writer.GetWrittenBytes(), Runtime.CurrentTimeMillis
+				());
 		}
 
 		/// <summary>comparison by signature.</summary>
@@ -89,8 +105,7 @@ namespace Db4objects.Db4o.Ext
 			{
 				return false;
 			}
-			return Db4objects.Db4o.Foundation.Arrays4.AreEqual(other.i_signature, this.i_signature
-				);
+			return Arrays4.AreEqual(other.i_signature, this.i_signature);
 		}
 
 		public override int GetHashCode()
@@ -101,9 +116,9 @@ namespace Db4objects.Db4o.Ext
 		/// <summary>gets the db4o ID, and may cache it for performance reasons.</summary>
 		/// <remarks>gets the db4o ID, and may cache it for performance reasons.</remarks>
 		/// <returns>the db4o ID for the ObjectContainer</returns>
-		public virtual int GetID(Db4objects.Db4o.Internal.Transaction trans)
+		public virtual int GetID(Transaction trans)
 		{
-			Db4objects.Db4o.Internal.ObjectContainerBase stream = trans.Stream();
+			ObjectContainerBase stream = trans.Container();
 			if (stream != i_stream)
 			{
 				i_stream = stream;
@@ -132,12 +147,18 @@ namespace Db4objects.Db4o.Ext
 		{
 			if (peer == this)
 			{
-				throw new System.ArgumentException();
+				throw new ArgumentException();
 			}
 			if (i_uuid != peer.i_uuid)
 			{
 				return i_uuid < peer.i_uuid;
 			}
+			// the above logic has failed, both are the same
+			// age but we still want to distinguish in some 
+			// way, to have an order in the ReplicationRecord
+			// The following is arbitrary, it only needs to
+			// be repeatable.
+			// Let's distinguish by signature length 
 			if (i_signature.Length != peer.i_signature.Length)
 			{
 				return i_signature.Length < peer.i_signature.Length;
@@ -149,14 +170,17 @@ namespace Db4objects.Db4o.Ext
 					return i_signature[i] < peer.i_signature[i];
 				}
 			}
-			throw new System.Exception();
+			// This should never happen.
+			// FIXME: Add a message and move to Messages.
+			// 
+			throw new Exception();
 		}
 
 		/// <summary>make sure this Db4oDatabase is stored.</summary>
 		/// <remarks>make sure this Db4oDatabase is stored. Return the ID.</remarks>
-		public virtual int Bind(Db4objects.Db4o.Internal.Transaction trans)
+		public virtual int Bind(Transaction trans)
 		{
-			Db4objects.Db4o.Internal.ObjectContainerBase stream = trans.Stream();
+			ObjectContainerBase stream = trans.Container();
 			Db4objects.Db4o.Ext.Db4oDatabase stored = (Db4objects.Db4o.Ext.Db4oDatabase)stream
 				.Db4oTypeStored(trans, this);
 			if (stored == null)
@@ -165,7 +189,7 @@ namespace Db4objects.Db4o.Ext
 			}
 			if (stored == this)
 			{
-				return stream.GetID1(this);
+				return stream.GetID(trans, this);
 			}
 			if (i_uuid == 0)
 			{
@@ -174,8 +198,8 @@ namespace Db4objects.Db4o.Ext
 			stream.ShowInternalClasses(true);
 			try
 			{
-				int id = stream.GetID1(stored);
-				stream.Bind(this, id);
+				int id = stream.GetID(trans, stored);
+				stream.Bind(trans, this, id);
 				return id;
 			}
 			finally
@@ -184,14 +208,14 @@ namespace Db4objects.Db4o.Ext
 			}
 		}
 
-		private int StoreAndGetId(Db4objects.Db4o.Internal.Transaction trans)
+		private int StoreAndGetId(Transaction trans)
 		{
-			Db4objects.Db4o.Internal.ObjectContainerBase stream = trans.Stream();
+			ObjectContainerBase stream = trans.Container();
 			stream.ShowInternalClasses(true);
 			try
 			{
-				stream.Set3(trans, this, 2, false);
-				return stream.GetID1(this);
+				stream.Store3(trans, this, 2, false);
+				return stream.GetID(trans, this);
 			}
 			finally
 			{
@@ -200,36 +224,38 @@ namespace Db4objects.Db4o.Ext
 		}
 
 		/// <summary>find a Db4oDatabase with the same signature as this one</summary>
-		public virtual Db4objects.Db4o.Ext.Db4oDatabase Query(Db4objects.Db4o.Internal.Transaction
-			 trans)
+		public virtual Db4objects.Db4o.Ext.Db4oDatabase Query(Transaction trans)
 		{
+			// showInternalClasses(true);  has to be set for this method to be successful
 			if (i_uuid > 0)
 			{
+				// try fast query over uuid (creation time) first
 				Db4objects.Db4o.Ext.Db4oDatabase res = Query(trans, true);
 				if (res != null)
 				{
 					return res;
 				}
 			}
+			// if not found, try to find with signature
 			return Query(trans, false);
 		}
 
-		private Db4objects.Db4o.Ext.Db4oDatabase Query(Db4objects.Db4o.Internal.Transaction
-			 trans, bool constrainByUUID)
+		private Db4objects.Db4o.Ext.Db4oDatabase Query(Transaction trans, bool constrainByUUID
+			)
 		{
-			Db4objects.Db4o.Internal.ObjectContainerBase stream = trans.Stream();
-			Db4objects.Db4o.Query.IQuery q = stream.Query(trans);
+			ObjectContainerBase stream = trans.Container();
+			IQuery q = stream.Query(trans);
 			q.Constrain(GetType());
 			if (constrainByUUID)
 			{
-				q.Descend(CREATIONTIME_FIELD).Constrain(i_uuid);
+				q.Descend(CreationtimeField).Constrain(i_uuid);
 			}
-			Db4objects.Db4o.IObjectSet objectSet = q.Execute();
+			IObjectSet objectSet = q.Execute();
 			while (objectSet.HasNext())
 			{
 				Db4objects.Db4o.Ext.Db4oDatabase storedDatabase = (Db4objects.Db4o.Ext.Db4oDatabase
 					)objectSet.Next();
-				stream.Activate1(null, storedDatabase, 4);
+				stream.Activate(null, storedDatabase, new FixedActivationDepth(4));
 				if (storedDatabase.Equals(this))
 				{
 					return storedDatabase;
