@@ -1,14 +1,10 @@
-/* Copyright (C) 2004 - 2007  db4objects Inc.  http://www.db4o.com
+/* This file is part of the db4o object database http://www.db4o.com
 
-This file is part of the db4o open source object database.
+Copyright (C) 2004 - 2009  Versant Corporation http://www.versant.com
 
 db4o is free software; you can redistribute it and/or modify it under
-the terms of version 2 of the GNU General Public License as published
-by the Free Software Foundation and as clarified by db4objects' GPL 
-interpretation policy, available at
-http://www.db4o.com/about/company/legalpolicies/gplinterpretation/
-Alternatively you can write to db4objects, Inc., 1900 S Norfolk Street,
-Suite 350, San Mateo, CA 94403, USA.
+the terms of version 3 of the GNU General Public License as published
+by the Free Software Foundation.
 
 db4o is distributed in the hope that it will be useful, but WITHOUT ANY
 WARRANTY; without even the implied warranty of MERCHANTABILITY or
@@ -16,15 +12,14 @@ FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
 for more details.
 
 You should have received a copy of the GNU General Public License along
-with this program; if not, write to the Free Software Foundation, Inc.,
-59 Temple Place - Suite 330, Boston, MA  02111-1307, USA. */
+with this program.  If not, see http://www.gnu.org/licenses/. */
 namespace Db4objects.Db4o.Ext
 {
 	/// <summary>a unique universal identify for an object.</summary>
 	/// <remarks>
 	/// a unique universal identify for an object. <br /><br />The db4o UUID consists of
 	/// two parts:<br /> - an indexed long for fast access,<br /> - the signature of the
-	/// <see cref="Db4objects.Db4o.IObjectContainer">ObjectContainer</see>
+	/// <see cref="Db4objects.Db4o.IObjectContainer">IObjectContainer</see>
 	/// the object was created with.
 	/// <br /><br />Db4oUUIDs are valid representations of objects over multiple
 	/// ObjectContainers
@@ -35,6 +30,9 @@ namespace Db4objects.Db4o.Ext
 
 		private readonly byte[] signaturePart;
 
+		/// <summary>constructs a Db4oUUID from a long part and a signature part</summary>
+		/// <param name="longPart_">the long part</param>
+		/// <param name="signaturePart_">the signature part</param>
 		public Db4oUUID(long longPart_, byte[] signaturePart_)
 		{
 			longPart = longPart_;
@@ -58,7 +56,7 @@ namespace Db4objects.Db4o.Ext
 		/// returns the signature part of this UUID. <br /><br /> <br /><br />To uniquely
 		/// identify an object universally, db4o uses an indexed long and a reference to
 		/// the Db4oDatabase singleton object of the
-		/// <see cref="Db4objects.Db4o.IObjectContainer">ObjectContainer</see>
+		/// <see cref="Db4objects.Db4o.IObjectContainer">IObjectContainer</see>
 		/// it was created on. This method
 		/// returns the signature of the Db4oDatabase object of the ObjectContainer: the
 		/// signature of the origin ObjectContainer.
@@ -109,7 +107,6 @@ namespace Db4objects.Db4o.Ext
 
 		public override string ToString()
 		{
-			return base.ToString();
 			string sig = string.Empty;
 			for (int i = 0; i < signaturePart.Length; i++)
 			{
