@@ -1,14 +1,10 @@
-/* Copyright (C) 2004 - 2007  db4objects Inc.  http://www.db4o.com
+/* This file is part of the db4o object database http://www.db4o.com
 
-This file is part of the db4o open source object database.
+Copyright (C) 2004 - 2009  Versant Corporation http://www.versant.com
 
 db4o is free software; you can redistribute it and/or modify it under
-the terms of version 2 of the GNU General Public License as published
-by the Free Software Foundation and as clarified by db4objects' GPL 
-interpretation policy, available at
-http://www.db4o.com/about/company/legalpolicies/gplinterpretation/
-Alternatively you can write to db4objects, Inc., 1900 S Norfolk Street,
-Suite 350, San Mateo, CA 94403, USA.
+the terms of version 3 of the GNU General Public License as published
+by the Free Software Foundation.
 
 db4o is distributed in the hope that it will be useful, but WITHOUT ANY
 WARRANTY; without even the implied warranty of MERCHANTABILITY or
@@ -16,16 +12,24 @@ FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
 for more details.
 
 You should have received a copy of the GNU General Public License along
-with this program; if not, write to the Free Software Foundation, Inc.,
-59 Temple Place - Suite 330, Boston, MA  02111-1307, USA. */
+with this program.  If not, see http://www.gnu.org/licenses/. */
+using Db4objects.Db4o;
+using Db4objects.Db4o.Config;
+using Db4objects.Db4o.Ext;
+using Db4objects.Db4o.IO;
+using Db4objects.Db4o.Reflect;
+using Db4objects.Db4o.Reflect.Generic;
+using Db4objects.Db4o.Replication;
+using Db4objects.Db4o.Types;
+
 namespace Db4objects.Db4o.Ext
 {
 	/// <summary>
 	/// extended functionality for the
-	/// <see cref="Db4objects.Db4o.IObjectContainer">ObjectContainer</see>
+	/// <see cref="Db4objects.Db4o.IObjectContainer">IObjectContainer</see>
 	/// interface.
 	/// <br /><br />Every db4o
-	/// <see cref="Db4objects.Db4o.IObjectContainer">ObjectContainer</see>
+	/// <see cref="Db4objects.Db4o.IObjectContainer">IObjectContainer</see>
 	/// always is an <code>ExtObjectContainer</code> so a cast is possible.<br /><br />
 	/// <see cref="Db4objects.Db4o.IObjectContainer.Ext">Db4objects.Db4o.IObjectContainer.Ext
 	/// 	</see>
@@ -33,8 +37,50 @@ namespace Db4objects.Db4o.Ext
 	/// The ObjectContainer functionality is split to two interfaces to allow newcomers to
 	/// focus on the essential methods.
 	/// </summary>
-	public interface IExtObjectContainer : Db4objects.Db4o.IObjectContainer
+	public interface IExtObjectContainer : IObjectContainer
 	{
+		/// <summary>activates an object with the current activation strategy.</summary>
+		/// <remarks>
+		/// activates an object with the current activation strategy.
+		/// In regular activation mode the object will be activated to the
+		/// global activation depth, ( see
+		/// <see cref="Db4objects.Db4o.Config.IConfiguration.ActivationDepth">Db4objects.Db4o.Config.IConfiguration.ActivationDepth
+		/// 	</see>
+		/// )
+		/// and all configured settings for
+		/// <see cref="Db4objects.Db4o.Config.IObjectClass.MaximumActivationDepth">Db4objects.Db4o.Config.IObjectClass.MaximumActivationDepth
+		/// 	</see>
+		/// 
+		/// and
+		/// <see cref="Db4objects.Db4o.Config.IObjectClass.MaximumActivationDepth">Db4objects.Db4o.Config.IObjectClass.MaximumActivationDepth
+		/// 	</see>
+		/// will be respected.<br /><br />
+		/// In Transparent Activation Mode ( see
+		/// <see cref="Db4objects.Db4o.TA.TransparentActivationSupport">Db4objects.Db4o.TA.TransparentActivationSupport
+		/// 	</see>
+		/// )
+		/// the parameter object will only be activated, if it does not implement
+		/// <see cref="Db4objects.Db4o.TA.IActivatable">Db4objects.Db4o.TA.IActivatable</see>
+		/// . All referenced members that do not implement
+		/// <see cref="Db4objects.Db4o.TA.IActivatable">Db4objects.Db4o.TA.IActivatable</see>
+		/// will also be activated. Any
+		/// <see cref="Db4objects.Db4o.TA.IActivatable">Db4objects.Db4o.TA.IActivatable</see>
+		/// objects
+		/// along the referenced graph will break cascading activation.
+		/// </remarks>
+		/// <exception cref="Db4objects.Db4o.Ext.Db4oIOException"></exception>
+		/// <exception cref="Db4objects.Db4o.Ext.DatabaseClosedException"></exception>
+		void Activate(object obj);
+
+		/// <summary>deactivates an object.</summary>
+		/// <remarks>
+		/// deactivates an object.
+		/// Only the passed object will be deactivated, i.e, no object referenced by this
+		/// object will be deactivated.
+		/// </remarks>
+		/// <param name="obj">the object to be deactivated.</param>
+		void Deactivate(object obj);
+
 		/// <summary>backs up a database file of an open ObjectContainer.</summary>
 		/// <remarks>
 		/// backs up a database file of an open ObjectContainer.
@@ -43,10 +89,44 @@ namespace Db4objects.Db4o.Ext
 		/// the open ObjectContainer and to the backup.<br /><br />
 		/// While the backup is running, the ObjectContainer should not be closed.<br /><br />
 		/// If a file already exists at the specified path, it will be overwritten.<br /><br />
+		/// The backup call may be started in a seperated thread by the application,
+		/// if concurrent execution with normal database access is desired.<br /><br />
+		/// For backup, the IoAdapter factory configured for the container is used.<br /><br />
 		/// </remarks>
 		/// <param name="path">a fully qualified path</param>
+		/// <exception cref="Db4objects.Db4o.Ext.Db4oIOException">I/O operation failed or was unexpectedly interrupted.
+		/// 	</exception>
+		/// <exception cref="Db4objects.Db4o.Ext.DatabaseClosedException">db4o database file was closed or failed to open.
+		/// 	</exception>
+		/// <exception cref="System.NotSupportedException">
+		/// is thrown when the operation is not supported in current
+		/// configuration/environment
+		/// </exception>
 		void Backup(string path);
 
+		/// <summary>backs up a database file of an open ObjectContainer.</summary>
+		/// <remarks>
+		/// backs up a database file of an open ObjectContainer.
+		/// <br /><br />While the backup is running, the ObjectContainer can continue to be
+		/// used. Changes that are made while the backup is in progress, will be applied to
+		/// the open ObjectContainer and to the backup.<br /><br />
+		/// While the backup is running, the ObjectContainer should not be closed.<br /><br />
+		/// If a file already exists at the specified path, it will be overwritten.<br /><br />
+		/// The backup call may be started in a seperated thread by the application,
+		/// if concurrent execution with normal database access is desired.<br /><br />
+		/// </remarks>
+		/// <param name="path">a fully qualified path</param>
+		/// <param name="targetIo">target IoAdapter factory for backup</param>
+		/// <exception cref="Db4objects.Db4o.Ext.Db4oIOException">I/O operation failed or was unexpectedly interrupted.
+		/// 	</exception>
+		/// <exception cref="Db4objects.Db4o.Ext.DatabaseClosedException">db4o database file was closed or failed to open.
+		/// 	</exception>
+		/// <exception cref="System.NotSupportedException">
+		/// is thrown when the operation is not supported in current
+		/// configuration/environment
+		/// </exception>
+		void Backup(IoAdapter targetIo, string path);
+
 		/// <summary>binds an object to an internal object ID.</summary>
 		/// <remarks>
 		/// binds an object to an internal object ID.
@@ -55,12 +135,14 @@ namespace Db4objects.Db4o.Ext
 		/// reference with the object parameter. The method may be used to replace
 		/// objects or to reassociate an object with it's stored instance
 		/// after closing and opening a database file. A subsequent call to
-		/// <see cref="Db4objects.Db4o.IObjectContainer.Set">set(Object)</see>
+		/// <see cref="Db4objects.Db4o.IObjectContainer.Store">Db4objects.Db4o.IObjectContainer.Store
+		/// 	</see>
 		/// is
 		/// necessary to update the stored object.<br /><br />
 		/// <b>Requirements:</b><br />- The ID needs to be a valid internal object ID,
 		/// previously retrieved with
-		/// <see cref="Db4objects.Db4o.Ext.IExtObjectContainer.GetID">getID(Object)</see>
+		/// <see cref="Db4objects.Db4o.Ext.IExtObjectContainer.GetID">Db4objects.Db4o.Ext.IExtObjectContainer.GetID
+		/// 	</see>
 		/// .<br />
 		/// - The object parameter needs to be of the same class as the stored object.<br /><br />
 		/// </remarks>
@@ -68,6 +150,12 @@ namespace Db4objects.Db4o.Ext
 		/// 	</seealso>
 		/// <param name="obj">the object that is to be bound</param>
 		/// <param name="id">the internal id the object is to be bound to</param>
+		/// <exception cref="Db4objects.Db4o.Ext.DatabaseClosedException">db4o database file was closed or failed to open.
+		/// 	</exception>
+		/// <exception cref="Db4objects.Db4o.Ext.InvalidIDException">
+		/// when the provided id is outside the scope of the
+		/// database IDs.
+		/// </exception>
 		void Bind(object obj, long id);
 
 		/// <summary>
@@ -87,31 +175,34 @@ namespace Db4objects.Db4o.Ext
 		/// <see cref="Db4objects.Db4o.IObjectContainer">Db4objects.Db4o.IObjectContainer</see>
 		/// .
 		/// </returns>
-		Db4objects.Db4o.Types.IDb4oCollections Collections();
+		[System.ObsoleteAttribute(@"since 7.0. Use of old internal collections is discouraged. Please use  com.db4o.collections.ArrayList4 and com.db4o.collections.ArrayMap4 instead."
+			)]
+		IDb4oCollections Collections();
 
 		/// <summary>returns the Configuration context for this ObjectContainer.</summary>
 		/// <remarks>
 		/// returns the Configuration context for this ObjectContainer.
 		/// <br /><br />
 		/// Upon opening an ObjectContainer with any of the factory methods in the
-		/// <see cref="Db4objects.Db4o.Db4oFactory">Db4o class</see>
-		/// , the global
-		/// <see cref="Db4objects.Db4o.Config.IConfiguration">Configuration</see>
+		/// <see cref="Db4objects.Db4o.Db4oFactory">Db4objects.Db4o.Db4oFactory</see>
+		/// class, the global
+		/// <see cref="Db4objects.Db4o.Config.IConfiguration">IConfiguration</see>
 		/// context
 		/// is copied into the ObjectContainer. The
-		/// <see cref="Db4objects.Db4o.Config.IConfiguration">Configuration</see>
+		/// <see cref="Db4objects.Db4o.Config.IConfiguration">IConfiguration</see>
 		/// can be modified individually for
 		/// each ObjectContainer without any effects on the global settings.<br /><br />
 		/// </remarks>
 		/// <returns>
 		/// 
-		/// <see cref="Db4objects.Db4o.Config.IConfiguration">Configuration</see>
+		/// <see cref="Db4objects.Db4o.Config.IConfiguration">Db4objects.Db4o.Config.IConfiguration
+		/// 	</see>
 		/// the Configuration
 		/// context for this ObjectContainer
 		/// </returns>
 		/// <seealso cref="Db4objects.Db4o.Db4oFactory.Configure">Db4objects.Db4o.Db4oFactory.Configure
 		/// 	</seealso>
-		Db4objects.Db4o.Config.IConfiguration Configure();
+		IConfiguration Configure();
 
 		/// <summary>returns a member at the specific path without activating intermediate objects.
 		/// 	</summary>
@@ -131,19 +222,28 @@ namespace Db4objects.Db4o.Ext
 		/// returns the stored object for an internal ID.
 		/// <br /><br />This is the fastest method for direct access to objects. Internal
 		/// IDs can be obtained with
-		/// <see cref="Db4objects.Db4o.Ext.IExtObjectContainer.GetID">getID(Object)</see>
+		/// <see cref="Db4objects.Db4o.Ext.IExtObjectContainer.GetID">Db4objects.Db4o.Ext.IExtObjectContainer.GetID
+		/// 	</see>
 		/// .
 		/// Objects will not be activated by this method. They will be returned in the
 		/// activation state they are currently in, in the local cache.<br /><br />
+		/// To activate the returned object with the current activation strategy, call
+		/// <see cref="Db4objects.Db4o.Ext.IExtObjectContainer.Activate">Db4objects.Db4o.Ext.IExtObjectContainer.Activate
+		/// 	</see>
+		/// .<br /><br />
 		/// </remarks>
-		/// <param name="ID">the internal ID</param>
+		/// <param name="id">the internal ID</param>
 		/// <returns>
 		/// the object associated with the passed ID or <code>null</code>,
 		/// if no object is associated with this ID in this <code>ObjectContainer</code>.
 		/// </returns>
 		/// <seealso cref="Db4objects.Db4o.Config.IConfiguration.ActivationDepth">Why activation?
 		/// 	</seealso>
-		object GetByID(long ID);
+		/// <exception cref="Db4objects.Db4o.Ext.DatabaseClosedException">db4o database file was closed or failed to open.
+		/// 	</exception>
+		/// <exception cref="Db4objects.Db4o.Ext.InvalidIDException">when the provided id is not valid.
+		/// 	</exception>
+		object GetByID(long id);
 
 		/// <summary>
 		/// returns a stored object for a
@@ -168,7 +268,11 @@ namespace Db4objects.Db4o.Ext
 		/// <returns>the object for the UUID</returns>
 		/// <seealso cref="Db4objects.Db4o.Config.IConfiguration.ActivationDepth">Why activation?
 		/// 	</seealso>
-		object GetByUUID(Db4objects.Db4o.Ext.Db4oUUID uuid);
+		/// <exception cref="Db4objects.Db4o.Ext.Db4oIOException">I/O operation failed or was unexpectedly interrupted.
+		/// 	</exception>
+		/// <exception cref="Db4objects.Db4o.Ext.DatabaseClosedException">db4o database file was closed or failed to open.
+		/// 	</exception>
+		object GetByUUID(Db4oUUID uuid);
 
 		/// <summary>returns the internal unique object ID.</summary>
 		/// <remarks>
@@ -177,7 +281,8 @@ namespace Db4objects.Db4o.Ext
 		/// guaranteed to be unique within one <code>ObjectContainer</code>.
 		/// An object carries the same ID in every db4o session. Internal IDs can
 		/// be used to look up objects with the very fast
-		/// <see cref="Db4objects.Db4o.Ext.IExtObjectContainer.GetByID">getByID</see>
+		/// <see cref="Db4objects.Db4o.Ext.IExtObjectContainer.GetByID">Db4objects.Db4o.Ext.IExtObjectContainer.GetByID
+		/// 	</see>
 		/// method.<br /><br />
 		/// Internal IDs will change when a database is defragmented. Use
 		/// <see cref="Db4objects.Db4o.Ext.IExtObjectContainer.GetObjectInfo">Db4objects.Db4o.Ext.IExtObjectContainer.GetObjectInfo
@@ -211,12 +316,15 @@ namespace Db4objects.Db4o.Ext
 		/// <see cref="Db4objects.Db4o.Ext.IObjectInfo">Db4objects.Db4o.Ext.IObjectInfo</see>
 		/// 
 		/// </returns>
-		Db4objects.Db4o.Ext.IObjectInfo GetObjectInfo(object obj);
+		IObjectInfo GetObjectInfo(object obj);
 
-		/// <summary>returns the Db4oDatabase identity object for this ObjectContainer.</summary>
-		/// <remarks>returns the Db4oDatabase identity object for this ObjectContainer.</remarks>
+		/// <summary>
+		/// returns the
+		/// <see cref="Db4objects.Db4o.Ext.Db4oDatabase">Db4objects.Db4o.Ext.Db4oDatabase</see>
+		/// identity object for this ObjectContainer.
+		/// </summary>
 		/// <returns>the Db4oDatabase identity object for this ObjectContainer.</returns>
-		Db4objects.Db4o.Ext.Db4oDatabase Identity();
+		Db4oDatabase Identity();
 
 		/// <summary>tests if an object is activated.</summary>
 		/// <remarks>
@@ -233,8 +341,8 @@ namespace Db4objects.Db4o.Ext
 		/// tests if an object with this ID is currently cached.
 		/// <br /><br />
 		/// </remarks>
-		/// <param name="ID">the internal ID</param>
-		bool IsCached(long ID);
+		/// <param name="id">the internal id</param>
+		bool IsCached(long id);
 
 		/// <summary>tests if this <code>ObjectContainer</code> is closed.</summary>
 		/// <remarks>
@@ -251,6 +359,8 @@ namespace Db4objects.Db4o.Ext
 		/// </remarks>
 		/// <param name="obj">to be tested<br /><br /></param>
 		/// <returns><code>true</code> if the passed object is stored.</returns>
+		/// <exception cref="Db4objects.Db4o.Ext.DatabaseClosedException">db4o database file was closed or failed to open.
+		/// 	</exception>
 		bool IsStored(object obj);
 
 		/// <summary>
@@ -265,7 +375,7 @@ namespace Db4objects.Db4o.Ext
 		/// all class representations that are known to this
 		/// ObjectContainer because they have been used or stored.
 		/// </returns>
-		Db4objects.Db4o.Reflect.IReflectClass[] KnownClasses();
+		IReflectClass[] KnownClasses();
 
 		/// <summary>returns the main synchronisation lock.</summary>
 		/// <remarks>
@@ -277,6 +387,8 @@ namespace Db4objects.Db4o.Ext
 		/// since deadlocks can be produced with just two lines of code.
 		/// </remarks>
 		/// <returns>Object the ObjectContainer lock object</returns>
+		[System.ObsoleteAttribute(@"Use is not recommended. Use your own monitor objects instead."
+			)]
 		object Lock();
 
 		/// <summary>aids migration of objects between ObjectContainers.</summary>
@@ -295,7 +407,7 @@ namespace Db4objects.Db4o.Ext
 		/// objects are to be migrated
 		/// from or <code>null</code> to denote that migration is completed.
 		/// </param>
-		void MigrateFrom(Db4objects.Db4o.IObjectContainer objectContainer);
+		void MigrateFrom(IObjectContainer objectContainer);
 
 		/// <summary>
 		/// returns a transient copy of a persistent object with all members set
@@ -309,7 +421,7 @@ namespace Db4objects.Db4o.Ext
 		/// With the <code>committed</code> parameter it is possible to specify,
 		/// whether the desired object should contain the committed values or the
 		/// values that were set by the running transaction with
-		/// <see cref="Db4objects.Db4o.IObjectContainer.Set">Db4objects.Db4o.IObjectContainer.Set
+		/// <see cref="Db4objects.Db4o.IObjectContainer.Store">Db4objects.Db4o.IObjectContainer.Store
 		/// 	</see>
 		/// .
 		/// <br /><br />A possible usecase for this feature:<br />
@@ -353,7 +465,7 @@ namespace Db4objects.Db4o.Ext
 		/// <summary>Return the reflector currently being used by db4objects.</summary>
 		/// <remarks>Return the reflector currently being used by db4objects.</remarks>
 		/// <returns>the current Reflector.</returns>
-		Db4objects.Db4o.Reflect.Generic.GenericReflector Reflector();
+		GenericReflector Reflector();
 
 		/// <summary>refreshs all members on a stored object to the specified depth.</summary>
 		/// <remarks>
@@ -375,24 +487,6 @@ namespace Db4objects.Db4o.Ext
 		/// <param name="name">the name of the semaphore to be released.</param>
 		void ReleaseSemaphore(string name);
 
-		/// <summary>
-		/// prepares for replication with another
-		/// <see cref="Db4objects.Db4o.IObjectContainer">Db4objects.Db4o.IObjectContainer</see>
-		/// .
-		/// <br /><br />An
-		/// <see cref="Db4objects.Db4o.IObjectContainer">Db4objects.Db4o.IObjectContainer</see>
-		/// can only be involved in a replication
-		/// process with one other
-		/// <see cref="Db4objects.Db4o.IObjectContainer">Db4objects.Db4o.IObjectContainer</see>
-		/// at the same time.<br /><br />
-		/// The returned
-		/// <see cref="Db4objects.Db4o.Replication.IReplicationProcess">Db4objects.Db4o.Replication.IReplicationProcess
-		/// 	</see>
-		/// interface provides methods to commit
-		/// and to cancel the replication process.
-		/// <br /><br />This ObjectContainer will be "peerA" for the
-		/// returned ReplicationProcess. The other ObjectContainer will be "peerB".
-		/// </summary>
 		/// <param name="peerB">
 		/// the
 		/// <see cref="Db4objects.Db4o.IObjectContainer">Db4objects.Db4o.IObjectContainer</see>
@@ -417,23 +511,42 @@ namespace Db4objects.Db4o.Ext
 		/// 	</see>
 		/// interface for this replication process.
 		/// </returns>
-		Db4objects.Db4o.Replication.IReplicationProcess ReplicationBegin(Db4objects.Db4o.IObjectContainer
-			 peerB, Db4objects.Db4o.Replication.IReplicationConflictHandler conflictHandler);
+		[System.ObsoleteAttribute(@"Since db4o-5.2. Use db4o Replication System (dRS) instead.<br><br> prepares for replication with another"
+			)]
+		IReplicationProcess ReplicationBegin(IObjectContainer peerB, IReplicationConflictHandler
+			 conflictHandler);
 
 		/// <summary>deep update interface to store or update objects.</summary>
 		/// <remarks>
 		/// deep update interface to store or update objects.
 		/// <br /><br />In addition to the normal storage interface,
-		/// <see cref="Db4objects.Db4o.IObjectContainer.Set">ObjectContainer#set(Object)</see>
+		/// <see cref="Db4objects.Db4o.IObjectContainer.Store">Db4objects.Db4o.IObjectContainer.Store
+		/// 	</see>
 		/// ,
 		/// this method allows a manual specification of the depth, the passed object is to be updated.<br /><br />
 		/// </remarks>
 		/// <param name="obj">the object to be stored or updated.</param>
 		/// <param name="depth">the depth to which the object is to be updated</param>
-		/// <seealso cref="Db4objects.Db4o.IObjectContainer.Set">Db4objects.Db4o.IObjectContainer.Set
+		/// <seealso cref="Db4objects.Db4o.IObjectContainer.Store">Db4objects.Db4o.IObjectContainer.Store
 		/// 	</seealso>
+		[System.ObsoleteAttribute(@"Use")]
 		void Set(object obj, int depth);
 
+		/// <summary>deep update interface to store or update objects.</summary>
+		/// <remarks>
+		/// deep update interface to store or update objects.
+		/// <br /><br />In addition to the normal storage interface,
+		/// <see cref="Db4objects.Db4o.IObjectContainer.Store">Db4objects.Db4o.IObjectContainer.Store
+		/// 	</see>
+		/// ,
+		/// this method allows a manual specification of the depth, the passed object is to be updated.<br /><br />
+		/// </remarks>
+		/// <param name="obj">the object to be stored or updated.</param>
+		/// <param name="depth">the depth to which the object is to be updated</param>
+		/// <seealso cref="Db4objects.Db4o.IObjectContainer.Store">Db4objects.Db4o.IObjectContainer.Store
+		/// 	</seealso>
+		void Store(object obj, int depth);
+
 		/// <summary>attempts to set a semaphore.</summary>
 		/// <remarks>
 		/// attempts to set a semaphore.
@@ -479,7 +592,7 @@ namespace Db4objects.Db4o.Ext
 		/// <see cref="Db4objects.Db4o.Ext.IExtObjectContainer.GetID">getID(Object)</see>
 		/// <br /> -
 		/// generate a unique client ID. A suggested name:  "CLIENT_" +
-		/// System.currentTimeMillis().<br /><br />
+		/// currentTime.<br /><br />
 		/// </remarks>
 		/// <param name="name">the name of the semaphore to be set</param>
 		/// <param name="waitForAvailability">
@@ -513,14 +626,14 @@ namespace Db4objects.Db4o.Ext
 		/// <see cref="Db4objects.Db4o.Ext.IStoredClass">Db4objects.Db4o.Ext.IStoredClass</see>
 		/// meta information object.
 		/// </returns>
-		Db4objects.Db4o.Ext.IStoredClass StoredClass(object clazz);
+		IStoredClass StoredClass(object clazz);
 
 		/// <summary>
 		/// returns an array of all
 		/// <see cref="Db4objects.Db4o.Ext.IStoredClass">Db4objects.Db4o.Ext.IStoredClass</see>
 		/// meta information objects.
 		/// </summary>
-		Db4objects.Db4o.Ext.IStoredClass[] StoredClasses();
+		IStoredClass[] StoredClasses();
 
 		/// <summary>
 		/// returns the
@@ -537,7 +650,7 @@ namespace Db4objects.Db4o.Ext
 		/// <see cref="Db4objects.Db4o.Ext.ISystemInfo">Db4objects.Db4o.Ext.ISystemInfo</see>
 		/// for this ObjectContainer.
 		/// </returns>
-		Db4objects.Db4o.Ext.ISystemInfo SystemInfo();
+		ISystemInfo SystemInfo();
 
 		/// <summary>returns the current transaction serial number.</summary>
 		/// <remarks>
