@@ -1,14 +1,10 @@
-/* Copyright (C) 2004 - 2007  db4objects Inc.  http://www.db4o.com
+/* This file is part of the db4o object database http://www.db4o.com
 
-This file is part of the db4o open source object database.
+Copyright (C) 2004 - 2009  Versant Corporation http://www.versant.com
 
 db4o is free software; you can redistribute it and/or modify it under
-the terms of version 2 of the GNU General Public License as published
-by the Free Software Foundation and as clarified by db4objects' GPL 
-interpretation policy, available at
-http://www.db4o.com/about/company/legalpolicies/gplinterpretation/
-Alternatively you can write to db4objects, Inc., 1900 S Norfolk Street,
-Suite 350, San Mateo, CA 94403, USA.
+the terms of version 3 of the GNU General Public License as published
+by the Free Software Foundation.
 
 db4o is distributed in the hope that it will be useful, but WITHOUT ANY
 WARRANTY; without even the implied warranty of MERCHANTABILITY or
@@ -16,8 +12,10 @@ FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
 for more details.
 
 You should have received a copy of the GNU General Public License along
-with this program; if not, write to the Free Software Foundation, Inc.,
-59 Temple Place - Suite 330, Boston, MA  02111-1307, USA. */
+with this program.  If not, see http://www.gnu.org/licenses/. */
+using Db4objects.Db4o;
+using Db4objects.Db4o.Config;
+
 namespace Db4objects.Db4o.Ext
 {
 	/// <summary>extended functionality for the ObjectServer interface.</summary>
@@ -30,7 +28,7 @@ namespace Db4objects.Db4o.Ext
 	/// The functionality is split to two interfaces to allow newcomers to
 	/// focus on the essential methods.
 	/// </remarks>
-	public interface IExtObjectServer : Db4objects.Db4o.IObjectServer
+	public interface IExtObjectServer : IObjectServer
 	{
 		/// <summary>backs up the database file used by the ObjectServer.</summary>
 		/// <remarks>
@@ -42,8 +40,13 @@ namespace Db4objects.Db4o.Ext
 		/// If a file already exists at the specified path, it will be overwritten.<br /><br />
 		/// </remarks>
 		/// <param name="path">a fully qualified path</param>
+		/// <exception cref="System.IO.IOException"></exception>
 		void Backup(string path);
 
+		/// <summary>returns the number of connected clients.</summary>
+		/// <remarks>returns the number of connected clients.</remarks>
+		int ClientCount();
+
 		/// <summary>
 		/// returns the
 		/// <see cref="Db4objects.Db4o.Config.IConfiguration">Db4objects.Db4o.Config.IConfiguration
@@ -65,7 +68,7 @@ namespace Db4objects.Db4o.Ext
 		/// <returns>the Configuration context for this ObjectServer</returns>
 		/// <seealso cref="Db4objects.Db4o.Db4oFactory.Configure">Db4objects.Db4o.Db4oFactory.Configure
 		/// 	</seealso>
-		Db4objects.Db4o.Config.IConfiguration Configure();
+		IConfiguration Configure();
 
 		/// <summary>returns the ObjectContainer used by the server.</summary>
 		/// <remarks>
@@ -73,7 +76,7 @@ namespace Db4objects.Db4o.Ext
 		/// <br /><br />
 		/// </remarks>
 		/// <returns>the ObjectContainer used by the server</returns>
-		Db4objects.Db4o.IObjectContainer ObjectContainer();
+		IObjectContainer ObjectContainer();
 
 		/// <summary>removes client access permissions for the specified user.</summary>
 		/// <remarks>
@@ -82,5 +85,8 @@ namespace Db4objects.Db4o.Ext
 		/// </remarks>
 		/// <param name="userName">the name of the user</param>
 		void RevokeAccess(string userName);
+
+		/// <returns>The local port this server uses, 0 if disconnected or in embedded mode</returns>
+		int Port();
 	}
 }
