@@ -1,14 +1,10 @@
-/* Copyright (C) 2004 - 2007  db4objects Inc.  http://www.db4o.com
+/* This file is part of the db4o object database http://www.db4o.com
 
-This file is part of the db4o open source object database.
+Copyright (C) 2004 - 2009  Versant Corporation http://www.versant.com
 
 db4o is free software; you can redistribute it and/or modify it under
-the terms of version 2 of the GNU General Public License as published
-by the Free Software Foundation and as clarified by db4objects' GPL 
-interpretation policy, available at
-http://www.db4o.com/about/company/legalpolicies/gplinterpretation/
-Alternatively you can write to db4objects, Inc., 1900 S Norfolk Street,
-Suite 350, San Mateo, CA 94403, USA.
+the terms of version 3 of the GNU General Public License as published
+by the Free Software Foundation.
 
 db4o is distributed in the hope that it will be useful, but WITHOUT ANY
 WARRANTY; without even the implied warranty of MERCHANTABILITY or
@@ -16,16 +12,17 @@ FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
 for more details.
 
 You should have received a copy of the GNU General Public License along
-with this program; if not, write to the Free Software Foundation, Inc.,
-59 Temple Place - Suite 330, Boston, MA  02111-1307, USA. */
+with this program.  If not, see http://www.gnu.org/licenses/. */
+using Db4objects.Db4o;
+
 namespace Db4objects.Db4o.Ext
 {
 	/// <summary>callback methods.</summary>
 	/// <remarks>
 	/// callback methods.
-	/// <br /><br /><b>Examples: ../com/db4o/samples/callbacks.</b><br /><br />
-	/// This interface only serves as a lists of all available callback methods.
-	/// Every method is called individually, independant of implementing this interface.<br /><br />
+	/// <br /><br />
+	/// This interface only serves as a list of all available callback methods.
+	/// Every method is called individually, independantly of implementing this interface.<br /><br />
 	/// <b>Using callbacks</b><br />
 	/// Simply implement one or more of the listed methods in your application classes to
 	/// do tasks before activation, deactivation, delete, new or update, to cancel the
@@ -46,14 +43,14 @@ namespace Db4objects.Db4o.Ext
 		/// <param name="container">the <code>ObjectContainer</code> the object is stored in.
 		/// 	</param>
 		/// <returns>false to prevent activation.</returns>
-		bool ObjectCanActivate(Db4objects.Db4o.IObjectContainer container);
+		bool ObjectCanActivate(IObjectContainer container);
 
 		/// <summary>called before an Object is deactivated.</summary>
 		/// <remarks>called before an Object is deactivated.</remarks>
 		/// <param name="container">the <code>ObjectContainer</code> the object is stored in.
 		/// 	</param>
 		/// <returns>false to prevent deactivation.</returns>
-		bool ObjectCanDeactivate(Db4objects.Db4o.IObjectContainer container);
+		bool ObjectCanDeactivate(IObjectContainer container);
 
 		/// <summary>called before an Object is deleted.</summary>
 		/// <remarks>
@@ -64,33 +61,33 @@ namespace Db4objects.Db4o.Ext
 		/// <param name="container">the <code>ObjectContainer</code> the object is stored in.
 		/// 	</param>
 		/// <returns>false to prevent the object from being deleted.</returns>
-		bool ObjectCanDelete(Db4objects.Db4o.IObjectContainer container);
+		bool ObjectCanDelete(IObjectContainer container);
 
 		/// <summary>called before an Object is stored the first time.</summary>
 		/// <remarks>called before an Object is stored the first time.</remarks>
 		/// <param name="container">the <code>ObjectContainer</code> is about to be stored to.
 		/// 	</param>
 		/// <returns>false to prevent the object from being stored.</returns>
-		bool ObjectCanNew(Db4objects.Db4o.IObjectContainer container);
+		bool ObjectCanNew(IObjectContainer container);
 
 		/// <summary>called before a persisted Object is updated.</summary>
 		/// <remarks>called before a persisted Object is updated.</remarks>
 		/// <param name="container">the <code>ObjectContainer</code> the object is stored in.
 		/// 	</param>
 		/// <returns>false to prevent the object from being updated.</returns>
-		bool ObjectCanUpdate(Db4objects.Db4o.IObjectContainer container);
+		bool ObjectCanUpdate(IObjectContainer container);
 
 		/// <summary>called upon activation of an object.</summary>
 		/// <remarks>called upon activation of an object.</remarks>
 		/// <param name="container">the <code>ObjectContainer</code> the object is stored in.
 		/// 	</param>
-		void ObjectOnActivate(Db4objects.Db4o.IObjectContainer container);
+		void ObjectOnActivate(IObjectContainer container);
 
 		/// <summary>called upon deactivation of an object.</summary>
 		/// <remarks>called upon deactivation of an object.</remarks>
 		/// <param name="container">the <code>ObjectContainer</code> the object is stored in.
 		/// 	</param>
-		void ObjectOnDeactivate(Db4objects.Db4o.IObjectContainer container);
+		void ObjectOnDeactivate(IObjectContainer container);
 
 		/// <summary>called after an object was deleted.</summary>
 		/// <remarks>
@@ -100,18 +97,18 @@ namespace Db4objects.Db4o.Ext
 		/// </remarks>
 		/// <param name="container">the <code>ObjectContainer</code> the object was stored in.
 		/// 	</param>
-		void ObjectOnDelete(Db4objects.Db4o.IObjectContainer container);
+		void ObjectOnDelete(IObjectContainer container);
 
 		/// <summary>called after a new object was stored.</summary>
 		/// <remarks>called after a new object was stored.</remarks>
 		/// <param name="container">the <code>ObjectContainer</code> the object is stored to.
 		/// 	</param>
-		void ObjectOnNew(Db4objects.Db4o.IObjectContainer container);
+		void ObjectOnNew(IObjectContainer container);
 
 		/// <summary>called after an object was updated.</summary>
 		/// <remarks>called after an object was updated.</remarks>
 		/// <param name="container">the <code>ObjectContainer</code> the object is stored in.
 		/// 	</param>
-		void ObjectOnUpdate(Db4objects.Db4o.IObjectContainer container);
+		void ObjectOnUpdate(IObjectContainer container);
 	}
 }
