@@ -1,14 +1,10 @@
-/* Copyright (C) 2004 - 2007  db4objects Inc.  http://www.db4o.com
+/* This file is part of the db4o object database http://www.db4o.com
 
-This file is part of the db4o open source object database.
+Copyright (C) 2004 - 2009  Versant Corporation http://www.versant.com
 
 db4o is free software; you can redistribute it and/or modify it under
-the terms of version 2 of the GNU General Public License as published
-by the Free Software Foundation and as clarified by db4objects' GPL 
-interpretation policy, available at
-http://www.db4o.com/about/company/legalpolicies/gplinterpretation/
-Alternatively you can write to db4objects, Inc., 1900 S Norfolk Street,
-Suite 350, San Mateo, CA 94403, USA.
+the terms of version 3 of the GNU General Public License as published
+by the Free Software Foundation.
 
 db4o is distributed in the hope that it will be useful, but WITHOUT ANY
 WARRANTY; without even the implied warranty of MERCHANTABILITY or
@@ -16,8 +12,9 @@ FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
 for more details.
 
 You should have received a copy of the GNU General Public License along
-with this program; if not, write to the Free Software Foundation, Inc.,
-59 Temple Place - Suite 330, Boston, MA  02111-1307, USA. */
+with this program.  If not, see http://www.gnu.org/licenses/. */
+using Db4objects.Db4o.Ext;
+
 namespace Db4objects.Db4o.Ext
 {
 	/// <summary>the internal representation of a stored class.</summary>
@@ -38,11 +35,15 @@ namespace Db4objects.Db4o.Ext
 		/// 	</summary>
 		/// <remarks>returns the StoredClass for the parent of the class, this StoredClass represents.
 		/// 	</remarks>
-		Db4objects.Db4o.Ext.IStoredClass GetParentStoredClass();
+		IStoredClass GetParentStoredClass();
 
 		/// <summary>returns all stored fields of this stored class.</summary>
 		/// <remarks>returns all stored fields of this stored class.</remarks>
-		Db4objects.Db4o.Ext.IStoredField[] GetStoredFields();
+		IStoredField[] GetStoredFields();
+
+		/// <summary>returns true if this StoredClass has a class index.</summary>
+		/// <remarks>returns true if this StoredClass has a class index.</remarks>
+		bool HasClassIndex();
 
 		/// <summary>renames this stored class.</summary>
 		/// <remarks>
@@ -54,6 +55,7 @@ namespace Db4objects.Db4o.Ext
 		/// <param name="name">the new name</param>
 		void Rename(string name);
 
+		// TODO: add field creation
 		/// <summary>returns an existing stored field of this stored class.</summary>
 		/// <remarks>returns an existing stored field of this stored class.</remarks>
 		/// <param name="name">the name of the field</param>
@@ -69,6 +71,19 @@ namespace Db4objects.Db4o.Ext
 		/// the
 		/// <see cref="Db4objects.Db4o.Ext.IStoredField">Db4objects.Db4o.Ext.IStoredField</see>
 		/// </returns>
-		Db4objects.Db4o.Ext.IStoredField StoredField(string name, object type);
+		IStoredField StoredField(string name, object type);
+
+		/// <summary>
+		/// Returns the number of instances of this class that have been persisted to the
+		/// database, as seen by the transaction (container) that produces this StoredClass
+		/// instance.
+		/// </summary>
+		/// <remarks>
+		/// Returns the number of instances of this class that have been persisted to the
+		/// database, as seen by the transaction (container) that produces this StoredClass
+		/// instance.
+		/// </remarks>
+		/// <returns>The number of instances</returns>
+		int InstanceCount();
 	}
 }
