@@ -1,14 +1,10 @@
-/* Copyright (C) 2004 - 2007  db4objects Inc.  http://www.db4o.com
+/* This file is part of the db4o object database http://www.db4o.com
 
-This file is part of the db4o open source object database.
+Copyright (C) 2004 - 2009  Versant Corporation http://www.versant.com
 
 db4o is free software; you can redistribute it and/or modify it under
-the terms of version 2 of the GNU General Public License as published
-by the Free Software Foundation and as clarified by db4objects' GPL 
-interpretation policy, available at
-http://www.db4o.com/about/company/legalpolicies/gplinterpretation/
-Alternatively you can write to db4objects, Inc., 1900 S Norfolk Street,
-Suite 350, San Mateo, CA 94403, USA.
+the terms of version 3 of the GNU General Public License as published
+by the Free Software Foundation.
 
 db4o is distributed in the hope that it will be useful, but WITHOUT ANY
 WARRANTY; without even the implied warranty of MERCHANTABILITY or
@@ -16,14 +12,20 @@ FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
 for more details.
 
 You should have received a copy of the GNU General Public License along
-with this program; if not, write to the Free Software Foundation, Inc.,
-59 Temple Place - Suite 330, Boston, MA  02111-1307, USA. */
+with this program.  If not, see http://www.gnu.org/licenses/. */
+using Db4objects.Db4o.Foundation;
+using Db4objects.Db4o.Reflect;
+
 namespace Db4objects.Db4o.Ext
 {
 	/// <summary>the internal representation of a field on a stored class.</summary>
 	/// <remarks>the internal representation of a field on a stored class.</remarks>
 	public interface IStoredField
 	{
+		/// <summary>creates an index on this field at runtime.</summary>
+		/// <remarks>creates an index on this field at runtime.</remarks>
+		void CreateIndex();
+
 		/// <summary>returns the field value on the passed object.</summary>
 		/// <remarks>
 		/// returns the field value on the passed object.
@@ -42,9 +44,12 @@ namespace Db4objects.Db4o.Ext
 		/// <remarks>
 		/// returns the Class (Java) / Type (.NET) of the field.
 		/// <br /><br />For array fields this method will return the type of the array.
-		/// Use {link #isArray()} to detect arrays.
+		/// Use
+		/// <see cref="Db4objects.Db4o.Ext.IStoredField.IsArray">Db4objects.Db4o.Ext.IStoredField.IsArray
+		/// 	</see>
+		/// to detect arrays.
 		/// </remarks>
-		Db4objects.Db4o.Reflect.IReflectClass GetStoredType();
+		IReflectClass GetStoredType();
 
 		/// <summary>returns true if the field is an array.</summary>
 		/// <remarks>returns true if the field is an array.</remarks>
@@ -73,11 +78,19 @@ namespace Db4objects.Db4o.Ext
 		/// deactivated objects will be passed to the visitor.
 		/// </remarks>
 		/// <param name="visitor">the visitor to be called with each index value.</param>
-		void TraverseValues(Db4objects.Db4o.Foundation.IVisitor4 visitor);
+		void TraverseValues(IVisitor4 visitor);
 
 		/// <summary>Returns whether this field has an index or not.</summary>
 		/// <remarks>Returns whether this field has an index or not.</remarks>
 		/// <returns>true if this field has an index.</returns>
 		bool HasIndex();
+		//  will need for replication. Requested for 3.0 
+		//	
+		//	/**
+		//	 * sets the field value on the passed object.
+		//	 * @param onObject
+		//	 * @param fieldValue
+		//	 */
+		//	public void set(Object onObject, Object fieldValue);
 	}
 }
