@@ -1,14 +1,10 @@
-/* Copyright (C) 2004 - 2007  db4objects Inc.  http://www.db4o.com
+/* This file is part of the db4o object database http://www.db4o.com
 
-This file is part of the db4o open source object database.
+Copyright (C) 2004 - 2009  Versant Corporation http://www.versant.com
 
 db4o is free software; you can redistribute it and/or modify it under
-the terms of version 2 of the GNU General Public License as published
-by the Free Software Foundation and as clarified by db4objects' GPL 
-interpretation policy, available at
-http://www.db4o.com/about/company/legalpolicies/gplinterpretation/
-Alternatively you can write to db4objects, Inc., 1900 S Norfolk Street,
-Suite 350, San Mateo, CA 94403, USA.
+the terms of version 3 of the GNU General Public License as published
+by the Free Software Foundation.
 
 db4o is distributed in the hope that it will be useful, but WITHOUT ANY
 WARRANTY; without even the implied warranty of MERCHANTABILITY or
@@ -16,36 +12,50 @@ FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
 for more details.
 
 You should have received a copy of the GNU General Public License along
-with this program; if not, write to the Free Software Foundation, Inc.,
-59 Temple Place - Suite 330, Boston, MA  02111-1307, USA. */
+with this program.  If not, see http://www.gnu.org/licenses/. */
 namespace Db4objects.Db4o.Ext
 {
 	/// <summary>carries in-memory data for db4o in-memory operation.</summary>
 	/// <remarks>
 	/// carries in-memory data for db4o in-memory operation.
-	/// <br /><br />In-memory ObjectContainers are useful for maximum performance
+	/// <br/><br/>In-memory ObjectContainers are useful for maximum performance
 	/// on small databases, for swapping objects or for storing db4o format data
-	/// to other media or other databases.<br /><br />Be aware of the danger of running
+	/// to other media or other databases.<br/><br/>Be aware of the danger of running
 	/// into OutOfMemory problems or complete loss of all data, in case of hardware
-	/// or JVM failures.
-	/// <br /><br />
+	/// or runtime failures.
+	/// <br/><br/>
+	/// 
 	/// </remarks>
-	/// <seealso cref="Db4objects.Db4o.Ext.ExtDb4oFactory.OpenMemoryFile">Db4objects.Db4o.Ext.ExtDb4oFactory.OpenMemoryFile
-	/// 	</seealso>
+	/// <seealso cref="ExtDb4oFactory.OpenMemoryFile">ExtDb4oFactory.OpenMemoryFile</seealso>
 	public class MemoryFile
 	{
 		private byte[] i_bytes;
 
-		private const int INITIAL_SIZE_AND_INC = 1024 * 64;
+		private const int InitialSizeAndInc = 1024 * 64;
 
-		private int i_initialSize = INITIAL_SIZE_AND_INC;
+		private int i_initialSize = InitialSizeAndInc;
 
-		private int i_incrementSizeBy = INITIAL_SIZE_AND_INC;
+		private int i_incrementSizeBy = InitialSizeAndInc;
 
+		/// <summary>constructs a new MemoryFile without any data.</summary>
+		/// <remarks>constructs a new MemoryFile without any data.</remarks>
+		/// <seealso cref="Db4objects.Db4o.Ext.ExtDb4oFactory.OpenMemoryFile">Db4objects.Db4o.Ext.ExtDb4oFactory.OpenMemoryFile
+		/// 	</seealso>
 		public MemoryFile()
 		{
 		}
 
+		/// <summary>
+		/// constructs a MemoryFile to use the byte data from a previous
+		/// MemoryFile.
+		/// </summary>
+		/// <remarks>
+		/// constructs a MemoryFile to use the byte data from a previous
+		/// MemoryFile.
+		/// </remarks>
+		/// <param name="bytes">the raw byte data.</param>
+		/// <seealso cref="Db4objects.Db4o.Ext.ExtDb4oFactory.OpenMemoryFile">Db4objects.Db4o.Ext.ExtDb4oFactory.OpenMemoryFile
+		/// 	</seealso>
 		public MemoryFile(byte[] bytes)
 		{
 			i_bytes = bytes;
@@ -112,7 +122,7 @@ namespace Db4objects.Db4o.Ext
 		/// configures the size the MemoryFile is to be enlarged by, if it grows
 		/// beyond the current size.
 		/// <br /><br />Call this method before passing the MemoryFile to
-		/// <see cref="Db4objects.Db4o.Ext.ExtDb4oFactory.OpenMemoryFile">ExtDb4o#openMemoryFile(MemoryFile)
+		/// <see cref="Db4objects.Db4o.Ext.ExtDb4oFactory.OpenMemoryFile">Db4objects.Db4o.Ext.ExtDb4oFactory.OpenMemoryFile
 		/// 	</see>
 		/// .
 		/// <br /><br />
@@ -130,7 +140,7 @@ namespace Db4objects.Db4o.Ext
 		/// <remarks>
 		/// configures the initial size of the MemoryFile.
 		/// <br /><br />Call this method before passing the MemoryFile to
-		/// <see cref="Db4objects.Db4o.Ext.ExtDb4oFactory.OpenMemoryFile">ExtDb4o#openMemoryFile(MemoryFile)
+		/// <see cref="Db4objects.Db4o.Ext.ExtDb4oFactory.OpenMemoryFile">Db4objects.Db4o.Ext.ExtDb4oFactory.OpenMemoryFile
 		/// 	</see>
 		/// .
 		/// <br /><br />
