@@ -1,14 +1,10 @@
-/* Copyright (C) 2004 - 2007  db4objects Inc.  http://www.db4o.com
+/* This file is part of the db4o object database http://www.db4o.com
 
-This file is part of the db4o open source object database.
+Copyright (C) 2004 - 2009  Versant Corporation http://www.versant.com
 
 db4o is free software; you can redistribute it and/or modify it under
-the terms of version 2 of the GNU General Public License as published
-by the Free Software Foundation and as clarified by db4objects' GPL 
-interpretation policy, available at
-http://www.db4o.com/about/company/legalpolicies/gplinterpretation/
-Alternatively you can write to db4objects, Inc., 1900 S Norfolk Street,
-Suite 350, San Mateo, CA 94403, USA.
+the terms of version 3 of the GNU General Public License as published
+by the Free Software Foundation.
 
 db4o is distributed in the hope that it will be useful, but WITHOUT ANY
 WARRANTY; without even the implied warranty of MERCHANTABILITY or
@@ -16,8 +12,9 @@ FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
 for more details.
 
 You should have received a copy of the GNU General Public License along
-with this program; if not, write to the Free Software Foundation, Inc.,
-59 Temple Place - Suite 330, Boston, MA  02111-1307, USA. */
+with this program.  If not, see http://www.gnu.org/licenses/. */
+using Db4objects.Db4o.Foundation;
+
 namespace Db4objects.Db4o.Foundation
 {
 	/// <exclude></exclude>
@@ -36,20 +33,18 @@ namespace Db4objects.Db4o.Foundation
 			}
 		}
 
-		public static void Qsort(Db4objects.Db4o.Foundation.IQuickSortable4 sortable)
+		public static void Qsort(IQuickSortable4 sortable)
 		{
-			Db4objects.Db4o.Foundation.Stack4 stack = new Db4objects.Db4o.Foundation.Stack4();
+			Stack4 stack = new Stack4();
 			AddRange(stack, 0, sortable.Size() - 1);
 			Qsort(sortable, stack);
 		}
 
-		private static void Qsort(Db4objects.Db4o.Foundation.IQuickSortable4 sortable, Db4objects.Db4o.Foundation.Stack4
-			 stack)
+		private static void Qsort(IQuickSortable4 sortable, Stack4 stack)
 		{
 			while (!stack.IsEmpty())
 			{
-				Db4objects.Db4o.Foundation.Algorithms4.Range range = (Db4objects.Db4o.Foundation.Algorithms4.Range
-					)stack.Peek();
+				Algorithms4.Range range = (Algorithms4.Range)stack.Peek();
 				stack.Pop();
 				int from = range._from;
 				int to = range._to;
@@ -74,18 +69,16 @@ namespace Db4objects.Db4o.Foundation
 			}
 		}
 
-		private static void AddRange(Db4objects.Db4o.Foundation.Stack4 stack, int from, int
-			 to)
+		private static void AddRange(Stack4 stack, int from, int to)
 		{
 			if (to - from < 1)
 			{
 				return;
 			}
-			stack.Push(new Db4objects.Db4o.Foundation.Algorithms4.Range(from, to));
+			stack.Push(new Algorithms4.Range(from, to));
 		}
 
-		private static void Swap(Db4objects.Db4o.Foundation.IQuickSortable4 sortable, int
-			 left, int right)
+		private static void Swap(IQuickSortable4 sortable, int left, int right)
 		{
 			if (left == right)
 			{
