@@ -1,14 +1,10 @@
-/* Copyright (C) 2004 - 2007  db4objects Inc.  http://www.db4o.com
+/* This file is part of the db4o object database http://www.db4o.com
 
-This file is part of the db4o open source object database.
+Copyright (C) 2004 - 2009  Versant Corporation http://www.versant.com
 
 db4o is free software; you can redistribute it and/or modify it under
-the terms of version 2 of the GNU General Public License as published
-by the Free Software Foundation and as clarified by db4objects' GPL 
-interpretation policy, available at
-http://www.db4o.com/about/company/legalpolicies/gplinterpretation/
-Alternatively you can write to db4objects, Inc., 1900 S Norfolk Street,
-Suite 350, San Mateo, CA 94403, USA.
+the terms of version 3 of the GNU General Public License as published
+by the Free Software Foundation.
 
 db4o is distributed in the hope that it will be useful, but WITHOUT ANY
 WARRANTY; without even the implied warranty of MERCHANTABILITY or
@@ -16,38 +12,45 @@ FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
 for more details.
 
 You should have received a copy of the GNU General Public License along
-with this program; if not, write to the Free Software Foundation, Inc.,
-59 Temple Place - Suite 330, Boston, MA  02111-1307, USA. */
+with this program.  If not, see http://www.gnu.org/licenses/. */
+using System;
+using System.Collections;
+using Db4objects.Db4o.Foundation;
+using Db4objects.Db4o.Types;
+
 namespace Db4objects.Db4o.Foundation
 {
 	/// <summary>Fast linked list for all usecases.</summary>
 	/// <remarks>Fast linked list for all usecases.</remarks>
 	/// <exclude></exclude>
-	public class Collection4 : System.Collections.IEnumerable, Db4objects.Db4o.Foundation.IDeepClone
-		, Db4objects.Db4o.Types.IUnversioned
+	public class Collection4 : ISequence4, IEnumerable, IDeepClone, IUnversioned
 	{
 		/// <summary>first element of the linked list</summary>
-		private Db4objects.Db4o.Foundation.List4 _first;
+		private List4 _first;
 
-		private Db4objects.Db4o.Foundation.List4 _last;
+		private List4 _last;
 
 		/// <summary>number of elements collected</summary>
 		private int _size;
 
 		private int _version;
 
-		private static readonly object NOT_FOUND = new object();
-
 		public Collection4()
 		{
 		}
 
-		public Collection4(System.Collections.IEnumerable other)
+		public Collection4(object[] elements)
+		{
+			// FIELDS ARE PUBLIC SO THEY CAN BE REFLECTED ON IN JDKs <= 1.1
+			AddAll(elements);
+		}
+
+		public Collection4(IEnumerable other)
 		{
 			AddAll(other);
 		}
 
-		public Collection4(System.Collections.IEnumerator iterator)
+		public Collection4(IEnumerator iterator)
 		{
 			AddAll(iterator);
 		}
@@ -56,7 +59,7 @@ namespace Db4objects.Db4o.Foundation
 		{
 			if (Size() != 1)
 			{
-				throw new System.InvalidOperationException();
+				throw new InvalidOperationException();
 			}
 			return _first._element;
 		}
@@ -84,7 +87,7 @@ namespace Db4objects.Db4o.Foundation
 			}
 			else
 			{
-				_first = new Db4objects.Db4o.Foundation.List4(_first, element);
+				_first = new List4(_first, element);
 				_size++;
 			}
 		}
@@ -93,12 +96,12 @@ namespace Db4objects.Db4o.Foundation
 		{
 			if (_last == null)
 			{
-				_first = new Db4objects.Db4o.Foundation.List4(element);
+				_first = new List4(element);
 				_last = _first;
 			}
 			else
 			{
-				_last._next = new Db4objects.Db4o.Foundation.List4(element);
+				_last._next = new List4(element);
 				_last = _last._next;
 			}
 			_size++;
@@ -113,13 +116,13 @@ namespace Db4objects.Db4o.Foundation
 			}
 		}
 
-		public void AddAll(System.Collections.IEnumerable other)
+		public void AddAll(IEnumerable other)
 		{
 			AssertNotNull(other);
 			AddAll(other.GetEnumerator());
 		}
 
-		public void AddAll(System.Collections.IEnumerator iterator)
+		public void AddAll(IEnumerator iterator)
 		{
 			AssertNotNull(iterator);
 			while (iterator.MoveNext())
@@ -138,10 +141,10 @@ namespace Db4objects.Db4o.Foundation
 
 		public bool Contains(object element)
 		{
-			return GetInternal(element) != NOT_FOUND;
+			return Find(element) != null;
 		}
 
-		public virtual bool ContainsAll(System.Collections.IEnumerator iter)
+		public virtual bool ContainsAll(IEnumerator iter)
 		{
 			AssertNotNull(iter);
 			while (iter.MoveNext())
@@ -158,7 +161,7 @@ namespace Db4objects.Db4o.Foundation
 		/// <remarks>tests if the object is in the Collection. == comparison.</remarks>
 		public bool ContainsByIdentity(object element)
 		{
-			System.Collections.IEnumerator i = InternalIterator();
+			IEnumerator i = InternalIterator();
 			while (i.MoveNext())
 			{
 				object current = i.Current;
@@ -170,41 +173,28 @@ namespace Db4objects.Db4o.Foundation
 			return false;
 		}
 
+		private List4 Find(object obj)
+		{
+			List4 current = _first;
+			while (current != null)
+			{
+				if (current.Holds(obj))
+				{
+					return current;
+				}
+				current = current._next;
+			}
+			return null;
+		}
+
 		/// <summary>
 		/// returns the first object found in the Collections that equals() the
 		/// passed object
 		/// </summary>
 		public object Get(object element)
 		{
-			object obj = GetInternal(element);
-			if (obj == NOT_FOUND)
-			{
-				return null;
-			}
-			return obj;
-		}
-
-		private object GetInternal(object element)
-		{
-			if (element == null)
-			{
-				return ContainsNull() ? null : NOT_FOUND;
-			}
-			System.Collections.IEnumerator i = InternalIterator();
-			while (i.MoveNext())
-			{
-				object current = i.Current;
-				if (element.Equals(current))
-				{
-					return current;
-				}
-			}
-			return NOT_FOUND;
-		}
-
-		private bool ContainsNull()
-		{
-			return ContainsByIdentity(null);
+			List4 holder = Find(element);
+			return holder == null ? null : holder._element;
 		}
 
 		public virtual object DeepClone(object newParent)
@@ -212,13 +202,13 @@ namespace Db4objects.Db4o.Foundation
 			Db4objects.Db4o.Foundation.Collection4 col = new Db4objects.Db4o.Foundation.Collection4
 				();
 			object element = null;
-			System.Collections.IEnumerator i = InternalIterator();
+			IEnumerator i = InternalIterator();
 			while (i.MoveNext())
 			{
 				element = i.Current;
-				if (element is Db4objects.Db4o.Foundation.IDeepClone)
+				if (element is IDeepClone)
 				{
-					col.Add(((Db4objects.Db4o.Foundation.IDeepClone)element).DeepClone(newParent));
+					col.Add(((IDeepClone)element).DeepClone(newParent));
 				}
 				else
 				{
@@ -232,13 +222,13 @@ namespace Db4objects.Db4o.Foundation
 		/// <remarks>makes sure the passed object is in the Collection. equals() comparison.</remarks>
 		public object Ensure(object element)
 		{
-			object existing = GetInternal(element);
-			if (existing == NOT_FOUND)
+			List4 list = Find(element);
+			if (list == null)
 			{
 				Add(element);
 				return element;
 			}
-			return existing;
+			return list._element;
 		}
 
 		/// <summary>
@@ -250,10 +240,60 @@ namespace Db4objects.Db4o.Foundation
 		/// to be the fastest.
 		/// </remarks>
 		/// <returns></returns>
-		public System.Collections.IEnumerator GetEnumerator()
+		public IEnumerator GetEnumerator()
 		{
-			return _first == null ? Db4objects.Db4o.Foundation.Iterator4Impl.EMPTY : new Db4objects.Db4o.Foundation.Collection4Iterator
-				(this, _first);
+			return _first == null ? Iterators.EmptyIterator : new Collection4Iterator(this, _first
+				);
+		}
+
+		public virtual object Get(int index)
+		{
+			if (index < 0)
+			{
+				throw new ArgumentException();
+			}
+			List4 cur = _first;
+			while (index > 0 && cur != null)
+			{
+				cur = cur._next;
+				index--;
+			}
+			if (cur == null)
+			{
+				throw new ArgumentException();
+			}
+			return cur._element;
+		}
+
+		/// <summary>
+		/// Removes all the elements from this collection that are returned by
+		/// iterable.
+		/// </summary>
+		/// <remarks>
+		/// Removes all the elements from this collection that are returned by
+		/// iterable.
+		/// </remarks>
+		/// <param name="iterable"></param>
+		public virtual void RemoveAll(IEnumerable iterable)
+		{
+			RemoveAll(iterable.GetEnumerator());
+		}
+
+		/// <summary>
+		/// Removes all the elements from this collection that are returned by
+		/// iterator.
+		/// </summary>
+		/// <remarks>
+		/// Removes all the elements from this collection that are returned by
+		/// iterator.
+		/// </remarks>
+		/// <param name="iterable"></param>
+		public virtual void RemoveAll(IEnumerator iterator)
+		{
+			while (iterator.MoveNext())
+			{
+				Remove(iterator.Current);
+			}
 		}
 
 		/// <summary>
@@ -262,8 +302,8 @@ namespace Db4objects.Db4o.Foundation
 		/// </summary>
 		public virtual object Remove(object a_object)
 		{
-			Db4objects.Db4o.Foundation.List4 previous = null;
-			Db4objects.Db4o.Foundation.List4 current = _first;
+			List4 previous = null;
+			List4 current = _first;
 			while (current != null)
 			{
 				if (current.Holds(a_object))
@@ -279,8 +319,16 @@ namespace Db4objects.Db4o.Foundation
 			return null;
 		}
 
-		private void AdjustOnRemoval(Db4objects.Db4o.Foundation.List4 previous, Db4objects.Db4o.Foundation.List4
-			 removed)
+		public virtual void Replace(object oldObject, object newObject)
+		{
+			List4 list = Find(oldObject);
+			if (list != null)
+			{
+				list._element = newObject;
+			}
+		}
+
+		private void AdjustOnRemoval(List4 previous, List4 removed)
 		{
 			if (removed == _first)
 			{
@@ -301,6 +349,22 @@ namespace Db4objects.Db4o.Foundation
 			return _size;
 		}
 
+		public virtual int IndexOf(object obj)
+		{
+			int index = 0;
+			List4 current = _first;
+			while (current != null)
+			{
+				if (current.Holds(obj))
+				{
+					return index;
+				}
+				index++;
+				current = current._next;
+			}
+			return -1;
+		}
+
 		public bool IsEmpty()
 		{
 			return _size == 0;
@@ -315,7 +379,7 @@ namespace Db4objects.Db4o.Foundation
 		public object[] ToArray(object[] a_array)
 		{
 			int j = 0;
-			System.Collections.IEnumerator i = InternalIterator();
+			IEnumerator i = InternalIterator();
 			while (i.MoveNext())
 			{
 				a_array[j++] = i.Current;
@@ -332,22 +396,7 @@ namespace Db4objects.Db4o.Foundation
 
 		public override string ToString()
 		{
-			if (_size == 0)
-			{
-				return "[]";
-			}
-			System.Text.StringBuilder sb = new System.Text.StringBuilder();
-			sb.Append("[");
-			System.Collections.IEnumerator i = InternalIterator();
-			i.MoveNext();
-			sb.Append(i.Current);
-			while (i.MoveNext())
-			{
-				sb.Append(", ");
-				sb.Append(i.Current);
-			}
-			sb.Append("]");
-			return sb.ToString();
+			return Iterators.ToString(InternalIterator());
 		}
 
 		private void Changed()
@@ -364,7 +413,7 @@ namespace Db4objects.Db4o.Foundation
 		{
 			if (element == null)
 			{
-				throw new System.ArgumentNullException();
+				throw new ArgumentNullException();
 			}
 		}
 
@@ -376,9 +425,9 @@ namespace Db4objects.Db4o.Foundation
 		/// Leaner iterator for faster iteration (but unprotected against
 		/// concurrent modifications).
 		/// </remarks>
-		private System.Collections.IEnumerator InternalIterator()
+		private IEnumerator InternalIterator()
 		{
-			return new Db4objects.Db4o.Foundation.Iterator4Impl(_first);
+			return new Iterator4Impl(_first);
 		}
 	}
 }
