@@ -1,14 +1,10 @@
-/* Copyright (C) 2004 - 2007  db4objects Inc.  http://www.db4o.com
+/* This file is part of the db4o object database http://www.db4o.com
 
-This file is part of the db4o open source object database.
+Copyright (C) 2004 - 2009  Versant Corporation http://www.versant.com
 
 db4o is free software; you can redistribute it and/or modify it under
-the terms of version 2 of the GNU General Public License as published
-by the Free Software Foundation and as clarified by db4objects' GPL 
-interpretation policy, available at
-http://www.db4o.com/about/company/legalpolicies/gplinterpretation/
-Alternatively you can write to db4objects, Inc., 1900 S Norfolk Street,
-Suite 350, San Mateo, CA 94403, USA.
+the terms of version 3 of the GNU General Public License as published
+by the Free Software Foundation.
 
 db4o is distributed in the hope that it will be useful, but WITHOUT ANY
 WARRANTY; without even the implied warranty of MERCHANTABILITY or
@@ -16,26 +12,29 @@ FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
 for more details.
 
 You should have received a copy of the GNU General Public License along
-with this program; if not, write to the Free Software Foundation, Inc.,
-59 Temple Place - Suite 330, Boston, MA  02111-1307, USA. */
+with this program.  If not, see http://www.gnu.org/licenses/. */
+using System;
+using System.Collections;
+using Db4objects.Db4o.Foundation;
+
 namespace Db4objects.Db4o.Foundation
 {
-	public class CompositeIterator4 : System.Collections.IEnumerator
+	public class CompositeIterator4 : IEnumerator
 	{
-		private readonly System.Collections.IEnumerator _iterators;
+		protected readonly IEnumerator _iterators;
 
-		private System.Collections.IEnumerator _currentIterator;
+		protected IEnumerator _currentIterator;
 
-		public CompositeIterator4(System.Collections.IEnumerator[] iterators) : this(new 
-			Db4objects.Db4o.Foundation.ArrayIterator4(iterators))
+		public CompositeIterator4(IEnumerator[] iterators) : this(new ArrayIterator4(iterators
+			))
 		{
 		}
 
-		public CompositeIterator4(System.Collections.IEnumerator iterators)
+		public CompositeIterator4(IEnumerator iterators)
 		{
 			if (null == iterators)
 			{
-				throw new System.ArgumentNullException();
+				throw new ArgumentNullException();
 			}
 			_iterators = iterators;
 		}
@@ -74,7 +73,7 @@ namespace Db4objects.Db4o.Foundation
 			}
 		}
 
-		public virtual System.Collections.IEnumerator CurrentIterator()
+		public virtual IEnumerator CurrentIterator()
 		{
 			return _currentIterator;
 		}
@@ -87,9 +86,9 @@ namespace Db4objects.Db4o.Foundation
 			}
 		}
 
-		protected virtual System.Collections.IEnumerator NextIterator(object current)
+		protected virtual IEnumerator NextIterator(object current)
 		{
-			return (System.Collections.IEnumerator)current;
+			return (IEnumerator)current;
 		}
 	}
 }
