@@ -1,14 +1,10 @@
-/* Copyright (C) 2004 - 2007  db4objects Inc.  http://www.db4o.com
+/* This file is part of the db4o object database http://www.db4o.com
 
-This file is part of the db4o open source object database.
+Copyright (C) 2004 - 2009  Versant Corporation http://www.versant.com
 
 db4o is free software; you can redistribute it and/or modify it under
-the terms of version 2 of the GNU General Public License as published
-by the Free Software Foundation and as clarified by db4objects' GPL 
-interpretation policy, available at
-http://www.db4o.com/about/company/legalpolicies/gplinterpretation/
-Alternatively you can write to db4objects, Inc., 1900 S Norfolk Street,
-Suite 350, San Mateo, CA 94403, USA.
+the terms of version 3 of the GNU General Public License as published
+by the Free Software Foundation.
 
 db4o is distributed in the hope that it will be useful, but WITHOUT ANY
 WARRANTY; without even the implied warranty of MERCHANTABILITY or
@@ -16,12 +12,15 @@ FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
 for more details.
 
 You should have received a copy of the GNU General Public License along
-with this program; if not, write to the Free Software Foundation, Inc.,
-59 Temple Place - Suite 330, Boston, MA  02111-1307, USA. */
+with this program.  If not, see http://www.gnu.org/licenses/. */
+using System.Collections;
+using Db4objects.Db4o.Foundation;
+using Sharpen;
+
 namespace Db4objects.Db4o.Foundation
 {
 	/// <exclude></exclude>
-	public class IntArrayList : System.Collections.IEnumerable
+	public class IntArrayList : IEnumerable
 	{
 		protected int[] i_content;
 
@@ -37,6 +36,20 @@ namespace Db4objects.Db4o.Foundation
 		}
 
 		public virtual void Add(int a_value)
+		{
+			EnsureCapacity();
+			i_content[i_count++] = a_value;
+		}
+
+		public virtual void Add(int index, int a_value)
+		{
+			EnsureCapacity();
+			System.Array.Copy(i_content, index, i_content, index + 1, i_count - index);
+			i_content[index] = a_value;
+			i_count++;
+		}
+
+		private void EnsureCapacity()
 		{
 			if (i_count >= i_content.Length)
 			{
@@ -49,7 +62,6 @@ namespace Db4objects.Db4o.Foundation
 				System.Array.Copy(i_content, 0, temp, 0, i_content.Length);
 				i_content = temp;
 			}
-			i_content[i_count++] = a_value;
 		}
 
 		public virtual int IndexOf(int a_value)
@@ -79,12 +91,12 @@ namespace Db4objects.Db4o.Foundation
 			return longs;
 		}
 
-		public virtual Db4objects.Db4o.Foundation.IIntIterator4 IntIterator()
+		public virtual IIntIterator4 IntIterator()
 		{
-			return new Db4objects.Db4o.Foundation.IntIterator4Impl(i_content, i_count);
+			return new IntIterator4Impl(i_content, i_count);
 		}
 
-		public virtual System.Collections.IEnumerator GetEnumerator()
+		public virtual IEnumerator GetEnumerator()
 		{
 			return IntIterator();
 		}
