@@ -1,14 +1,10 @@
-/* Copyright (C) 2004 - 2007  db4objects Inc.  http://www.db4o.com
+/* This file is part of the db4o object database http://www.db4o.com
 
-This file is part of the db4o open source object database.
+Copyright (C) 2004 - 2009  Versant Corporation http://www.versant.com
 
 db4o is free software; you can redistribute it and/or modify it under
-the terms of version 2 of the GNU General Public License as published
-by the Free Software Foundation and as clarified by db4objects' GPL 
-interpretation policy, available at
-http://www.db4o.com/about/company/legalpolicies/gplinterpretation/
-Alternatively you can write to db4objects, Inc., 1900 S Norfolk Street,
-Suite 350, San Mateo, CA 94403, USA.
+the terms of version 3 of the GNU General Public License as published
+by the Free Software Foundation.
 
 db4o is distributed in the hope that it will be useful, but WITHOUT ANY
 WARRANTY; without even the implied warranty of MERCHANTABILITY or
@@ -16,8 +12,10 @@ FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
 for more details.
 
 You should have received a copy of the GNU General Public License along
-with this program; if not, write to the Free Software Foundation, Inc.,
-59 Temple Place - Suite 330, Boston, MA  02111-1307, USA. */
+with this program.  If not, see http://www.gnu.org/licenses/. */
+using System;
+using System.Collections;
+
 namespace Db4objects.Db4o.Foundation
 {
 	/// <summary>
@@ -31,42 +29,42 @@ namespace Db4objects.Db4o.Foundation
 	/// <exclude></exclude>
 	public class Iterable4Adaptor
 	{
-		private static readonly object EOF = new object();
+		private static readonly object EofMarker = new object();
 
-		private static readonly object MOVE_NEXT = new object();
+		private static readonly object MoveNextMarker = new object();
 
-		private readonly System.Collections.IEnumerable _delegate;
+		private readonly IEnumerable _delegate;
 
-		private System.Collections.IEnumerator _iterator;
+		private IEnumerator _iterator;
 
-		private object _current = MOVE_NEXT;
+		private object _current = MoveNextMarker;
 
-		public Iterable4Adaptor(System.Collections.IEnumerable delegate_)
+		public Iterable4Adaptor(IEnumerable delegate_)
 		{
 			_delegate = delegate_;
 		}
 
 		public virtual bool HasNext()
 		{
-			if (_current == MOVE_NEXT)
+			if (_current == MoveNextMarker)
 			{
 				return MoveNext();
 			}
-			return _current != EOF;
+			return _current != EofMarker;
 		}
 
 		public virtual object Next()
 		{
 			if (!HasNext())
 			{
-				throw new System.InvalidOperationException();
+				throw new InvalidOperationException();
 			}
 			object returnValue = _current;
-			_current = MOVE_NEXT;
+			_current = MoveNextMarker;
 			return returnValue;
 		}
 
-		private bool MoveNext()
+		protected virtual bool MoveNext()
 		{
 			if (null == _iterator)
 			{
@@ -77,14 +75,14 @@ namespace Db4objects.Db4o.Foundation
 				_current = _iterator.Current;
 				return true;
 			}
-			_current = EOF;
+			_current = EofMarker;
 			return false;
 		}
 
 		public virtual void Reset()
 		{
 			_iterator = null;
-			_current = MOVE_NEXT;
+			_current = MoveNextMarker;
 		}
 	}
 }
