@@ -1,14 +1,10 @@
-/* Copyright (C) 2004 - 2007  db4objects Inc.  http://www.db4o.com
+/* This file is part of the db4o object database http://www.db4o.com
 
-This file is part of the db4o open source object database.
+Copyright (C) 2004 - 2009  Versant Corporation http://www.versant.com
 
 db4o is free software; you can redistribute it and/or modify it under
-the terms of version 2 of the GNU General Public License as published
-by the Free Software Foundation and as clarified by db4objects' GPL 
-interpretation policy, available at
-http://www.db4o.com/about/company/legalpolicies/gplinterpretation/
-Alternatively you can write to db4objects, Inc., 1900 S Norfolk Street,
-Suite 350, San Mateo, CA 94403, USA.
+the terms of version 3 of the GNU General Public License as published
+by the Free Software Foundation.
 
 db4o is distributed in the hope that it will be useful, but WITHOUT ANY
 WARRANTY; without even the implied warranty of MERCHANTABILITY or
@@ -16,8 +12,7 @@ FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
 for more details.
 
 You should have received a copy of the GNU General Public License along
-with this program; if not, write to the Free Software Foundation, Inc.,
-59 Temple Place - Suite 330, Boston, MA  02111-1307, USA. */
+with this program.  If not, see http://www.gnu.org/licenses/. */
 namespace Db4objects.Db4o.Foundation
 {
 	/// <summary>yes/no/dontknow data type</summary>
@@ -25,20 +20,20 @@ namespace Db4objects.Db4o.Foundation
 	[System.Serializable]
 	public sealed class TernaryBool
 	{
-		private const int NO_ID = -1;
+		private const int NoId = -1;
 
-		private const int YES_ID = 1;
+		private const int YesId = 1;
 
-		private const int UNSPECIFIED_ID = 0;
+		private const int UnspecifiedId = 0;
 
-		public static readonly Db4objects.Db4o.Foundation.TernaryBool NO = new Db4objects.Db4o.Foundation.TernaryBool
-			(NO_ID);
+		public static readonly Db4objects.Db4o.Foundation.TernaryBool No = new Db4objects.Db4o.Foundation.TernaryBool
+			(NoId);
 
-		public static readonly Db4objects.Db4o.Foundation.TernaryBool YES = new Db4objects.Db4o.Foundation.TernaryBool
-			(YES_ID);
+		public static readonly Db4objects.Db4o.Foundation.TernaryBool Yes = new Db4objects.Db4o.Foundation.TernaryBool
+			(YesId);
 
-		public static readonly Db4objects.Db4o.Foundation.TernaryBool UNSPECIFIED = new Db4objects.Db4o.Foundation.TernaryBool
-			(UNSPECIFIED_ID);
+		public static readonly Db4objects.Db4o.Foundation.TernaryBool Unspecified = new Db4objects.Db4o.Foundation.TernaryBool
+			(UnspecifiedId);
 
 		private readonly int _value;
 
@@ -51,12 +46,12 @@ namespace Db4objects.Db4o.Foundation
 		{
 			switch (_value)
 			{
-				case NO_ID:
+				case NoId:
 				{
 					return false;
 				}
 
-				case YES_ID:
+				case YesId:
 				{
 					return true;
 				}
@@ -69,24 +64,24 @@ namespace Db4objects.Db4o.Foundation
 			}
 		}
 
-		public bool Unspecified()
+		public bool IsUnspecified()
 		{
-			return this == UNSPECIFIED;
+			return this == Unspecified;
 		}
 
 		public bool DefiniteYes()
 		{
-			return this == YES;
+			return this == Yes;
 		}
 
 		public bool DefiniteNo()
 		{
-			return this == NO;
+			return this == No;
 		}
 
 		public static Db4objects.Db4o.Foundation.TernaryBool ForBoolean(bool value)
 		{
-			return (value ? YES : NO);
+			return (value ? Yes : No);
 		}
 
 		public override bool Equals(object obj)
@@ -113,19 +108,41 @@ namespace Db4objects.Db4o.Foundation
 		{
 			switch (_value)
 			{
-				case NO_ID:
+				case NoId:
 				{
-					return NO;
+					return No;
 				}
 
-				case YES_ID:
+				case YesId:
 				{
-					return YES;
+					return Yes;
 				}
 
 				default:
 				{
-					return UNSPECIFIED;
+					return Unspecified;
+					break;
+				}
+			}
+		}
+
+		public override string ToString()
+		{
+			switch (_value)
+			{
+				case NoId:
+				{
+					return "NO";
+				}
+
+				case YesId:
+				{
+					return "YES";
+				}
+
+				default:
+				{
+					return "UNSPECIFIED";
 					break;
 				}
 			}
