@@ -1,14 +1,10 @@
-/* Copyright (C) 2004 - 2007  db4objects Inc.  http://www.db4o.com
+/* This file is part of the db4o object database http://www.db4o.com
 
-This file is part of the db4o open source object database.
+Copyright (C) 2004 - 2009  Versant Corporation http://www.versant.com
 
 db4o is free software; you can redistribute it and/or modify it under
-the terms of version 2 of the GNU General Public License as published
-by the Free Software Foundation and as clarified by db4objects' GPL 
-interpretation policy, available at
-http://www.db4o.com/about/company/legalpolicies/gplinterpretation/
-Alternatively you can write to db4objects, Inc., 1900 S Norfolk Street,
-Suite 350, San Mateo, CA 94403, USA.
+the terms of version 3 of the GNU General Public License as published
+by the Free Software Foundation.
 
 db4o is distributed in the hope that it will be useful, but WITHOUT ANY
 WARRANTY; without even the implied warranty of MERCHANTABILITY or
@@ -16,12 +12,14 @@ FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
 for more details.
 
 You should have received a copy of the GNU General Public License along
-with this program; if not, write to the Free Software Foundation, Inc.,
-59 Temple Place - Suite 330, Boston, MA  02111-1307, USA. */
+with this program.  If not, see http://www.gnu.org/licenses/. */
+using System;
+using Db4objects.Db4o.Foundation;
+
 namespace Db4objects.Db4o.Foundation
 {
 	/// <exclude></exclude>
-	public abstract class Tree : Db4objects.Db4o.Foundation.IShallowClone, Db4objects.Db4o.Foundation.IDeepClone
+	public abstract class Tree : IShallowClone, IDeepClone
 	{
 		public sealed class ByRef
 		{
@@ -29,22 +27,21 @@ namespace Db4objects.Db4o.Foundation
 			{
 			}
 
-			public ByRef(Db4objects.Db4o.Foundation.Tree initialValue)
+			public ByRef(Tree initialValue)
 			{
 				value = initialValue;
 			}
 
-			public Db4objects.Db4o.Foundation.Tree value;
+			public Tree value;
 		}
 
-		public Db4objects.Db4o.Foundation.Tree _preceding;
+		public Tree _preceding;
 
 		public int _size = 1;
 
-		public Db4objects.Db4o.Foundation.Tree _subsequent;
+		public Tree _subsequent;
 
-		public static Db4objects.Db4o.Foundation.Tree Add(Db4objects.Db4o.Foundation.Tree
-			 a_old, Db4objects.Db4o.Foundation.Tree a_new)
+		public static Tree Add(Tree a_old, Tree a_new)
 		{
 			if (a_old == null)
 			{
@@ -53,8 +50,7 @@ namespace Db4objects.Db4o.Foundation
 			return a_old.Add(a_new);
 		}
 
-		public virtual Db4objects.Db4o.Foundation.Tree Add(Db4objects.Db4o.Foundation.Tree
-			 a_new)
+		public virtual Tree Add(Tree a_new)
 		{
 			return Add(a_new, Compare(a_new));
 		}
@@ -71,8 +67,7 @@ namespace Db4objects.Db4o.Foundation
 		/// prevails in the tree using #duplicateOrThis(). This mechanism
 		/// allows doing find() and add() in one run.
 		/// </remarks>
-		public virtual Db4objects.Db4o.Foundation.Tree Add(Db4objects.Db4o.Foundation.Tree
-			 a_new, int a_cmp)
+		public virtual Tree Add(Tree a_new, int a_cmp)
 		{
 			if (a_cmp < 0)
 			{
@@ -133,7 +128,7 @@ namespace Db4objects.Db4o.Foundation
 		/// in the tree on adding, using the #addedOrExisting() method.
 		/// This mechanism allows doing find() and add() in one run.
 		/// </remarks>
-		public virtual Db4objects.Db4o.Foundation.Tree AddedOrExisting()
+		public virtual Tree AddedOrExisting()
 		{
 			if (WasAddedToTree())
 			{
@@ -147,7 +142,7 @@ namespace Db4objects.Db4o.Foundation
 			return _size != 0;
 		}
 
-		public Db4objects.Db4o.Foundation.Tree Balance()
+		public Tree Balance()
 		{
 			int cmp = _subsequent.Nodes() - _preceding.Nodes();
 			if (cmp < -2)
@@ -168,7 +163,7 @@ namespace Db4objects.Db4o.Foundation
 			}
 		}
 
-		public virtual Db4objects.Db4o.Foundation.Tree BalanceCheckNulls()
+		public virtual Tree BalanceCheckNulls()
 		{
 			if (_subsequent == null)
 			{
@@ -221,22 +216,18 @@ namespace Db4objects.Db4o.Foundation
 		/// returns positive if this is greater than a_to
 		/// returns negative if this is smaller than a_to
 		/// </summary>
-		public abstract int Compare(Db4objects.Db4o.Foundation.Tree a_to);
+		public abstract int Compare(Tree a_to);
 
-		public static Db4objects.Db4o.Foundation.Tree DeepClone(Db4objects.Db4o.Foundation.Tree
-			 a_tree, object a_param)
+		public static Tree DeepClone(Tree a_tree, object a_param)
 		{
 			if (a_tree == null)
 			{
 				return null;
 			}
-			Db4objects.Db4o.Foundation.Tree newNode = (Db4objects.Db4o.Foundation.Tree)a_tree
-				.DeepClone(a_param);
+			Tree newNode = (Tree)a_tree.DeepClone(a_param);
 			newNode._size = a_tree._size;
-			newNode._preceding = Db4objects.Db4o.Foundation.Tree.DeepClone(a_tree._preceding, 
-				a_param);
-			newNode._subsequent = Db4objects.Db4o.Foundation.Tree.DeepClone(a_tree._subsequent
-				, a_param);
+			newNode._preceding = Tree.DeepClone(a_tree._preceding, a_param);
+			newNode._subsequent = Tree.DeepClone(a_tree._subsequent, a_param);
 			return newNode;
 		}
 
@@ -250,8 +241,7 @@ namespace Db4objects.Db4o.Foundation
 			return true;
 		}
 
-		public Db4objects.Db4o.Foundation.Tree Filter(Db4objects.Db4o.Foundation.IPredicate4
-			 a_filter)
+		public Tree Filter(IPredicate4 a_filter)
 		{
 			if (_preceding != null)
 			{
@@ -268,8 +258,7 @@ namespace Db4objects.Db4o.Foundation
 			return this;
 		}
 
-		public static Db4objects.Db4o.Foundation.Tree Find(Db4objects.Db4o.Foundation.Tree
-			 a_in, Db4objects.Db4o.Foundation.Tree a_tree)
+		public static Tree Find(Tree a_in, Tree a_tree)
 		{
 			if (a_in == null)
 			{
@@ -278,8 +267,7 @@ namespace Db4objects.Db4o.Foundation
 			return a_in.Find(a_tree);
 		}
 
-		public Db4objects.Db4o.Foundation.Tree Find(Db4objects.Db4o.Foundation.Tree a_tree
-			)
+		public Tree Find(Tree a_tree)
 		{
 			int cmp = Compare(a_tree);
 			if (cmp < 0)
@@ -306,8 +294,7 @@ namespace Db4objects.Db4o.Foundation
 			return null;
 		}
 
-		public static Db4objects.Db4o.Foundation.Tree FindGreaterOrEqual(Db4objects.Db4o.Foundation.Tree
-			 a_in, Db4objects.Db4o.Foundation.Tree a_finder)
+		public static Tree FindGreaterOrEqual(Tree a_in, Tree a_finder)
 		{
 			if (a_in == null)
 			{
@@ -318,10 +305,10 @@ namespace Db4objects.Db4o.Foundation
 			{
 				return a_in;
 			}
+			// the highest node in the hierarchy !!!
 			if (cmp > 0)
 			{
-				Db4objects.Db4o.Foundation.Tree node = FindGreaterOrEqual(a_in._preceding, a_finder
-					);
+				Tree node = FindGreaterOrEqual(a_in._preceding, a_finder);
 				if (node != null)
 				{
 					return node;
@@ -331,8 +318,7 @@ namespace Db4objects.Db4o.Foundation
 			return FindGreaterOrEqual(a_in._subsequent, a_finder);
 		}
 
-		public static Db4objects.Db4o.Foundation.Tree FindSmaller(Db4objects.Db4o.Foundation.Tree
-			 a_in, Db4objects.Db4o.Foundation.Tree a_node)
+		public static Tree FindSmaller(Tree a_in, Tree a_node)
 		{
 			if (a_in == null)
 			{
@@ -341,7 +327,7 @@ namespace Db4objects.Db4o.Foundation
 			int cmp = a_in.Compare(a_node);
 			if (cmp < 0)
 			{
-				Db4objects.Db4o.Foundation.Tree node = FindSmaller(a_in._subsequent, a_node);
+				Tree node = FindSmaller(a_in._subsequent, a_node);
 				if (node != null)
 				{
 					return node;
@@ -351,7 +337,7 @@ namespace Db4objects.Db4o.Foundation
 			return FindSmaller(a_in._preceding, a_node);
 		}
 
-		public Db4objects.Db4o.Foundation.Tree First()
+		public Tree First()
 		{
 			if (_preceding == null)
 			{
@@ -360,8 +346,25 @@ namespace Db4objects.Db4o.Foundation
 			return _preceding.First();
 		}
 
-		public virtual void OnAttemptToAddDuplicate(Db4objects.Db4o.Foundation.Tree a_tree
-			)
+		public static Tree Last(Tree tree)
+		{
+			if (tree == null)
+			{
+				return null;
+			}
+			return tree.Last();
+		}
+
+		public Tree Last()
+		{
+			if (_subsequent == null)
+			{
+				return this;
+			}
+			return _subsequent.Last();
+		}
+
+		public virtual void OnAttemptToAddDuplicate(Tree a_tree)
 		{
 			_size = 0;
 			_preceding = a_tree;
@@ -378,7 +381,7 @@ namespace Db4objects.Db4o.Foundation
 			return 1;
 		}
 
-		public virtual Db4objects.Db4o.Foundation.Tree Remove()
+		public virtual Tree Remove()
 		{
 			if (_subsequent != null && _preceding != null)
 			{
@@ -401,7 +404,7 @@ namespace Db4objects.Db4o.Foundation
 			SetSizeOwn();
 		}
 
-		public virtual Db4objects.Db4o.Foundation.Tree RemoveFirst()
+		public virtual Tree RemoveFirst()
 		{
 			if (_preceding == null)
 			{
@@ -412,8 +415,7 @@ namespace Db4objects.Db4o.Foundation
 			return this;
 		}
 
-		public static Db4objects.Db4o.Foundation.Tree RemoveLike(Db4objects.Db4o.Foundation.Tree
-			 from, Db4objects.Db4o.Foundation.Tree a_find)
+		public static Tree RemoveLike(Tree from, Tree a_find)
 		{
 			if (from == null)
 			{
@@ -422,8 +424,7 @@ namespace Db4objects.Db4o.Foundation
 			return from.RemoveLike(a_find);
 		}
 
-		public Db4objects.Db4o.Foundation.Tree RemoveLike(Db4objects.Db4o.Foundation.Tree
-			 a_find)
+		public Tree RemoveLike(Tree a_find)
 		{
 			int cmp = Compare(a_find);
 			if (cmp == 0)
@@ -448,8 +449,7 @@ namespace Db4objects.Db4o.Foundation
 			return this;
 		}
 
-		public Db4objects.Db4o.Foundation.Tree RemoveNode(Db4objects.Db4o.Foundation.Tree
-			 a_tree)
+		public Tree RemoveNode(Tree a_tree)
 		{
 			if (this == a_tree)
 			{
@@ -474,9 +474,9 @@ namespace Db4objects.Db4o.Foundation
 			return this;
 		}
 
-		public Db4objects.Db4o.Foundation.Tree RotateLeft()
+		public Tree RotateLeft()
 		{
-			Db4objects.Db4o.Foundation.Tree tree = _subsequent;
+			Tree tree = _subsequent;
 			_subsequent = tree._preceding;
 			CalculateSize();
 			tree._preceding = this;
@@ -491,9 +491,9 @@ namespace Db4objects.Db4o.Foundation
 			return tree;
 		}
 
-		public Db4objects.Db4o.Foundation.Tree RotateRight()
+		public Tree RotateRight()
 		{
-			Db4objects.Db4o.Foundation.Tree tree = _preceding;
+			Tree tree = _preceding;
 			_preceding = tree._subsequent;
 			CalculateSize();
 			tree._subsequent = this;
@@ -508,7 +508,7 @@ namespace Db4objects.Db4o.Foundation
 			return tree;
 		}
 
-		private Db4objects.Db4o.Foundation.Tree RotateSmallestUp()
+		private Tree RotateSmallestUp()
 		{
 			if (_preceding != null)
 			{
@@ -538,18 +538,17 @@ namespace Db4objects.Db4o.Foundation
 			_size = OwnSize() + _subsequent._size;
 		}
 
-		public virtual void SetSizeOwnPlus(Db4objects.Db4o.Foundation.Tree tree)
+		public virtual void SetSizeOwnPlus(Tree tree)
 		{
 			_size = OwnSize() + tree._size;
 		}
 
-		public virtual void SetSizeOwnPlus(Db4objects.Db4o.Foundation.Tree tree1, Db4objects.Db4o.Foundation.Tree
-			 tree2)
+		public virtual void SetSizeOwnPlus(Tree tree1, Tree tree2)
 		{
 			_size = OwnSize() + tree1._size + tree2._size;
 		}
 
-		public static int Size(Db4objects.Db4o.Foundation.Tree a_tree)
+		public static int Size(Tree a_tree)
 		{
 			if (a_tree == null)
 			{
@@ -564,8 +563,7 @@ namespace Db4objects.Db4o.Foundation
 			return _size;
 		}
 
-		public static void Traverse(Db4objects.Db4o.Foundation.Tree tree, Db4objects.Db4o.Foundation.IVisitor4
-			 visitor)
+		public static void Traverse(Tree tree, IVisitor4 visitor)
 		{
 			if (tree == null)
 			{
@@ -574,7 +572,7 @@ namespace Db4objects.Db4o.Foundation
 			tree.Traverse(visitor);
 		}
 
-		public void Traverse(Db4objects.Db4o.Foundation.IVisitor4 a_visitor)
+		public void Traverse(IVisitor4 a_visitor)
 		{
 			if (_preceding != null)
 			{
@@ -587,7 +585,7 @@ namespace Db4objects.Db4o.Foundation
 			}
 		}
 
-		public void TraverseFromLeaves(Db4objects.Db4o.Foundation.IVisitor4 a_visitor)
+		public void TraverseFromLeaves(IVisitor4 a_visitor)
 		{
 			if (_preceding != null)
 			{
@@ -600,8 +598,25 @@ namespace Db4objects.Db4o.Foundation
 			a_visitor.Visit(this);
 		}
 
-		protected virtual Db4objects.Db4o.Foundation.Tree ShallowCloneInternal(Db4objects.Db4o.Foundation.Tree
-			 tree)
+		// Keep the debug methods to debug the depth	
+		//	final void debugDepth(){
+		//	    System.out.println("Tree depth: " + debugDepth(0));
+		//	}
+		//	
+		//	final int debugDepth(int d){
+		//	    int max = d + 1;
+		//	    if (i_preceding != null){
+		//	        max = i_preceding.debugDepth(d + 1);
+		//	    }
+		//	    if(i_subsequent != null){
+		//	        int ms = i_subsequent.debugDepth(d + 1);
+		//	        if(ms > max){
+		//	            max = ms;
+		//	        }
+		//	    }
+		//	    return max;
+		//	}
+		protected virtual Tree ShallowCloneInternal(Tree tree)
 		{
 			tree._preceding = _preceding;
 			tree._size = _size;
@@ -611,9 +626,14 @@ namespace Db4objects.Db4o.Foundation
 
 		public virtual object ShallowClone()
 		{
-			throw new System.NotImplementedException();
+			throw new NotImplementedException();
 		}
 
 		public abstract object Key();
+
+		public virtual object Root()
+		{
+			return this;
+		}
 	}
 }
