@@ -1,14 +1,10 @@
-/* Copyright (C) 2004 - 2007  db4objects Inc.  http://www.db4o.com
+/* This file is part of the db4o object database http://www.db4o.com
 
-This file is part of the db4o open source object database.
+Copyright (C) 2004 - 2009  Versant Corporation http://www.versant.com
 
 db4o is free software; you can redistribute it and/or modify it under
-the terms of version 2 of the GNU General Public License as published
-by the Free Software Foundation and as clarified by db4objects' GPL 
-interpretation policy, available at
-http://www.db4o.com/about/company/legalpolicies/gplinterpretation/
-Alternatively you can write to db4objects, Inc., 1900 S Norfolk Street,
-Suite 350, San Mateo, CA 94403, USA.
+the terms of version 3 of the GNU General Public License as published
+by the Free Software Foundation.
 
 db4o is distributed in the hope that it will be useful, but WITHOUT ANY
 WARRANTY; without even the implied warranty of MERCHANTABILITY or
@@ -16,8 +12,13 @@ FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
 for more details.
 
 You should have received a copy of the GNU General Public License along
-with this program; if not, write to the Free Software Foundation, Inc.,
-59 Temple Place - Suite 330, Boston, MA  02111-1307, USA. */
+with this program.  If not, see http://www.gnu.org/licenses/. */
+using System;
+using Db4objects.Db4o.Ext;
+using Db4objects.Db4o.IO;
+using Db4objects.Db4o.Internal.Fileheader;
+using Sharpen;
+
 namespace Db4objects.Db4o.IO
 {
 	/// <summary>
@@ -31,11 +32,11 @@ namespace Db4objects.Db4o.IO
 	/// <code>delegateAdapter = new RandomAccessFileAdapter();</code><br />
 	/// <code>Db4o.configure().io(new CachedIoAdapter(delegateAdapter));</code><br />
 	/// </remarks>
-	public class CachedIoAdapter : Db4objects.Db4o.IO.IoAdapter
+	public class CachedIoAdapter : IoAdapter
 	{
-		private Db4objects.Db4o.IO.CachedIoAdapter.Page _head;
+		private CachedIoAdapter.Page _head;
 
-		private Db4objects.Db4o.IO.CachedIoAdapter.Page _tail;
+		private CachedIoAdapter.Page _tail;
 
 		private long _position;
 
@@ -47,32 +48,64 @@ namespace Db4objects.Db4o.IO
 
 		private long _filePointer;
 
-		private Db4objects.Db4o.IO.IoAdapter _io;
+		private IoAdapter _io;
 
-		private static int DEFAULT_PAGE_SIZE = 1024;
+		private bool _readOnly;
 
-		private static int DEFAULT_PAGE_COUNT = 64;
+		private static int DefaultPageSize = 1024;
 
-		public CachedIoAdapter(Db4objects.Db4o.IO.IoAdapter ioAdapter) : this(ioAdapter, 
-			DEFAULT_PAGE_SIZE, DEFAULT_PAGE_COUNT)
+		private static int DefaultPageCount = 64;
+
+		/// <summary>
+		/// Creates an instance of CachedIoAdapter with the default page size and
+		/// page count.
+		/// </summary>
+		/// <remarks>
+		/// Creates an instance of CachedIoAdapter with the default page size and
+		/// page count.
+		/// </remarks>
+		/// <param name="ioAdapter">delegate IO adapter (RandomAccessFileAdapter by default)</param>
+		public CachedIoAdapter(IoAdapter ioAdapter) : this(ioAdapter, DefaultPageSize, DefaultPageCount
+			)
 		{
 		}
 
-		public CachedIoAdapter(Db4objects.Db4o.IO.IoAdapter ioAdapter, int pageSize, int 
-			pageCount)
+		/// <summary>
+		/// Creates an instance of CachedIoAdapter with a custom page size and page
+		/// count.<br />
+		/// </summary>
+		/// <param name="ioAdapter">delegate IO adapter (RandomAccessFileAdapter by default)</param>
+		/// <param name="pageSize">cache page size</param>
+		/// <param name="pageCount">allocated amount of pages</param>
+		public CachedIoAdapter(IoAdapter ioAdapter, int pageSize, int pageCount)
 		{
+			// private Hashtable4 _posPageMap = new Hashtable4(PAGE_COUNT);
 			_io = ioAdapter;
 			_pageSize = pageSize;
 			_pageCount = pageCount;
 		}
 
-		public CachedIoAdapter(string path, bool lockFile, long initialLength, Db4objects.Db4o.IO.IoAdapter
-			 io, int pageSize, int pageCount)
+		/// <summary>Creates an instance of CachedIoAdapter with extended parameters.<br /></summary>
+		/// <param name="path">database file path</param>
+		/// <param name="lockFile">determines if the file should be locked</param>
+		/// <param name="initialLength">initial file length, new writes will start from this point
+		/// 	</param>
+		/// <param name="readOnly">
+		/// 
+		/// if the file should be used in read-onlyt mode.
+		/// </param>
+		/// <param name="io">delegate IO adapter (RandomAccessFileAdapter by default)</param>
+		/// <param name="pageSize">cache page size</param>
+		/// <param name="pageCount">allocated amount of pages</param>
+		/// <exception cref="Db4objects.Db4o.Ext.Db4oIOException"></exception>
+		public CachedIoAdapter(string path, bool lockFile, long initialLength, bool readOnly
+			, IoAdapter io, int pageSize, int pageCount)
 		{
+			_readOnly = readOnly;
 			_pageSize = pageSize;
 			_pageCount = pageCount;
 			InitCache();
-			InitIOAdaptor(path, lockFile, initialLength, io);
+			InitIOAdaptor(path, lockFile, initialLength, readOnly, io);
 			_position = initialLength;
 			_filePointer = initialLength;
 			_fileLength = _io.GetLength();
@@ -83,11 +116,12 @@ namespace Db4objects.Db4o.IO
 		/// <param name="lockFile">determines if the file should be locked</param>
 		/// <param name="initialLength">initial file length, new writes will start from this point
 		/// 	</param>
-		public override Db4objects.Db4o.IO.IoAdapter Open(string path, bool lockFile, long
-			 initialLength)
+		/// <exception cref="Db4objects.Db4o.Ext.Db4oIOException"></exception>
+		public override IoAdapter Open(string path, bool lockFile, long initialLength, bool
+			 readOnly)
 		{
-			return new Db4objects.Db4o.IO.CachedIoAdapter(path, lockFile, initialLength, _io, 
-				_pageSize, _pageCount);
+			return new Db4objects.Db4o.IO.CachedIoAdapter(path, lockFile, initialLength, readOnly
+				, _io, _pageSize, _pageCount);
 		}
 
 		/// <summary>Deletes the database file</summary>
@@ -104,21 +138,22 @@ namespace Db4objects.Db4o.IO
 			return _io.Exists(path);
 		}
 
-		private void InitIOAdaptor(string path, bool lockFile, long initialLength, Db4objects.Db4o.IO.IoAdapter
-			 io)
+		/// <exception cref="Db4objects.Db4o.Ext.Db4oIOException"></exception>
+		private void InitIOAdaptor(string path, bool lockFile, long initialLength, bool readOnly
+			, IoAdapter io)
 		{
-			_io = io.Open(path, lockFile, initialLength);
+			_io = io.Open(path, lockFile, initialLength, readOnly);
 		}
 
 		private void InitCache()
 		{
-			_head = new Db4objects.Db4o.IO.CachedIoAdapter.Page(_pageSize);
+			_head = new CachedIoAdapter.Page(_pageSize);
 			_head._prev = null;
-			Db4objects.Db4o.IO.CachedIoAdapter.Page page = _head;
-			Db4objects.Db4o.IO.CachedIoAdapter.Page next = _head;
+			CachedIoAdapter.Page page = _head;
+			CachedIoAdapter.Page next = _head;
 			for (int i = 0; i < _pageCount - 1; ++i)
 			{
-				next = new Db4objects.Db4o.IO.CachedIoAdapter.Page(_pageSize);
+				next = new CachedIoAdapter.Page(_pageSize);
 				page._next = next;
 				next._prev = page;
 				page = next;
@@ -133,10 +168,11 @@ namespace Db4objects.Db4o.IO
 		/// </remarks>
 		/// <param name="buffer">destination buffer</param>
 		/// <param name="length">how many bytes to read</param>
+		/// <exception cref="Db4objects.Db4o.Ext.Db4oIOException"></exception>
 		public override int Read(byte[] buffer, int length)
 		{
 			long startAddress = _position;
-			Db4objects.Db4o.IO.CachedIoAdapter.Page page;
+			CachedIoAdapter.Page page;
 			int readBytes;
 			int bytesToRead = length;
 			int totalRead = 0;
@@ -160,15 +196,18 @@ namespace Db4objects.Db4o.IO
 		/// <summary>Writes the buffer to cache using pages</summary>
 		/// <param name="buffer">source buffer</param>
 		/// <param name="length">how many bytes to write</param>
+		/// <exception cref="Db4objects.Db4o.Ext.Db4oIOException"></exception>
 		public override void Write(byte[] buffer, int length)
 		{
+			ValidateReadOnly();
 			long startAddress = _position;
-			Db4objects.Db4o.IO.CachedIoAdapter.Page page = null;
+			CachedIoAdapter.Page page = null;
 			int writtenBytes;
 			int bytesToWrite = length;
 			int bufferOffset = 0;
 			while (bytesToWrite > 0)
 			{
+				// page doesn't need to loadFromDisk if the whole page is dirty
 				bool loadFromDisk = (bytesToWrite < _pageSize) || (startAddress % _pageSize != 0);
 				page = GetPage(startAddress, loadFromDisk);
 				page.EnsureEndAddress(GetLength());
@@ -184,38 +223,56 @@ namespace Db4objects.Db4o.IO
 			}
 			long endAddress = startAddress;
 			_position = endAddress;
-			_fileLength = System.Math.Max(endAddress, _fileLength);
+			_fileLength = Math.Max(endAddress, _fileLength);
+		}
+
+		private void ValidateReadOnly()
+		{
+			if (_readOnly)
+			{
+				throw new Db4oIOException();
+			}
 		}
 
 		/// <summary>Flushes cache to a physical storage</summary>
+		/// <exception cref="Db4objects.Db4o.Ext.Db4oIOException"></exception>
 		public override void Sync()
 		{
+			ValidateReadOnly();
 			FlushAllPages();
 			_io.Sync();
 		}
 
 		/// <summary>Returns the file length</summary>
+		/// <exception cref="Db4objects.Db4o.Ext.Db4oIOException"></exception>
 		public override long GetLength()
 		{
 			return _fileLength;
 		}
 
 		/// <summary>Flushes and closes the file</summary>
+		/// <exception cref="Db4objects.Db4o.Ext.Db4oIOException"></exception>
 		public override void Close()
 		{
-			FlushAllPages();
-			_io.Close();
+			try
+			{
+				FlushAllPages();
+			}
+			finally
+			{
+				_io.Close();
+			}
 		}
 
-		public override Db4objects.Db4o.IO.IoAdapter DelegatedIoAdapter()
+		public override IoAdapter DelegatedIoAdapter()
 		{
 			return _io.DelegatedIoAdapter();
 		}
 
-		private Db4objects.Db4o.IO.CachedIoAdapter.Page GetPage(long startAddress, bool loadFromDisk
-			)
+		/// <exception cref="Db4objects.Db4o.Ext.Db4oIOException"></exception>
+		private CachedIoAdapter.Page GetPage(long startAddress, bool loadFromDisk)
 		{
-			Db4objects.Db4o.IO.CachedIoAdapter.Page page = GetPageFromCache(startAddress);
+			CachedIoAdapter.Page page = GetPageFromCache(startAddress);
 			if (page != null)
 			{
 				if (ContainsHeaderBlock(page))
@@ -225,6 +282,7 @@ namespace Db4objects.Db4o.IO
 				page.EnsureEndAddress(_fileLength);
 				return page;
 			}
+			// in case that page is not found in the cache
 			page = GetFreePageFromCache();
 			if (loadFromDisk)
 			{
@@ -237,30 +295,32 @@ namespace Db4objects.Db4o.IO
 			return page;
 		}
 
-		private bool ContainsHeaderBlock(Db4objects.Db4o.IO.CachedIoAdapter.Page page)
+		private bool ContainsHeaderBlock(CachedIoAdapter.Page page)
 		{
-			return page.StartAddress() <= Db4objects.Db4o.Internal.Fileheader.FileHeader1.LENGTH;
+			return page.StartAddress() <= FileHeader1.HeaderLength;
 		}
 
-		private void ResetPageAddress(Db4objects.Db4o.IO.CachedIoAdapter.Page page, long 
-			startAddress)
+		private void ResetPageAddress(CachedIoAdapter.Page page, long startAddress)
 		{
 			page.StartAddress(startAddress);
 			page.EndAddress(startAddress + _pageSize);
 		}
 
-		private Db4objects.Db4o.IO.CachedIoAdapter.Page GetFreePageFromCache()
+		/// <exception cref="Db4objects.Db4o.Ext.Db4oIOException"></exception>
+		private CachedIoAdapter.Page GetFreePageFromCache()
 		{
 			if (!_tail.IsFree())
 			{
 				FlushPage(_tail);
 			}
+			// _posPageMap.remove(new Long(tail.startPosition / PAGE_SIZE));
 			return _tail;
 		}
 
-		private Db4objects.Db4o.IO.CachedIoAdapter.Page GetPageFromCache(long pos)
+		/// <exception cref="Db4objects.Db4o.Ext.Db4oIOException"></exception>
+		private CachedIoAdapter.Page GetPageFromCache(long pos)
 		{
-			Db4objects.Db4o.IO.CachedIoAdapter.Page page = _head;
+			CachedIoAdapter.Page page = _head;
 			while (page != null)
 			{
 				if (page.Contains(pos))
@@ -272,9 +332,12 @@ namespace Db4objects.Db4o.IO
 			return null;
 		}
 
+		// Page page = (Page) _posPageMap.get(new Long(pos/PAGE_SIZE));
+		// return page;
+		/// <exception cref="Db4objects.Db4o.Ext.Db4oIOException"></exception>
 		private void FlushAllPages()
 		{
-			Db4objects.Db4o.IO.CachedIoAdapter.Page node = _head;
+			CachedIoAdapter.Page node = _head;
 			while (node != null)
 			{
 				FlushPage(node);
@@ -282,7 +345,8 @@ namespace Db4objects.Db4o.IO
 			}
 		}
 
-		private void FlushPage(Db4objects.Db4o.IO.CachedIoAdapter.Page page)
+		/// <exception cref="Db4objects.Db4o.Ext.Db4oIOException"></exception>
+		private void FlushPage(CachedIoAdapter.Page page)
 		{
 			if (!page._dirty)
 			{
@@ -293,8 +357,8 @@ namespace Db4objects.Db4o.IO
 			return;
 		}
 
-		private void GetPageFromDisk(Db4objects.Db4o.IO.CachedIoAdapter.Page page, long pos
-			)
+		/// <exception cref="Db4objects.Db4o.Ext.Db4oIOException"></exception>
+		private void GetPageFromDisk(CachedIoAdapter.Page page, long pos)
 		{
 			long startAddress = pos - pos % _pageSize;
 			page.StartAddress(startAddress);
@@ -310,7 +374,9 @@ namespace Db4objects.Db4o.IO
 			}
 		}
 
-		private int IoRead(Db4objects.Db4o.IO.CachedIoAdapter.Page page)
+		// _posPageMap.put(new Long(page.startPosition / PAGE_SIZE), page);
+		/// <exception cref="Db4objects.Db4o.Ext.Db4oIOException"></exception>
+		private int IoRead(CachedIoAdapter.Page page)
 		{
 			int count = _io.Read(page._buffer);
 			if (count > 0)
@@ -320,7 +386,7 @@ namespace Db4objects.Db4o.IO
 			return count;
 		}
 
-		private void MovePageToHead(Db4objects.Db4o.IO.CachedIoAdapter.Page page)
+		private void MovePageToHead(CachedIoAdapter.Page page)
 		{
 			if (page == _head)
 			{
@@ -328,7 +394,7 @@ namespace Db4objects.Db4o.IO
 			}
 			if (page == _tail)
 			{
-				Db4objects.Db4o.IO.CachedIoAdapter.Page tempTail = _tail._prev;
+				CachedIoAdapter.Page tempTail = _tail._prev;
 				tempTail._next = null;
 				_tail._next = _head;
 				_tail._prev = null;
@@ -347,20 +413,32 @@ namespace Db4objects.Db4o.IO
 			}
 		}
 
-		private void WritePageToDisk(Db4objects.Db4o.IO.CachedIoAdapter.Page page)
+		/// <exception cref="Db4objects.Db4o.Ext.Db4oIOException"></exception>
+		private void WritePageToDisk(CachedIoAdapter.Page page)
 		{
-			_io.Write(page._buffer, page.Size());
-			_filePointer = page.EndAddress();
-			page._dirty = false;
+			ValidateReadOnly();
+			try
+			{
+				_io.Write(page._buffer, page.Size());
+				_filePointer = page.EndAddress();
+				page._dirty = false;
+			}
+			catch (Db4oIOException e)
+			{
+				_readOnly = true;
+				throw;
+			}
 		}
 
 		/// <summary>Moves the pointer to the specified file position</summary>
 		/// <param name="pos">position within the file</param>
+		/// <exception cref="Db4objects.Db4o.Ext.Db4oIOException"></exception>
 		public override void Seek(long pos)
 		{
 			_position = pos;
 		}
 
+		/// <exception cref="Db4objects.Db4o.Ext.Db4oIOException"></exception>
 		private void IoSeek(long pos)
 		{
 			if (_filePointer != pos)
@@ -378,15 +456,15 @@ namespace Db4objects.Db4o.IO
 
 			internal long _endAddress;
 
-			internal int _bufferSize;
+			internal readonly int _bufferSize;
 
 			internal bool _dirty;
 
-			internal Db4objects.Db4o.IO.CachedIoAdapter.Page _prev;
+			internal CachedIoAdapter.Page _prev;
 
-			internal Db4objects.Db4o.IO.CachedIoAdapter.Page _next;
+			internal CachedIoAdapter.Page _next;
 
-			public static byte[] zeroBytes;
+			private byte[] zeroBytes;
 
 			public Page(int size)
 			{
@@ -399,7 +477,7 @@ namespace Db4objects.Db4o.IO
 				long bufferEndAddress = _startAddress + _bufferSize;
 				if (_endAddress < bufferEndAddress && fileLength > _endAddress)
 				{
-					long newEndAddress = System.Math.Min(fileLength, bufferEndAddress);
+					long newEndAddress = Math.Min(fileLength, bufferEndAddress);
 					if (zeroBytes == null)
 					{
 						zeroBytes = new byte[_bufferSize];
@@ -440,9 +518,10 @@ namespace Db4objects.Db4o.IO
 			{
 				int bufferOffset = (int)(startAddress - _startAddress);
 				int pageAvailbeDataSize = (int)(_endAddress - startAddress);
-				int readBytes = System.Math.Min(pageAvailbeDataSize, length);
+				int readBytes = Math.Min(pageAvailbeDataSize, length);
 				if (readBytes <= 0)
 				{
+					// meaning reach EOF
 					return -1;
 				}
 				System.Array.Copy(_buffer, bufferOffset, @out, outOffset, readBytes);
@@ -453,8 +532,8 @@ namespace Db4objects.Db4o.IO
 				)
 			{
 				int bufferOffset = (int)(startAddress - _startAddress);
-				int pageAvailabeBufferSize = (int)(_bufferSize - bufferOffset);
-				int writtenBytes = System.Math.Min(pageAvailabeBufferSize, length);
+				int pageAvailabeBufferSize = _bufferSize - bufferOffset;
+				int writtenBytes = Math.Min(pageAvailabeBufferSize, length);
 				System.Array.Copy(data, dataOffset, _buffer, bufferOffset, writtenBytes);
 				long endAddress = startAddress + writtenBytes;
 				if (endAddress > _endAddress)
