@@ -1,14 +1,10 @@
-/* Copyright (C) 2004 - 2007  db4objects Inc.  http://www.db4o.com
+/* This file is part of the db4o object database http://www.db4o.com
 
-This file is part of the db4o open source object database.
+Copyright (C) 2004 - 2009  Versant Corporation http://www.versant.com
 
 db4o is free software; you can redistribute it and/or modify it under
-the terms of version 2 of the GNU General Public License as published
-by the Free Software Foundation and as clarified by db4objects' GPL 
-interpretation policy, available at
-http://www.db4o.com/about/company/legalpolicies/gplinterpretation/
-Alternatively you can write to db4objects, Inc., 1900 S Norfolk Street,
-Suite 350, San Mateo, CA 94403, USA.
+the terms of version 3 of the GNU General Public License as published
+by the Free Software Foundation.
 
 db4o is distributed in the hope that it will be useful, but WITHOUT ANY
 WARRANTY; without even the implied warranty of MERCHANTABILITY or
@@ -16,21 +12,20 @@ FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
 for more details.
 
 You should have received a copy of the GNU General Public License along
-with this program; if not, write to the Free Software Foundation, Inc.,
-59 Temple Place - Suite 330, Boston, MA  02111-1307, USA. */
+with this program.  If not, see http://www.gnu.org/licenses/. */
+using System;
+using Db4objects.Db4o;
+using Db4objects.Db4o.IO;
+
 namespace Db4objects.Db4o.IO
 {
-	/// <summary>
-	/// Base class for database file adapters, both for file and memory
-	/// databases.
-	/// </summary>
-	/// <remarks>
-	/// Base class for database file adapters, both for file and memory
-	/// databases.
-	/// </remarks>
+	/// <summary>Base class for database file adapters, both for file and memory databases.
+	/// 	</summary>
+	/// <remarks>Base class for database file adapters, both for file and memory databases.
+	/// 	</remarks>
 	public abstract class IoAdapter
 	{
-		private const int COPY_SIZE = 4096;
+		private const int CopySize = 4096;
 
 		private int _blockSize;
 
@@ -39,12 +34,13 @@ namespace Db4objects.Db4o.IO
 		{
 			if (0 == _blockSize)
 			{
-				throw new System.InvalidOperationException();
+				throw new InvalidOperationException();
 			}
 			return (long)blockAddress * _blockSize + blockAddressOffset;
 		}
 
 		/// <summary>copies a block within a file in block mode</summary>
+		/// <exception cref="Db4objects.Db4o.Ext.Db4oIOException"></exception>
 		public virtual void BlockCopy(int oldAddress, int oldAddressOffset, int newAddress
 			, int newAddressOffset, int length)
 		{
@@ -53,12 +49,14 @@ namespace Db4objects.Db4o.IO
 		}
 
 		/// <summary>sets the read/write pointer in the file using block mode</summary>
+		/// <exception cref="Db4objects.Db4o.Ext.Db4oIOException"></exception>
 		public virtual void BlockSeek(int address)
 		{
 			BlockSeek(address, 0);
 		}
 
 		/// <summary>sets the read/write pointer in the file using block mode</summary>
+		/// <exception cref="Db4objects.Db4o.Ext.Db4oIOException"></exception>
 		public virtual void BlockSeek(int address, int offset)
 		{
 			Seek(RegularAddress(address, offset));
@@ -69,25 +67,31 @@ namespace Db4objects.Db4o.IO
 		{
 			if (blockSize < 1)
 			{
-				throw new System.ArgumentException();
+				throw new ArgumentException();
 			}
 			_blockSize = blockSize;
 		}
 
 		/// <summary>implement to close the adapter</summary>
+		/// <exception cref="Db4objects.Db4o.Ext.Db4oIOException"></exception>
 		public abstract void Close();
 
 		/// <summary>copies a block within a file in absolute mode</summary>
+		/// <exception cref="Db4objects.Db4o.Ext.Db4oIOException"></exception>
 		public virtual void Copy(long oldAddress, long newAddress, int length)
 		{
-			if (length > COPY_SIZE)
+			if (DTrace.enabled)
 			{
-				byte[] buffer = new byte[COPY_SIZE];
+				DTrace.IoCopy.LogLength(newAddress, length);
+			}
+			if (length > CopySize)
+			{
+				byte[] buffer = new byte[CopySize];
 				int pos = 0;
-				while (pos + COPY_SIZE < length)
+				while (pos + CopySize < length)
 				{
 					Copy(buffer, oldAddress + pos, newAddress + pos);
-					pos += COPY_SIZE;
+					pos += CopySize;
 				}
 				oldAddress += pos;
 				newAddress += pos;
@@ -96,6 +100,7 @@ namespace Db4objects.Db4o.IO
 			Copy(new byte[length], oldAddress, newAddress);
 		}
 
+		/// <exception cref="Db4objects.Db4o.Ext.Db4oIOException"></exception>
 		private void Copy(byte[] buffer, long oldAddress, long newAddress)
 		{
 			Seek(oldAddress);
@@ -111,35 +116,43 @@ namespace Db4objects.Db4o.IO
 		public abstract bool Exists(string path);
 
 		/// <summary>implement to return the absolute length of the file</summary>
+		/// <exception cref="Db4objects.Db4o.Ext.Db4oIOException"></exception>
 		public abstract long GetLength();
 
 		/// <summary>implement to open the file</summary>
-		public abstract Db4objects.Db4o.IO.IoAdapter Open(string path, bool lockFile, long
-			 initialLength);
+		/// <exception cref="Db4objects.Db4o.Ext.Db4oIOException"></exception>
+		public abstract IoAdapter Open(string path, bool lockFile, long initialLength, bool
+			 readOnly);
 
 		/// <summary>reads a buffer at the seeked address</summary>
 		/// <returns>the number of bytes read and returned</returns>
+		/// <exception cref="Db4objects.Db4o.Ext.Db4oIOException"></exception>
 		public virtual int Read(byte[] buffer)
 		{
 			return Read(buffer, buffer.Length);
 		}
 
 		/// <summary>implement to read a buffer at the seeked address</summary>
+		/// <exception cref="Db4objects.Db4o.Ext.Db4oIOException"></exception>
 		public abstract int Read(byte[] bytes, int length);
 
 		/// <summary>implement to set the read/write pointer in the file, absolute mode</summary>
+		/// <exception cref="Db4objects.Db4o.Ext.Db4oIOException"></exception>
 		public abstract void Seek(long pos);
 
 		/// <summary>implement to flush the file contents to storage</summary>
+		/// <exception cref="Db4objects.Db4o.Ext.Db4oIOException"></exception>
 		public abstract void Sync();
 
 		/// <summary>writes a buffer to the seeked address</summary>
+		/// <exception cref="Db4objects.Db4o.Ext.Db4oIOException"></exception>
 		public virtual void Write(byte[] bytes)
 		{
 			Write(bytes, bytes.Length);
 		}
 
 		/// <summary>implement to write a buffer at the seeked address</summary>
+		/// <exception cref="Db4objects.Db4o.Ext.Db4oIOException"></exception>
 		public abstract void Write(byte[] buffer, int length);
 
 		/// <summary>returns the block size currently used</summary>
@@ -148,7 +161,9 @@ namespace Db4objects.Db4o.IO
 			return _blockSize;
 		}
 
-		public virtual Db4objects.Db4o.IO.IoAdapter DelegatedIoAdapter()
+		/// <summary>Delegated IO Adapter</summary>
+		/// <returns>reference to itself</returns>
+		public virtual IoAdapter DelegatedIoAdapter()
 		{
 			return this;
 		}
