@@ -1,14 +1,10 @@
-/* Copyright (C) 2004 - 2007  db4objects Inc.  http://www.db4o.com
+/* This file is part of the db4o object database http://www.db4o.com
 
-This file is part of the db4o open source object database.
+Copyright (C) 2004 - 2009  Versant Corporation http://www.versant.com
 
 db4o is free software; you can redistribute it and/or modify it under
-the terms of version 2 of the GNU General Public License as published
-by the Free Software Foundation and as clarified by db4objects' GPL 
-interpretation policy, available at
-http://www.db4o.com/about/company/legalpolicies/gplinterpretation/
-Alternatively you can write to db4objects, Inc., 1900 S Norfolk Street,
-Suite 350, San Mateo, CA 94403, USA.
+the terms of version 3 of the GNU General Public License as published
+by the Free Software Foundation.
 
 db4o is distributed in the hope that it will be useful, but WITHOUT ANY
 WARRANTY; without even the implied warranty of MERCHANTABILITY or
@@ -16,27 +12,30 @@ FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
 for more details.
 
 You should have received a copy of the GNU General Public License along
-with this program; if not, write to the Free Software Foundation, Inc.,
-59 Temple Place - Suite 330, Boston, MA  02111-1307, USA. */
+with this program.  If not, see http://www.gnu.org/licenses/. */
+using Db4objects.Db4o.IO;
+
 namespace Db4objects.Db4o.IO
 {
 	/// <summary>base class for IoAdapters that delegate to other IoAdapters (decorator pattern)
 	/// 	</summary>
-	public abstract class VanillaIoAdapter : Db4objects.Db4o.IO.IoAdapter
+	public abstract class VanillaIoAdapter : IoAdapter
 	{
-		protected Db4objects.Db4o.IO.IoAdapter _delegate;
+		protected IoAdapter _delegate;
 
-		public VanillaIoAdapter(Db4objects.Db4o.IO.IoAdapter delegateAdapter)
+		public VanillaIoAdapter(IoAdapter delegateAdapter)
 		{
 			_delegate = delegateAdapter;
 		}
 
-		protected VanillaIoAdapter(Db4objects.Db4o.IO.IoAdapter delegateAdapter, string path
-			, bool lockFile, long initialLength)
+		/// <exception cref="Db4objects.Db4o.Ext.Db4oIOException"></exception>
+		protected VanillaIoAdapter(IoAdapter delegateAdapter, string path, bool lockFile, 
+			long initialLength, bool readOnly) : this(delegateAdapter.Open(path, lockFile, initialLength
+			, readOnly))
 		{
-			_delegate = delegateAdapter.Open(path, lockFile, initialLength);
 		}
 
+		/// <exception cref="Db4objects.Db4o.Ext.Db4oIOException"></exception>
 		public override void Close()
 		{
 			_delegate.Close();
@@ -52,26 +51,31 @@ namespace Db4objects.Db4o.IO
 			return _delegate.Exists(path);
 		}
 
+		/// <exception cref="Db4objects.Db4o.Ext.Db4oIOException"></exception>
 		public override long GetLength()
 		{
 			return _delegate.GetLength();
 		}
 
+		/// <exception cref="Db4objects.Db4o.Ext.Db4oIOException"></exception>
 		public override int Read(byte[] bytes, int length)
 		{
 			return _delegate.Read(bytes, length);
 		}
 
+		/// <exception cref="Db4objects.Db4o.Ext.Db4oIOException"></exception>
 		public override void Seek(long pos)
 		{
 			_delegate.Seek(pos);
 		}
 
+		/// <exception cref="Db4objects.Db4o.Ext.Db4oIOException"></exception>
 		public override void Sync()
 		{
 			_delegate.Sync();
 		}
 
+		/// <exception cref="Db4objects.Db4o.Ext.Db4oIOException"></exception>
 		public override void Write(byte[] buffer, int length)
 		{
 			_delegate.Write(buffer, length);
