@@ -1,14 +1,10 @@
-/* Copyright (C) 2004 - 2007  db4objects Inc.  http://www.db4o.com
+/* This file is part of the db4o object database http://www.db4o.com
 
-This file is part of the db4o open source object database.
+Copyright (C) 2004 - 2009  Versant Corporation http://www.versant.com
 
 db4o is free software; you can redistribute it and/or modify it under
-the terms of version 2 of the GNU General Public License as published
-by the Free Software Foundation and as clarified by db4objects' GPL 
-interpretation policy, available at
-http://www.db4o.com/about/company/legalpolicies/gplinterpretation/
-Alternatively you can write to db4objects, Inc., 1900 S Norfolk Street,
-Suite 350, San Mateo, CA 94403, USA.
+the terms of version 3 of the GNU General Public License as published
+by the Free Software Foundation.
 
 db4o is distributed in the hope that it will be useful, but WITHOUT ANY
 WARRANTY; without even the implied warranty of MERCHANTABILITY or
@@ -16,8 +12,11 @@ FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
 for more details.
 
 You should have received a copy of the GNU General Public License along
-with this program; if not, write to the Free Software Foundation, Inc.,
-59 Temple Place - Suite 330, Boston, MA  02111-1307, USA. */
+with this program.  If not, see http://www.gnu.org/licenses/. */
+using Db4objects.Db4o;
+using Db4objects.Db4o.Config;
+using Db4objects.Db4o.Ext;
+
 namespace Db4objects.Db4o
 {
 	/// <summary>the db4o server interface.</summary>
@@ -46,26 +45,33 @@ namespace Db4objects.Db4o
 	/// 	</seealso>
 	public interface IObjectServer
 	{
-		/// <summary>closes the <code>ObjectServer</code> and writes all cached data.</summary>
-		/// <remarks>
-		/// closes the <code>ObjectServer</code> and writes all cached data.
+		/// <summary>
+		/// closes the
+		/// <see cref="Db4objects.Db4o.IObjectServer"></see>
+		/// and writes all cached data.
 		/// <br /><br />
-		/// </remarks>
+		/// </summary>
 		/// <returns>
 		/// true - denotes that the last instance connected to the
 		/// used database file was closed.
 		/// </returns>
 		bool Close();
 
-		/// <summary>returns an ObjectServer with extended functionality.</summary>
-		/// <remarks>
-		/// returns an ObjectServer with extended functionality.
-		/// <br /><br />Use this method as a convient accessor to extended methods.
-		/// Every ObjectServer can be casted to an ExtObjectServer.
+		/// <summary>
+		/// returns an
+		/// <see cref="Db4objects.Db4o.IObjectServer"></see>
+		/// with extended functionality.
+		/// <br /><br />Use this method as a convenient accessor to extended methods.
+		/// Every
+		/// <see cref="Db4objects.Db4o.IObjectServer"></see>
+		/// can be casted to an
+		/// <see cref="Db4objects.Db4o.Ext.IExtObjectServer">Db4objects.Db4o.Ext.IExtObjectServer
+		/// 	</see>
+		/// .
 		/// <br /><br />The functionality is split to two interfaces to allow newcomers to
 		/// focus on the essential methods.
-		/// </remarks>
-		Db4objects.Db4o.Ext.IExtObjectServer Ext();
+		/// </summary>
+		IExtObjectServer Ext();
 
 		/// <summary>grants client access to the specified user with the specified password.</summary>
 		/// <remarks>
@@ -89,24 +95,24 @@ namespace Db4objects.Db4o
 		/// <br /><br />Every client has it's own transaction and uses it's own cache
 		/// for it's own version of all peristent objects.
 		/// </remarks>
-		Db4objects.Db4o.IObjectContainer OpenClient();
+		IObjectContainer OpenClient();
 
 		/// <summary>
 		/// See
-		/// <see>openClient()</see>
+		/// <see cref="Db4objects.Db4o.IObjectServer.OpenClient">Db4objects.Db4o.IObjectServer.OpenClient
+		/// 	</see>
 		/// </summary>
 		/// <param name="config">
 		/// a custom
-		/// <see cref="Db4objects.Db4o.Config.IConfiguration">Configuration</see>
+		/// <see cref="Db4objects.Db4o.Config.IConfiguration">IConfiguration</see>
 		/// instance to be obtained via
 		/// <see cref="Db4objects.Db4o.Db4oFactory.NewConfiguration">Db4objects.Db4o.Db4oFactory.NewConfiguration
 		/// 	</see>
 		/// </param>
 		/// <returns>
 		/// an open
-		/// <see cref="Db4objects.Db4o.IObjectContainer">ObjectContainer</see>
+		/// <see cref="Db4objects.Db4o.IObjectContainer">IObjectContainer</see>
 		/// </returns>
-		Db4objects.Db4o.IObjectContainer OpenClient(Db4objects.Db4o.Config.IConfiguration
-			 config);
+		IObjectContainer OpenClient(IConfiguration config);
 	}
 }
