@@ -1,14 +1,10 @@
-/* Copyright (C) 2004 - 2007  db4objects Inc.  http://www.db4o.com
+/* This file is part of the db4o object database http://www.db4o.com
 
-This file is part of the db4o open source object database.
+Copyright (C) 2004 - 2009  Versant Corporation http://www.versant.com
 
 db4o is free software; you can redistribute it and/or modify it under
-the terms of version 2 of the GNU General Public License as published
-by the Free Software Foundation and as clarified by db4objects' GPL 
-interpretation policy, available at
-http://www.db4o.com/about/company/legalpolicies/gplinterpretation/
-Alternatively you can write to db4objects, Inc., 1900 S Norfolk Street,
-Suite 350, San Mateo, CA 94403, USA.
+the terms of version 3 of the GNU General Public License as published
+by the Free Software Foundation.
 
 db4o is distributed in the hope that it will be useful, but WITHOUT ANY
 WARRANTY; without even the implied warranty of MERCHANTABILITY or
@@ -16,8 +12,17 @@ FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
 for more details.
 
 You should have received a copy of the GNU General Public License along
-with this program; if not, write to the Free Software Foundation, Inc.,
-59 Temple Place - Suite 330, Boston, MA  02111-1307, USA. */
+with this program.  If not, see http://www.gnu.org/licenses/. */
+using System.IO;
+using Db4objects.Db4o;
+using Db4objects.Db4o.Ext;
+using Db4objects.Db4o.Foundation.IO;
+using Db4objects.Db4o.Internal;
+using Db4objects.Db4o.Internal.Activation;
+using Db4objects.Db4o.Types;
+using Sharpen;
+using Sharpen.IO;
+
 namespace Db4objects.Db4o.Internal
 {
 	/// <summary>
@@ -30,9 +35,9 @@ namespace Db4objects.Db4o.Internal
 	/// </remarks>
 	/// <moveto>com.db4o.internal.blobs</moveto>
 	/// <exclude></exclude>
-	public class BlobImpl : Db4objects.Db4o.Types.IBlob, Sharpen.Lang.ICloneable, Db4objects.Db4o.Internal.IDb4oTypeImpl
+	public class BlobImpl : IBlob, System.ICloneable, IDb4oTypeImpl
 	{
-		public const int COPYBUFFER_LENGTH = 4096;
+		public const int CopybufferLength = 4096;
 
 		public string fileName;
 
@@ -42,20 +47,21 @@ namespace Db4objects.Db4o.Internal
 		private Sharpen.IO.File i_file;
 
 		[System.NonSerialized]
-		private Db4objects.Db4o.IBlobStatus i_getStatusFrom;
+		private IBlobStatus i_getStatusFrom;
 
 		public int i_length;
 
 		[System.NonSerialized]
-		private double i_status = Db4objects.Db4o.Ext.Status.UNUSED;
+		private double i_status = Status.Unused;
 
 		[System.NonSerialized]
-		private Db4objects.Db4o.Internal.ObjectContainerBase i_stream;
+		private ObjectContainerBase i_stream;
 
 		[System.NonSerialized]
-		private Db4objects.Db4o.Internal.Transaction i_trans;
+		private Transaction i_trans;
 
-		public virtual int AdjustReadDepth(int a_depth)
+		/// <param name="depth"></param>
+		public virtual int AdjustReadDepth(int depth)
 		{
 			return 1;
 		}
@@ -78,59 +84,30 @@ namespace Db4objects.Db4o.Internal
 			return name;
 		}
 
-		private void Copy(Sharpen.IO.File from, Sharpen.IO.File to)
+		/// <exception cref="System.IO.IOException"></exception>
+		private static void Copy(Sharpen.IO.File from, Sharpen.IO.File to)
 		{
-			to.Delete();
-			Sharpen.IO.BufferedInputStream @in = new Sharpen.IO.BufferedInputStream(new Sharpen.IO.FileInputStream
-				(from));
-			try
-			{
-				Sharpen.IO.BufferedOutputStream @out = new Sharpen.IO.BufferedOutputStream(new Sharpen.IO.FileOutputStream
-					(to));
-				try
-				{
-					byte[] buffer = new byte[COPYBUFFER_LENGTH];
-					int bytesread = -1;
-					while ((bytesread = @in.Read(buffer)) >= 0)
-					{
-						@out.Write(buffer, 0, bytesread);
-					}
-					@out.Flush();
-				}
-				finally
-				{
-					@out.Close();
-				}
-			}
-			finally
-			{
-				@in.Close();
-			}
+			System.IO.File.Copy(from, to);
 		}
 
-		public virtual object CreateDefault(Db4objects.Db4o.Internal.Transaction a_trans)
+		public virtual object CreateDefault(Transaction a_trans)
 		{
-			Db4objects.Db4o.Internal.BlobImpl bi = null;
-			try
-			{
-				bi = (Db4objects.Db4o.Internal.BlobImpl)this.MemberwiseClone();
-				bi.SetTrans(a_trans);
-			}
-			catch (Sharpen.Lang.CloneNotSupportedException)
-			{
-				return null;
-			}
+			BlobImpl bi = null;
+			bi = (BlobImpl)this.MemberwiseClone();
+			bi.SetTrans(a_trans);
 			return bi;
 		}
 
-		public virtual Sharpen.IO.FileInputStream GetClientInputStream()
+		/// <exception cref="System.Exception"></exception>
+		public virtual FileInputStream GetClientInputStream()
 		{
-			return new Sharpen.IO.FileInputStream(i_file);
+			return new FileInputStream(i_file);
 		}
 
-		public virtual Sharpen.IO.FileOutputStream GetClientOutputStream()
+		/// <exception cref="System.Exception"></exception>
+		public virtual FileOutputStream GetClientOutputStream()
 		{
-			return new Sharpen.IO.FileOutputStream(i_file);
+			return new FileOutputStream(i_file);
 		}
 
 		public virtual string GetFileName()
@@ -145,21 +122,21 @@ namespace Db4objects.Db4o.Internal
 
 		public virtual double GetStatus()
 		{
-			if (i_status == Db4objects.Db4o.Ext.Status.PROCESSING && i_getStatusFrom != null)
+			if (i_status == Status.Processing && i_getStatusFrom != null)
 			{
 				return i_getStatusFrom.GetStatus();
 			}
-			if (i_status == Db4objects.Db4o.Ext.Status.UNUSED)
+			if (i_status == Status.Unused)
 			{
 				if (i_length > 0)
 				{
-					i_status = Db4objects.Db4o.Ext.Status.AVAILABLE;
+					i_status = Status.Available;
 				}
 			}
 			return i_status;
 		}
 
-		public virtual void GetStatusFrom(Db4objects.Db4o.IBlobStatus from)
+		public virtual void GetStatusFrom(IBlobStatus from)
 		{
 			i_getStatusFrom = from;
 		}
@@ -169,19 +146,19 @@ namespace Db4objects.Db4o.Internal
 			return false;
 		}
 
+		/// <exception cref="System.IO.IOException"></exception>
 		public virtual void ReadFrom(Sharpen.IO.File file)
 		{
 			if (!file.Exists())
 			{
-				throw new System.IO.IOException(Db4objects.Db4o.Internal.Messages.Get(41, file.GetAbsolutePath
-					()));
+				throw new IOException(Messages.Get(41, file.GetAbsolutePath()));
 			}
 			i_length = (int)file.Length();
 			CheckExt(file);
 			if (i_stream.IsClient())
 			{
 				i_file = file;
-				((Db4objects.Db4o.IBlobTransport)i_stream).ReadBlobFrom(i_trans, this, file);
+				((IBlobTransport)i_stream).ReadBlobFrom(i_trans, this, file);
 			}
 			else
 			{
@@ -189,6 +166,7 @@ namespace Db4objects.Db4o.Internal
 			}
 		}
 
+		/// <exception cref="System.IO.IOException"></exception>
 		public virtual void ReadLocal(Sharpen.IO.File file)
 		{
 			bool copied = false;
@@ -206,22 +184,24 @@ namespace Db4objects.Db4o.Internal
 			{
 				Copy(file, ServerFile(CheckExt(file), true));
 			}
-			lock (i_stream.i_lock)
+			lock (i_stream._lock)
 			{
-				i_stream.SetInternal(i_trans, this, false);
+				i_stream.StoreInternal(i_trans, this, false);
 			}
-			i_status = Db4objects.Db4o.Ext.Status.COMPLETED;
+			i_status = Status.Completed;
 		}
 
 		public virtual void PreDeactivate()
 		{
 		}
 
+		// do nothing
+		/// <exception cref="System.IO.IOException"></exception>
 		public virtual Sharpen.IO.File ServerFile(string promptName, bool writeToServer)
 		{
-			lock (i_stream.i_lock)
+			lock (i_stream._lock)
 			{
-				i_stream.Activate1(i_trans, this, 2);
+				i_stream.Activate(i_trans, this, new FixedActivationDepth(2));
 			}
 			string path = ServerPath();
 			i_stream.ConfigImpl().EnsureDirExists(path);
@@ -235,7 +215,7 @@ namespace Db4objects.Db4o.Internal
 					}
 					else
 					{
-						fileName = "b_" + Sharpen.Runtime.CurrentTimeMillis();
+						fileName = "b_" + Runtime.CurrentTimeMillis();
 					}
 					string tryPath = fileName + i_ext;
 					int i = 0;
@@ -244,14 +224,15 @@ namespace Db4objects.Db4o.Internal
 						tryPath = fileName + "_" + i++ + i_ext;
 						if (i == 99)
 						{
-							i_status = Db4objects.Db4o.Ext.Status.ERROR;
-							throw new System.IO.IOException(Db4objects.Db4o.Internal.Messages.Get(40));
+							// should never happen
+							i_status = Status.Error;
+							throw new IOException(Messages.Get(40));
 						}
 					}
 					fileName = tryPath;
-					lock (i_stream.i_lock)
+					lock (i_stream._lock)
 					{
-						i_stream.SetInternal(i_trans, this, false);
+						i_stream.StoreInternal(i_trans, this, false);
 					}
 				}
 			}
@@ -259,7 +240,7 @@ namespace Db4objects.Db4o.Internal
 			{
 				if (fileName == null)
 				{
-					throw new System.IO.IOException(Db4objects.Db4o.Internal.Messages.Get(38));
+					throw new IOException(Messages.Get(38));
 				}
 			}
 			string lastTryPath = path + Sharpen.IO.File.separator + fileName;
@@ -267,12 +248,13 @@ namespace Db4objects.Db4o.Internal
 			{
 				if (!(new Sharpen.IO.File(lastTryPath).Exists()))
 				{
-					throw new System.IO.IOException(Db4objects.Db4o.Internal.Messages.Get(39));
+					throw new IOException(Messages.Get(39));
 				}
 			}
 			return new Sharpen.IO.File(lastTryPath);
 		}
 
+		/// <exception cref="System.IO.IOException"></exception>
 		private string ServerPath()
 		{
 			string path = i_stream.ConfigImpl().BlobPath();
@@ -289,29 +271,31 @@ namespace Db4objects.Db4o.Internal
 			i_status = status;
 		}
 
-		public virtual void SetTrans(Db4objects.Db4o.Internal.Transaction a_trans)
+		public virtual void SetTrans(Transaction a_trans)
 		{
 			i_trans = a_trans;
-			i_stream = a_trans.Stream();
+			i_stream = a_trans.Container();
 		}
 
+		/// <exception cref="System.IO.IOException"></exception>
 		public virtual void WriteLocal(Sharpen.IO.File file)
 		{
 			Copy(ServerFile(null, false), file);
-			i_status = Db4objects.Db4o.Ext.Status.COMPLETED;
+			i_status = Status.Completed;
 		}
 
+		/// <exception cref="System.IO.IOException"></exception>
 		public virtual void WriteTo(Sharpen.IO.File file)
 		{
-			if (GetStatus() == Db4objects.Db4o.Ext.Status.UNUSED)
+			if (GetStatus() == Status.Unused)
 			{
-				throw new System.IO.IOException(Db4objects.Db4o.Internal.Messages.Get(43));
+				throw new IOException(Messages.Get(43));
 			}
 			if (i_stream.IsClient())
 			{
 				i_file = file;
-				i_status = Db4objects.Db4o.Ext.Status.QUEUED;
-				((Db4objects.Db4o.IBlobTransport)i_stream).WriteBlobTo(i_trans, this, file);
+				i_status = Status.Queued;
+				((IBlobTransport)i_stream).WriteBlobTo(i_trans, this, file);
 			}
 			else
 			{
@@ -319,18 +303,44 @@ namespace Db4objects.Db4o.Internal
 			}
 		}
 
-		public virtual void ReplicateFrom(object obj)
-		{
-		}
-
-		public virtual object StoredTo(Db4objects.Db4o.Internal.Transaction a_trans)
+		public virtual object StoredTo(Transaction a_trans)
 		{
 			return this;
 		}
 
-		public virtual void SetYapObject(Db4objects.Db4o.Internal.ObjectReference a_yapObject
-			)
+		public virtual void SetObjectReference(ObjectReference a_yapObject)
 		{
 		}
+
+		// not necessary
+		/// <exception cref="System.IO.IOException"></exception>
+		public virtual void DeleteFile()
+		{
+			if (GetStatus() == Status.Unused)
+			{
+				throw new IOException(Messages.Get(43));
+			}
+			if (i_stream.IsClient())
+			{
+				((IBlobTransport)i_stream).DeleteBlobFile(i_trans, this);
+			}
+			else
+			{
+				ServerFile(null, false).Delete();
+			}
+			fileName = null;
+			i_ext = null;
+			i_length = 0;
+			SetStatus(Status.Unused);
+			lock (i_stream._lock)
+			{
+				i_stream.StoreInternal(i_trans, this, false);
+			}
+		}
+
+		object System.ICloneable.Clone()
+		{
+			return MemberwiseClone();
+		}
 	}
 }
