@@ -1,14 +1,10 @@
-/* Copyright (C) 2004 - 2007  db4objects Inc.  http://www.db4o.com
+/* This file is part of the db4o object database http://www.db4o.com
 
-This file is part of the db4o open source object database.
+Copyright (C) 2004 - 2009  Versant Corporation http://www.versant.com
 
 db4o is free software; you can redistribute it and/or modify it under
-the terms of version 2 of the GNU General Public License as published
-by the Free Software Foundation and as clarified by db4objects' GPL 
-interpretation policy, available at
-http://www.db4o.com/about/company/legalpolicies/gplinterpretation/
-Alternatively you can write to db4objects, Inc., 1900 S Norfolk Street,
-Suite 350, San Mateo, CA 94403, USA.
+the terms of version 3 of the GNU General Public License as published
+by the Free Software Foundation.
 
 db4o is distributed in the hope that it will be useful, but WITHOUT ANY
 WARRANTY; without even the implied warranty of MERCHANTABILITY or
@@ -16,8 +12,14 @@ FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
 for more details.
 
 You should have received a copy of the GNU General Public License along
-with this program; if not, write to the Free Software Foundation, Inc.,
-59 Temple Place - Suite 330, Boston, MA  02111-1307, USA. */
+with this program.  If not, see http://www.gnu.org/licenses/. */
+using System;
+using Db4objects.Db4o;
+using Db4objects.Db4o.Foundation;
+using Db4objects.Db4o.Internal;
+using Db4objects.Db4o.Internal.Btree;
+using Sharpen;
+
 namespace Db4objects.Db4o.Internal.Btree
 {
 	/// <summary>
@@ -34,15 +36,13 @@ namespace Db4objects.Db4o.Internal.Btree
 	/// as needed with prepareRead() and prepareWrite().
 	/// </remarks>
 	/// <exclude></exclude>
-	public sealed class BTreeNode : Db4objects.Db4o.Internal.PersistentBase
+	public sealed class BTreeNode : PersistentBase
 	{
-		private const int COUNT_LEAF_AND_3_LINK_LENGTH = (Db4objects.Db4o.Internal.Const4
-			.INT_LENGTH * 4) + 1;
+		private const int CountLeafAnd3LinkLength = (Const4.IntLength * 4) + 1;
 
-		private const int SLOT_LEADING_LENGTH = Db4objects.Db4o.Internal.Const4.LEADING_LENGTH
-			 + COUNT_LEAF_AND_3_LINK_LENGTH;
+		private const int SlotLeadingLength = Const4.LeadingLength + CountLeafAnd3LinkLength;
 
-		internal readonly Db4objects.Db4o.Internal.Btree.BTree _btree;
+		internal readonly BTree _btree;
 
 		private int _count;
 
@@ -63,8 +63,8 @@ namespace Db4objects.Db4o.Internal.Btree
 
 		private bool _dead;
 
-		public BTreeNode(Db4objects.Db4o.Internal.Btree.BTree btree, int count, bool isLeaf
-			, int parentID, int previousID, int nextID)
+		public BTreeNode(BTree btree, int count, bool isLeaf, int parentID, int previousID
+			, int nextID)
 		{
 			_btree = btree;
 			_parentID = parentID;
@@ -75,16 +75,16 @@ namespace Db4objects.Db4o.Internal.Btree
 			PrepareArrays();
 		}
 
-		public BTreeNode(int id, Db4objects.Db4o.Internal.Btree.BTree btree)
+		public BTreeNode(int id, BTree btree)
 		{
 			_btree = btree;
 			SetID(id);
 			SetStateDeactivated();
 		}
 
-		public BTreeNode(Db4objects.Db4o.Internal.Transaction trans, Db4objects.Db4o.Internal.Btree.BTreeNode
-			 firstChild, Db4objects.Db4o.Internal.Btree.BTreeNode secondChild) : this(firstChild
-			._btree, 2, false, 0, 0, 0)
+		public BTreeNode(Transaction trans, Db4objects.Db4o.Internal.Btree.BTreeNode firstChild
+			, Db4objects.Db4o.Internal.Btree.BTreeNode secondChild) : this(firstChild._btree
+			, 2, false, 0, 0, 0)
 		{
 			_keys[0] = firstChild._keys[0];
 			_children[0] = firstChild;
@@ -95,7 +95,7 @@ namespace Db4objects.Db4o.Internal.Btree
 			secondChild.SetParentID(trans, GetID());
 		}
 
-		public Db4objects.Db4o.Internal.Btree.BTree Btree()
+		public BTree Btree()
 		{
 			return _btree;
 		}
@@ -104,17 +104,17 @@ namespace Db4objects.Db4o.Internal.Btree
 		/// the split node if this node is split
 		/// or this if the first key has changed
 		/// </returns>
-		public Db4objects.Db4o.Internal.Btree.BTreeNode Add(Db4objects.Db4o.Internal.Transaction
-			 trans)
+		public Db4objects.Db4o.Internal.Btree.BTreeNode Add(Transaction trans, IPreparedComparison
+			 preparedComparison, object obj)
 		{
-			Db4objects.Db4o.Internal.Buffer reader = PrepareRead(trans);
-			Db4objects.Db4o.Internal.Btree.Searcher s = Search(reader);
+			ByteArrayBuffer reader = PrepareRead(trans);
+			Searcher s = Search(preparedComparison, reader);
 			if (_isLeaf)
 			{
 				PrepareWrite(trans);
 				if (WasRemoved(trans, s))
 				{
-					CancelRemoval(trans, s.Cursor());
+					CancelRemoval(trans, obj, s.Cursor());
 					return null;
 				}
 				if (s.Count() > 0 && !s.BeforeFirst())
@@ -122,12 +122,13 @@ namespace Db4objects.Db4o.Internal.Btree
 					s.MoveForward();
 				}
 				PrepareInsert(s.Cursor());
-				_keys[s.Cursor()] = NewAddPatch(trans);
+				_keys[s.Cursor()] = NewAddPatch(trans, obj);
 			}
 			else
 			{
 				Db4objects.Db4o.Internal.Btree.BTreeNode childNode = Child(reader, s.Cursor());
-				Db4objects.Db4o.Internal.Btree.BTreeNode childNodeOrSplit = childNode.Add(trans);
+				Db4objects.Db4o.Internal.Btree.BTreeNode childNodeOrSplit = childNode.Add(trans, 
+					preparedComparison, obj);
 				if (childNodeOrSplit == null)
 				{
 					return null;
@@ -158,99 +159,87 @@ namespace Db4objects.Db4o.Internal.Btree
 			return _count >= _btree.NodeSize();
 		}
 
-		private Db4objects.Db4o.Internal.Btree.BTreeAdd NewAddPatch(Db4objects.Db4o.Internal.Transaction
-			 trans)
+		private BTreeAdd NewAddPatch(Transaction trans, object obj)
 		{
 			SizeIncrement(trans);
-			return new Db4objects.Db4o.Internal.Btree.BTreeAdd(trans, CurrentKey());
+			return new BTreeAdd(trans, obj);
 		}
 
-		private object CurrentKey()
+		private void CancelRemoval(Transaction trans, object obj, int index)
 		{
-			return KeyHandler().Current();
-		}
-
-		private void CancelRemoval(Db4objects.Db4o.Internal.Transaction trans, int index)
-		{
-			Db4objects.Db4o.Internal.Btree.BTreeUpdate patch = (Db4objects.Db4o.Internal.Btree.BTreeUpdate
-				)KeyPatch(index);
-			Db4objects.Db4o.Internal.Btree.BTreeUpdate nextPatch = patch.RemoveFor(trans);
-			_keys[index] = NewCancelledRemoval(trans, patch.GetObject(), nextPatch);
+			BTreeUpdate patch = (BTreeUpdate)KeyPatch(index);
+			BTreeUpdate nextPatch = patch.RemoveFor(trans);
+			_keys[index] = NewCancelledRemoval(trans, patch.GetObject(), obj, nextPatch);
 			SizeIncrement(trans);
 		}
 
-		private Db4objects.Db4o.Internal.Btree.BTreePatch NewCancelledRemoval(Db4objects.Db4o.Internal.Transaction
-			 trans, object originalObject, Db4objects.Db4o.Internal.Btree.BTreeUpdate existingPatches
-			)
+		private BTreePatch NewCancelledRemoval(Transaction trans, object originalObject, 
+			object currentObject, BTreeUpdate existingPatches)
 		{
-			return new Db4objects.Db4o.Internal.Btree.BTreeCancelledRemoval(trans, originalObject
-				, CurrentKey(), existingPatches);
+			return new BTreeCancelledRemoval(trans, originalObject, currentObject, existingPatches
+				);
 		}
 
-		private void SizeIncrement(Db4objects.Db4o.Internal.Transaction trans)
+		private void SizeIncrement(Transaction trans)
 		{
 			_btree.SizeChanged(trans, 1);
 		}
 
-		private bool WasRemoved(Db4objects.Db4o.Internal.Transaction trans, Db4objects.Db4o.Internal.Btree.Searcher
-			 s)
+		private bool WasRemoved(Transaction trans, Searcher s)
 		{
 			if (!s.FoundMatch())
 			{
 				return false;
 			}
-			Db4objects.Db4o.Internal.Btree.BTreePatch patch = KeyPatch(trans, s.Cursor());
+			BTreePatch patch = KeyPatch(trans, s.Cursor());
 			return patch != null && patch.IsRemove();
 		}
 
-		internal Db4objects.Db4o.Internal.Btree.BTreeNodeSearchResult SearchLeaf(Db4objects.Db4o.Internal.Transaction
-			 trans, Db4objects.Db4o.Internal.Btree.SearchTarget target)
+		internal BTreeNodeSearchResult SearchLeaf(Transaction trans, IPreparedComparison 
+			preparedComparison, SearchTarget target)
 		{
-			Db4objects.Db4o.Internal.Buffer reader = PrepareRead(trans);
-			Db4objects.Db4o.Internal.Btree.Searcher s = Search(reader, target);
+			ByteArrayBuffer reader = PrepareRead(trans);
+			Searcher s = Search(preparedComparison, reader, target);
 			if (!_isLeaf)
 			{
-				return Child(reader, s.Cursor()).SearchLeaf(trans, target);
+				return Child(reader, s.Cursor()).SearchLeaf(trans, preparedComparison, target);
 			}
-			if (!s.FoundMatch() || target == Db4objects.Db4o.Internal.Btree.SearchTarget.ANY 
-				|| target == Db4objects.Db4o.Internal.Btree.SearchTarget.HIGHEST)
+			if (!s.FoundMatch() || target == SearchTarget.Any || target == SearchTarget.Highest)
 			{
-				return new Db4objects.Db4o.Internal.Btree.BTreeNodeSearchResult(trans, reader, Btree
-					(), s, this);
+				return new BTreeNodeSearchResult(trans, reader, Btree(), s, this);
 			}
-			if (target == Db4objects.Db4o.Internal.Btree.SearchTarget.LOWEST)
+			if (target == SearchTarget.Lowest)
 			{
-				Db4objects.Db4o.Internal.Btree.BTreeNodeSearchResult res = FindLowestLeafMatch(trans
-					, s.Cursor() - 1);
+				BTreeNodeSearchResult res = FindLowestLeafMatch(trans, preparedComparison, s.Cursor
+					() - 1);
 				if (res != null)
 				{
 					return res;
 				}
 				return CreateMatchingSearchResult(trans, reader, s.Cursor());
 			}
-			throw new System.InvalidOperationException();
+			throw new InvalidOperationException();
 		}
 
-		private Db4objects.Db4o.Internal.Btree.BTreeNodeSearchResult FindLowestLeafMatch(
-			Db4objects.Db4o.Internal.Transaction trans, int index)
+		private BTreeNodeSearchResult FindLowestLeafMatch(Transaction trans, IPreparedComparison
+			 preparedComparison, int index)
 		{
-			return FindLowestLeafMatch(trans, PrepareRead(trans), index);
+			return FindLowestLeafMatch(trans, preparedComparison, PrepareRead(trans), index);
 		}
 
-		private Db4objects.Db4o.Internal.Btree.BTreeNodeSearchResult FindLowestLeafMatch(
-			Db4objects.Db4o.Internal.Transaction trans, Db4objects.Db4o.Internal.Buffer reader
-			, int index)
+		private BTreeNodeSearchResult FindLowestLeafMatch(Transaction trans, IPreparedComparison
+			 preparedComparison, ByteArrayBuffer reader, int index)
 		{
 			if (index >= 0)
 			{
-				if (!CompareEquals(reader, index))
+				if (!CompareEquals(preparedComparison, reader, index))
 				{
 					return null;
 				}
 				if (index > 0)
 				{
-					Db4objects.Db4o.Internal.Btree.BTreeNodeSearchResult res = FindLowestLeafMatch(trans
-						, reader, index - 1);
+					BTreeNodeSearchResult res = FindLowestLeafMatch(trans, preparedComparison, reader
+						, index - 1);
 					if (res != null)
 					{
 						return res;
@@ -261,9 +250,9 @@ namespace Db4objects.Db4o.Internal.Btree
 			Db4objects.Db4o.Internal.Btree.BTreeNode node = PreviousNode();
 			if (node != null)
 			{
-				Db4objects.Db4o.Internal.Buffer nodeReader = node.PrepareRead(trans);
-				Db4objects.Db4o.Internal.Btree.BTreeNodeSearchResult res = node.FindLowestLeafMatch
-					(trans, nodeReader, node.LastIndex());
+				ByteArrayBuffer nodeReader = node.PrepareRead(trans);
+				BTreeNodeSearchResult res = node.FindLowestLeafMatch(trans, preparedComparison, nodeReader
+					, node.LastIndex());
 				if (res != null)
 				{
 					return res;
@@ -276,21 +265,20 @@ namespace Db4objects.Db4o.Internal.Btree
 			return CreateMatchingSearchResult(trans, reader, index);
 		}
 
-		private bool CompareEquals(Db4objects.Db4o.Internal.Buffer reader, int index)
+		private bool CompareEquals(IPreparedComparison preparedComparison, ByteArrayBuffer
+			 reader, int index)
 		{
 			if (CanWrite())
 			{
-				return CompareInWriteMode(index) == 0;
+				return CompareInWriteMode(preparedComparison, index) == 0;
 			}
-			return CompareInReadMode(reader, index) == 0;
+			return CompareInReadMode(preparedComparison, reader, index) == 0;
 		}
 
-		private Db4objects.Db4o.Internal.Btree.BTreeNodeSearchResult CreateMatchingSearchResult
-			(Db4objects.Db4o.Internal.Transaction trans, Db4objects.Db4o.Internal.Buffer reader
-			, int index)
+		private BTreeNodeSearchResult CreateMatchingSearchResult(Transaction trans, ByteArrayBuffer
+			 reader, int index)
 		{
-			return new Db4objects.Db4o.Internal.Btree.BTreeNodeSearchResult(trans, reader, Btree
-				(), this, index, true);
+			return new BTreeNodeSearchResult(trans, reader, Btree(), this, index, true);
 		}
 
 		public bool CanWrite()
@@ -307,8 +295,8 @@ namespace Db4objects.Db4o.Internal.Btree
 			return _btree.ProduceNode(((int)_children[index]));
 		}
 
-		internal Db4objects.Db4o.Internal.Btree.BTreeNode Child(Db4objects.Db4o.Internal.Buffer
-			 reader, int index)
+		internal Db4objects.Db4o.Internal.Btree.BTreeNode Child(ByteArrayBuffer reader, int
+			 index)
 		{
 			if (ChildLoaded(index))
 			{
@@ -326,7 +314,7 @@ namespace Db4objects.Db4o.Internal.Btree
 			return child;
 		}
 
-		private int ChildID(Db4objects.Db4o.Internal.Buffer reader, int index)
+		private int ChildID(ByteArrayBuffer reader, int index)
 		{
 			if (_children == null)
 			{
@@ -363,14 +351,17 @@ namespace Db4objects.Db4o.Internal.Btree
 			return ((Db4objects.Db4o.Internal.Btree.BTreeNode)_children[index]).CanWrite();
 		}
 
-		internal void Commit(Db4objects.Db4o.Internal.Transaction trans)
+		internal void Commit(Transaction trans)
 		{
 			CommitOrRollback(trans, true);
 		}
 
-		internal void CommitOrRollback(Db4objects.Db4o.Internal.Transaction trans, bool isCommit
-			)
+		internal void CommitOrRollback(Transaction trans, bool isCommit)
 		{
+			if (DTrace.enabled)
+			{
+				DTrace.BtreeNodeCommitOrRollback.Log(GetID());
+			}
 			if (_dead)
 			{
 				return;
@@ -390,12 +381,12 @@ namespace Db4objects.Db4o.Internal.Btree
 			for (int i = 0; i < _count; i++)
 			{
 				object key = _keys[i];
-				Db4objects.Db4o.Internal.Btree.BTreePatch patch = KeyPatch(i);
+				BTreePatch patch = KeyPatch(i);
 				if (patch != null)
 				{
 					key = isCommit ? patch.Commit(trans, _btree) : patch.Rollback(trans, _btree);
 				}
-				if (key != Db4objects.Db4o.Foundation.No4.INSTANCE)
+				if (key != No4.Instance)
 				{
 					tempKeys[count] = key;
 					count++;
@@ -408,18 +399,19 @@ namespace Db4objects.Db4o.Internal.Btree
 				return;
 			}
 			SetStateDirty();
+			// TODO: Merge nodes here on low _count value.
 			if (_keys[0] != keyZero)
 			{
 				TellParentAboutChangedKey(trans);
 			}
 		}
 
-		private bool FreeIfEmpty(Db4objects.Db4o.Internal.Transaction trans)
+		private bool FreeIfEmpty(Transaction trans)
 		{
 			return FreeIfEmpty(trans, _count);
 		}
 
-		private bool FreeIfEmpty(Db4objects.Db4o.Internal.Transaction trans, int count)
+		private bool FreeIfEmpty(Transaction trans, int count)
 		{
 			if (count > 0)
 			{
@@ -458,7 +450,7 @@ namespace Db4objects.Db4o.Internal.Btree
 			return GetID();
 		}
 
-		private void Free(Db4objects.Db4o.Internal.Transaction trans)
+		public override void Free(Transaction trans)
 		{
 			_dead = true;
 			if (!IsRoot())
@@ -468,7 +460,7 @@ namespace Db4objects.Db4o.Internal.Btree
 			}
 			PointPreviousTo(trans, _nextID);
 			PointNextTo(trans, _previousID);
-			trans.SystemTransaction().SlotFreePointerOnCommit(GetID());
+			base.Free(trans);
 			_btree.RemoveNode(this);
 		}
 
@@ -487,7 +479,7 @@ namespace Db4objects.Db4o.Internal.Btree
 			}
 		}
 
-		private void RemoveChild(Db4objects.Db4o.Internal.Transaction trans, Db4objects.Db4o.Internal.Btree.BTreeNode
+		private void RemoveChild(Transaction trans, Db4objects.Db4o.Internal.Btree.BTreeNode
 			 child)
 		{
 			PrepareWrite(trans);
@@ -507,15 +499,16 @@ namespace Db4objects.Db4o.Internal.Btree
 					}
 					if (_count == 0)
 					{
+						// root node empty case only, have to turn it into a leaf
 						_isLeaf = true;
 					}
 					return;
 				}
 			}
-			throw new System.InvalidOperationException("child not found");
+			throw new InvalidOperationException("child not found");
 		}
 
-		private void KeyChanged(Db4objects.Db4o.Internal.Transaction trans, Db4objects.Db4o.Internal.Btree.BTreeNode
+		private void KeyChanged(Transaction trans, Db4objects.Db4o.Internal.Btree.BTreeNode
 			 child)
 		{
 			PrepareWrite(trans);
@@ -530,11 +523,10 @@ namespace Db4objects.Db4o.Internal.Btree
 					return;
 				}
 			}
-			throw new System.InvalidOperationException("child not found");
+			throw new InvalidOperationException("child not found");
 		}
 
-		private void TellParentAboutChangedKey(Db4objects.Db4o.Internal.Transaction trans
-			)
+		private void TellParentAboutChangedKey(Transaction trans)
 		{
 			if (!IsRoot())
 			{
@@ -543,7 +535,7 @@ namespace Db4objects.Db4o.Internal.Btree
 			}
 		}
 
-		private bool IsDirty(Db4objects.Db4o.Internal.Transaction trans)
+		private bool IsDirty(Transaction trans)
 		{
 			if (!CanWrite())
 			{
@@ -559,15 +551,16 @@ namespace Db4objects.Db4o.Internal.Btree
 			return false;
 		}
 
-		private int CompareInWriteMode(int index)
+		private int CompareInWriteMode(IPreparedComparison preparedComparison, int index)
 		{
-			return KeyHandler().CompareTo(Key(index));
+			return -preparedComparison.CompareTo(Key(index));
 		}
 
-		private int CompareInReadMode(Db4objects.Db4o.Internal.Buffer reader, int index)
+		private int CompareInReadMode(IPreparedComparison preparedComparison, ByteArrayBuffer
+			 reader, int index)
 		{
 			SeekKey(reader, index);
-			return KeyHandler().CompareTo(KeyHandler().ReadIndexEntry(reader));
+			return -preparedComparison.CompareTo(KeyHandler().ReadIndexEntry(reader));
 		}
 
 		public int Count()
@@ -580,12 +573,12 @@ namespace Db4objects.Db4o.Internal.Btree
 			int len = KeyHandler().LinkLength();
 			if (!_isLeaf)
 			{
-				len += Db4objects.Db4o.Internal.Const4.ID_LENGTH;
+				len += Const4.IdLength;
 			}
 			return len;
 		}
 
-		public int FirstKeyIndex(Db4objects.Db4o.Internal.Transaction trans)
+		public int FirstKeyIndex(Transaction trans)
 		{
 			for (int ix = 0; ix < _count; ix++)
 			{
@@ -597,7 +590,7 @@ namespace Db4objects.Db4o.Internal.Btree
 			return -1;
 		}
 
-		public int LastKeyIndex(Db4objects.Db4o.Internal.Transaction trans)
+		public int LastKeyIndex(Transaction trans)
 		{
 			for (int ix = _count - 1; ix >= 0; ix--)
 			{
@@ -609,33 +602,33 @@ namespace Db4objects.Db4o.Internal.Btree
 			return -1;
 		}
 
-		public bool IndexIsValid(Db4objects.Db4o.Internal.Transaction trans, int index)
+		public bool IndexIsValid(Transaction trans, int index)
 		{
 			if (!CanWrite())
 			{
 				return true;
 			}
-			Db4objects.Db4o.Internal.Btree.BTreePatch patch = KeyPatch(index);
+			BTreePatch patch = KeyPatch(index);
 			if (patch == null)
 			{
 				return true;
 			}
-			return patch.Key(trans) != Db4objects.Db4o.Foundation.No4.INSTANCE;
+			return patch.Key(trans) != No4.Instance;
 		}
 
-		private object FirstKey(Db4objects.Db4o.Internal.Transaction trans)
+		private object FirstKey(Transaction trans)
 		{
 			int index = FirstKeyIndex(trans);
 			if (-1 == index)
 			{
-				return Db4objects.Db4o.Foundation.No4.INSTANCE;
+				return No4.Instance;
 			}
 			return Key(trans, index);
 		}
 
 		public override byte GetIdentifier()
 		{
-			return Db4objects.Db4o.Internal.Const4.BTREE_NODE;
+			return Const4.BtreeNode;
 		}
 
 		private void PrepareInsert(int pos)
@@ -656,6 +649,10 @@ namespace Db4objects.Db4o.Internal.Btree
 
 		private void Remove(int pos)
 		{
+			if (DTrace.enabled)
+			{
+				DTrace.BtreeNodeRemove.Log(GetID());
+			}
 			int len = _count - pos;
 			_count--;
 			System.Array.Copy(_keys, pos + 1, _keys, pos, len);
@@ -670,15 +667,14 @@ namespace Db4objects.Db4o.Internal.Btree
 		internal object Key(int index)
 		{
 			object obj = _keys[index];
-			if (obj is Db4objects.Db4o.Internal.Btree.BTreePatch)
+			if (obj is BTreePatch)
 			{
-				return ((Db4objects.Db4o.Internal.Btree.BTreePatch)obj).GetObject();
+				return ((BTreePatch)obj).GetObject();
 			}
 			return obj;
 		}
 
-		internal object Key(Db4objects.Db4o.Internal.Transaction trans, Db4objects.Db4o.Internal.Buffer
-			 reader, int index)
+		internal object Key(Transaction trans, ByteArrayBuffer reader, int index)
 		{
 			if (CanWrite())
 			{
@@ -688,9 +684,9 @@ namespace Db4objects.Db4o.Internal.Btree
 			return KeyHandler().ReadIndexEntry(reader);
 		}
 
-		internal object Key(Db4objects.Db4o.Internal.Transaction trans, int index)
+		internal object Key(Transaction trans, int index)
 		{
-			Db4objects.Db4o.Internal.Btree.BTreePatch patch = KeyPatch(index);
+			BTreePatch patch = KeyPatch(index);
 			if (patch == null)
 			{
 				return _keys[index];
@@ -698,28 +694,27 @@ namespace Db4objects.Db4o.Internal.Btree
 			return patch.Key(trans);
 		}
 
-		private Db4objects.Db4o.Internal.Btree.BTreePatch KeyPatch(int index)
+		private BTreePatch KeyPatch(int index)
 		{
 			object obj = _keys[index];
-			if (obj is Db4objects.Db4o.Internal.Btree.BTreePatch)
+			if (obj is BTreePatch)
 			{
-				return (Db4objects.Db4o.Internal.Btree.BTreePatch)obj;
+				return (BTreePatch)obj;
 			}
 			return null;
 		}
 
-		private Db4objects.Db4o.Internal.Btree.BTreePatch KeyPatch(Db4objects.Db4o.Internal.Transaction
-			 trans, int index)
+		private BTreePatch KeyPatch(Transaction trans, int index)
 		{
 			object obj = _keys[index];
-			if (obj is Db4objects.Db4o.Internal.Btree.BTreePatch)
+			if (obj is BTreePatch)
 			{
-				return ((Db4objects.Db4o.Internal.Btree.BTreePatch)obj).ForTransaction(trans);
+				return ((BTreePatch)obj).ForTransaction(trans);
 			}
 			return null;
 		}
 
-		private Db4objects.Db4o.Internal.IX.IIndexable4 KeyHandler()
+		private IIndexable4 KeyHandler()
 		{
 			return _btree.KeyHandler();
 		}
@@ -749,12 +744,10 @@ namespace Db4objects.Db4o.Internal.Btree
 
 		public override int OwnLength()
 		{
-			return SLOT_LEADING_LENGTH + (_count * EntryLength()) + Db4objects.Db4o.Internal.Const4
-				.BRACKETS_BYTES;
+			return SlotLeadingLength + (_count * EntryLength()) + Const4.BracketsBytes;
 		}
 
-		internal Db4objects.Db4o.Internal.Buffer PrepareRead(Db4objects.Db4o.Internal.Transaction
-			 trans)
+		internal ByteArrayBuffer PrepareRead(Transaction trans)
 		{
 			if (CanWrite())
 			{
@@ -770,13 +763,13 @@ namespace Db4objects.Db4o.Internal.Btree
 				_btree.AddToProcessing(this);
 				return null;
 			}
-			Db4objects.Db4o.Internal.Buffer reader = trans.i_file.ReadReaderByID(trans.SystemTransaction
+			ByteArrayBuffer reader = ((LocalTransaction)trans).File().ReadReaderByID(trans.SystemTransaction
 				(), GetID());
 			ReadNodeHeader(reader);
 			return reader;
 		}
 
-		internal void PrepareWrite(Db4objects.Db4o.Internal.Transaction trans)
+		internal void PrepareWrite(Transaction trans)
 		{
 			if (_dead)
 			{
@@ -805,7 +798,7 @@ namespace Db4objects.Db4o.Internal.Btree
 			}
 		}
 
-		private void ReadNodeHeader(Db4objects.Db4o.Internal.Buffer reader)
+		private void ReadNodeHeader(ByteArrayBuffer reader)
 		{
 			_count = reader.ReadInt();
 			byte leafByte = reader.ReadByte();
@@ -815,8 +808,7 @@ namespace Db4objects.Db4o.Internal.Btree
 			_nextID = reader.ReadInt();
 		}
 
-		public override void ReadThis(Db4objects.Db4o.Internal.Transaction trans, Db4objects.Db4o.Internal.Buffer
-			 reader)
+		public override void ReadThis(Transaction trans, ByteArrayBuffer reader)
 		{
 			ReadNodeHeader(reader);
 			PrepareArrays();
@@ -831,22 +823,23 @@ namespace Db4objects.Db4o.Internal.Btree
 			}
 		}
 
-		public void Remove(Db4objects.Db4o.Internal.Transaction trans, int index)
+		public void Remove(Transaction trans, IPreparedComparison preparedComparison, object
+			 obj, int index)
 		{
 			if (!_isLeaf)
 			{
-				throw new System.InvalidOperationException();
+				throw new InvalidOperationException();
 			}
 			PrepareWrite(trans);
-			Db4objects.Db4o.Internal.Btree.BTreePatch patch = KeyPatch(index);
+			BTreePatch patch = KeyPatch(index);
+			// no patch, no problem, can remove
 			if (patch == null)
 			{
-				_keys[index] = NewRemovePatch(trans);
+				_keys[index] = NewRemovePatch(trans, obj);
 				KeyChanged(trans, index);
 				return;
 			}
-			Db4objects.Db4o.Internal.Btree.BTreePatch transPatch = patch.ForTransaction(trans
-				);
+			BTreePatch transPatch = patch.ForTransaction(trans);
 			if (transPatch != null)
 			{
 				if (transPatch.IsAdd())
@@ -856,45 +849,47 @@ namespace Db4objects.Db4o.Internal.Btree
 				}
 				if (transPatch.IsCancelledRemoval())
 				{
-					Db4objects.Db4o.Internal.Btree.BTreeRemove removePatch = NewRemovePatch(trans, transPatch
-						.GetObject());
-					_keys[index] = ((Db4objects.Db4o.Internal.Btree.BTreeUpdate)patch).ReplacePatch(transPatch
-						, removePatch);
+					BTreeRemove removePatch = ApplyNewRemovePatch(trans, transPatch.GetObject());
+					_keys[index] = ((BTreeUpdate)patch).ReplacePatch(transPatch, removePatch);
 					KeyChanged(trans, index);
 					return;
 				}
 			}
 			else
 			{
+				// If the patch is a removal of a cancelled removal for another
+				// transaction, we need one for this transaction also.
 				if (!patch.IsAdd())
 				{
-					((Db4objects.Db4o.Internal.Btree.BTreeUpdate)patch).Append(NewRemovePatch(trans));
+					((BTreeUpdate)patch).Append(NewRemovePatch(trans, obj));
 					return;
 				}
 			}
+			// now we try if removal is OK for the next element in this node
 			if (index != LastIndex())
 			{
-				if (CompareInWriteMode(index + 1) != 0)
+				if (CompareInWriteMode(preparedComparison, index + 1) != 0)
 				{
 					return;
 				}
-				Remove(trans, index + 1);
+				Remove(trans, preparedComparison, obj, index + 1);
 				return;
 			}
+			// nothing else worked so far, move on to the next node, try there
 			Db4objects.Db4o.Internal.Btree.BTreeNode node = NextNode();
 			if (node == null)
 			{
 				return;
 			}
 			node.PrepareWrite(trans);
-			if (node.CompareInWriteMode(0) != 0)
+			if (node.CompareInWriteMode(preparedComparison, 0) != 0)
 			{
 				return;
 			}
-			node.Remove(trans, 0);
+			node.Remove(trans, preparedComparison, obj, 0);
 		}
 
-		private void CancelAdding(Db4objects.Db4o.Internal.Transaction trans, int index)
+		private void CancelAdding(Transaction trans, int index)
 		{
 			_btree.NotifyRemoveListener(KeyPatch(index).GetObject());
 			if (FreeIfEmpty(trans, _count - 1))
@@ -907,7 +902,7 @@ namespace Db4objects.Db4o.Internal.Btree
 			SizeDecrement(trans);
 		}
 
-		private void SizeDecrement(Db4objects.Db4o.Internal.Transaction trans)
+		private void SizeDecrement(Transaction trans)
 		{
 			_btree.SizeChanged(trans, -1);
 		}
@@ -917,20 +912,18 @@ namespace Db4objects.Db4o.Internal.Btree
 			return _count - 1;
 		}
 
-		private Db4objects.Db4o.Internal.Btree.BTreeRemove NewRemovePatch(Db4objects.Db4o.Internal.Transaction
-			 trans)
+		private BTreeRemove NewRemovePatch(Transaction trans, object obj)
 		{
-			return NewRemovePatch(trans, CurrentKey());
+			return ApplyNewRemovePatch(trans, obj);
 		}
 
-		private Db4objects.Db4o.Internal.Btree.BTreeRemove NewRemovePatch(Db4objects.Db4o.Internal.Transaction
-			 trans, object key)
+		private BTreeRemove ApplyNewRemovePatch(Transaction trans, object key)
 		{
-			_btree.SizeChanged(trans, -1);
-			return new Db4objects.Db4o.Internal.Btree.BTreeRemove(trans, key);
+			SizeDecrement(trans);
+			return new BTreeRemove(trans, key);
 		}
 
-		private void KeyChanged(Db4objects.Db4o.Internal.Transaction trans, int index)
+		private void KeyChanged(Transaction trans, int index)
 		{
 			if (index == 0)
 			{
@@ -938,57 +931,55 @@ namespace Db4objects.Db4o.Internal.Btree
 			}
 		}
 
-		internal void Rollback(Db4objects.Db4o.Internal.Transaction trans)
+		internal void Rollback(Transaction trans)
 		{
 			CommitOrRollback(trans, false);
 		}
 
-		private Db4objects.Db4o.Internal.Btree.Searcher Search(Db4objects.Db4o.Internal.Buffer
-			 reader)
+		private Searcher Search(IPreparedComparison preparedComparison, ByteArrayBuffer reader
+			)
 		{
-			return Search(reader, Db4objects.Db4o.Internal.Btree.SearchTarget.ANY);
+			return Search(preparedComparison, reader, SearchTarget.Any);
 		}
 
-		private Db4objects.Db4o.Internal.Btree.Searcher Search(Db4objects.Db4o.Internal.Buffer
-			 reader, Db4objects.Db4o.Internal.Btree.SearchTarget target)
+		private Searcher Search(IPreparedComparison preparedComparison, ByteArrayBuffer reader
+			, SearchTarget target)
 		{
-			Db4objects.Db4o.Internal.Btree.Searcher s = new Db4objects.Db4o.Internal.Btree.Searcher
-				(target, _count);
+			Searcher s = new Searcher(target, _count);
 			if (CanWrite())
 			{
 				while (s.Incomplete())
 				{
-					s.ResultIs(CompareInWriteMode(s.Cursor()));
+					s.ResultIs(CompareInWriteMode(preparedComparison, s.Cursor()));
 				}
 			}
 			else
 			{
 				while (s.Incomplete())
 				{
-					s.ResultIs(CompareInReadMode(reader, s.Cursor()));
+					s.ResultIs(CompareInReadMode(preparedComparison, reader, s.Cursor()));
 				}
 			}
 			return s;
 		}
 
-		private void SeekAfterKey(Db4objects.Db4o.Internal.Buffer reader, int ix)
+		private void SeekAfterKey(ByteArrayBuffer reader, int ix)
 		{
 			SeekKey(reader, ix);
 			reader._offset += KeyHandler().LinkLength();
 		}
 
-		private void SeekChild(Db4objects.Db4o.Internal.Buffer reader, int ix)
+		private void SeekChild(ByteArrayBuffer reader, int ix)
 		{
 			SeekAfterKey(reader, ix);
 		}
 
-		private void SeekKey(Db4objects.Db4o.Internal.Buffer reader, int ix)
+		private void SeekKey(ByteArrayBuffer reader, int ix)
 		{
-			reader._offset = SLOT_LEADING_LENGTH + (EntryLength() * ix);
+			reader._offset = SlotLeadingLength + (EntryLength() * ix);
 		}
 
-		private Db4objects.Db4o.Internal.Btree.BTreeNode Split(Db4objects.Db4o.Internal.Transaction
-			 trans)
+		private Db4objects.Db4o.Internal.Btree.BTreeNode Split(Transaction trans)
 		{
 			Db4objects.Db4o.Internal.Btree.BTreeNode res = new Db4objects.Db4o.Internal.Btree.BTreeNode
 				(_btree, _btree._halfNodeSize, _isLeaf, _parentID, GetID(), _nextID);
@@ -1028,7 +1019,7 @@ namespace Db4objects.Db4o.Internal.Btree
 			return res;
 		}
 
-		private void PointNextTo(Db4objects.Db4o.Internal.Transaction trans, int id)
+		private void PointNextTo(Transaction trans, int id)
 		{
 			if (_nextID != 0)
 			{
@@ -1036,7 +1027,7 @@ namespace Db4objects.Db4o.Internal.Btree
 			}
 		}
 
-		private void PointPreviousTo(Db4objects.Db4o.Internal.Transaction trans, int id)
+		private void PointPreviousTo(Transaction trans, int id)
 		{
 			if (_previousID != 0)
 			{
@@ -1062,10 +1053,9 @@ namespace Db4objects.Db4o.Internal.Btree
 			return _btree.ProduceNode(_nextID);
 		}
 
-		internal Db4objects.Db4o.Internal.Btree.BTreePointer FirstPointer(Db4objects.Db4o.Internal.Transaction
-			 trans)
+		internal BTreePointer FirstPointer(Transaction trans)
 		{
-			Db4objects.Db4o.Internal.Buffer reader = PrepareRead(trans);
+			ByteArrayBuffer reader = PrepareRead(trans);
 			if (_isLeaf)
 			{
 				return LeafFirstPointer(trans, reader);
@@ -1073,13 +1063,12 @@ namespace Db4objects.Db4o.Internal.Btree
 			return BranchFirstPointer(trans, reader);
 		}
 
-		private Db4objects.Db4o.Internal.Btree.BTreePointer BranchFirstPointer(Db4objects.Db4o.Internal.Transaction
-			 trans, Db4objects.Db4o.Internal.Buffer reader)
+		private BTreePointer BranchFirstPointer(Transaction trans, ByteArrayBuffer reader
+			)
 		{
 			for (int i = 0; i < _count; i++)
 			{
-				Db4objects.Db4o.Internal.Btree.BTreePointer childFirstPointer = Child(reader, i).
-					FirstPointer(trans);
+				BTreePointer childFirstPointer = Child(reader, i).FirstPointer(trans);
 				if (childFirstPointer != null)
 				{
 					return childFirstPointer;
@@ -1088,22 +1077,19 @@ namespace Db4objects.Db4o.Internal.Btree
 			return null;
 		}
 
-		private Db4objects.Db4o.Internal.Btree.BTreePointer LeafFirstPointer(Db4objects.Db4o.Internal.Transaction
-			 trans, Db4objects.Db4o.Internal.Buffer reader)
+		private BTreePointer LeafFirstPointer(Transaction trans, ByteArrayBuffer reader)
 		{
 			int index = FirstKeyIndex(trans);
 			if (index == -1)
 			{
 				return null;
 			}
-			return new Db4objects.Db4o.Internal.Btree.BTreePointer(trans, reader, this, index
-				);
+			return new BTreePointer(trans, reader, this, index);
 		}
 
-		public Db4objects.Db4o.Internal.Btree.BTreePointer LastPointer(Db4objects.Db4o.Internal.Transaction
-			 trans)
+		public BTreePointer LastPointer(Transaction trans)
 		{
-			Db4objects.Db4o.Internal.Buffer reader = PrepareRead(trans);
+			ByteArrayBuffer reader = PrepareRead(trans);
 			if (_isLeaf)
 			{
 				return LeafLastPointer(trans, reader);
@@ -1111,13 +1097,11 @@ namespace Db4objects.Db4o.Internal.Btree
 			return BranchLastPointer(trans, reader);
 		}
 
-		private Db4objects.Db4o.Internal.Btree.BTreePointer BranchLastPointer(Db4objects.Db4o.Internal.Transaction
-			 trans, Db4objects.Db4o.Internal.Buffer reader)
+		private BTreePointer BranchLastPointer(Transaction trans, ByteArrayBuffer reader)
 		{
 			for (int i = _count - 1; i >= 0; i--)
 			{
-				Db4objects.Db4o.Internal.Btree.BTreePointer childLastPointer = Child(reader, i).LastPointer
-					(trans);
+				BTreePointer childLastPointer = Child(reader, i).LastPointer(trans);
 				if (childLastPointer != null)
 				{
 					return childLastPointer;
@@ -1126,16 +1110,14 @@ namespace Db4objects.Db4o.Internal.Btree
 			return null;
 		}
 
-		private Db4objects.Db4o.Internal.Btree.BTreePointer LeafLastPointer(Db4objects.Db4o.Internal.Transaction
-			 trans, Db4objects.Db4o.Internal.Buffer reader)
+		private BTreePointer LeafLastPointer(Transaction trans, ByteArrayBuffer reader)
 		{
 			int index = LastKeyIndex(trans);
 			if (index == -1)
 			{
 				return null;
 			}
-			return new Db4objects.Db4o.Internal.Btree.BTreePointer(trans, reader, this, index
-				);
+			return new BTreePointer(trans, reader, this, index);
 		}
 
 		internal void Purge()
@@ -1156,7 +1138,7 @@ namespace Db4objects.Db4o.Internal.Btree
 			}
 			for (int i = 0; i < _count; i++)
 			{
-				if (_keys[i] is Db4objects.Db4o.Internal.Btree.BTreePatch)
+				if (_keys[i] is BTreePatch)
 				{
 					HoldChildrenAsIDs();
 					_btree.AddNode(this);
@@ -1165,34 +1147,33 @@ namespace Db4objects.Db4o.Internal.Btree
 			}
 		}
 
-		private void SetParentID(Db4objects.Db4o.Internal.Transaction trans, int id)
+		private void SetParentID(Transaction trans, int id)
 		{
 			PrepareWrite(trans);
 			_parentID = id;
 		}
 
-		private void SetPreviousID(Db4objects.Db4o.Internal.Transaction trans, int id)
+		private void SetPreviousID(Transaction trans, int id)
 		{
 			PrepareWrite(trans);
 			_previousID = id;
 		}
 
-		private void SetNextID(Db4objects.Db4o.Internal.Transaction trans, int id)
+		private void SetNextID(Transaction trans, int id)
 		{
 			PrepareWrite(trans);
 			_nextID = id;
 		}
 
-		public void TraverseKeys(Db4objects.Db4o.Internal.Transaction trans, Db4objects.Db4o.Foundation.IVisitor4
-			 visitor)
+		public void TraverseKeys(Transaction trans, IVisitor4 visitor)
 		{
-			Db4objects.Db4o.Internal.Buffer reader = PrepareRead(trans);
+			ByteArrayBuffer reader = PrepareRead(trans);
 			if (_isLeaf)
 			{
 				for (int i = 0; i < _count; i++)
 				{
 					object obj = Key(trans, reader, i);
-					if (obj != Db4objects.Db4o.Foundation.No4.INSTANCE)
+					if (obj != No4.Instance)
 					{
 						visitor.Visit(obj);
 					}
@@ -1220,18 +1201,17 @@ namespace Db4objects.Db4o.Internal.Btree
 			return base.WriteObjectBegin();
 		}
 
-		public override void WriteThis(Db4objects.Db4o.Internal.Transaction trans, Db4objects.Db4o.Internal.Buffer
-			 a_writer)
+		public override void WriteThis(Transaction trans, ByteArrayBuffer a_writer)
 		{
 			int count = 0;
 			int startOffset = a_writer._offset;
-			a_writer.IncrementOffset(COUNT_LEAF_AND_3_LINK_LENGTH);
+			a_writer.IncrementOffset(CountLeafAnd3LinkLength);
 			if (_isLeaf)
 			{
 				for (int i = 0; i < _count; i++)
 				{
 					object obj = Key(trans, i);
-					if (obj != Db4objects.Db4o.Foundation.No4.INSTANCE)
+					if (obj != No4.Instance)
 					{
 						count++;
 						KeyHandler().WriteIndexEntry(a_writer, obj);
@@ -1247,7 +1227,7 @@ namespace Db4objects.Db4o.Internal.Btree
 						Db4objects.Db4o.Internal.Btree.BTreeNode child = (Db4objects.Db4o.Internal.Btree.BTreeNode
 							)_children[i];
 						object childKey = child.FirstKey(trans);
-						if (childKey != Db4objects.Db4o.Foundation.No4.INSTANCE)
+						if (childKey != No4.Instance)
 						{
 							count++;
 							KeyHandler().WriteIndexEntry(a_writer, childKey);
@@ -1265,7 +1245,7 @@ namespace Db4objects.Db4o.Internal.Btree
 			int endOffset = a_writer._offset;
 			a_writer._offset = startOffset;
 			a_writer.WriteInt(count);
-			a_writer.Append(_isLeaf ? (byte)1 : (byte)0);
+			a_writer.WriteByte(_isLeaf ? (byte)1 : (byte)0);
 			a_writer.WriteInt(_parentID);
 			a_writer.WriteInt(_previousID);
 			a_writer.WriteInt(_nextID);
@@ -1306,7 +1286,7 @@ namespace Db4objects.Db4o.Internal.Btree
 			return str;
 		}
 
-		public void DebugLoadFully(Db4objects.Db4o.Internal.Transaction trans)
+		public void DebugLoadFully(Transaction trans)
 		{
 			PrepareWrite(trans);
 			if (_isLeaf)
@@ -1323,35 +1303,44 @@ namespace Db4objects.Db4o.Internal.Btree
 			}
 		}
 
-		public static void DefragIndex(Db4objects.Db4o.Internal.ReaderPair readers, Db4objects.Db4o.Internal.IX.IIndexable4
-			 keyHandler)
+		public static void DefragIndex(DefragmentContextImpl context, IIndexable4 keyHandler
+			)
 		{
-			int count = readers.ReadInt();
-			byte leafByte = readers.ReadByte();
+			// count
+			int count = context.ReadInt();
+			// leafByte
+			byte leafByte = context.ReadByte();
 			bool isLeaf = (leafByte == 1);
-			readers.CopyID();
-			readers.CopyID();
-			readers.CopyID();
+			context.CopyID();
+			// parent ID
+			context.CopyID();
+			// previous ID
+			context.CopyID();
+			// next ID
 			for (int i = 0; i < count; i++)
 			{
-				keyHandler.DefragIndexEntry(readers);
+				keyHandler.DefragIndexEntry(context);
 				if (!isLeaf)
 				{
-					readers.CopyID();
+					context.CopyID();
 				}
 			}
 		}
 
+		public override bool IsFreespaceComponent()
+		{
+			return _btree.IsFreespaceComponent();
+		}
+
 		public bool IsLeaf()
 		{
 			return _isLeaf;
 		}
 
 		/// <summary>This traversal goes over all nodes, not just leafs</summary>
-		internal void TraverseAllNodes(Db4objects.Db4o.Internal.Transaction trans, Db4objects.Db4o.Foundation.IVisitor4
-			 command)
+		internal void TraverseAllNodes(Transaction trans, IVisitor4 command)
 		{
-			Db4objects.Db4o.Internal.Buffer reader = PrepareRead(trans);
+			ByteArrayBuffer reader = PrepareRead(trans);
 			command.Visit(this);
 			if (_isLeaf)
 			{
