@@ -1,14 +1,10 @@
-/* Copyright (C) 2004 - 2007  db4objects Inc.  http://www.db4o.com
+/* This file is part of the db4o object database http://www.db4o.com
 
-This file is part of the db4o open source object database.
+Copyright (C) 2004 - 2009  Versant Corporation http://www.versant.com
 
 db4o is free software; you can redistribute it and/or modify it under
-the terms of version 2 of the GNU General Public License as published
-by the Free Software Foundation and as clarified by db4objects' GPL 
-interpretation policy, available at
-http://www.db4o.com/about/company/legalpolicies/gplinterpretation/
-Alternatively you can write to db4objects, Inc., 1900 S Norfolk Street,
-Suite 350, San Mateo, CA 94403, USA.
+the terms of version 3 of the GNU General Public License as published
+by the Free Software Foundation.
 
 db4o is distributed in the hope that it will be useful, but WITHOUT ANY
 WARRANTY; without even the implied warranty of MERCHANTABILITY or
@@ -16,8 +12,11 @@ FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
 for more details.
 
 You should have received a copy of the GNU General Public License along
-with this program; if not, write to the Free Software Foundation, Inc.,
-59 Temple Place - Suite 330, Boston, MA  02111-1307, USA. */
+with this program.  If not, see http://www.gnu.org/licenses/. */
+using System;
+using Db4objects.Db4o.Internal;
+using Db4objects.Db4o.Internal.Btree;
+
 namespace Db4objects.Db4o.Internal.Btree
 {
 	/// <exclude></exclude>
@@ -59,20 +58,20 @@ namespace Db4objects.Db4o.Internal.Btree
 			return y;
 		}
 
-		private readonly Db4objects.Db4o.Internal.Btree.BTreeNode _node;
+		private readonly BTreeNode _node;
 
 		private readonly int _index;
 
 		private readonly Db4objects.Db4o.Internal.Transaction _transaction;
 
-		private readonly Db4objects.Db4o.Internal.Buffer _nodeReader;
+		private readonly ByteArrayBuffer _nodeReader;
 
-		public BTreePointer(Db4objects.Db4o.Internal.Transaction transaction, Db4objects.Db4o.Internal.Buffer
-			 nodeReader, Db4objects.Db4o.Internal.Btree.BTreeNode node, int index)
+		public BTreePointer(Db4objects.Db4o.Internal.Transaction transaction, ByteArrayBuffer
+			 nodeReader, BTreeNode node, int index)
 		{
 			if (transaction == null || node == null)
 			{
-				throw new System.ArgumentNullException();
+				throw new ArgumentNullException();
 			}
 			_transaction = transaction;
 			_nodeReader = nodeReader;
@@ -90,7 +89,7 @@ namespace Db4objects.Db4o.Internal.Btree
 			return _index;
 		}
 
-		public Db4objects.Db4o.Internal.Btree.BTreeNode Node()
+		public BTreeNode Node()
 		{
 			return _node;
 		}
@@ -100,7 +99,7 @@ namespace Db4objects.Db4o.Internal.Btree
 			return Node().Key(Transaction(), NodeReader(), Index());
 		}
 
-		private Db4objects.Db4o.Internal.Buffer NodeReader()
+		private ByteArrayBuffer NodeReader()
 		{
 			return _nodeReader;
 		}
@@ -118,8 +117,8 @@ namespace Db4objects.Db4o.Internal.Btree
 				indexInMyNode++;
 			}
 			int newIndex = -1;
-			Db4objects.Db4o.Internal.Btree.BTreeNode nextNode = Node();
-			Db4objects.Db4o.Internal.Buffer nextReader = null;
+			BTreeNode nextNode = Node();
+			ByteArrayBuffer nextReader = null;
 			while (newIndex == -1)
 			{
 				nextNode = nextNode.NextNode();
@@ -147,8 +146,8 @@ namespace Db4objects.Db4o.Internal.Btree
 				indexInMyNode--;
 			}
 			int newIndex = -1;
-			Db4objects.Db4o.Internal.Btree.BTreeNode previousNode = Node();
-			Db4objects.Db4o.Internal.Buffer previousReader = null;
+			BTreeNode previousNode = Node();
+			ByteArrayBuffer previousReader = null;
 			while (newIndex == -1)
 			{
 				previousNode = previousNode.PreviousNode();
@@ -196,16 +195,16 @@ namespace Db4objects.Db4o.Internal.Btree
 		{
 			if (null == y)
 			{
-				throw new System.ArgumentNullException();
+				throw new ArgumentNullException();
 			}
 			if (Btree() != y.Btree())
 			{
-				throw new System.ArgumentException();
+				throw new ArgumentException();
 			}
-			return Btree().CompareKeys(Key(), y.Key());
+			return Btree().CompareKeys(Transaction().Context(), Key(), y.Key());
 		}
 
-		private Db4objects.Db4o.Internal.Btree.BTree Btree()
+		private BTree Btree()
 		{
 			return Node().Btree();
 		}
