@@ -1,14 +1,10 @@
-/* Copyright (C) 2004 - 2007  db4objects Inc.  http://www.db4o.com
+/* This file is part of the db4o object database http://www.db4o.com
 
-This file is part of the db4o open source object database.
+Copyright (C) 2004 - 2009  Versant Corporation http://www.versant.com
 
 db4o is free software; you can redistribute it and/or modify it under
-the terms of version 2 of the GNU General Public License as published
-by the Free Software Foundation and as clarified by db4objects' GPL 
-interpretation policy, available at
-http://www.db4o.com/about/company/legalpolicies/gplinterpretation/
-Alternatively you can write to db4objects, Inc., 1900 S Norfolk Street,
-Suite 350, San Mateo, CA 94403, USA.
+the terms of version 3 of the GNU General Public License as published
+by the Free Software Foundation.
 
 db4o is distributed in the hope that it will be useful, but WITHOUT ANY
 WARRANTY; without even the implied warranty of MERCHANTABILITY or
@@ -16,16 +12,19 @@ FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
 for more details.
 
 You should have received a copy of the GNU General Public License along
-with this program; if not, write to the Free Software Foundation, Inc.,
-59 Temple Place - Suite 330, Boston, MA  02111-1307, USA. */
+with this program.  If not, see http://www.gnu.org/licenses/. */
+using System;
+using Db4objects.Db4o.Foundation;
+using Db4objects.Db4o.Internal;
+using Db4objects.Db4o.Internal.Btree;
+
 namespace Db4objects.Db4o.Internal.Btree
 {
 	public abstract class BTreeUpdate : Db4objects.Db4o.Internal.Btree.BTreePatch
 	{
-		protected Db4objects.Db4o.Internal.Btree.BTreeUpdate _next;
+		protected BTreeUpdate _next;
 
-		public BTreeUpdate(Db4objects.Db4o.Internal.Transaction transaction, object obj) : 
-			base(transaction, obj)
+		public BTreeUpdate(Transaction transaction, object obj) : base(transaction, obj)
 		{
 		}
 
@@ -34,7 +33,7 @@ namespace Db4objects.Db4o.Internal.Btree
 			return _next != null;
 		}
 
-		public override Db4objects.Db4o.Internal.Btree.BTreePatch ForTransaction(Db4objects.Db4o.Internal.Transaction
+		public override Db4objects.Db4o.Internal.Btree.BTreePatch ForTransaction(Transaction
 			 trans)
 		{
 			if (_transaction == trans)
@@ -48,8 +47,7 @@ namespace Db4objects.Db4o.Internal.Btree
 			return _next.ForTransaction(trans);
 		}
 
-		public virtual Db4objects.Db4o.Internal.Btree.BTreeUpdate RemoveFor(Db4objects.Db4o.Internal.Transaction
-			 trans)
+		public virtual BTreeUpdate RemoveFor(Transaction trans)
 		{
 			if (_transaction == trans)
 			{
@@ -62,11 +60,12 @@ namespace Db4objects.Db4o.Internal.Btree
 			return _next.RemoveFor(trans);
 		}
 
-		public virtual void Append(Db4objects.Db4o.Internal.Btree.BTreeUpdate patch)
+		public virtual void Append(BTreeUpdate patch)
 		{
 			if (_transaction == patch._transaction)
 			{
-				throw new System.ArgumentException();
+				// don't allow two patches for the same transaction
+				throw new ArgumentException();
 			}
 			if (!HasNext())
 			{
@@ -87,23 +86,29 @@ namespace Db4objects.Db4o.Internal.Btree
 			}
 		}
 
-		protected abstract void Committed(Db4objects.Db4o.Internal.Btree.BTree btree);
+		protected abstract void Committed(BTree btree);
 
-		public override object Commit(Db4objects.Db4o.Internal.Transaction trans, Db4objects.Db4o.Internal.Btree.BTree
-			 btree)
+		public override object Commit(Transaction trans, BTree btree)
 		{
-			Db4objects.Db4o.Internal.Btree.BTreeUpdate patch = (Db4objects.Db4o.Internal.Btree.BTreeUpdate
-				)ForTransaction(trans);
-			if (patch is Db4objects.Db4o.Internal.Btree.BTreeCancelledRemoval)
+			BTreeUpdate patch = (BTreeUpdate)ForTransaction(trans);
+			if (patch is BTreeCancelledRemoval)
 			{
 				object obj = patch.GetCommittedObject();
 				ApplyKeyChange(obj);
 			}
+			else
+			{
+				if (patch is BTreeRemove)
+				{
+					RemovedBy(trans, btree);
+					patch.Committed(btree);
+					return No4.Instance;
+				}
+			}
 			return InternalCommit(trans, btree);
 		}
 
-		protected virtual object InternalCommit(Db4objects.Db4o.Internal.Transaction trans
-			, Db4objects.Db4o.Internal.Btree.BTree btree)
+		protected object InternalCommit(Transaction trans, BTree btree)
 		{
 			if (_transaction == trans)
 			{
@@ -123,9 +128,9 @@ namespace Db4objects.Db4o.Internal.Btree
 
 		private void SetNextIfPatch(object newNext)
 		{
-			if (newNext is Db4objects.Db4o.Internal.Btree.BTreeUpdate)
+			if (newNext is BTreeUpdate)
 			{
-				_next = (Db4objects.Db4o.Internal.Btree.BTreeUpdate)newNext;
+				_next = (BTreeUpdate)newNext;
 			}
 			else
 			{
@@ -135,8 +140,7 @@ namespace Db4objects.Db4o.Internal.Btree
 
 		protected abstract object GetCommittedObject();
 
-		public override object Rollback(Db4objects.Db4o.Internal.Transaction trans, Db4objects.Db4o.Internal.Btree.BTree
-			 btree)
+		public override object Rollback(Transaction trans, BTree btree)
 		{
 			if (_transaction == trans)
 			{
@@ -153,7 +157,7 @@ namespace Db4objects.Db4o.Internal.Btree
 			return this;
 		}
 
-		public override object Key(Db4objects.Db4o.Internal.Transaction trans)
+		public override object Key(Transaction trans)
 		{
 			Db4objects.Db4o.Internal.Btree.BTreePatch patch = ForTransaction(trans);
 			if (patch == null)
@@ -162,13 +166,13 @@ namespace Db4objects.Db4o.Internal.Btree
 			}
 			if (patch.IsRemove())
 			{
-				return Db4objects.Db4o.Foundation.No4.INSTANCE;
+				return No4.Instance;
 			}
 			return patch.GetObject();
 		}
 
-		public virtual Db4objects.Db4o.Internal.Btree.BTreeUpdate ReplacePatch(Db4objects.Db4o.Internal.Btree.BTreePatch
-			 patch, Db4objects.Db4o.Internal.Btree.BTreeUpdate update)
+		public virtual BTreeUpdate ReplacePatch(Db4objects.Db4o.Internal.Btree.BTreePatch
+			 patch, BTreeUpdate update)
 		{
 			if (patch == this)
 			{
@@ -177,10 +181,24 @@ namespace Db4objects.Db4o.Internal.Btree
 			}
 			if (_next == null)
 			{
-				throw new System.InvalidOperationException();
+				throw new InvalidOperationException();
 			}
 			_next = _next.ReplacePatch(patch, update);
 			return this;
 		}
+
+		public virtual void RemovedBy(Transaction trans, BTree btree)
+		{
+			if (trans != _transaction)
+			{
+				AdjustSizeOnRemovalByOtherTransaction(btree);
+			}
+			if (HasNext())
+			{
+				_next.RemovedBy(trans, btree);
+			}
+		}
+
+		protected abstract void AdjustSizeOnRemovalByOtherTransaction(BTree btree);
 	}
 }
