@@ -1,14 +1,10 @@
-/* Copyright (C) 2004 - 2007  db4objects Inc.  http://www.db4o.com
+/* This file is part of the db4o object database http://www.db4o.com
 
-This file is part of the db4o open source object database.
+Copyright (C) 2004 - 2009  Versant Corporation http://www.versant.com
 
 db4o is free software; you can redistribute it and/or modify it under
-the terms of version 2 of the GNU General Public License as published
-by the Free Software Foundation and as clarified by db4objects' GPL 
-interpretation policy, available at
-http://www.db4o.com/about/company/legalpolicies/gplinterpretation/
-Alternatively you can write to db4objects, Inc., 1900 S Norfolk Street,
-Suite 350, San Mateo, CA 94403, USA.
+the terms of version 3 of the GNU General Public License as published
+by the Free Software Foundation.
 
 db4o is distributed in the hope that it will be useful, but WITHOUT ANY
 WARRANTY; without even the implied warranty of MERCHANTABILITY or
@@ -16,8 +12,10 @@ FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
 for more details.
 
 You should have received a copy of the GNU General Public License along
-with this program; if not, write to the Free Software Foundation, Inc.,
-59 Temple Place - Suite 330, Boston, MA  02111-1307, USA. */
+with this program.  If not, see http://www.gnu.org/licenses/. */
+using System;
+using Db4objects.Db4o.Internal.Btree;
+
 namespace Db4objects.Db4o.Internal.Btree
 {
 	/// <exclude></exclude>
@@ -31,15 +29,15 @@ namespace Db4objects.Db4o.Internal.Btree
 
 		private int _cmp;
 
-		private readonly Db4objects.Db4o.Internal.Btree.SearchTarget _target;
+		private readonly SearchTarget _target;
 
 		private readonly int _count;
 
-		public Searcher(Db4objects.Db4o.Internal.Btree.SearchTarget target, int count)
+		public Searcher(SearchTarget target, int count)
 		{
 			if (count < 0)
 			{
-				throw new System.ArgumentException();
+				throw new ArgumentException();
 			}
 			_target = target;
 			_count = count;
@@ -77,26 +75,26 @@ namespace Db4objects.Db4o.Internal.Btree
 				}
 				return;
 			}
-			if (_target == Db4objects.Db4o.Internal.Btree.SearchTarget.ANY)
+			if (_target == SearchTarget.Any)
 			{
 				_lower = _cursor;
 				_upper = _cursor;
 			}
 			else
 			{
-				if (_target == Db4objects.Db4o.Internal.Btree.SearchTarget.HIGHEST)
+				if (_target == SearchTarget.Highest)
 				{
 					_lower = _cursor;
 				}
 				else
 				{
-					if (_target == Db4objects.Db4o.Internal.Btree.SearchTarget.LOWEST)
+					if (_target == SearchTarget.Lowest)
 					{
 						_upper = _cursor;
 					}
 					else
 					{
-						throw new System.InvalidOperationException("Unknown target");
+						throw new InvalidOperationException("Unknown target");
 					}
 				}
 			}
@@ -107,8 +105,7 @@ namespace Db4objects.Db4o.Internal.Btree
 			int oldCursor = _cursor;
 			if (_upper - _lower <= 1)
 			{
-				if ((_target == Db4objects.Db4o.Internal.Btree.SearchTarget.LOWEST) && (_cmp == 0
-					))
+				if ((_target == SearchTarget.Lowest) && (_cmp == 0))
 				{
 					_cursor = _lower;
 				}
@@ -133,6 +130,7 @@ namespace Db4objects.Db4o.Internal.Btree
 			{
 				return false;
 			}
+			// _cursor is 0: not after last
 			return (_cursor == _count - 1) && _cmp < 0;
 		}
 
