@@ -1,14 +1,10 @@
-/* Copyright (C) 2004 - 2007  db4objects Inc.  http://www.db4o.com
+/* This file is part of the db4o object database http://www.db4o.com
 
-This file is part of the db4o open source object database.
+Copyright (C) 2004 - 2009  Versant Corporation http://www.versant.com
 
 db4o is free software; you can redistribute it and/or modify it under
-the terms of version 2 of the GNU General Public License as published
-by the Free Software Foundation and as clarified by db4objects' GPL 
-interpretation policy, available at
-http://www.db4o.com/about/company/legalpolicies/gplinterpretation/
-Alternatively you can write to db4objects, Inc., 1900 S Norfolk Street,
-Suite 350, San Mateo, CA 94403, USA.
+the terms of version 3 of the GNU General Public License as published
+by the Free Software Foundation.
 
 db4o is distributed in the hope that it will be useful, but WITHOUT ANY
 WARRANTY; without even the implied warranty of MERCHANTABILITY or
@@ -16,25 +12,32 @@ FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
 for more details.
 
 You should have received a copy of the GNU General Public License along
-with this program; if not, write to the Free Software Foundation, Inc.,
-59 Temple Place - Suite 330, Boston, MA  02111-1307, USA. */
+with this program.  If not, see http://www.gnu.org/licenses/. */
+using System.Collections;
+using Db4objects.Db4o.Foundation;
+using Db4objects.Db4o.Internal.CS;
+using Db4objects.Db4o.Internal.Query.Result;
+using Sharpen;
+
 namespace Db4objects.Db4o.Internal.CS
 {
 	/// <exclude></exclude>
-	internal class ClientQueryResultIterator : System.Collections.IEnumerator
+	internal class ClientQueryResultIterator : IEnumerator
 	{
+		private static readonly IPrefetchingStrategy _prefetchingStrategy = SingleMessagePrefetchingStrategy
+			.Instance;
+
 		private object[] _prefetchedObjects;
 
 		private int _remainingObjects;
 
 		private int _prefetchRight;
 
-		private readonly Db4objects.Db4o.Internal.Query.Result.AbstractQueryResult _client;
+		private readonly AbstractQueryResult _client;
 
-		private readonly Db4objects.Db4o.Foundation.IIntIterator4 _ids;
+		private readonly IIntIterator4 _ids;
 
-		public ClientQueryResultIterator(Db4objects.Db4o.Internal.Query.Result.AbstractQueryResult
-			 client)
+		internal ClientQueryResultIterator(AbstractQueryResult client)
 		{
 			_client = client;
 			_ids = client.IterateIDs();
@@ -83,6 +86,7 @@ namespace Db4objects.Db4o.Internal.CS
 
 		private bool SkipNulls()
 		{
+			// skip nulls (deleted objects)
 			if (PrefetchedCurrent() == null)
 			{
 				return MoveNext();
@@ -93,8 +97,8 @@ namespace Db4objects.Db4o.Internal.CS
 		private void Prefetch()
 		{
 			EnsureObjectCacheAllocated(PrefetchCount());
-			_remainingObjects = Stream().PrefetchObjects(_ids, _prefetchedObjects, PrefetchCount
-				());
+			_remainingObjects = _prefetchingStrategy.PrefetchObjects(Stream(), _client.Transaction
+				(), _ids, _prefetchedObjects, PrefetchCount());
 			_prefetchRight = _remainingObjects;
 		}
 
@@ -103,9 +107,9 @@ namespace Db4objects.Db4o.Internal.CS
 			return Stream().Config().PrefetchObjectCount();
 		}
 
-		private Db4objects.Db4o.Internal.CS.ClientObjectContainer Stream()
+		private ClientObjectContainer Stream()
 		{
-			return (Db4objects.Db4o.Internal.CS.ClientObjectContainer)_client.Stream();
+			return (ClientObjectContainer)_client.Stream();
 		}
 
 		private object PrefetchedCurrent()
@@ -113,6 +117,20 @@ namespace Db4objects.Db4o.Internal.CS
 			return _prefetchedObjects[_prefetchRight - _remainingObjects - 1];
 		}
 
+		// TODO: open this as an external tuning interface in ExtObjectSet
+		//	public void prefetch(int count){
+		//		if(count < 1){
+		//			count = 1;
+		//		}
+		//		i_prefetchCount = count;
+		//		Object[] temp = new Object[i_prefetchCount];
+		//		if(i_remainingObjects > 0){
+		//			// Potential problem here: 
+		//			// On reducing the prefetch size, this will crash.
+		//			System.arraycopy(i_prefetched, 0, temp, 0, i_remainingObjects);
+		//		}
+		//		i_prefetched = temp;
+		//	}
 		private void EnsureObjectCacheAllocated(int prefetchObjectCount)
 		{
 			if (_prefetchedObjects == null)
