@@ -1,14 +1,10 @@
-/* Copyright (C) 2004 - 2007  db4objects Inc.  http://www.db4o.com
+/* This file is part of the db4o object database http://www.db4o.com
 
-This file is part of the db4o open source object database.
+Copyright (C) 2004 - 2009  Versant Corporation http://www.versant.com
 
 db4o is free software; you can redistribute it and/or modify it under
-the terms of version 2 of the GNU General Public License as published
-by the Free Software Foundation and as clarified by db4objects' GPL 
-interpretation policy, available at
-http://www.db4o.com/about/company/legalpolicies/gplinterpretation/
-Alternatively you can write to db4objects, Inc., 1900 S Norfolk Street,
-Suite 350, San Mateo, CA 94403, USA.
+the terms of version 3 of the GNU General Public License as published
+by the Free Software Foundation.
 
 db4o is distributed in the hope that it will be useful, but WITHOUT ANY
 WARRANTY; without even the implied warranty of MERCHANTABILITY or
@@ -16,14 +12,18 @@ FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
 for more details.
 
 You should have received a copy of the GNU General Public License along
-with this program; if not, write to the Free Software Foundation, Inc.,
-59 Temple Place - Suite 330, Boston, MA  02111-1307, USA. */
+with this program.  If not, see http://www.gnu.org/licenses/. */
+using System;
+using Db4objects.Db4o.Foundation;
+using Db4objects.Db4o.Internal;
+using Db4objects.Db4o.Internal.CS;
+
 namespace Db4objects.Db4o.Internal.CS
 {
 	/// <exclude></exclude>
-	public class LazyClientIdIterator : Db4objects.Db4o.Foundation.IIntIterator4
+	public class LazyClientIdIterator : IIntIterator4
 	{
-		private readonly Db4objects.Db4o.Internal.CS.LazyClientQueryResult _queryResult;
+		private readonly LazyClientQueryResult _queryResult;
 
 		private int _current;
 
@@ -33,8 +33,7 @@ namespace Db4objects.Db4o.Internal.CS
 
 		private int _available;
 
-		public LazyClientIdIterator(Db4objects.Db4o.Internal.CS.LazyClientQueryResult queryResult
-			)
+		public LazyClientIdIterator(LazyClientQueryResult queryResult)
 		{
 			_queryResult = queryResult;
 			_batchSize = queryResult.Config().PrefetchObjectCount();
@@ -46,7 +45,7 @@ namespace Db4objects.Db4o.Internal.CS
 		{
 			if (_current < 0)
 			{
-				throw new System.InvalidOperationException();
+				throw new InvalidOperationException();
 			}
 			return _ids[_current];
 		}
@@ -84,8 +83,7 @@ namespace Db4objects.Db4o.Internal.CS
 			_current = -1;
 		}
 
-		public virtual void LoadFromIdReader(Db4objects.Db4o.Internal.Buffer reader, int 
-			count)
+		public virtual void LoadFromIdReader(ByteArrayBuffer reader, int count)
 		{
 			for (int i = 0; i < count; i++)
 			{
