@@ -1,14 +1,10 @@
-/* Copyright (C) 2004 - 2007  db4objects Inc.  http://www.db4o.com
+/* This file is part of the db4o object database http://www.db4o.com
 
-This file is part of the db4o open source object database.
+Copyright (C) 2004 - 2009  Versant Corporation http://www.versant.com
 
 db4o is free software; you can redistribute it and/or modify it under
-the terms of version 2 of the GNU General Public License as published
-by the Free Software Foundation and as clarified by db4objects' GPL 
-interpretation policy, available at
-http://www.db4o.com/about/company/legalpolicies/gplinterpretation/
-Alternatively you can write to db4objects, Inc., 1900 S Norfolk Street,
-Suite 350, San Mateo, CA 94403, USA.
+the terms of version 3 of the GNU General Public License as published
+by the Free Software Foundation.
 
 db4o is distributed in the hope that it will be useful, but WITHOUT ANY
 WARRANTY; without even the implied warranty of MERCHANTABILITY or
@@ -16,60 +12,58 @@ FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
 for more details.
 
 You should have received a copy of the GNU General Public License along
-with this program; if not, write to the Free Software Foundation, Inc.,
-59 Temple Place - Suite 330, Boston, MA  02111-1307, USA. */
+with this program.  If not, see http://www.gnu.org/licenses/. */
+using System;
+using Db4objects.Db4o.Query;
+
 namespace Db4objects.Db4o.Internal.Cluster
 {
 	/// <exclude></exclude>
-	public class ClusterConstraint : Db4objects.Db4o.Query.IConstraint
+	public class ClusterConstraint : IConstraint
 	{
 		internal readonly Db4objects.Db4o.Cluster.Cluster _cluster;
 
-		internal readonly Db4objects.Db4o.Query.IConstraint[] _constraints;
+		internal readonly IConstraint[] _constraints;
 
-		public ClusterConstraint(Db4objects.Db4o.Cluster.Cluster cluster, Db4objects.Db4o.Query.IConstraint[]
-			 constraints)
+		public ClusterConstraint(Db4objects.Db4o.Cluster.Cluster cluster, IConstraint[] constraints
+			)
 		{
 			_cluster = cluster;
 			_constraints = constraints;
 		}
 
-		private Db4objects.Db4o.Internal.Cluster.ClusterConstraint Compatible(Db4objects.Db4o.Query.IConstraint
+		private Db4objects.Db4o.Internal.Cluster.ClusterConstraint Compatible(IConstraint
 			 with)
 		{
 			if (!(with is Db4objects.Db4o.Internal.Cluster.ClusterConstraint))
 			{
-				throw new System.ArgumentException();
+				throw new ArgumentException();
 			}
 			Db4objects.Db4o.Internal.Cluster.ClusterConstraint other = (Db4objects.Db4o.Internal.Cluster.ClusterConstraint
 				)with;
 			if (other._constraints.Length != _constraints.Length)
 			{
-				throw new System.ArgumentException();
+				throw new ArgumentException();
 			}
 			return other;
 		}
 
-		public virtual Db4objects.Db4o.Query.IConstraint And(Db4objects.Db4o.Query.IConstraint
-			 with)
+		public virtual IConstraint And(IConstraint with)
 		{
 			return Join(with, true);
 		}
 
-		public virtual Db4objects.Db4o.Query.IConstraint Or(Db4objects.Db4o.Query.IConstraint
-			 with)
+		public virtual IConstraint Or(IConstraint with)
 		{
 			return Join(with, false);
 		}
 
-		private Db4objects.Db4o.Query.IConstraint Join(Db4objects.Db4o.Query.IConstraint 
-			with, bool isAnd)
+		private IConstraint Join(IConstraint with, bool isAnd)
 		{
 			lock (_cluster)
 			{
 				Db4objects.Db4o.Internal.Cluster.ClusterConstraint other = Compatible(with);
-				Db4objects.Db4o.Query.IConstraint[] newConstraints = new Db4objects.Db4o.Query.IConstraint
-					[_constraints.Length];
+				IConstraint[] newConstraints = new IConstraint[_constraints.Length];
 				for (int i = 0; i < _constraints.Length; i++)
 				{
 					newConstraints[i] = isAnd ? _constraints[i].And(other._constraints[i]) : _constraints
@@ -80,7 +74,7 @@ namespace Db4objects.Db4o.Internal.Cluster
 			}
 		}
 
-		public virtual Db4objects.Db4o.Query.IConstraint Equal()
+		public virtual IConstraint Equal()
 		{
 			lock (_cluster)
 			{
@@ -92,7 +86,7 @@ namespace Db4objects.Db4o.Internal.Cluster
 			}
 		}
 
-		public virtual Db4objects.Db4o.Query.IConstraint Greater()
+		public virtual IConstraint Greater()
 		{
 			lock (_cluster)
 			{
@@ -104,7 +98,7 @@ namespace Db4objects.Db4o.Internal.Cluster
 			}
 		}
 
-		public virtual Db4objects.Db4o.Query.IConstraint Smaller()
+		public virtual IConstraint Smaller()
 		{
 			lock (_cluster)
 			{
@@ -116,7 +110,7 @@ namespace Db4objects.Db4o.Internal.Cluster
 			}
 		}
 
-		public virtual Db4objects.Db4o.Query.IConstraint Identity()
+		public virtual IConstraint Identity()
 		{
 			lock (_cluster)
 			{
@@ -128,7 +122,19 @@ namespace Db4objects.Db4o.Internal.Cluster
 			}
 		}
 
-		public virtual Db4objects.Db4o.Query.IConstraint Like()
+		public virtual IConstraint ByExample()
+		{
+			lock (_cluster)
+			{
+				for (int i = 0; i < _constraints.Length; i++)
+				{
+					_constraints[i].ByExample();
+				}
+				return this;
+			}
+		}
+
+		public virtual IConstraint Like()
 		{
 			lock (_cluster)
 			{
@@ -140,7 +146,7 @@ namespace Db4objects.Db4o.Internal.Cluster
 			}
 		}
 
-		public virtual Db4objects.Db4o.Query.IConstraint StartsWith(bool caseSensitive)
+		public virtual IConstraint StartsWith(bool caseSensitive)
 		{
 			lock (_cluster)
 			{
@@ -152,7 +158,7 @@ namespace Db4objects.Db4o.Internal.Cluster
 			}
 		}
 
-		public virtual Db4objects.Db4o.Query.IConstraint EndsWith(bool caseSensitive)
+		public virtual IConstraint EndsWith(bool caseSensitive)
 		{
 			lock (_cluster)
 			{
@@ -164,7 +170,7 @@ namespace Db4objects.Db4o.Internal.Cluster
 			}
 		}
 
-		public virtual Db4objects.Db4o.Query.IConstraint Contains()
+		public virtual IConstraint Contains()
 		{
 			lock (_cluster)
 			{
@@ -176,7 +182,7 @@ namespace Db4objects.Db4o.Internal.Cluster
 			}
 		}
 
-		public virtual Db4objects.Db4o.Query.IConstraint Not()
+		public virtual IConstraint Not()
 		{
 			lock (_cluster)
 			{
@@ -190,7 +196,7 @@ namespace Db4objects.Db4o.Internal.Cluster
 
 		public virtual object GetObject()
 		{
-			throw new System.NotSupportedException();
+			throw new NotSupportedException();
 		}
 	}
 }
