@@ -1,14 +1,10 @@
-/* Copyright (C) 2004 - 2007  db4objects Inc.  http://www.db4o.com
+/* This file is part of the db4o object database http://www.db4o.com
 
-This file is part of the db4o open source object database.
+Copyright (C) 2004 - 2009  Versant Corporation http://www.versant.com
 
 db4o is free software; you can redistribute it and/or modify it under
-the terms of version 2 of the GNU General Public License as published
-by the Free Software Foundation and as clarified by db4objects' GPL 
-interpretation policy, available at
-http://www.db4o.com/about/company/legalpolicies/gplinterpretation/
-Alternatively you can write to db4objects, Inc., 1900 S Norfolk Street,
-Suite 350, San Mateo, CA 94403, USA.
+the terms of version 3 of the GNU General Public License as published
+by the Free Software Foundation.
 
 db4o is distributed in the hope that it will be useful, but WITHOUT ANY
 WARRANTY; without even the implied warranty of MERCHANTABILITY or
@@ -16,13 +12,21 @@ FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
 for more details.
 
 You should have received a copy of the GNU General Public License along
-with this program; if not, write to the Free Software Foundation, Inc.,
-59 Temple Place - Suite 330, Boston, MA  02111-1307, USA. */
+with this program.  If not, see http://www.gnu.org/licenses/. */
+using Db4objects.Db4o;
+using Db4objects.Db4o.Events;
+using Db4objects.Db4o.Internal;
+using Db4objects.Db4o.Internal.Callbacks;
+using Db4objects.Db4o.Internal.Events;
+using Db4objects.Db4o.Query;
+
 namespace Db4objects.Db4o.Internal.Events
 {
 	/// <exclude></exclude>
-	public class EventRegistryImpl : Db4objects.Db4o.Internal.Callbacks.ICallbacks, Db4objects.Db4o.Events.IEventRegistry
+	public class EventRegistryImpl : ICallbacks, IEventRegistry
 	{
+		private readonly IInternalObjectContainer _container;
+
 		protected Db4objects.Db4o.Events.QueryEventHandler _queryStarted;
 
 		protected Db4objects.Db4o.Events.QueryEventHandler _queryFinished;
@@ -47,83 +51,114 @@ namespace Db4objects.Db4o.Internal.Events
 
 		protected Db4objects.Db4o.Events.ObjectEventHandler _deactivated;
 
+		protected Db4objects.Db4o.Events.CommitEventHandler _committing;
+
+		protected Db4objects.Db4o.Events.CommitEventHandler _committed;
+
+		protected Db4objects.Db4o.Events.ObjectEventHandler _instantiated;
+
 		protected Db4objects.Db4o.Events.ClassEventHandler _classRegistered;
 
-		public virtual void OnQueryFinished(Db4objects.Db4o.Query.IQuery query)
+		protected Db4objects.Db4o.Events.ObjectContainerEventHandler _closing;
+
+		public EventRegistryImpl(IInternalObjectContainer container)
 		{
-			Db4objects.Db4o.Internal.Events.EventPlatform.TriggerQueryEvent(_queryFinished, query
+			_container = container;
+		}
+
+		// Callbacks implementation
+		public virtual void QueryOnFinished(Transaction transaction, IQuery query)
+		{
+			EventPlatform.TriggerQueryEvent(transaction, _queryFinished, query);
+		}
+
+		public virtual void QueryOnStarted(Transaction transaction, IQuery query)
+		{
+			EventPlatform.TriggerQueryEvent(transaction, _queryStarted, query);
+		}
+
+		public virtual bool ObjectCanNew(Transaction transaction, object obj)
+		{
+			return EventPlatform.TriggerCancellableObjectEventArgs(transaction, _creating, obj
 				);
 		}
 
-		public virtual void OnQueryStarted(Db4objects.Db4o.Query.IQuery query)
+		public virtual bool ObjectCanActivate(Transaction transaction, object obj)
 		{
-			Db4objects.Db4o.Internal.Events.EventPlatform.TriggerQueryEvent(_queryStarted, query
+			return EventPlatform.TriggerCancellableObjectEventArgs(transaction, _activating, 
+				obj);
+		}
+
+		public virtual bool ObjectCanUpdate(Transaction transaction, object obj)
+		{
+			return EventPlatform.TriggerCancellableObjectEventArgs(transaction, _updating, obj
 				);
 		}
 
-		public virtual bool ObjectCanNew(object obj)
+		public virtual bool ObjectCanDelete(Transaction transaction, object obj)
 		{
-			return Db4objects.Db4o.Internal.Events.EventPlatform.TriggerCancellableObjectEventArgs
-				(_creating, obj);
-		}
-
-		public virtual bool ObjectCanActivate(object obj)
-		{
-			return Db4objects.Db4o.Internal.Events.EventPlatform.TriggerCancellableObjectEventArgs
-				(_activating, obj);
-		}
-
-		public virtual bool ObjectCanUpdate(object obj)
-		{
-			return Db4objects.Db4o.Internal.Events.EventPlatform.TriggerCancellableObjectEventArgs
-				(_updating, obj);
-		}
-
-		public virtual bool ObjectCanDelete(object obj)
-		{
-			return Db4objects.Db4o.Internal.Events.EventPlatform.TriggerCancellableObjectEventArgs
-				(_deleting, obj);
-		}
-
-		public virtual bool ObjectCanDeactivate(object obj)
-		{
-			return Db4objects.Db4o.Internal.Events.EventPlatform.TriggerCancellableObjectEventArgs
-				(_deactivating, obj);
-		}
-
-		public virtual void ObjectOnActivate(object obj)
-		{
-			Db4objects.Db4o.Internal.Events.EventPlatform.TriggerObjectEvent(_activated, obj);
-		}
-
-		public virtual void ObjectOnNew(object obj)
-		{
-			Db4objects.Db4o.Internal.Events.EventPlatform.TriggerObjectEvent(_created, obj);
-		}
-
-		public virtual void ObjectOnUpdate(object obj)
-		{
-			Db4objects.Db4o.Internal.Events.EventPlatform.TriggerObjectEvent(_updated, obj);
-		}
-
-		public virtual void ObjectOnDelete(object obj)
-		{
-			Db4objects.Db4o.Internal.Events.EventPlatform.TriggerObjectEvent(_deleted, obj);
-		}
-
-		public virtual void ClassOnRegistered(Db4objects.Db4o.Internal.ClassMetadata clazz
-			)
-		{
-			Db4objects.Db4o.Internal.Events.EventPlatform.TriggerClassEvent(_classRegistered, 
-				clazz);
-		}
-
-		public virtual void ObjectOnDeactivate(object obj)
-		{
-			Db4objects.Db4o.Internal.Events.EventPlatform.TriggerObjectEvent(_deactivated, obj
+			return EventPlatform.TriggerCancellableObjectEventArgs(transaction, _deleting, obj
 				);
 		}
 
+		public virtual bool ObjectCanDeactivate(Transaction transaction, object obj)
+		{
+			return EventPlatform.TriggerCancellableObjectEventArgs(transaction, _deactivating
+				, obj);
+		}
+
+		public virtual void ObjectOnActivate(Transaction transaction, object obj)
+		{
+			EventPlatform.TriggerObjectEvent(transaction, _activated, obj);
+		}
+
+		public virtual void ObjectOnNew(Transaction transaction, object obj)
+		{
+			EventPlatform.TriggerObjectEvent(transaction, _created, obj);
+		}
+
+		public virtual void ObjectOnUpdate(Transaction transaction, object obj)
+		{
+			EventPlatform.TriggerObjectEvent(transaction, _updated, obj);
+		}
+
+		public virtual void ObjectOnDelete(Transaction transaction, object obj)
+		{
+			EventPlatform.TriggerObjectEvent(transaction, _deleted, obj);
+		}
+
+		public virtual void ClassOnRegistered(ClassMetadata clazz)
+		{
+			EventPlatform.TriggerClassEvent(_classRegistered, clazz);
+		}
+
+		public virtual void ObjectOnDeactivate(Transaction transaction, object obj)
+		{
+			EventPlatform.TriggerObjectEvent(transaction, _deactivated, obj);
+		}
+
+		public virtual void ObjectOnInstantiate(Transaction transaction, object obj)
+		{
+			EventPlatform.TriggerObjectEvent(transaction, _instantiated, obj);
+		}
+
+		public virtual void CommitOnStarted(Transaction transaction, CallbackObjectInfoCollections
+			 objectInfoCollections)
+		{
+			EventPlatform.TriggerCommitEvent(transaction, _committing, objectInfoCollections);
+		}
+
+		public virtual void CommitOnCompleted(Transaction transaction, CallbackObjectInfoCollections
+			 objectInfoCollections)
+		{
+			EventPlatform.TriggerCommitEvent(transaction, _committed, objectInfoCollections);
+		}
+
+		public virtual void CloseOnStarted(IObjectContainer container)
+		{
+			EventPlatform.TriggerObjectContainerEvent(container, _closing);
+		}
+
 		public virtual event Db4objects.Db4o.Events.QueryEventHandler QueryFinished
 		{
 			add
@@ -236,20 +271,6 @@ namespace Db4objects.Db4o.Internal.Events
 			}
 		}
 
-		public virtual event Db4objects.Db4o.Events.ClassEventHandler ClassRegistered
-		{
-			add
-			{
-				_classRegistered = (Db4objects.Db4o.Events.ClassEventHandler)System.Delegate.Combine
-					(_classRegistered, value);
-			}
-			remove
-			{
-				_classRegistered = (Db4objects.Db4o.Events.ClassEventHandler)System.Delegate.Remove
-					(_classRegistered, value);
-			}
-		}
-
 		public virtual event Db4objects.Db4o.Events.ObjectEventHandler Activated
 		{
 			add
@@ -305,5 +326,103 @@ namespace Db4objects.Db4o.Internal.Events
 					_deactivated, value);
 			}
 		}
+
+		public virtual event Db4objects.Db4o.Events.CommitEventHandler Committing
+		{
+			add
+			{
+				_committing = (Db4objects.Db4o.Events.CommitEventHandler)System.Delegate.Combine(
+					_committing, value);
+			}
+			remove
+			{
+				_committing = (Db4objects.Db4o.Events.CommitEventHandler)System.Delegate.Remove(_committing
+					, value);
+			}
+		}
+
+		public virtual event Db4objects.Db4o.Events.CommitEventHandler Committed
+		{
+			add
+			{
+				_committed = (Db4objects.Db4o.Events.CommitEventHandler)System.Delegate.Combine(_committed
+					, value);
+				OnCommittedListener();
+			}
+			remove
+			{
+				_committed = (Db4objects.Db4o.Events.CommitEventHandler)System.Delegate.Remove(_committed
+					, value);
+			}
+		}
+
+		public virtual event Db4objects.Db4o.Events.ClassEventHandler ClassRegistered
+		{
+			add
+			{
+				_classRegistered = (Db4objects.Db4o.Events.ClassEventHandler)System.Delegate.Combine
+					(_classRegistered, value);
+			}
+			remove
+			{
+				_classRegistered = (Db4objects.Db4o.Events.ClassEventHandler)System.Delegate.Remove
+					(_classRegistered, value);
+			}
+		}
+
+		public virtual event Db4objects.Db4o.Events.ObjectEventHandler Instantiated
+		{
+			add
+			{
+				_instantiated = (Db4objects.Db4o.Events.ObjectEventHandler)System.Delegate.Combine
+					(_instantiated, value);
+			}
+			remove
+			{
+				_instantiated = (Db4objects.Db4o.Events.ObjectEventHandler)System.Delegate.Remove
+					(_instantiated, value);
+			}
+		}
+
+		public virtual event Db4objects.Db4o.Events.ObjectContainerEventHandler Closing
+		{
+			add
+			{
+				_closing = (Db4objects.Db4o.Events.ObjectContainerEventHandler)System.Delegate.Combine
+					(_closing, value);
+			}
+			remove
+			{
+				_closing = (Db4objects.Db4o.Events.ObjectContainerEventHandler)System.Delegate.Remove
+					(_closing, value);
+			}
+		}
+
+		protected virtual void OnCommittedListener()
+		{
+			// TODO: notify the server that we are interested in 
+			// committed callbacks
+			_container.OnCommittedListener();
+		}
+
+		public virtual bool CaresAboutCommitting()
+		{
+			return EventPlatform.HasListeners(_committing);
+		}
+
+		public virtual bool CaresAboutCommitted()
+		{
+			return EventPlatform.HasListeners(_committed);
+		}
+
+		public virtual bool CaresAboutDeleting()
+		{
+			return EventPlatform.HasListeners(_deleting);
+		}
+
+		public virtual bool CaresAboutDeleted()
+		{
+			return EventPlatform.HasListeners(_deleted);
+		}
 	}
 }
