@@ -1,14 +1,10 @@
-/* Copyright (C) 2004 - 2007  db4objects Inc.  http://www.db4o.com
+/* This file is part of the db4o object database http://www.db4o.com
 
-This file is part of the db4o open source object database.
+Copyright (C) 2004 - 2009  Versant Corporation http://www.versant.com
 
 db4o is free software; you can redistribute it and/or modify it under
-the terms of version 2 of the GNU General Public License as published
-by the Free Software Foundation and as clarified by db4objects' GPL 
-interpretation policy, available at
-http://www.db4o.com/about/company/legalpolicies/gplinterpretation/
-Alternatively you can write to db4objects, Inc., 1900 S Norfolk Street,
-Suite 350, San Mateo, CA 94403, USA.
+the terms of version 3 of the GNU General Public License as published
+by the Free Software Foundation.
 
 db4o is distributed in the hope that it will be useful, but WITHOUT ANY
 WARRANTY; without even the implied warranty of MERCHANTABILITY or
@@ -16,59 +12,74 @@ FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
 for more details.
 
 You should have received a copy of the GNU General Public License along
-with this program; if not, write to the Free Software Foundation, Inc.,
-59 Temple Place - Suite 330, Boston, MA  02111-1307, USA. */
+with this program.  If not, see http://www.gnu.org/licenses/. */
+using System;
+using Db4objects.Db4o.Config;
+using Db4objects.Db4o.Ext;
+using Db4objects.Db4o.IO;
+using Db4objects.Db4o.Internal;
+using Sharpen;
+
 namespace Db4objects.Db4o.Internal
 {
 	/// <exclude></exclude>
-	public class InMemoryObjectContainer : Db4objects.Db4o.Internal.LocalObjectContainer
+	public class InMemoryObjectContainer : LocalObjectContainer
 	{
 		private bool _closed = false;
 
-		private readonly Db4objects.Db4o.Ext.MemoryFile _memoryFile;
+		private readonly MemoryFile _memoryFile;
 
 		private int _length = 0;
 
-		protected InMemoryObjectContainer(Db4objects.Db4o.Config.IConfiguration config, Db4objects.Db4o.Internal.ObjectContainerBase
-			 parent, Db4objects.Db4o.Ext.MemoryFile memoryFile) : base(config, parent)
+		/// <exception cref="Db4objects.Db4o.Ext.OldFormatException"></exception>
+		protected InMemoryObjectContainer(IConfiguration config, ObjectContainerBase parent
+			, MemoryFile memoryFile) : base(config, parent)
 		{
 			_memoryFile = memoryFile;
-			try
-			{
-				Open();
-			}
-			catch (System.Exception e)
-			{
-				Db4objects.Db4o.Internal.Exceptions4.ThrowRuntimeException(22, e);
-			}
-			Initialize3();
+			Open();
 		}
 
-		public InMemoryObjectContainer(Db4objects.Db4o.Config.IConfiguration config, Db4objects.Db4o.Ext.MemoryFile
-			 memoryFile) : this(config, null, memoryFile)
+		public InMemoryObjectContainer(IConfiguration config, MemoryFile memoryFile) : this
+			(config, null, memoryFile)
 		{
 		}
 
-		public override void Backup(string path)
+		/// <exception cref="Db4objects.Db4o.Ext.OldFormatException"></exception>
+		protected sealed override void OpenImpl()
 		{
-			Db4objects.Db4o.Internal.Exceptions4.ThrowRuntimeException(60);
+			byte[] bytes = _memoryFile.GetBytes();
+			if (bytes == null || bytes.Length == 0)
+			{
+				_memoryFile.SetBytes(new byte[_memoryFile.GetInitialSize()]);
+				ConfigureNewFile();
+				CommitTransaction();
+				WriteHeader(false, false);
+			}
+			else
+			{
+				_length = bytes.Length;
+				ReadThis();
+			}
+		}
+
+		/// <exception cref="System.NotSupportedException"></exception>
+		public override void Backup(IoAdapter targetIo, string path)
+		{
+			throw new NotSupportedException();
 		}
 
 		public override void BlockSize(int size)
 		{
 		}
 
-		protected override bool Close2()
+		// do nothing, blocksize is always 1
+		protected override void FreeInternalResources()
+		{
+		}
+
+		// nothing to do here
+		protected override void ShutdownDataStorage()
 		{
-			try
-			{
-				Write(true);
-			}
-			catch (System.Exception t)
-			{
-				FatalException(t);
-			}
-			base.Close2();
 			if (!_closed)
 			{
 				byte[] temp = new byte[_length];
@@ -76,13 +87,14 @@ namespace Db4objects.Db4o.Internal
 				_memoryFile.SetBytes(temp);
 			}
 			_closed = true;
-			return true;
+			DropReferences();
 		}
 
-		public override void ShutdownStorage()
+		protected virtual void DropReferences()
 		{
 		}
 
+		// do nothing
 		public override void Copy(int oldAddress, int oldAddressOffset, int newAddress, int
 			 newAddressOffset, int length)
 		{
@@ -93,12 +105,6 @@ namespace Db4objects.Db4o.Internal
 				);
 		}
 
-		internal override void EmergencyClose()
-		{
-			base.EmergencyClose();
-			_closed = true;
-		}
-
 		public override long FileLength()
 		{
 			return _length;
@@ -119,32 +125,15 @@ namespace Db4objects.Db4o.Internal
 			return false;
 		}
 
-		private void Open()
-		{
-			byte[] bytes = _memoryFile.GetBytes();
-			if (bytes == null || bytes.Length == 0)
-			{
-				_memoryFile.SetBytes(new byte[_memoryFile.GetInitialSize()]);
-				ConfigureNewFile();
-				Write(false);
-				WriteHeader(false, false);
-			}
-			else
-			{
-				_length = bytes.Length;
-				ReadThis();
-			}
-		}
-
 		public override void ReadBytes(byte[] bytes, int address, int length)
 		{
 			try
 			{
 				System.Array.Copy(_memoryFile.GetBytes(), address, bytes, 0, length);
 			}
-			catch (System.Exception e)
+			catch (Exception e)
 			{
-				Db4objects.Db4o.Internal.Exceptions4.ThrowRuntimeException(13, e);
+				Exceptions4.ThrowRuntimeException(13, e);
 			}
 		}
 
@@ -158,13 +147,13 @@ namespace Db4objects.Db4o.Internal
 		{
 		}
 
-		public override void WriteBytes(Db4objects.Db4o.Internal.Buffer bytes, int address
-			, int addressOffset)
+		public override void WriteBytes(ByteArrayBuffer buffer, int address, int addressOffset
+			)
 		{
 			int fullAddress = address + addressOffset;
-			int length = bytes.GetLength();
+			int length = buffer.Length();
 			EnsureMemoryFileSize(fullAddress + length);
-			System.Array.Copy(bytes._buffer, 0, _memoryFile.GetBytes(), fullAddress, length);
+			System.Array.Copy(buffer._buffer, 0, _memoryFile.GetBytes(), fullAddress, length);
 		}
 
 		private void EnsureMemoryFileSize(int last)
@@ -180,7 +169,7 @@ namespace Db4objects.Db4o.Internal
 				return;
 			}
 			int increment = _memoryFile.GetIncrementSizeBy();
-			while (last > increment)
+			while (last > (increment + bytes.Length))
 			{
 				increment <<= 1;
 			}
@@ -193,5 +182,15 @@ namespace Db4objects.Db4o.Internal
 		public override void OverwriteDeletedBytes(int a_address, int a_length)
 		{
 		}
+
+		public override void Reserve(int byteCount)
+		{
+			throw new NotSupportedException();
+		}
+
+		public override byte BlockSize()
+		{
+			return 1;
+		}
 	}
 }
