@@ -1,14 +1,10 @@
-/* Copyright (C) 2004 - 2007  db4objects Inc.  http://www.db4o.com
+/* This file is part of the db4o object database http://www.db4o.com
 
-This file is part of the db4o open source object database.
+Copyright (C) 2004 - 2009  Versant Corporation http://www.versant.com
 
 db4o is free software; you can redistribute it and/or modify it under
-the terms of version 2 of the GNU General Public License as published
-by the Free Software Foundation and as clarified by db4objects' GPL 
-interpretation policy, available at
-http://www.db4o.com/about/company/legalpolicies/gplinterpretation/
-Alternatively you can write to db4objects, Inc., 1900 S Norfolk Street,
-Suite 350, San Mateo, CA 94403, USA.
+the terms of version 3 of the GNU General Public License as published
+by the Free Software Foundation.
 
 db4o is distributed in the hope that it will be useful, but WITHOUT ANY
 WARRANTY; without even the implied warranty of MERCHANTABILITY or
@@ -16,12 +12,16 @@ FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
 for more details.
 
 You should have received a copy of the GNU General Public License along
-with this program; if not, write to the Free Software Foundation, Inc.,
-59 Temple Place - Suite 330, Boston, MA  02111-1307, USA. */
+with this program.  If not, see http://www.gnu.org/licenses/. */
+using Db4objects.Db4o.Foundation;
+using Db4objects.Db4o.Internal.Marshall;
+
 namespace Db4objects.Db4o.Internal.Marshall
 {
 	public class RawFieldSpec
 	{
+		private readonly AspectType _type;
+
 		private readonly string _name;
 
 		private readonly int _handlerID;
@@ -36,12 +36,13 @@ namespace Db4objects.Db4o.Internal.Marshall
 
 		private int _indexID;
 
-		public RawFieldSpec(string name, int handlerID, byte attribs)
+		public RawFieldSpec(AspectType aspectType, string name, int handlerID, byte attribs
+			)
 		{
+			_type = aspectType;
 			_name = name;
 			_handlerID = handlerID;
-			Db4objects.Db4o.Foundation.BitMap4 bitmap = new Db4objects.Db4o.Foundation.BitMap4
-				(attribs);
+			BitMap4 bitmap = new BitMap4(attribs);
 			_isPrimitive = bitmap.IsTrue(0);
 			_isArray = bitmap.IsTrue(1);
 			_isNArray = bitmap.IsTrue(2);
@@ -49,8 +50,9 @@ namespace Db4objects.Db4o.Internal.Marshall
 			_indexID = 0;
 		}
 
-		public RawFieldSpec(string name)
+		public RawFieldSpec(AspectType aspectType, string name)
 		{
+			_type = aspectType;
 			_name = name;
 			_handlerID = 0;
 			_isPrimitive = false;
@@ -104,5 +106,10 @@ namespace Db4objects.Db4o.Internal.Marshall
 		{
 			return "RawFieldSpec(" + Name() + ")";
 		}
+
+		public virtual bool IsFieldMetadata()
+		{
+			return _type.IsFieldMetadata();
+		}
 	}
 }
