@@ -1,14 +1,10 @@
-/* Copyright (C) 2004 - 2007  db4objects Inc.  http://www.db4o.com
+/* This file is part of the db4o object database http://www.db4o.com
 
-This file is part of the db4o open source object database.
+Copyright (C) 2004 - 2009  Versant Corporation http://www.versant.com
 
 db4o is free software; you can redistribute it and/or modify it under
-the terms of version 2 of the GNU General Public License as published
-by the Free Software Foundation and as clarified by db4objects' GPL 
-interpretation policy, available at
-http://www.db4o.com/about/company/legalpolicies/gplinterpretation/
-Alternatively you can write to db4objects, Inc., 1900 S Norfolk Street,
-Suite 350, San Mateo, CA 94403, USA.
+the terms of version 3 of the GNU General Public License as published
+by the Free Software Foundation.
 
 db4o is distributed in the hope that it will be useful, but WITHOUT ANY
 WARRANTY; without even the implied warranty of MERCHANTABILITY or
@@ -16,32 +12,37 @@ FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
 for more details.
 
 You should have received a copy of the GNU General Public License along
-with this program; if not, write to the Free Software Foundation, Inc.,
-59 Temple Place - Suite 330, Boston, MA  02111-1307, USA. */
+with this program.  If not, see http://www.gnu.org/licenses/. */
+using System;
+using System.IO;
+using Db4objects.Db4o;
+using Db4objects.Db4o.Config;
+using Db4objects.Db4o.Internal;
+
 namespace Db4objects.Db4o.Internal
 {
 	/// <exclude></exclude>
 	public sealed class Messages
 	{
-		public const int INCOMPATIBLE_FORMAT = 17;
+		public const int IncompatibleFormat = 17;
 
-		public const int CLOSED_OR_OPEN_FAILED = 20;
+		public const int ClosedOrOpenFailed = 20;
 
-		public const int FAILED_TO_SHUTDOWN = 28;
+		public const int FailedToShutdown = 28;
 
-		public const int FATAL_MSG_ID = 44;
+		public const int FatalMsgId = 44;
 
-		public const int NOT_IMPLEMENTED = 49;
+		public const int NotImplemented = 49;
 
-		public const int OLD_DATABASE_FORMAT = 65;
+		public const int OldDatabaseFormat = 65;
 
-		public const int ONLY_FOR_INDEXED_FIELDS = 66;
+		public const int OnlyForIndexedFields = 66;
 
-		public const int CLIENT_SERVER_UNSUPPORTED = 67;
+		public const int ClientServerUnsupported = 67;
 
-		public const int COULD_NOT_OPEN_PORT = 30;
+		public const int CouldNotOpenPort = 30;
 
-		public const int SERVER_LISTENING_ON_PORT = 31;
+		public const int ServerListeningOnPort = 31;
 
 		private static string[] i_messages;
 
@@ -87,16 +88,15 @@ namespace Db4objects.Db4o.Internal
 					, "Uncaught Exception. Engine closed.", "writing log for %", "% is closed. close() was called or open() failed."
 					, "Filename not specified.", "The database file is locked by another process.", 
 					"Class not available: %. Check CLASSPATH settings.", "finalized while performing a task.\n DO NOT USE CTRL + C OR System.exit() TO STOP THE ENGINE."
-					, "Please mail the following to exception@db4o.com:\n <db4o " + Db4objects.Db4o.Db4oVersion
-					.NAME + " stacktrace>", "</db4o " + Db4objects.Db4o.Db4oVersion.NAME + " stacktrace>"
-					, "Creation of lock file failed: %", "Previous session was not shut down correctly"
-					, "This method call is only possible on stored objects", "Could not open port: %"
-					, "Server listening on port: %", "Client % connected.", "Client % timed out and closed."
-					, "Connection closed by client %.", "Connection closed by server. %.", "% connected to server."
-					, "The directory % can neither be found nor created.", "This blob was never stored."
-					, "Blob file % not available.", "Failure finding blob filename.", "File does not exist %."
-					, "Failed to connect to server.", "No blob data stored.", "Uncaught Exception. db4o engine closed."
-					, "Add constructor that won't throw exceptions, configure constructor calls, or provide a translator to class % and make sure the class is deployed to the server with the same package/namespace + assembly name."
+					, "Please mail the following to exception@db4o.com:\n <db4o " + Db4oVersion.Name
+					 + " stacktrace>", "</db4o " + Db4oVersion.Name + " stacktrace>", "Creation of lock file failed: %"
+					, "Previous session was not shut down correctly", "This method call is only possible on stored objects"
+					, "Could not open port: %", "Server listening on port: %", "Client % connected."
+					, "Client % timed out and closed.", "Connection closed by client %.", "Connection closed by server. %."
+					, "% connected to server.", "The directory % can neither be found nor created.", 
+					"This blob was never stored.", "Blob file % not available.", "Failure finding blob filename."
+					, "File does not exist %.", "Failed to connect to server.", "No blob data stored."
+					, "Uncaught Exception. db4o engine closed.", "Add constructor that won't throw exceptions, configure constructor calls, or provide a translator to class % and make sure the class is deployed to the server with the same package/namespace + assembly name."
 					, "This method can only be called before opening the database file.", "AccessibleObject#setAccessible() is not available. Private fields can not be stored."
 					, "ObjectTranslator could not be installed: %.", "Not implemented", "% closed by ShutdownHook."
 					, "This constraint is not persistent. It has no database identity.", "Add at least one ObjectContainer to the Cluster"
@@ -112,37 +112,52 @@ namespace Db4objects.Db4o.Internal
 			}
 		}
 
-		public static void LogErr(Db4objects.Db4o.Config.IConfiguration config, int code, 
-			string msg, System.Exception t)
+		// unused
+		// 5
+		// 10
+		// 15
+		// 20
+		// 25
+		// 30
+		// 35
+		// 40
+		// 45
+		// 50
+		// 55
+		// 60
+		// 65
+		// 66
+		// 67
+		// 69
+		public static void LogErr(IConfiguration config, int code, string msg, Exception 
+			t)
 		{
-			if (config == null)
-			{
-				config = Db4objects.Db4o.Db4oFactory.Configure();
-			}
-			System.IO.TextWriter ps = ((Db4objects.Db4o.Internal.Config4Impl)config).ErrStream
-				();
-			new Db4objects.Db4o.Internal.Message(msg, code, ps);
+			TextWriter ps = ((Config4Impl)SafeConfig(config)).ErrStream();
+			new Message(msg, code, ps);
 			if (t != null)
 			{
-				new Db4objects.Db4o.Internal.Message(null, 25, ps);
+				new Message(null, 25, ps);
 				Sharpen.Runtime.PrintStackTrace(t, ps);
-				new Db4objects.Db4o.Internal.Message(null, 26, ps, false);
+				new Message(null, 26, ps, false);
 			}
 		}
 
-		public static void LogMsg(Db4objects.Db4o.Config.IConfiguration config, int code, 
-			string msg)
+		[System.ObsoleteAttribute(@"uses deprecated api")]
+		private static IConfiguration SafeConfig(IConfiguration config)
 		{
-			Db4objects.Db4o.Internal.Config4Impl c4i = (Db4objects.Db4o.Internal.Config4Impl)
-				config;
-			if (c4i == null)
+			if (config != null)
 			{
-				c4i = (Db4objects.Db4o.Internal.Config4Impl)Db4objects.Db4o.Db4oFactory.Configure
-					();
+				return config;
 			}
-			if (c4i.MessageLevel() > Db4objects.Db4o.Internal.Const4.NONE)
+			return Db4oFactory.Configure();
+		}
+
+		public static void LogMsg(IConfiguration config, int code, string msg)
+		{
+			Config4Impl c4i = (Config4Impl)config;
+			if (c4i.MessageLevel() > Const4.None)
 			{
-				new Db4objects.Db4o.Internal.Message(msg, code, c4i.OutStream());
+				new Message(msg, code, c4i.OutStream());
 			}
 		}
 	}
