@@ -1,14 +1,10 @@
-/* Copyright (C) 2004 - 2007  db4objects Inc.  http://www.db4o.com
+/* This file is part of the db4o object database http://www.db4o.com
 
-This file is part of the db4o open source object database.
+Copyright (C) 2004 - 2009  Versant Corporation http://www.versant.com
 
 db4o is free software; you can redistribute it and/or modify it under
-the terms of version 2 of the GNU General Public License as published
-by the Free Software Foundation and as clarified by db4objects' GPL 
-interpretation policy, available at
-http://www.db4o.com/about/company/legalpolicies/gplinterpretation/
-Alternatively you can write to db4objects, Inc., 1900 S Norfolk Street,
-Suite 350, San Mateo, CA 94403, USA.
+the terms of version 3 of the GNU General Public License as published
+by the Free Software Foundation.
 
 db4o is distributed in the hope that it will be useful, but WITHOUT ANY
 WARRANTY; without even the implied warranty of MERCHANTABILITY or
@@ -16,32 +12,38 @@ FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
 for more details.
 
 You should have received a copy of the GNU General Public License along
-with this program; if not, write to the Free Software Foundation, Inc.,
-59 Temple Place - Suite 330, Boston, MA  02111-1307, USA. */
+with this program.  If not, see http://www.gnu.org/licenses/. */
+using System;
+using System.Collections;
+using Db4objects.Db4o;
+using Db4objects.Db4o.Foundation;
+using Db4objects.Db4o.Internal;
+using Db4objects.Db4o.Internal.Query.Processor;
+using Db4objects.Db4o.Query;
+using Db4objects.Db4o.Reflect;
+using Db4objects.Db4o.Types;
+
 namespace Db4objects.Db4o.Internal.Query.Processor
 {
 	/// <summary>Base class for all constraints on queries.</summary>
 	/// <remarks>Base class for all constraints on queries.</remarks>
 	/// <exclude></exclude>
-	public abstract class QCon : Db4objects.Db4o.Query.IConstraint, Db4objects.Db4o.Foundation.IVisitor4
-		, Db4objects.Db4o.Types.IUnversioned
+	public abstract class QCon : IConstraint, IVisitor4, IUnversioned
 	{
-		internal static readonly Db4objects.Db4o.Internal.IDGenerator idGenerator = new Db4objects.Db4o.Internal.IDGenerator
-			();
+		internal static readonly IDGenerator idGenerator = new IDGenerator();
 
 		[System.NonSerialized]
-		internal Db4objects.Db4o.Internal.Query.Processor.QCandidates i_candidates;
+		internal QCandidates i_candidates;
 
-		public Db4objects.Db4o.Foundation.Collection4 i_childrenCandidates;
+		public Collection4 i_childrenCandidates;
 
-		public Db4objects.Db4o.Foundation.List4 _children;
+		public List4 _children;
 
-		public Db4objects.Db4o.Internal.Query.Processor.QE i_evaluator = Db4objects.Db4o.Internal.Query.Processor.QE
-			.DEFAULT;
+		public QE i_evaluator = QE.Default;
 
 		public int i_id;
 
-		public Db4objects.Db4o.Foundation.Collection4 i_joins;
+		public Collection4 i_joins;
 
 		public int i_orderID = 0;
 
@@ -58,6 +60,23 @@ namespace Db4objects.Db4o.Internal.Query.Processor
 
 		internal QCon(Db4objects.Db4o.Internal.Transaction a_trans)
 		{
+			//Used for query debug only.
+			// our candidate object tree
+			// collection of QCandidates to collect children elements and to
+			// execute children. For convenience we hold them in the constraint,
+			// so we can do collection and execution in two steps
+			// all subconstraints
+			// for evaluation
+			// ID handling for fast find of QConstraint objects in 
+			// pending OR evaluations
+			// ANDs and ORs on this constraint
+			// positive indicates ascending, negative indicates descending
+			// value indicates ID supplied by ID generator.
+			// lower IDs are applied first
+			// the parent of this constraint or null, if this is a root
+			// prevents circular calls on removal
+			// our transaction to get a stream object anywhere
+			// C/S only
 			i_id = idGenerator.Next();
 			i_trans = a_trans;
 		}
@@ -65,36 +84,38 @@ namespace Db4objects.Db4o.Internal.Query.Processor
 		internal virtual Db4objects.Db4o.Internal.Query.Processor.QCon AddConstraint(Db4objects.Db4o.Internal.Query.Processor.QCon
 			 a_child)
 		{
-			_children = new Db4objects.Db4o.Foundation.List4(_children, a_child);
+			_children = new List4(_children, a_child);
 			return a_child;
 		}
 
+		public virtual ObjectContainerBase Container()
+		{
+			return Transaction().Container();
+		}
+
 		public virtual Db4objects.Db4o.Internal.Transaction Transaction()
 		{
 			return i_trans;
 		}
 
-		internal virtual void AddJoin(Db4objects.Db4o.Internal.Query.Processor.QConJoin a_join
-			)
+		internal virtual void AddJoin(QConJoin a_join)
 		{
 			if (i_joins == null)
 			{
-				i_joins = new Db4objects.Db4o.Foundation.Collection4();
+				i_joins = new Collection4();
 			}
 			i_joins.Add(a_join);
 		}
 
 		internal virtual Db4objects.Db4o.Internal.Query.Processor.QCon AddSharedConstraint
-			(Db4objects.Db4o.Internal.Query.Processor.QField a_field, object a_object)
+			(QField a_field, object a_object)
 		{
-			Db4objects.Db4o.Internal.Query.Processor.QConObject newConstraint = new Db4objects.Db4o.Internal.Query.Processor.QConObject
-				(i_trans, this, a_field, a_object);
+			QConObject newConstraint = new QConObject(i_trans, this, a_field, a_object);
 			AddConstraint(newConstraint);
 			return newConstraint;
 		}
 
-		public virtual Db4objects.Db4o.Query.IConstraint And(Db4objects.Db4o.Query.IConstraint
-			 andWith)
+		public virtual IConstraint And(IConstraint andWith)
 		{
 			lock (StreamLock())
 			{
@@ -111,24 +132,23 @@ namespace Db4objects.Db4o.Internal.Query.Processor
 			}
 		}
 
-		internal virtual bool Attach(Db4objects.Db4o.Internal.Query.Processor.QQuery query
-			, string a_field)
+		internal virtual bool Attach(QQuery query, string a_field)
 		{
 			Db4objects.Db4o.Internal.Query.Processor.QCon qcon = this;
-			Db4objects.Db4o.Internal.ClassMetadata yc = GetYapClass();
-			bool[] foundField = { false };
-			ForEachChildField(a_field, new _AnonymousInnerClass108(this, foundField, query));
+			ClassMetadata yc = GetYapClass();
+			bool[] foundField = new bool[] { false };
+			ForEachChildField(a_field, new _IVisitor4_112(foundField, query));
 			if (foundField[0])
 			{
 				return true;
 			}
-			Db4objects.Db4o.Internal.Query.Processor.QField qf = null;
+			QField qf = null;
 			if (yc == null || yc.HoldsAnyClass())
 			{
-				int[] count = { 0 };
-				Db4objects.Db4o.Internal.FieldMetadata[] yfs = { null };
-				i_trans.Stream().ClassCollection().AttachQueryNode(a_field, new _AnonymousInnerClass126
-					(this, yfs, count));
+				int[] count = new int[] { 0 };
+				FieldMetadata[] yfs = new FieldMetadata[] { null };
+				i_trans.Container().ClassCollection().AttachQueryNode(a_field, new _IVisitor4_130
+					(yfs, count));
 				if (count[0] == 0)
 				{
 					return false;
@@ -139,41 +159,36 @@ namespace Db4objects.Db4o.Internal.Query.Processor
 				}
 				else
 				{
-					qf = new Db4objects.Db4o.Internal.Query.Processor.QField(i_trans, a_field, null, 
-						0, 0);
+					qf = new QField(i_trans, a_field, null, 0, 0);
 				}
 			}
 			else
 			{
-				if (yc.ConfigInstantiates())
+				if (yc.CustomizedNewInstance())
 				{
-					i_trans.Stream().i_handlers._diagnosticProcessor.DescendIntoTranslator(yc, a_field
+					i_trans.Container()._handlers._diagnosticProcessor.DescendIntoTranslator(yc, a_field
 						);
 				}
-				Db4objects.Db4o.Internal.FieldMetadata yf = yc.GetYapField(a_field);
+				FieldMetadata yf = yc.FieldMetadataForName(a_field);
 				if (yf != null)
 				{
 					qf = yf.QField(i_trans);
 				}
 				if (qf == null)
 				{
-					qf = new Db4objects.Db4o.Internal.Query.Processor.QField(i_trans, a_field, null, 
-						0, 0);
+					qf = new QField(i_trans, a_field, null, 0, 0);
 				}
 			}
-			Db4objects.Db4o.Internal.Query.Processor.QConPath qcp = new Db4objects.Db4o.Internal.Query.Processor.QConPath
-				(i_trans, qcon, qf);
+			QConPath qcp = new QConPath(i_trans, qcon, qf);
 			query.AddConstraint(qcp);
 			qcon.AddConstraint(qcp);
 			return true;
 		}
 
-		private sealed class _AnonymousInnerClass108 : Db4objects.Db4o.Foundation.IVisitor4
+		private sealed class _IVisitor4_112 : IVisitor4
 		{
-			public _AnonymousInnerClass108(QCon _enclosing, bool[] foundField, Db4objects.Db4o.Internal.Query.Processor.QQuery
-				 query)
+			public _IVisitor4_112(bool[] foundField, QQuery query)
 			{
-				this._enclosing = _enclosing;
 				this.foundField = foundField;
 				this.query = query;
 			}
@@ -184,32 +199,26 @@ namespace Db4objects.Db4o.Internal.Query.Processor
 				query.AddConstraint((Db4objects.Db4o.Internal.Query.Processor.QCon)obj);
 			}
 
-			private readonly QCon _enclosing;
-
 			private readonly bool[] foundField;
 
-			private readonly Db4objects.Db4o.Internal.Query.Processor.QQuery query;
+			private readonly QQuery query;
 		}
 
-		private sealed class _AnonymousInnerClass126 : Db4objects.Db4o.Foundation.IVisitor4
+		private sealed class _IVisitor4_130 : IVisitor4
 		{
-			public _AnonymousInnerClass126(QCon _enclosing, Db4objects.Db4o.Internal.FieldMetadata[]
-				 yfs, int[] count)
+			public _IVisitor4_130(FieldMetadata[] yfs, int[] count)
 			{
-				this._enclosing = _enclosing;
 				this.yfs = yfs;
 				this.count = count;
 			}
 
 			public void Visit(object obj)
 			{
-				yfs[0] = (Db4objects.Db4o.Internal.FieldMetadata)((object[])obj)[1];
+				yfs[0] = (FieldMetadata)((object[])obj)[1];
 				count[0]++;
 			}
 
-			private readonly QCon _enclosing;
-
-			private readonly Db4objects.Db4o.Internal.FieldMetadata[] yfs;
+			private readonly FieldMetadata[] yfs;
 
 			private readonly int[] count;
 		}
@@ -221,6 +230,7 @@ namespace Db4objects.Db4o.Internal.Query.Processor
 
 		public virtual bool CanLoadByIndex()
 		{
+			// virtual
 			return false;
 		}
 
@@ -232,39 +242,41 @@ namespace Db4objects.Db4o.Internal.Query.Processor
 			}
 		}
 
-		internal virtual void Collect(Db4objects.Db4o.Internal.Query.Processor.QCandidates
-			 a_candidates)
+		/// <param name="candidates"></param>
+		internal virtual void Collect(QCandidates candidates)
 		{
 		}
 
-		public virtual Db4objects.Db4o.Query.IConstraint Contains()
+		// virtual
+		public virtual IConstraint Contains()
 		{
 			throw NotSupported();
 		}
 
-		internal virtual void CreateCandidates(Db4objects.Db4o.Foundation.Collection4 a_candidateCollection
-			)
+		internal virtual void CreateCandidates(Collection4 a_candidateCollection)
 		{
-			System.Collections.IEnumerator j = a_candidateCollection.GetEnumerator();
+			IEnumerator j = a_candidateCollection.GetEnumerator();
 			while (j.MoveNext())
 			{
-				Db4objects.Db4o.Internal.Query.Processor.QCandidates candidates = (Db4objects.Db4o.Internal.Query.Processor.QCandidates
-					)j.Current;
+				QCandidates candidates = (QCandidates)j.Current;
 				if (candidates.TryAddConstraint(this))
 				{
 					i_candidates = candidates;
 					return;
 				}
 			}
-			i_candidates = new Db4objects.Db4o.Internal.Query.Processor.QCandidates(i_trans, 
-				GetYapClass(), GetField());
+			i_candidates = new QCandidates((LocalTransaction)i_trans, GetYapClass(), GetField
+				());
 			i_candidates.AddConstraint(this);
 			a_candidateCollection.Add(i_candidates);
 		}
 
-		internal virtual void DoNotInclude(Db4objects.Db4o.Internal.Query.Processor.QCandidate
-			 a_root)
+		internal virtual void DoNotInclude(QCandidate a_root)
 		{
+			if (DTrace.enabled)
+			{
+				DTrace.Donotinclude.Log(i_id);
+			}
 			if (i_parent != null)
 			{
 				i_parent.Visit1(a_root, this, false);
@@ -275,40 +287,43 @@ namespace Db4objects.Db4o.Internal.Query.Processor
 			}
 		}
 
-		public virtual Db4objects.Db4o.Query.IConstraint Equal()
+		public virtual IConstraint Equal()
 		{
 			throw NotSupported();
 		}
 
-		internal virtual bool Evaluate(Db4objects.Db4o.Internal.Query.Processor.QCandidate
-			 a_candidate)
+		/// <param name="candidate"></param>
+		internal virtual bool Evaluate(QCandidate candidate)
 		{
-			throw Db4objects.Db4o.Internal.Exceptions4.VirtualException();
+			throw Exceptions4.VirtualException();
 		}
 
 		internal virtual void EvaluateChildren()
 		{
-			System.Collections.IEnumerator i = i_childrenCandidates.GetEnumerator();
+			IEnumerator i = i_childrenCandidates.GetEnumerator();
 			while (i.MoveNext())
 			{
-				((Db4objects.Db4o.Internal.Query.Processor.QCandidates)i.Current).Evaluate();
+				((QCandidates)i.Current).Evaluate();
 			}
 		}
 
 		internal virtual void EvaluateCollectChildren()
 		{
-			System.Collections.IEnumerator i = i_childrenCandidates.GetEnumerator();
+			if (DTrace.enabled)
+			{
+				DTrace.CollectChildren.Log(i_id);
+			}
+			IEnumerator i = i_childrenCandidates.GetEnumerator();
 			while (i.MoveNext())
 			{
-				((Db4objects.Db4o.Internal.Query.Processor.QCandidates)i.Current).Collect(i_candidates
-					);
+				((QCandidates)i.Current).Collect(i_candidates);
 			}
 		}
 
 		internal virtual void EvaluateCreateChildrenCandidates()
 		{
-			i_childrenCandidates = new Db4objects.Db4o.Foundation.Collection4();
-			System.Collections.IEnumerator i = IterateChildren();
+			i_childrenCandidates = new Collection4();
+			IEnumerator i = IterateChildren();
 			while (i.MoveNext())
 			{
 				((Db4objects.Db4o.Internal.Query.Processor.QCon)i.Current).CreateCandidates(i_childrenCandidates
@@ -318,7 +333,7 @@ namespace Db4objects.Db4o.Internal.Query.Processor
 
 		internal virtual void EvaluateEvaluations()
 		{
-			System.Collections.IEnumerator i = IterateChildren();
+			IEnumerator i = IterateChildren();
 			while (i.MoveNext())
 			{
 				((Db4objects.Db4o.Internal.Query.Processor.QCon)i.Current).EvaluateEvaluationsExec
@@ -326,11 +341,14 @@ namespace Db4objects.Db4o.Internal.Query.Processor
 			}
 		}
 
-		internal virtual void EvaluateEvaluationsExec(Db4objects.Db4o.Internal.Query.Processor.QCandidates
-			 a_candidates, bool rereadObject)
+		/// <param name="candidates"></param>
+		/// <param name="rereadObject"></param>
+		internal virtual void EvaluateEvaluationsExec(QCandidates candidates, bool rereadObject
+			)
 		{
 		}
 
+		// virtual
 		internal virtual void EvaluateSelf()
 		{
 			i_candidates.Filter(this);
@@ -338,11 +356,13 @@ namespace Db4objects.Db4o.Internal.Query.Processor
 
 		internal virtual void EvaluateSimpleChildren()
 		{
+			// TODO: sort the constraints for YapFields first,
+			// so we stay with the same YapField
 			if (_children == null)
 			{
 				return;
 			}
-			System.Collections.IEnumerator i = IterateChildren();
+			IEnumerator i = IterateChildren();
 			while (i.MoveNext())
 			{
 				Db4objects.Db4o.Internal.Query.Processor.QCon qcon = (Db4objects.Db4o.Internal.Query.Processor.QCon
@@ -356,16 +376,17 @@ namespace Db4objects.Db4o.Internal.Query.Processor
 			i_candidates.SetCurrentConstraint(null);
 		}
 
-		internal virtual void EvaluateSimpleExec(Db4objects.Db4o.Internal.Query.Processor.QCandidates
-			 a_candidates)
+		/// <param name="candidates"></param>
+		internal virtual void EvaluateSimpleExec(QCandidates candidates)
 		{
 		}
 
+		// virtual
 		internal virtual void ExchangeConstraint(Db4objects.Db4o.Internal.Query.Processor.QCon
 			 a_exchange, Db4objects.Db4o.Internal.Query.Processor.QCon a_with)
 		{
-			Db4objects.Db4o.Foundation.List4 previous = null;
-			Db4objects.Db4o.Foundation.List4 current = _children;
+			List4 previous = null;
+			List4 current = _children;
 			while (current != null)
 			{
 				if (current._element == a_exchange)
@@ -382,20 +403,18 @@ namespace Db4objects.Db4o.Internal.Query.Processor
 				previous = current;
 				current = current._next;
 			}
-			_children = new Db4objects.Db4o.Foundation.List4(_children, a_with);
+			_children = new List4(_children, a_with);
 		}
 
-		internal virtual void ForEachChildField(string name, Db4objects.Db4o.Foundation.IVisitor4
-			 visitor)
+		internal virtual void ForEachChildField(string name, IVisitor4 visitor)
 		{
-			System.Collections.IEnumerator i = IterateChildren();
+			IEnumerator i = IterateChildren();
 			while (i.MoveNext())
 			{
 				object obj = i.Current;
-				if (obj is Db4objects.Db4o.Internal.Query.Processor.QConObject)
+				if (obj is QConObject)
 				{
-					if (((Db4objects.Db4o.Internal.Query.Processor.QConObject)obj).i_field.i_name.Equals
-						(name))
+					if (((QConObject)obj).i_field.i_name.Equals(name))
 					{
 						visitor.Visit(obj);
 					}
@@ -403,7 +422,7 @@ namespace Db4objects.Db4o.Internal.Query.Processor
 			}
 		}
 
-		public virtual Db4objects.Db4o.Internal.Query.Processor.QField GetField()
+		public virtual QField GetField()
 		{
 			return null;
 		}
@@ -429,15 +448,14 @@ namespace Db4objects.Db4o.Internal.Query.Processor
 			{
 				return this;
 			}
-			System.Collections.IEnumerator i = IterateJoins();
+			IEnumerator i = IterateJoins();
 			if (i_joins.Size() == 1)
 			{
 				i.MoveNext();
 				return ((Db4objects.Db4o.Internal.Query.Processor.QCon)i.Current).ProduceTopLevelJoin
 					();
 			}
-			Db4objects.Db4o.Foundation.Collection4 col = new Db4objects.Db4o.Foundation.Collection4
-				();
+			Collection4 col = new Collection4();
 			while (i.MoveNext())
 			{
 				col.Ensure(((Db4objects.Db4o.Internal.Query.Processor.QCon)i.Current).ProduceTopLevelJoin
@@ -453,18 +471,18 @@ namespace Db4objects.Db4o.Internal.Query.Processor
 			}
 			while (i.MoveNext())
 			{
-				qcon = (Db4objects.Db4o.Internal.Query.Processor.QCon)qcon.And((Db4objects.Db4o.Query.IConstraint
-					)i.Current);
+				qcon = (Db4objects.Db4o.Internal.Query.Processor.QCon)qcon.And((IConstraint)i.Current
+					);
 			}
 			return qcon;
 		}
 
-		internal virtual Db4objects.Db4o.Internal.ClassMetadata GetYapClass()
+		internal virtual ClassMetadata GetYapClass()
 		{
 			return null;
 		}
 
-		public virtual Db4objects.Db4o.Query.IConstraint Greater()
+		public virtual IConstraint Greater()
 		{
 			throw NotSupported();
 		}
@@ -484,60 +502,6 @@ namespace Db4objects.Db4o.Internal.Query.Processor
 			return i_parent;
 		}
 
-		public virtual bool HasOrJoins()
-		{
-			Db4objects.Db4o.Foundation.Collection4 lookedAt = new Db4objects.Db4o.Foundation.Collection4
-				();
-			return HasOrJoins(lookedAt);
-		}
-
-		internal virtual bool HasOrJoins(Db4objects.Db4o.Foundation.Collection4 lookedAt)
-		{
-			if (lookedAt.ContainsByIdentity(this))
-			{
-				return false;
-			}
-			lookedAt.Add(this);
-			if (i_joins == null)
-			{
-				return false;
-			}
-			System.Collections.IEnumerator i = IterateJoins();
-			while (i.MoveNext())
-			{
-				Db4objects.Db4o.Internal.Query.Processor.QConJoin join = (Db4objects.Db4o.Internal.Query.Processor.QConJoin
-					)i.Current;
-				if (join.IsOr())
-				{
-					return true;
-				}
-				if (join.HasOrJoins(lookedAt))
-				{
-					return true;
-				}
-			}
-			return false;
-		}
-
-		public virtual bool HasOrJoinWith(Db4objects.Db4o.Internal.Query.Processor.QConObject
-			 y)
-		{
-			System.Collections.IEnumerator i = IterateJoins();
-			while (i.MoveNext())
-			{
-				Db4objects.Db4o.Internal.Query.Processor.QConJoin join = (Db4objects.Db4o.Internal.Query.Processor.QConJoin
-					)i.Current;
-				if (join.IsOr())
-				{
-					if (y == join.GetOtherConstraint(this))
-					{
-						return true;
-					}
-				}
-			}
-			return false;
-		}
-
 		public virtual bool HasJoins()
 		{
 			if (i_joins == null)
@@ -556,7 +520,12 @@ namespace Db4objects.Db4o.Internal.Query.Processor
 			return false;
 		}
 
-		public virtual Db4objects.Db4o.Query.IConstraint Identity()
+		public virtual IConstraint Identity()
+		{
+			throw NotSupported();
+		}
+
+		public virtual IConstraint ByExample()
 		{
 			throw NotSupported();
 		}
@@ -568,7 +537,7 @@ namespace Db4objects.Db4o.Internal.Query.Processor
 
 		internal virtual bool IsNot()
 		{
-			return i_evaluator is Db4objects.Db4o.Internal.Query.Processor.QENot;
+			return i_evaluator is QENot;
 		}
 
 		internal virtual bool IsNullConstraint()
@@ -576,29 +545,31 @@ namespace Db4objects.Db4o.Internal.Query.Processor
 			return false;
 		}
 
-		internal virtual System.Collections.IEnumerator IterateJoins()
+		internal virtual IEnumerator IterateJoins()
 		{
 			if (i_joins == null)
 			{
-				return Db4objects.Db4o.Foundation.Iterator4Impl.EMPTY;
+				return Iterators.EmptyIterator;
 			}
 			return i_joins.GetEnumerator();
 		}
 
-		public virtual System.Collections.IEnumerator IterateChildren()
+		public virtual IEnumerator IterateChildren()
 		{
 			if (_children == null)
 			{
-				return Db4objects.Db4o.Foundation.Iterator4Impl.EMPTY;
+				return Iterators.EmptyIterator;
 			}
-			return new Db4objects.Db4o.Foundation.Iterator4Impl(_children);
+			return new Iterator4Impl(_children);
 		}
 
-		internal virtual Db4objects.Db4o.Query.IConstraint Join(Db4objects.Db4o.Query.IConstraint
-			 a_with, bool a_and)
+		internal virtual IConstraint Join(IConstraint a_with, bool a_and)
 		{
 			if (!(a_with is Db4objects.Db4o.Internal.Query.Processor.QCon))
 			{
+				// TODO: one of our STOr test cases somehow carries 
+				// the same constraint twice. This may be a result
+				// of a funny AND. Check!
 				return null;
 			}
 			if (a_with == this)
@@ -608,39 +579,38 @@ namespace Db4objects.Db4o.Internal.Query.Processor
 			return Join1((Db4objects.Db4o.Internal.Query.Processor.QCon)a_with, a_and);
 		}
 
-		internal virtual Db4objects.Db4o.Query.IConstraint Join1(Db4objects.Db4o.Internal.Query.Processor.QCon
-			 a_with, bool a_and)
+		internal virtual IConstraint Join1(Db4objects.Db4o.Internal.Query.Processor.QCon 
+			a_with, bool a_and)
 		{
-			if (a_with is Db4objects.Db4o.Internal.Query.Processor.QConstraints)
+			if (a_with is QConstraints)
 			{
 				int j = 0;
-				Db4objects.Db4o.Foundation.Collection4 joinHooks = new Db4objects.Db4o.Foundation.Collection4
-					();
-				Db4objects.Db4o.Query.IConstraint[] constraints = ((Db4objects.Db4o.Internal.Query.Processor.QConstraints
-					)a_with).ToArray();
+				Collection4 joinHooks = new Collection4();
+				IConstraint[] constraints = ((QConstraints)a_with).ToArray();
 				for (j = 0; j < constraints.Length; j++)
 				{
 					joinHooks.Ensure(((Db4objects.Db4o.Internal.Query.Processor.QCon)constraints[j]).
 						JoinHook());
 				}
-				Db4objects.Db4o.Query.IConstraint[] joins = new Db4objects.Db4o.Query.IConstraint
-					[joinHooks.Size()];
+				IConstraint[] joins = new IConstraint[joinHooks.Size()];
 				j = 0;
-				System.Collections.IEnumerator i = joinHooks.GetEnumerator();
+				IEnumerator i = joinHooks.GetEnumerator();
 				while (i.MoveNext())
 				{
-					joins[j++] = Join((Db4objects.Db4o.Query.IConstraint)i.Current, a_and);
+					joins[j++] = Join((IConstraint)i.Current, a_and);
 				}
-				return new Db4objects.Db4o.Internal.Query.Processor.QConstraints(i_trans, joins);
+				return new QConstraints(i_trans, joins);
 			}
 			Db4objects.Db4o.Internal.Query.Processor.QCon myHook = JoinHook();
 			Db4objects.Db4o.Internal.Query.Processor.QCon otherHook = a_with.JoinHook();
 			if (myHook == otherHook)
 			{
+				// You might like to check out, what happens, if you
+				// remove this line. It seems to open a bug in an
+				// StOr testcase.
 				return myHook;
 			}
-			Db4objects.Db4o.Internal.Query.Processor.QConJoin cj = new Db4objects.Db4o.Internal.Query.Processor.QConJoin
-				(i_trans, myHook, otherHook, a_and);
+			QConJoin cj = new QConJoin(i_trans, myHook, otherHook, a_and);
 			myHook.AddJoin(cj);
 			otherHook.AddJoin(cj);
 			return cj;
@@ -651,17 +621,17 @@ namespace Db4objects.Db4o.Internal.Query.Processor
 			return ProduceTopLevelJoin();
 		}
 
-		public virtual Db4objects.Db4o.Query.IConstraint Like()
+		public virtual IConstraint Like()
 		{
 			throw NotSupported();
 		}
 
-		public virtual Db4objects.Db4o.Query.IConstraint StartsWith(bool caseSensitive)
+		public virtual IConstraint StartsWith(bool caseSensitive)
 		{
 			throw NotSupported();
 		}
 
-		public virtual Db4objects.Db4o.Query.IConstraint EndsWith(bool caseSensitive)
+		public virtual IConstraint EndsWith(bool caseSensitive)
 		{
 			throw NotSupported();
 		}
@@ -670,6 +640,11 @@ namespace Db4objects.Db4o.Internal.Query.Processor
 		{
 		}
 
+		// System.out.println(indent + "JOINS");
+		// joins += join.i_id + " ";
+		//		System.out.println(joins);
+		//		System.out.println(indent + getClass().getName() + " " + i_id + " " + i_debugField + " " + joins );
+		// System.out.println(indent + "CONSTRAINTS");
 		internal virtual string LogObject()
 		{
 			return string.Empty;
@@ -677,38 +652,38 @@ namespace Db4objects.Db4o.Internal.Query.Processor
 
 		internal virtual void Marshall()
 		{
-			System.Collections.IEnumerator i = IterateChildren();
+			IEnumerator i = IterateChildren();
 			while (i.MoveNext())
 			{
 				((Db4objects.Db4o.Internal.Query.Processor.QCon)i.Current).Marshall();
 			}
 		}
 
-		public virtual Db4objects.Db4o.Query.IConstraint Not()
+		public virtual IConstraint Not()
 		{
 			lock (StreamLock())
 			{
-				if (!(i_evaluator is Db4objects.Db4o.Internal.Query.Processor.QENot))
+				if (!(i_evaluator is QENot))
 				{
-					i_evaluator = new Db4objects.Db4o.Internal.Query.Processor.QENot(i_evaluator);
+					i_evaluator = new QENot(i_evaluator);
 				}
 				return this;
 			}
 		}
 
-		private System.Exception NotSupported()
+		private Exception NotSupported()
 		{
-			return new System.Exception("Not supported.");
+			return new Exception("Not supported.");
 		}
 
+		/// <param name="other"></param>
 		public virtual bool OnSameFieldAs(Db4objects.Db4o.Internal.Query.Processor.QCon other
 			)
 		{
 			return false;
 		}
 
-		public virtual Db4objects.Db4o.Query.IConstraint Or(Db4objects.Db4o.Query.IConstraint
-			 orWith)
+		public virtual IConstraint Or(IConstraint orWith)
 		{
 			lock (StreamLock())
 			{
@@ -733,21 +708,27 @@ namespace Db4objects.Db4o.Internal.Query.Processor
 			{
 				return;
 			}
-			System.Collections.IEnumerator i = IterateJoins();
-			while (i.MoveNext())
-			{
-				Db4objects.Db4o.Internal.Query.Processor.QConJoin qcj = (Db4objects.Db4o.Internal.Query.Processor.QConJoin
-					)i.Current;
-				if (qcj.RemoveForParent(this))
-				{
-					i_joins.Remove(qcj);
-				}
-			}
+			Collection4 toBeRemoved = CollectJoinsToBeRemoved();
+			i_joins.RemoveAll(toBeRemoved);
 			CheckLastJoinRemoved();
 		}
 
-		internal virtual void RemoveJoin(Db4objects.Db4o.Internal.Query.Processor.QConJoin
-			 a_join)
+		private Collection4 CollectJoinsToBeRemoved()
+		{
+			Collection4 toBeRemoved = new Collection4();
+			IEnumerator joinIter = IterateJoins();
+			while (joinIter.MoveNext())
+			{
+				QConJoin join = (QConJoin)joinIter.Current;
+				if (join.RemoveForParent(this))
+				{
+					toBeRemoved.Add(join);
+				}
+			}
+			return toBeRemoved;
+		}
+
+		internal virtual void RemoveJoin(QConJoin a_join)
 		{
 			i_joins.Remove(a_join);
 			CheckLastJoinRemoved();
@@ -757,12 +738,11 @@ namespace Db4objects.Db4o.Internal.Query.Processor
 		{
 			if (IsNot())
 			{
-				i_evaluator = ((Db4objects.Db4o.Internal.Query.Processor.QENot)i_evaluator).i_evaluator;
+				i_evaluator = ((QENot)i_evaluator).i_evaluator;
 			}
 		}
 
-		public virtual void SetCandidates(Db4objects.Db4o.Internal.Query.Processor.QCandidates
-			 a_candidates)
+		public virtual void SetCandidates(QCandidates a_candidates)
 		{
 			i_candidates = a_candidates;
 		}
@@ -783,26 +763,32 @@ namespace Db4objects.Db4o.Internal.Query.Processor
 			i_parent = a_newParent;
 		}
 
+		/// <param name="obj"></param>
+		/// <param name="removeExisting"></param>
 		internal virtual Db4objects.Db4o.Internal.Query.Processor.QCon ShareParent(object
-			 a_object, bool[] removeExisting)
+			 obj, bool[] removeExisting)
 		{
+			// virtual
 			return null;
 		}
 
-		internal virtual Db4objects.Db4o.Internal.Query.Processor.QConClass ShareParentForClass
-			(Db4objects.Db4o.Reflect.IReflectClass a_class, bool[] removeExisting)
+		/// <param name="claxx"></param>
+		/// <param name="removeExisting"></param>
+		internal virtual QConClass ShareParentForClass(IReflectClass claxx, bool[] removeExisting
+			)
 		{
+			// virtual
 			return null;
 		}
 
-		public virtual Db4objects.Db4o.Query.IConstraint Smaller()
+		public virtual IConstraint Smaller()
 		{
 			throw NotSupported();
 		}
 
 		protected virtual object StreamLock()
 		{
-			return i_trans.Stream().i_lock;
+			return i_trans.Container()._lock;
 		}
 
 		internal virtual bool SupportsOrdering()
@@ -832,7 +818,7 @@ namespace Db4objects.Db4o.Internal.Query.Processor
 
 		private void UnmarshallChildren(Db4objects.Db4o.Internal.Transaction a_trans)
 		{
-			System.Collections.IEnumerator i = IterateChildren();
+			IEnumerator i = IterateChildren();
 			while (i.MoveNext())
 			{
 				((Db4objects.Db4o.Internal.Query.Processor.QCon)i.Current).Unmarshall(a_trans);
@@ -843,7 +829,7 @@ namespace Db4objects.Db4o.Internal.Query.Processor
 		{
 			if (HasJoins())
 			{
-				System.Collections.IEnumerator i = IterateJoins();
+				IEnumerator i = IterateJoins();
 				while (i.MoveNext())
 				{
 					((Db4objects.Db4o.Internal.Query.Processor.QCon)i.Current).Unmarshall(a_trans);
@@ -853,42 +839,45 @@ namespace Db4objects.Db4o.Internal.Query.Processor
 
 		public virtual void Visit(object obj)
 		{
-			Db4objects.Db4o.Internal.Query.Processor.QCandidate qc = (Db4objects.Db4o.Internal.Query.Processor.QCandidate
-				)obj;
+			QCandidate qc = (QCandidate)obj;
 			Visit1(qc.GetRoot(), this, Evaluate(qc));
 		}
 
-		internal virtual void Visit(Db4objects.Db4o.Internal.Query.Processor.QCandidate a_root
-			, bool res)
+		internal virtual void Visit(QCandidate a_root, bool res)
 		{
 			Visit1(a_root, this, i_evaluator.Not(res));
 		}
 
-		internal virtual void Visit1(Db4objects.Db4o.Internal.Query.Processor.QCandidate 
-			a_root, Db4objects.Db4o.Internal.Query.Processor.QCon a_reason, bool res)
+		/// <param name="reason"></param>
+		internal virtual void Visit1(QCandidate root, Db4objects.Db4o.Internal.Query.Processor.QCon
+			 reason, bool res)
 		{
+			// The a_reason parameter makes it eays to distinguish
+			// between calls from above (a_reason == this) and below.
 			if (HasJoins())
 			{
-				System.Collections.IEnumerator i = IterateJoins();
+				// this should probably be on the Join
+				IEnumerator i = IterateJoins();
 				while (i.MoveNext())
 				{
-					a_root.Evaluate(new Db4objects.Db4o.Internal.Query.Processor.QPending((Db4objects.Db4o.Internal.Query.Processor.QConJoin
-						)i.Current, this, res));
+					root.Evaluate(new QPending((QConJoin)i.Current, this, res));
 				}
 			}
 			else
 			{
 				if (!res)
 				{
-					DoNotInclude(a_root);
+					DoNotInclude(root);
 				}
 			}
 		}
 
-		internal void VisitOnNull(Db4objects.Db4o.Internal.Query.Processor.QCandidate a_root
-			)
+		internal void VisitOnNull(QCandidate a_root)
 		{
-			System.Collections.IEnumerator i = IterateChildren();
+			// TODO: It may be more efficient to rule out 
+			// all possible keepOnNull issues when starting
+			// evaluation.
+			IEnumerator i = IterateChildren();
 			while (i.MoveNext())
 			{
 				((Db4objects.Db4o.Internal.Query.Processor.QCon)i.Current).VisitOnNull(a_root);
@@ -904,7 +893,7 @@ namespace Db4objects.Db4o.Internal.Query.Processor
 			return true;
 		}
 
-		public virtual Db4objects.Db4o.Internal.Query.Processor.QE Evaluator()
+		public virtual QE Evaluator()
 		{
 			return i_evaluator;
 		}
@@ -915,7 +904,7 @@ namespace Db4objects.Db4o.Internal.Query.Processor
 			{
 				return true;
 			}
-			System.Collections.IEnumerator i = IterateChildren();
+			IEnumerator i = IterateChildren();
 			while (i.MoveNext())
 			{
 				if (((Db4objects.Db4o.Internal.Query.Processor.QCon)i.Current).RequiresSort())
