@@ -1,14 +1,10 @@
-/* Copyright (C) 2004 - 2007  db4objects Inc.  http://www.db4o.com
+/* This file is part of the db4o object database http://www.db4o.com
 
-This file is part of the db4o open source object database.
+Copyright (C) 2004 - 2009  Versant Corporation http://www.versant.com
 
 db4o is free software; you can redistribute it and/or modify it under
-the terms of version 2 of the GNU General Public License as published
-by the Free Software Foundation and as clarified by db4objects' GPL 
-interpretation policy, available at
-http://www.db4o.com/about/company/legalpolicies/gplinterpretation/
-Alternatively you can write to db4objects, Inc., 1900 S Norfolk Street,
-Suite 350, San Mateo, CA 94403, USA.
+the terms of version 3 of the GNU General Public License as published
+by the Free Software Foundation.
 
 db4o is distributed in the hope that it will be useful, but WITHOUT ANY
 WARRANTY; without even the implied warranty of MERCHANTABILITY or
@@ -16,42 +12,45 @@ FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
 for more details.
 
 You should have received a copy of the GNU General Public License along
-with this program; if not, write to the Free Software Foundation, Inc.,
-59 Temple Place - Suite 330, Boston, MA  02111-1307, USA. */
+with this program.  If not, see http://www.gnu.org/licenses/. */
+using System;
+using System.Collections;
+using Db4objects.Db4o.Internal;
+using Db4objects.Db4o.Internal.Query.Processor;
+
 namespace Db4objects.Db4o.Internal.Query.Processor
 {
 	/// <summary>Join constraint on queries</summary>
 	/// <exclude></exclude>
-	public class QConJoin : Db4objects.Db4o.Internal.Query.Processor.QCon
+	public class QConJoin : QCon
 	{
 		public bool i_and;
 
-		public Db4objects.Db4o.Internal.Query.Processor.QCon i_constraint1;
+		public QCon i_constraint1;
 
-		public Db4objects.Db4o.Internal.Query.Processor.QCon i_constraint2;
+		public QCon i_constraint2;
 
 		public QConJoin()
 		{
 		}
 
-		internal QConJoin(Db4objects.Db4o.Internal.Transaction a_trans, Db4objects.Db4o.Internal.Query.Processor.QCon
-			 a_c1, Db4objects.Db4o.Internal.Query.Processor.QCon a_c2, bool a_and) : base(a_trans
+		internal QConJoin(Transaction a_trans, QCon a_c1, QCon a_c2, bool a_and) : base(a_trans
 			)
 		{
+			// FIELDS MUST BE PUBLIC TO BE REFLECTED ON UNDER JDK <= 1.1
+			// C/S
 			i_constraint1 = a_c1;
 			i_constraint2 = a_c2;
 			i_and = a_and;
 		}
 
-		internal override void DoNotInclude(Db4objects.Db4o.Internal.Query.Processor.QCandidate
-			 a_root)
+		internal override void DoNotInclude(QCandidate a_root)
 		{
 			i_constraint1.DoNotInclude(a_root);
 			i_constraint2.DoNotInclude(a_root);
 		}
 
-		internal override void ExchangeConstraint(Db4objects.Db4o.Internal.Query.Processor.QCon
-			 a_exchange, Db4objects.Db4o.Internal.Query.Processor.QCon a_with)
+		internal override void ExchangeConstraint(QCon a_exchange, QCon a_with)
 		{
 			base.ExchangeConstraint(a_exchange, a_with);
 			if (a_exchange == i_constraint1)
@@ -64,21 +63,19 @@ namespace Db4objects.Db4o.Internal.Query.Processor
 			}
 		}
 
-		internal virtual void EvaluatePending(Db4objects.Db4o.Internal.Query.Processor.QCandidate
-			 a_root, Db4objects.Db4o.Internal.Query.Processor.QPending a_pending, int a_secondResult
-			)
+		internal virtual void EvaluatePending(QCandidate a_root, QPending a_pending, int 
+			a_secondResult)
 		{
 			bool res = i_evaluator.Not(i_and ? ((a_pending._result + a_secondResult) > 0) : (
 				a_pending._result + a_secondResult) > -4);
 			if (HasJoins())
 			{
-				System.Collections.IEnumerator i = IterateJoins();
+				IEnumerator i = IterateJoins();
 				while (i.MoveNext())
 				{
 					Db4objects.Db4o.Internal.Query.Processor.QConJoin qcj = (Db4objects.Db4o.Internal.Query.Processor.QConJoin
 						)i.Current;
-					a_root.Evaluate(new Db4objects.Db4o.Internal.Query.Processor.QPending(qcj, this, 
-						res));
+					a_root.Evaluate(new QPending(qcj, this, res));
 				}
 			}
 			else
@@ -91,8 +88,7 @@ namespace Db4objects.Db4o.Internal.Query.Processor
 			}
 		}
 
-		public virtual Db4objects.Db4o.Internal.Query.Processor.QCon GetOtherConstraint(Db4objects.Db4o.Internal.Query.Processor.QCon
-			 a_constraint)
+		public virtual QCon GetOtherConstraint(QCon a_constraint)
 		{
 			if (a_constraint == i_constraint1)
 			{
@@ -105,7 +101,7 @@ namespace Db4objects.Db4o.Internal.Query.Processor
 					return i_constraint1;
 				}
 			}
-			throw new System.ArgumentException();
+			throw new ArgumentException();
 		}
 
 		internal override string LogObject()
@@ -113,14 +109,13 @@ namespace Db4objects.Db4o.Internal.Query.Processor
 			return string.Empty;
 		}
 
-		internal virtual bool RemoveForParent(Db4objects.Db4o.Internal.Query.Processor.QCon
-			 a_constraint)
+		internal virtual bool RemoveForParent(QCon a_constraint)
 		{
 			if (i_and)
 			{
-				Db4objects.Db4o.Internal.Query.Processor.QCon other = GetOtherConstraint(a_constraint
-					);
+				QCon other = GetOtherConstraint(a_constraint);
 				other.RemoveJoin(this);
+				// prevents circular call
 				other.Remove();
 				return true;
 			}
@@ -129,7 +124,6 @@ namespace Db4objects.Db4o.Internal.Query.Processor
 
 		public override string ToString()
 		{
-			return base.ToString();
 			string str = "QConJoin " + (i_and ? "AND " : "OR");
 			if (i_constraint1 != null)
 			{
