@@ -1,14 +1,10 @@
-/* Copyright (C) 2004 - 2007  db4objects Inc.  http://www.db4o.com
+/* This file is part of the db4o object database http://www.db4o.com
 
-This file is part of the db4o open source object database.
+Copyright (C) 2004 - 2009  Versant Corporation http://www.versant.com
 
 db4o is free software; you can redistribute it and/or modify it under
-the terms of version 2 of the GNU General Public License as published
-by the Free Software Foundation and as clarified by db4objects' GPL 
-interpretation policy, available at
-http://www.db4o.com/about/company/legalpolicies/gplinterpretation/
-Alternatively you can write to db4objects, Inc., 1900 S Norfolk Street,
-Suite 350, San Mateo, CA 94403, USA.
+the terms of version 3 of the GNU General Public License as published
+by the Free Software Foundation.
 
 db4o is distributed in the hope that it will be useful, but WITHOUT ANY
 WARRANTY; without even the implied warranty of MERCHANTABILITY or
@@ -16,8 +12,11 @@ FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
 for more details.
 
 You should have received a copy of the GNU General Public License along
-with this program; if not, write to the Free Software Foundation, Inc.,
-59 Temple Place - Suite 330, Boston, MA  02111-1307, USA. */
+with this program.  If not, see http://www.gnu.org/licenses/. */
+using Db4objects.Db4o.Internal;
+using Db4objects.Db4o.Internal.Query.Processor;
+using Db4objects.Db4o.Query;
+
 namespace Db4objects.Db4o.Internal.Query.Processor
 {
 	/// <summary>Array of constraints for queries.</summary>
@@ -26,30 +25,31 @@ namespace Db4objects.Db4o.Internal.Query.Processor
 	/// Necessary to be returned to Query#constraints()
 	/// </remarks>
 	/// <exclude></exclude>
-	public class QConstraints : Db4objects.Db4o.Internal.Query.Processor.QCon, Db4objects.Db4o.Query.IConstraints
+	public class QConstraints : QCon, IConstraints
 	{
-		private Db4objects.Db4o.Query.IConstraint[] i_constraints;
+		private IConstraint[] i_constraints;
 
-		internal QConstraints(Db4objects.Db4o.Internal.Transaction a_trans, Db4objects.Db4o.Query.IConstraint[]
-			 constraints) : base(a_trans)
+		internal QConstraints(Transaction a_trans, IConstraint[] constraints) : base(a_trans
+			)
 		{
 			i_constraints = constraints;
 		}
 
-		internal override Db4objects.Db4o.Query.IConstraint Join(Db4objects.Db4o.Query.IConstraint
-			 a_with, bool a_and)
+		internal override IConstraint Join(IConstraint a_with, bool a_and)
 		{
 			lock (StreamLock())
 			{
-				if (!(a_with is Db4objects.Db4o.Internal.Query.Processor.QCon))
+				if (!(a_with is QCon))
 				{
 					return null;
 				}
-				return ((Db4objects.Db4o.Internal.Query.Processor.QCon)a_with).Join1(this, a_and);
+				// resolving multiple constraints happens in QCon for
+				// a_with, so we simply turn things around
+				return ((QCon)a_with).Join1(this, a_and);
 			}
 		}
 
-		public virtual Db4objects.Db4o.Query.IConstraint[] ToArray()
+		public virtual IConstraint[] ToArray()
 		{
 			lock (StreamLock())
 			{
@@ -57,7 +57,7 @@ namespace Db4objects.Db4o.Internal.Query.Processor
 			}
 		}
 
-		public override Db4objects.Db4o.Query.IConstraint Contains()
+		public override IConstraint Contains()
 		{
 			lock (StreamLock())
 			{
@@ -69,7 +69,7 @@ namespace Db4objects.Db4o.Internal.Query.Processor
 			}
 		}
 
-		public override Db4objects.Db4o.Query.IConstraint Equal()
+		public override IConstraint Equal()
 		{
 			lock (StreamLock())
 			{
@@ -81,7 +81,7 @@ namespace Db4objects.Db4o.Internal.Query.Processor
 			}
 		}
 
-		public override Db4objects.Db4o.Query.IConstraint Greater()
+		public override IConstraint Greater()
 		{
 			lock (StreamLock())
 			{
@@ -93,7 +93,7 @@ namespace Db4objects.Db4o.Internal.Query.Processor
 			}
 		}
 
-		public override Db4objects.Db4o.Query.IConstraint Identity()
+		public override IConstraint Identity()
 		{
 			lock (StreamLock())
 			{
@@ -105,7 +105,7 @@ namespace Db4objects.Db4o.Internal.Query.Processor
 			}
 		}
 
-		public override Db4objects.Db4o.Query.IConstraint Not()
+		public override IConstraint Not()
 		{
 			lock (StreamLock())
 			{
@@ -117,7 +117,7 @@ namespace Db4objects.Db4o.Internal.Query.Processor
 			}
 		}
 
-		public override Db4objects.Db4o.Query.IConstraint Like()
+		public override IConstraint Like()
 		{
 			lock (StreamLock())
 			{
@@ -129,7 +129,7 @@ namespace Db4objects.Db4o.Internal.Query.Processor
 			}
 		}
 
-		public override Db4objects.Db4o.Query.IConstraint StartsWith(bool caseSensitive)
+		public override IConstraint StartsWith(bool caseSensitive)
 		{
 			lock (StreamLock())
 			{
@@ -141,7 +141,7 @@ namespace Db4objects.Db4o.Internal.Query.Processor
 			}
 		}
 
-		public override Db4objects.Db4o.Query.IConstraint EndsWith(bool caseSensitive)
+		public override IConstraint EndsWith(bool caseSensitive)
 		{
 			lock (StreamLock())
 			{
@@ -153,7 +153,7 @@ namespace Db4objects.Db4o.Internal.Query.Processor
 			}
 		}
 
-		public override Db4objects.Db4o.Query.IConstraint Smaller()
+		public override IConstraint Smaller()
 		{
 			lock (StreamLock())
 			{
