@@ -1,14 +1,10 @@
-/* Copyright (C) 2004 - 2007  db4objects Inc.  http://www.db4o.com
+/* This file is part of the db4o object database http://www.db4o.com
 
-This file is part of the db4o open source object database.
+Copyright (C) 2004 - 2009  Versant Corporation http://www.versant.com
 
 db4o is free software; you can redistribute it and/or modify it under
-the terms of version 2 of the GNU General Public License as published
-by the Free Software Foundation and as clarified by db4objects' GPL 
-interpretation policy, available at
-http://www.db4o.com/about/company/legalpolicies/gplinterpretation/
-Alternatively you can write to db4objects, Inc., 1900 S Norfolk Street,
-Suite 350, San Mateo, CA 94403, USA.
+the terms of version 3 of the GNU General Public License as published
+by the Free Software Foundation.
 
 db4o is distributed in the hope that it will be useful, but WITHOUT ANY
 WARRANTY; without even the implied warranty of MERCHANTABILITY or
@@ -16,8 +12,12 @@ FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
 for more details.
 
 You should have received a copy of the GNU General Public License along
-with this program; if not, write to the Free Software Foundation, Inc.,
-59 Temple Place - Suite 330, Boston, MA  02111-1307, USA. */
+with this program.  If not, see http://www.gnu.org/licenses/. */
+using Db4objects.Db4o.Foundation;
+using Db4objects.Db4o.Internal;
+using Db4objects.Db4o.Internal.Query.Processor;
+using Db4objects.Db4o.Types;
+
 namespace Db4objects.Db4o.Internal.Query.Processor
 {
 	/// <summary>Query Evaluator - Represents such things as &gt;, &gt;=, &lt;, &lt;=, EQUAL, LIKE, etc.
@@ -25,21 +25,19 @@ namespace Db4objects.Db4o.Internal.Query.Processor
 	/// <remarks>Query Evaluator - Represents such things as &gt;, &gt;=, &lt;, &lt;=, EQUAL, LIKE, etc.
 	/// 	</remarks>
 	/// <exclude></exclude>
-	public class QE : Db4objects.Db4o.Types.IUnversioned
+	public class QE : IUnversioned
 	{
-		internal static readonly Db4objects.Db4o.Internal.Query.Processor.QE DEFAULT = new 
-			Db4objects.Db4o.Internal.Query.Processor.QE();
+		internal static readonly QE Default = new QE();
 
-		public const int NULLS = 0;
+		public const int Nulls = 0;
 
-		public const int SMALLER = 1;
+		public const int Smaller = 1;
 
-		public const int EQUAL = 2;
+		public const int Equal = 2;
 
-		public const int GREATER = 3;
+		public const int Greater = 3;
 
-		internal virtual Db4objects.Db4o.Internal.Query.Processor.QE Add(Db4objects.Db4o.Internal.Query.Processor.QE
-			 evaluator)
+		internal virtual QE Add(QE evaluator)
 		{
 			return evaluator;
 		}
@@ -54,15 +52,19 @@ namespace Db4objects.Db4o.Internal.Query.Processor
 			return true;
 		}
 
-		internal virtual bool Evaluate(Db4objects.Db4o.Internal.Query.Processor.QConObject
-			 a_constraint, Db4objects.Db4o.Internal.Query.Processor.QCandidate a_candidate, 
-			object a_value)
+		internal virtual bool Evaluate(QConObject constraint, QCandidate candidate, object
+			 obj)
 		{
-			if (a_value == null)
+			IPreparedComparison prepareComparison = constraint.PrepareComparison(candidate);
+			if (obj == null)
 			{
-				return a_constraint.GetComparator(a_candidate) is Db4objects.Db4o.Internal.Null;
+				return prepareComparison is Null;
 			}
-			return a_constraint.GetComparator(a_candidate).IsEqual(a_value);
+			if (prepareComparison is PreparedArrayContainsComparison)
+			{
+				return ((PreparedArrayContainsComparison)prepareComparison).IsEqual(obj);
+			}
+			return prepareComparison.CompareTo(obj) == 0;
 		}
 
 		public override bool Equals(object obj)
@@ -75,6 +77,7 @@ namespace Db4objects.Db4o.Internal.Query.Processor
 			return GetType().GetHashCode();
 		}
 
+		// overridden in QENot 
 		internal virtual bool Not(bool res)
 		{
 			return res;
@@ -92,7 +95,7 @@ namespace Db4objects.Db4o.Internal.Query.Processor
 		/// <param name="bits"></param>
 		public virtual void IndexBitMap(bool[] bits)
 		{
-			bits[Db4objects.Db4o.Internal.Query.Processor.QE.EQUAL] = true;
+			bits[QE.Equal] = true;
 		}
 
 		public virtual bool SupportsIndex()
