@@ -1,14 +1,10 @@
-/* Copyright (C) 2004 - 2007  db4objects Inc.  http://www.db4o.com
+/* This file is part of the db4o object database http://www.db4o.com
 
-This file is part of the db4o open source object database.
+Copyright (C) 2004 - 2009  Versant Corporation http://www.versant.com
 
 db4o is free software; you can redistribute it and/or modify it under
-the terms of version 2 of the GNU General Public License as published
-by the Free Software Foundation and as clarified by db4objects' GPL 
-interpretation policy, available at
-http://www.db4o.com/about/company/legalpolicies/gplinterpretation/
-Alternatively you can write to db4objects, Inc., 1900 S Norfolk Street,
-Suite 350, San Mateo, CA 94403, USA.
+the terms of version 3 of the GNU General Public License as published
+by the Free Software Foundation.
 
 db4o is distributed in the hope that it will be useful, but WITHOUT ANY
 WARRANTY; without even the implied warranty of MERCHANTABILITY or
@@ -16,26 +12,27 @@ FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
 for more details.
 
 You should have received a copy of the GNU General Public License along
-with this program; if not, write to the Free Software Foundation, Inc.,
-59 Temple Place - Suite 330, Boston, MA  02111-1307, USA. */
+with this program.  If not, see http://www.gnu.org/licenses/. */
+using Db4objects.Db4o.Internal.Query.Processor;
+
 namespace Db4objects.Db4o.Internal.Query.Processor
 {
 	/// <exclude></exclude>
-	public class QENot : Db4objects.Db4o.Internal.Query.Processor.QE
+	public class QENot : QE
 	{
-		public Db4objects.Db4o.Internal.Query.Processor.QE i_evaluator;
+		public QE i_evaluator;
 
 		public QENot()
 		{
 		}
 
-		internal QENot(Db4objects.Db4o.Internal.Query.Processor.QE a_evaluator)
+		internal QENot(QE a_evaluator)
 		{
+			// CS
 			i_evaluator = a_evaluator;
 		}
 
-		internal override Db4objects.Db4o.Internal.Query.Processor.QE Add(Db4objects.Db4o.Internal.Query.Processor.QE
-			 evaluator)
+		internal override QE Add(QE evaluator)
 		{
 			if (!(evaluator is Db4objects.Db4o.Internal.Query.Processor.QENot))
 			{
@@ -54,8 +51,7 @@ namespace Db4objects.Db4o.Internal.Query.Processor
 			return false;
 		}
 
-		internal override bool Evaluate(Db4objects.Db4o.Internal.Query.Processor.QConObject
-			 a_constraint, Db4objects.Db4o.Internal.Query.Processor.QCandidate a_candidate, 
+		internal override bool Evaluate(QConObject a_constraint, QCandidate a_candidate, 
 			object a_value)
 		{
 			return !i_evaluator.Evaluate(a_constraint, a_candidate, a_value);
