@@ -1,14 +1,10 @@
-/* Copyright (C) 2004 - 2007  db4objects Inc.  http://www.db4o.com
+/* This file is part of the db4o object database http://www.db4o.com
 
-This file is part of the db4o open source object database.
+Copyright (C) 2004 - 2009  Versant Corporation http://www.versant.com
 
 db4o is free software; you can redistribute it and/or modify it under
-the terms of version 2 of the GNU General Public License as published
-by the Free Software Foundation and as clarified by db4objects' GPL 
-interpretation policy, available at
-http://www.db4o.com/about/company/legalpolicies/gplinterpretation/
-Alternatively you can write to db4objects, Inc., 1900 S Norfolk Street,
-Suite 350, San Mateo, CA 94403, USA.
+the terms of version 3 of the GNU General Public License as published
+by the Free Software Foundation.
 
 db4o is distributed in the hope that it will be useful, but WITHOUT ANY
 WARRANTY; without even the implied warranty of MERCHANTABILITY or
@@ -16,23 +12,25 @@ FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
 for more details.
 
 You should have received a copy of the GNU General Public License along
-with this program; if not, write to the Free Software Foundation, Inc.,
-59 Temple Place - Suite 330, Boston, MA  02111-1307, USA. */
+with this program.  If not, see http://www.gnu.org/licenses/. */
+using System;
+using Db4objects.Db4o.Foundation;
+using Db4objects.Db4o.Internal.Query.Processor;
+
 namespace Db4objects.Db4o.Internal.Query.Processor
 {
 	/// <exclude></exclude>
-	internal class QOrder : Db4objects.Db4o.Foundation.Tree
+	internal class QOrder : Tree
 	{
 		internal static int equalityIDGenerator = 1;
 
-		internal readonly Db4objects.Db4o.Internal.Query.Processor.QConObject _constraint;
+		internal readonly QConObject _constraint;
 
-		internal readonly Db4objects.Db4o.Internal.Query.Processor.QCandidate _candidate;
+		internal readonly QCandidate _candidate;
 
 		private int _equalityID;
 
-		internal QOrder(Db4objects.Db4o.Internal.Query.Processor.QConObject a_constraint, 
-			Db4objects.Db4o.Internal.Query.Processor.QCandidate a_candidate)
+		internal QOrder(QConObject a_constraint, QCandidate a_candidate)
 		{
 			_constraint = a_constraint;
 			_candidate = a_candidate;
@@ -48,7 +46,7 @@ namespace Db4objects.Db4o.Internal.Query.Processor
 			return _equalityID != 0 && _equalityID == other._equalityID;
 		}
 
-		public override int Compare(Db4objects.Db4o.Foundation.Tree a_to)
+		public override int Compare(Tree a_to)
 		{
 			int res = InternalCompare();
 			if (res != 0)
@@ -76,11 +74,13 @@ namespace Db4objects.Db4o.Internal.Query.Processor
 
 		private int InternalCompare()
 		{
-			if (_constraint.i_comparator.IsSmaller(_candidate.Value()))
+			int comparisonResult = _constraint._preparedComparison.CompareTo(_candidate.Value
+				());
+			if (comparisonResult > 0)
 			{
 				return -_constraint.Ordering();
 			}
-			if (_constraint.i_comparator.IsEqual(_candidate.Value()))
+			if (comparisonResult == 0)
 			{
 				return 0;
 			}
@@ -97,7 +97,7 @@ namespace Db4objects.Db4o.Internal.Query.Processor
 
 		public override object Key()
 		{
-			throw new System.NotImplementedException();
+			throw new NotImplementedException();
 		}
 
 		private static int GenerateEqualityID()
