@@ -1,14 +1,10 @@
-/* Copyright (C) 2004 - 2007  db4objects Inc.  http://www.db4o.com
+/* This file is part of the db4o object database http://www.db4o.com
 
-This file is part of the db4o open source object database.
+Copyright (C) 2004 - 2009  Versant Corporation http://www.versant.com
 
 db4o is free software; you can redistribute it and/or modify it under
-the terms of version 2 of the GNU General Public License as published
-by the Free Software Foundation and as clarified by db4objects' GPL 
-interpretation policy, available at
-http://www.db4o.com/about/company/legalpolicies/gplinterpretation/
-Alternatively you can write to db4objects, Inc., 1900 S Norfolk Street,
-Suite 350, San Mateo, CA 94403, USA.
+the terms of version 3 of the GNU General Public License as published
+by the Free Software Foundation.
 
 db4o is distributed in the hope that it will be useful, but WITHOUT ANY
 WARRANTY; without even the implied warranty of MERCHANTABILITY or
@@ -16,34 +12,37 @@ FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
 for more details.
 
 You should have received a copy of the GNU General Public License along
-with this program; if not, write to the Free Software Foundation, Inc.,
-59 Temple Place - Suite 330, Boston, MA  02111-1307, USA. */
+with this program.  If not, see http://www.gnu.org/licenses/. */
+using System;
+using Db4objects.Db4o.Foundation;
+using Db4objects.Db4o.Internal.Query.Processor;
+
 namespace Db4objects.Db4o.Internal.Query.Processor
 {
 	/// <exclude></exclude>
-	internal class QPending : Db4objects.Db4o.Foundation.Tree
+	internal class QPending : Tree
 	{
-		internal readonly Db4objects.Db4o.Internal.Query.Processor.QConJoin _join;
+		internal readonly QConJoin _join;
 
-		internal Db4objects.Db4o.Internal.Query.Processor.QCon _constraint;
+		internal QCon _constraint;
 
 		internal int _result;
 
-		internal const int FALSE = -4;
+		internal const int False = -4;
 
-		internal const int BOTH = 1;
+		internal const int Both = 1;
 
-		internal const int TRUE = 2;
+		internal const int True = 2;
 
-		internal QPending(Db4objects.Db4o.Internal.Query.Processor.QConJoin a_join, Db4objects.Db4o.Internal.Query.Processor.QCon
-			 a_constraint, bool a_firstResult)
+		internal QPending(QConJoin a_join, QCon a_constraint, bool a_firstResult)
 		{
+			// Constants, so QConJoin.evaluatePending is made easy:
 			_join = a_join;
 			_constraint = a_constraint;
-			_result = a_firstResult ? TRUE : FALSE;
+			_result = a_firstResult ? True : False;
 		}
 
-		public override int Compare(Db4objects.Db4o.Foundation.Tree a_to)
+		public override int Compare(Tree a_to)
 		{
 			return _constraint.i_id - ((Db4objects.Db4o.Internal.Query.Processor.QPending)a_to
 				)._constraint.i_id;
@@ -73,7 +72,7 @@ namespace Db4objects.Db4o.Internal.Query.Processor
 
 		public override object Key()
 		{
-			throw new System.NotImplementedException();
+			throw new NotImplementedException();
 		}
 	}
 }
