@@ -1,14 +1,10 @@
-/* Copyright (C) 2004 - 2007  db4objects Inc.  http://www.db4o.com
+/* This file is part of the db4o object database http://www.db4o.com
 
-This file is part of the db4o open source object database.
+Copyright (C) 2004 - 2009  Versant Corporation http://www.versant.com
 
 db4o is free software; you can redistribute it and/or modify it under
-the terms of version 2 of the GNU General Public License as published
-by the Free Software Foundation and as clarified by db4objects' GPL 
-interpretation policy, available at
-http://www.db4o.com/about/company/legalpolicies/gplinterpretation/
-Alternatively you can write to db4objects, Inc., 1900 S Norfolk Street,
-Suite 350, San Mateo, CA 94403, USA.
+the terms of version 3 of the GNU General Public License as published
+by the Free Software Foundation.
 
 db4o is distributed in the hope that it will be useful, but WITHOUT ANY
 WARRANTY; without even the implied warranty of MERCHANTABILITY or
@@ -16,22 +12,26 @@ FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
 for more details.
 
 You should have received a copy of the GNU General Public License along
-with this program; if not, write to the Free Software Foundation, Inc.,
-59 Temple Place - Suite 330, Boston, MA  02111-1307, USA. */
+with this program.  If not, see http://www.gnu.org/licenses/. */
+using System.Collections;
+using Db4objects.Db4o.Ext;
+using Db4objects.Db4o.Foundation;
+using Db4objects.Db4o.Internal.Query.Result;
+using Db4objects.Db4o.Query;
+
 namespace Db4objects.Db4o.Internal.Query.Result
 {
 	/// <exclude></exclude>
-	public class StatefulQueryResult
+	public class StatefulQueryResult : IEnumerable
 	{
-		private readonly Db4objects.Db4o.Internal.Query.Result.IQueryResult _delegate;
+		private readonly IQueryResult _delegate;
 
-		private readonly Db4objects.Db4o.Foundation.Iterable4Adaptor _iterable;
+		private readonly Iterable4Adaptor _iterable;
 
-		public StatefulQueryResult(Db4objects.Db4o.Internal.Query.Result.IQueryResult queryResult
-			)
+		public StatefulQueryResult(IQueryResult queryResult)
 		{
 			_delegate = queryResult;
-			_iterable = new Db4objects.Db4o.Foundation.Iterable4Adaptor(queryResult);
+			_iterable = new Iterable4Adaptor(queryResult);
 		}
 
 		public virtual object Get(int index)
@@ -48,7 +48,7 @@ namespace Db4objects.Db4o.Internal.Query.Result
 			{
 				long[] ids = new long[Size()];
 				int i = 0;
-				Db4objects.Db4o.Foundation.IIntIterator4 iterator = _delegate.IterateIDs();
+				IIntIterator4 iterator = _delegate.IterateIDs();
 				while (iterator.MoveNext())
 				{
 					ids[i++] = iterator.CurrentInt();
@@ -89,7 +89,7 @@ namespace Db4objects.Db4o.Internal.Query.Result
 			}
 		}
 
-		public virtual void Sort(Db4objects.Db4o.Query.IQueryComparator cmp)
+		public virtual void Sort(IQueryComparator cmp)
 		{
 			lock (Lock())
 			{
@@ -102,7 +102,7 @@ namespace Db4objects.Db4o.Internal.Query.Result
 			return _delegate.Lock();
 		}
 
-		internal virtual Db4objects.Db4o.Ext.IExtObjectContainer ObjectContainer()
+		internal virtual IExtObjectContainer ObjectContainer()
 		{
 			return _delegate.ObjectContainer();
 		}
@@ -120,7 +120,7 @@ namespace Db4objects.Db4o.Internal.Query.Result
 			}
 		}
 
-		public virtual System.Collections.IEnumerator IterateIDs()
+		public virtual IEnumerator IterateIDs()
 		{
 			lock (Lock())
 			{
@@ -128,7 +128,7 @@ namespace Db4objects.Db4o.Internal.Query.Result
 			}
 		}
 
-		public virtual System.Collections.IEnumerator Iterator()
+		public virtual IEnumerator GetEnumerator()
 		{
 			lock (Lock())
 			{
