@@ -1,14 +1,10 @@
-/* Copyright (C) 2004 - 2007  db4objects Inc.  http://www.db4o.com
+/* This file is part of the db4o object database http://www.db4o.com
 
-This file is part of the db4o open source object database.
+Copyright (C) 2004 - 2009  Versant Corporation http://www.versant.com
 
 db4o is free software; you can redistribute it and/or modify it under
-the terms of version 2 of the GNU General Public License as published
-by the Free Software Foundation and as clarified by db4objects' GPL 
-interpretation policy, available at
-http://www.db4o.com/about/company/legalpolicies/gplinterpretation/
-Alternatively you can write to db4objects, Inc., 1900 S Norfolk Street,
-Suite 350, San Mateo, CA 94403, USA.
+the terms of version 3 of the GNU General Public License as published
+by the Free Software Foundation.
 
 db4o is distributed in the hope that it will be useful, but WITHOUT ANY
 WARRANTY; without even the implied warranty of MERCHANTABILITY or
@@ -16,31 +12,33 @@ FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
 for more details.
 
 You should have received a copy of the GNU General Public License along
-with this program; if not, write to the Free Software Foundation, Inc.,
-59 Temple Place - Suite 330, Boston, MA  02111-1307, USA. */
+with this program.  If not, see http://www.gnu.org/licenses/. */
+using Db4objects.Db4o.Foundation;
+using Db4objects.Db4o.Internal;
+using Db4objects.Db4o.Internal.Query.Processor;
+
 namespace Db4objects.Db4o.Internal
 {
 	/// <summary>Base class for balanced trees.</summary>
 	/// <remarks>Base class for balanced trees.</remarks>
 	/// <exclude></exclude>
-	public class TreeInt : Db4objects.Db4o.Foundation.Tree, Db4objects.Db4o.Internal.IReadWriteable
+	public class TreeInt : Tree, IReadWriteable
 	{
 		public static Db4objects.Db4o.Internal.TreeInt Add(Db4objects.Db4o.Internal.TreeInt
 			 tree, int value)
 		{
-			return (Db4objects.Db4o.Internal.TreeInt)Db4objects.Db4o.Foundation.Tree.Add(tree
-				, new Db4objects.Db4o.Internal.TreeInt(value));
+			return (Db4objects.Db4o.Internal.TreeInt)Tree.Add(tree, new Db4objects.Db4o.Internal.TreeInt
+				(value));
 		}
 
 		public static Db4objects.Db4o.Internal.TreeInt RemoveLike(Db4objects.Db4o.Internal.TreeInt
 			 tree, int value)
 		{
-			return (Db4objects.Db4o.Internal.TreeInt)Db4objects.Db4o.Foundation.Tree.RemoveLike
-				(tree, new Db4objects.Db4o.Internal.TreeInt(value));
+			return (Db4objects.Db4o.Internal.TreeInt)Tree.RemoveLike(tree, new Db4objects.Db4o.Internal.TreeInt
+				(value));
 		}
 
-		public static Db4objects.Db4o.Foundation.Tree AddAll(Db4objects.Db4o.Foundation.Tree
-			 tree, Db4objects.Db4o.Foundation.IIntIterator4 iter)
+		public static Tree AddAll(Tree tree, IIntIterator4 iter)
 		{
 			if (!iter.MoveNext())
 			{
@@ -48,7 +46,7 @@ namespace Db4objects.Db4o.Internal
 			}
 			Db4objects.Db4o.Internal.TreeInt firstAdded = new Db4objects.Db4o.Internal.TreeInt
 				(iter.CurrentInt());
-			tree = Db4objects.Db4o.Foundation.Tree.Add(tree, firstAdded);
+			tree = Tree.Add(tree, firstAdded);
 			while (iter.MoveNext())
 			{
 				tree = tree.Add(new Db4objects.Db4o.Internal.TreeInt(iter.CurrentInt()));
@@ -63,12 +61,12 @@ namespace Db4objects.Db4o.Internal
 			this._key = a_key;
 		}
 
-		public override int Compare(Db4objects.Db4o.Foundation.Tree a_to)
+		public override int Compare(Tree a_to)
 		{
 			return _key - ((Db4objects.Db4o.Internal.TreeInt)a_to)._key;
 		}
 
-		internal virtual Db4objects.Db4o.Foundation.Tree DeepClone()
+		internal virtual Tree DeepClone()
 		{
 			return new Db4objects.Db4o.Internal.TreeInt(_key);
 		}
@@ -78,8 +76,7 @@ namespace Db4objects.Db4o.Internal
 			return false;
 		}
 
-		public static Db4objects.Db4o.Internal.TreeInt Find(Db4objects.Db4o.Foundation.Tree
-			 a_in, int a_key)
+		public static Db4objects.Db4o.Internal.TreeInt Find(Tree a_in, int a_key)
 		{
 			if (a_in == null)
 			{
@@ -115,23 +112,23 @@ namespace Db4objects.Db4o.Internal
 			return null;
 		}
 
-		public virtual object Read(Db4objects.Db4o.Internal.Buffer a_bytes)
+		public virtual object Read(ByteArrayBuffer a_bytes)
 		{
 			return new Db4objects.Db4o.Internal.TreeInt(a_bytes.ReadInt());
 		}
 
-		public virtual void Write(Db4objects.Db4o.Internal.Buffer a_writer)
+		public virtual void Write(ByteArrayBuffer a_writer)
 		{
 			a_writer.WriteInt(_key);
 		}
 
-		public static void Write(Db4objects.Db4o.Internal.Buffer a_writer, Db4objects.Db4o.Internal.TreeInt
+		public static void Write(ByteArrayBuffer a_writer, Db4objects.Db4o.Internal.TreeInt
 			 a_tree)
 		{
 			Write(a_writer, a_tree, a_tree == null ? 0 : a_tree.Size());
 		}
 
-		public static void Write(Db4objects.Db4o.Internal.Buffer a_writer, Db4objects.Db4o.Internal.TreeInt
+		public static void Write(ByteArrayBuffer a_writer, Db4objects.Db4o.Internal.TreeInt
 			 a_tree, int size)
 		{
 			if (a_tree == null)
@@ -140,12 +137,12 @@ namespace Db4objects.Db4o.Internal
 				return;
 			}
 			a_writer.WriteInt(size);
-			a_tree.Traverse(new _AnonymousInnerClass97(a_writer));
+			a_tree.Traverse(new _IVisitor4_97(a_writer));
 		}
 
-		private sealed class _AnonymousInnerClass97 : Db4objects.Db4o.Foundation.IVisitor4
+		private sealed class _IVisitor4_97 : IVisitor4
 		{
-			public _AnonymousInnerClass97(Db4objects.Db4o.Internal.Buffer a_writer)
+			public _IVisitor4_97(ByteArrayBuffer a_writer)
 			{
 				this.a_writer = a_writer;
 			}
@@ -155,12 +152,12 @@ namespace Db4objects.Db4o.Internal
 				((Db4objects.Db4o.Internal.TreeInt)a_object).Write(a_writer);
 			}
 
-			private readonly Db4objects.Db4o.Internal.Buffer a_writer;
+			private readonly ByteArrayBuffer a_writer;
 		}
 
 		public virtual int OwnLength()
 		{
-			return Db4objects.Db4o.Internal.Const4.INT_LENGTH;
+			return Const4.IntLength;
 		}
 
 		internal virtual bool VariableLength()
@@ -168,11 +165,9 @@ namespace Db4objects.Db4o.Internal
 			return false;
 		}
 
-		internal virtual Db4objects.Db4o.Internal.Query.Processor.QCandidate ToQCandidate
-			(Db4objects.Db4o.Internal.Query.Processor.QCandidates candidates)
+		internal virtual QCandidate ToQCandidate(QCandidates candidates)
 		{
-			Db4objects.Db4o.Internal.Query.Processor.QCandidate qc = new Db4objects.Db4o.Internal.Query.Processor.QCandidate
-				(candidates, null, _key, true);
+			QCandidate qc = new QCandidate(candidates, null, _key);
 			qc._preceding = ToQCandidate((Db4objects.Db4o.Internal.TreeInt)_preceding, candidates
 				);
 			qc._subsequent = ToQCandidate((Db4objects.Db4o.Internal.TreeInt)_subsequent, candidates
@@ -181,8 +176,8 @@ namespace Db4objects.Db4o.Internal
 			return qc;
 		}
 
-		public static Db4objects.Db4o.Internal.Query.Processor.QCandidate ToQCandidate(Db4objects.Db4o.Internal.TreeInt
-			 tree, Db4objects.Db4o.Internal.Query.Processor.QCandidates candidates)
+		public static QCandidate ToQCandidate(Db4objects.Db4o.Internal.TreeInt tree, QCandidates
+			 candidates)
 		{
 			if (tree == null)
 			{
@@ -196,8 +191,7 @@ namespace Db4objects.Db4o.Internal
 			return string.Empty + _key;
 		}
 
-		protected override Db4objects.Db4o.Foundation.Tree ShallowCloneInternal(Db4objects.Db4o.Foundation.Tree
-			 tree)
+		protected override Tree ShallowCloneInternal(Tree tree)
 		{
 			Db4objects.Db4o.Internal.TreeInt treeint = (Db4objects.Db4o.Internal.TreeInt)base
 				.ShallowCloneInternal(tree);
@@ -212,42 +206,39 @@ namespace Db4objects.Db4o.Internal
 			return ShallowCloneInternal(treeint);
 		}
 
-		public static int ByteCount(Db4objects.Db4o.Internal.TreeInt a_tree)
+		public static int MarshalledLength(Db4objects.Db4o.Internal.TreeInt a_tree)
 		{
 			if (a_tree == null)
 			{
-				return Db4objects.Db4o.Internal.Const4.INT_LENGTH;
+				return Const4.IntLength;
 			}
-			return a_tree.ByteCount();
+			return a_tree.MarshalledLength();
 		}
 
-		public int ByteCount()
+		public int MarshalledLength()
 		{
 			if (VariableLength())
 			{
-				int[] length = new int[] { Db4objects.Db4o.Internal.Const4.INT_LENGTH };
-				Traverse(new _AnonymousInnerClass152(this, length));
-				return length[0];
+				IntByRef mint = new IntByRef(Const4.IntLength);
+				Traverse(new _IVisitor4_152(mint));
+				return mint.value;
 			}
-			return Db4objects.Db4o.Internal.Const4.INT_LENGTH + (Size() * OwnLength());
+			return Const4.IntLength + (Size() * OwnLength());
 		}
 
-		private sealed class _AnonymousInnerClass152 : Db4objects.Db4o.Foundation.IVisitor4
+		private sealed class _IVisitor4_152 : IVisitor4
 		{
-			public _AnonymousInnerClass152(TreeInt _enclosing, int[] length)
+			public _IVisitor4_152(IntByRef mint)
 			{
-				this._enclosing = _enclosing;
-				this.length = length;
+				this.mint = mint;
 			}
 
 			public void Visit(object obj)
 			{
-				length[0] += ((Db4objects.Db4o.Internal.TreeInt)obj).OwnLength();
+				mint.value += ((Db4objects.Db4o.Internal.TreeInt)obj).OwnLength();
 			}
 
-			private readonly TreeInt _enclosing;
-
-			private readonly int[] length;
+			private readonly IntByRef mint;
 		}
 
 		public override object Key()
