@@ -1,14 +1,10 @@
-/* Copyright (C) 2004 - 2007  db4objects Inc.  http://www.db4o.com
+/* This file is part of the db4o object database http://www.db4o.com
 
-This file is part of the db4o open source object database.
+Copyright (C) 2004 - 2009  Versant Corporation http://www.versant.com
 
 db4o is free software; you can redistribute it and/or modify it under
-the terms of version 2 of the GNU General Public License as published
-by the Free Software Foundation and as clarified by db4objects' GPL 
-interpretation policy, available at
-http://www.db4o.com/about/company/legalpolicies/gplinterpretation/
-Alternatively you can write to db4objects, Inc., 1900 S Norfolk Street,
-Suite 350, San Mateo, CA 94403, USA.
+the terms of version 3 of the GNU General Public License as published
+by the Free Software Foundation.
 
 db4o is distributed in the hope that it will be useful, but WITHOUT ANY
 WARRANTY; without even the implied warranty of MERCHANTABILITY or
@@ -16,8 +12,10 @@ FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
 for more details.
 
 You should have received a copy of the GNU General Public License along
-with this program; if not, write to the Free Software Foundation, Inc.,
-59 Temple Place - Suite 330, Boston, MA  02111-1307, USA. */
+with this program.  If not, see http://www.gnu.org/licenses/. */
+using Db4objects.Db4o.Foundation;
+using Db4objects.Db4o.Internal;
+
 namespace Db4objects.Db4o.Internal
 {
 	/// <exclude></exclude>
@@ -39,8 +37,7 @@ namespace Db4objects.Db4o.Internal
 			return ShallowCloneInternal(new Db4objects.Db4o.Internal.TreeIntObject(_key));
 		}
 
-		protected override Db4objects.Db4o.Foundation.Tree ShallowCloneInternal(Db4objects.Db4o.Foundation.Tree
-			 tree)
+		protected override Tree ShallowCloneInternal(Tree tree)
 		{
 			Db4objects.Db4o.Internal.TreeIntObject tio = (Db4objects.Db4o.Internal.TreeIntObject
 				)base.ShallowCloneInternal(tree);
@@ -58,23 +55,22 @@ namespace Db4objects.Db4o.Internal
 			_object = obj;
 		}
 
-		public override object Read(Db4objects.Db4o.Internal.Buffer a_bytes)
+		public override object Read(ByteArrayBuffer a_bytes)
 		{
 			int key = a_bytes.ReadInt();
 			object obj = null;
 			if (_object is Db4objects.Db4o.Internal.TreeInt)
 			{
-				obj = new Db4objects.Db4o.Internal.TreeReader(a_bytes, (Db4objects.Db4o.Internal.IReadable
-					)_object).Read();
+				obj = new TreeReader(a_bytes, (IReadable)_object).Read();
 			}
 			else
 			{
-				obj = ((Db4objects.Db4o.Internal.IReadable)_object).Read(a_bytes);
+				obj = ((IReadable)_object).Read(a_bytes);
 			}
 			return new Db4objects.Db4o.Internal.TreeIntObject(key, obj);
 		}
 
-		public override void Write(Db4objects.Db4o.Internal.Buffer a_writer)
+		public override void Write(ByteArrayBuffer a_writer)
 		{
 			a_writer.WriteInt(_key);
 			if (_object == null)
@@ -90,7 +86,7 @@ namespace Db4objects.Db4o.Internal
 				}
 				else
 				{
-					((Db4objects.Db4o.Internal.IReadWriteable)_object).Write(a_writer);
+					((IReadWriteable)_object).Write(a_writer);
 				}
 			}
 		}
@@ -99,10 +95,9 @@ namespace Db4objects.Db4o.Internal
 		{
 			if (_object == null)
 			{
-				return Db4objects.Db4o.Internal.Const4.INT_LENGTH * 2;
+				return Const4.IntLength * 2;
 			}
-			return Db4objects.Db4o.Internal.Const4.INT_LENGTH + ((Db4objects.Db4o.Internal.IReadable
-				)_object).ByteCount();
+			return Const4.IntLength + ((IReadable)_object).MarshalledLength();
 		}
 
 		internal override bool VariableLength()
