@@ -1,14 +1,10 @@
-/* Copyright (C) 2004 - 2007  db4objects Inc.  http://www.db4o.com
+/* This file is part of the db4o object database http://www.db4o.com
 
-This file is part of the db4o open source object database.
+Copyright (C) 2004 - 2009  Versant Corporation http://www.versant.com
 
 db4o is free software; you can redistribute it and/or modify it under
-the terms of version 2 of the GNU General Public License as published
-by the Free Software Foundation and as clarified by db4objects' GPL 
-interpretation policy, available at
-http://www.db4o.com/about/company/legalpolicies/gplinterpretation/
-Alternatively you can write to db4objects, Inc., 1900 S Norfolk Street,
-Suite 350, San Mateo, CA 94403, USA.
+the terms of version 3 of the GNU General Public License as published
+by the Free Software Foundation.
 
 db4o is distributed in the hope that it will be useful, but WITHOUT ANY
 WARRANTY; without even the implied warranty of MERCHANTABILITY or
@@ -16,8 +12,7 @@ FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
 for more details.
 
 You should have received a copy of the GNU General Public License along
-with this program; if not, write to the Free Software Foundation, Inc.,
-59 Temple Place - Suite 330, Boston, MA  02111-1307, USA. */
+with this program.  If not, see http://www.gnu.org/licenses/. */
 namespace Db4objects.Db4o.Messaging
 {
 	/// <summary>message sender for client/server messaging.</summary>
@@ -26,18 +21,18 @@ namespace Db4objects.Db4o.Messaging
 	/// <br /><br />db4o allows using the client/server TCP connection to send
 	/// messages from the client to the server. Any object that can be
 	/// stored to a db4o database file may be used as a message.<br /><br />
-	/// See the sample in ../com/db4o/samples/messaging/ on how to
-	/// use the messaging feature. It is also used to stop the server
-	/// in ../com/db4o/samples/clientserver/StopServer.java<br /><br />
+	/// For an example see Reference documentation: <br />
+	/// http://developer.db4o.com/Resources/view.aspx/Reference/Client-Server/Messaging<br />
+	/// http://developer.db4o.com/Resources/view.aspx/Reference/Client-Server/Remote_Code_Execution<br /><br />
 	/// <b>See Also:</b><br />
-	/// <see cref="com.db4o.config.Configuration#getMessageSender()">com.db4o.config.Configuration#getMessageSender()
+	/// <see cref="Db4objects.Db4o.Config.IClientServerConfiguration.GetMessageSender">Db4objects.Db4o.Config.IClientServerConfiguration.GetMessageSender
 	/// 	</see>
 	/// ,<br />
 	/// <see cref="Db4objects.Db4o.Messaging.IMessageRecipient">Db4objects.Db4o.Messaging.IMessageRecipient
 	/// 	</see>
 	/// ,<br />
-	/// <see cref="com.db4o.config.Configuration#setMessageRecipient(MessageRecipient)">com.db4o.config.Configuration#setMessageRecipient(MessageRecipient)
-	/// 	</see>
+	/// <see cref="Db4objects.Db4o.Config.IClientServerConfiguration.SetMessageRecipient"
+	/// 	>Db4objects.Db4o.Config.IClientServerConfiguration.SetMessageRecipient</see>
 	/// </remarks>
 	public interface IMessageSender
 	{
