@@ -1,14 +1,10 @@
-/* Copyright (C) 2004 - 2007  db4objects Inc.  http://www.db4o.com
+/* This file is part of the db4o object database http://www.db4o.com
 
-This file is part of the db4o open source object database.
+Copyright (C) 2004 - 2009  Versant Corporation http://www.versant.com
 
 db4o is free software; you can redistribute it and/or modify it under
-the terms of version 2 of the GNU General Public License as published
-by the Free Software Foundation and as clarified by db4objects' GPL 
-interpretation policy, available at
-http://www.db4o.com/about/company/legalpolicies/gplinterpretation/
-Alternatively you can write to db4objects, Inc., 1900 S Norfolk Street,
-Suite 350, San Mateo, CA 94403, USA.
+the terms of version 3 of the GNU General Public License as published
+by the Free Software Foundation.
 
 db4o is distributed in the hope that it will be useful, but WITHOUT ANY
 WARRANTY; without even the implied warranty of MERCHANTABILITY or
@@ -16,8 +12,10 @@ FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
 for more details.
 
 You should have received a copy of the GNU General Public License along
-with this program; if not, write to the Free Software Foundation, Inc.,
-59 Temple Place - Suite 330, Boston, MA  02111-1307, USA. */
+with this program.  If not, see http://www.gnu.org/licenses/. */
+using Db4objects.Db4o;
+using Db4objects.Db4o.Internal;
+
 namespace Db4objects.Db4o
 {
 	/// <summary>The index record that is written to the database file.</summary>
@@ -27,7 +25,7 @@ namespace Db4objects.Db4o
 	/// </remarks>
 	/// <exclude></exclude>
 	/// <persistent></persistent>
-	public class MetaIndex : Db4objects.Db4o.IInternal4
+	public class MetaIndex : IInternal4
 	{
 		public int indexAddress;
 
@@ -41,17 +39,23 @@ namespace Db4objects.Db4o
 
 		private const int patchLength = 0;
 
-		public virtual void Read(Db4objects.Db4o.Internal.Buffer reader)
+		// The number of entries an the length are redundant, because the handler should
+		// return a fixed length, but we absolutely want to make sure, we don't free
+		// a slot into nowhere.
+		// TODO: make sure this aren't really needed
+		// and remove them 
+		public virtual void Read(ByteArrayBuffer reader)
 		{
 			indexAddress = reader.ReadInt();
 			indexEntries = reader.ReadInt();
 			indexLength = reader.ReadInt();
+			// no longer used apparently
 			reader.ReadInt();
 			reader.ReadInt();
 			reader.ReadInt();
 		}
 
-		public virtual void Write(Db4objects.Db4o.Internal.Buffer writer)
+		public virtual void Write(ByteArrayBuffer writer)
 		{
 			writer.WriteInt(indexAddress);
 			writer.WriteInt(indexEntries);
@@ -61,11 +65,14 @@ namespace Db4objects.Db4o
 			writer.WriteInt(patchLength);
 		}
 
-		public virtual void Free(Db4objects.Db4o.Internal.LocalObjectContainer file)
+		public virtual void Free(LocalObjectContainer file)
 		{
 			file.Free(indexAddress, indexLength);
 			indexAddress = 0;
 			indexLength = 0;
 		}
+		//        file.free(patchAddress, patchLength);
+		//        patchAddress = 0;
+		//        patchLength = 0;
 	}
 }
