@@ -1,14 +1,10 @@
-/* Copyright (C) 2004 - 2007  db4objects Inc.  http://www.db4o.com
+/* This file is part of the db4o object database http://www.db4o.com
 
-This file is part of the db4o open source object database.
+Copyright (C) 2004 - 2009  Versant Corporation http://www.versant.com
 
 db4o is free software; you can redistribute it and/or modify it under
-the terms of version 2 of the GNU General Public License as published
-by the Free Software Foundation and as clarified by db4objects' GPL 
-interpretation policy, available at
-http://www.db4o.com/about/company/legalpolicies/gplinterpretation/
-Alternatively you can write to db4objects, Inc., 1900 S Norfolk Street,
-Suite 350, San Mateo, CA 94403, USA.
+the terms of version 3 of the GNU General Public License as published
+by the Free Software Foundation.
 
 db4o is distributed in the hope that it will be useful, but WITHOUT ANY
 WARRANTY; without even the implied warranty of MERCHANTABILITY or
@@ -16,14 +12,17 @@ FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
 for more details.
 
 You should have received a copy of the GNU General Public License along
-with this program; if not, write to the Free Software Foundation, Inc.,
-59 Temple Place - Suite 330, Boston, MA  02111-1307, USA. */
+with this program.  If not, see http://www.gnu.org/licenses/. */
+using Db4objects.Db4o;
+using Db4objects.Db4o.Internal;
+
 namespace Db4objects.Db4o
 {
 	/// <summary>element of linked lists</summary>
 	/// <exclude></exclude>
 	/// <persistent></persistent>
-	public class P1ListElement : Db4objects.Db4o.P1Object
+	[System.ObsoleteAttribute(@"since 7.0")]
+	public class P1ListElement : P1Object
 	{
 		public Db4objects.Db4o.P1ListElement i_next;
 
@@ -33,31 +32,26 @@ namespace Db4objects.Db4o
 		{
 		}
 
-		public P1ListElement(Db4objects.Db4o.Internal.Transaction a_trans, Db4objects.Db4o.P1ListElement
-			 a_next, object a_object) : base(a_trans)
+		public P1ListElement(Transaction a_trans, Db4objects.Db4o.P1ListElement a_next, object
+			 a_object) : base(a_trans)
 		{
 			i_next = a_next;
 			i_object = a_object;
 		}
 
-		public override int AdjustReadDepth(int a_depth)
-		{
-			if (a_depth >= 1)
-			{
-				return 1;
-			}
-			return 0;
-		}
-
 		internal virtual object ActivatedObject(int a_depth)
 		{
+			// TODO: It may be possible to optimise away the following call
 			CheckActive();
+			if (null == i_object)
+			{
+				return null;
+			}
 			Activate(i_object, a_depth);
 			return i_object;
 		}
 
-		public override object CreateDefault(Db4objects.Db4o.Internal.Transaction a_trans
-			)
+		public override object CreateDefault(Transaction a_trans)
 		{
 			Db4objects.Db4o.P1ListElement elem4 = new Db4objects.Db4o.P1ListElement();
 			elem4.SetTrans(a_trans);
