@@ -1,14 +1,10 @@
-/* Copyright (C) 2004 - 2007  db4objects Inc.  http://www.db4o.com
+/* This file is part of the db4o object database http://www.db4o.com
 
-This file is part of the db4o open source object database.
+Copyright (C) 2004 - 2009  Versant Corporation http://www.versant.com
 
 db4o is free software; you can redistribute it and/or modify it under
-the terms of version 2 of the GNU General Public License as published
-by the Free Software Foundation and as clarified by db4objects' GPL 
-interpretation policy, available at
-http://www.db4o.com/about/company/legalpolicies/gplinterpretation/
-Alternatively you can write to db4objects, Inc., 1900 S Norfolk Street,
-Suite 350, San Mateo, CA 94403, USA.
+the terms of version 3 of the GNU General Public License as published
+by the Free Software Foundation.
 
 db4o is distributed in the hope that it will be useful, but WITHOUT ANY
 WARRANTY; without even the implied warranty of MERCHANTABILITY or
@@ -16,8 +12,12 @@ FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
 for more details.
 
 You should have received a copy of the GNU General Public License along
-with this program; if not, write to the Free Software Foundation, Inc.,
-59 Temple Place - Suite 330, Boston, MA  02111-1307, USA. */
+with this program.  If not, see http://www.gnu.org/licenses/. */
+using System;
+using System.Reflection;
+using Db4objects.Db4o.Internal;
+using Db4objects.Db4o.Query;
+
 namespace Db4objects.Db4o.Query
 {
 	/// <summary>Base class for native queries.</summary>
@@ -83,9 +83,9 @@ namespace Db4objects.Db4o.Query
 	/// - use the delegate notation for .NET 2.0.<br />
 	/// - extend the Predicate class for all other language dialects<br /><br />
 	/// A class that extends Predicate is required to
-	/// implement the #match() / #Match() method, following the native query
+	/// implement the #match() method, following the native query
 	/// conventions:<br />
-	/// - The name of the method is "#match()" (Java) / "#Match()" (.NET).<br />
+	/// - The name of the method is "#match()" (Java).<br />
 	/// - The method must be public public.<br />
 	/// - The method returns a boolean.<br />
 	/// - The method takes one parameter.<br />
@@ -98,40 +98,38 @@ namespace Db4objects.Db4o.Query
 	[System.Serializable]
 	public abstract class Predicate
 	{
-		/// <summary>public for implementation reasons, please ignore.</summary>
-		/// <remarks>public for implementation reasons, please ignore.</remarks>
-		public static readonly string PREDICATEMETHOD_NAME = "match";
+		internal static readonly Type ObjectClass = typeof(object);
 
-		internal static readonly System.Type OBJECT_CLASS = typeof(object);
-
-		private System.Type _extentType;
+		private Type _extentType;
 
 		[System.NonSerialized]
-		private System.Reflection.MethodInfo cachedFilterMethod = null;
+		private MethodInfo cachedFilterMethod = null;
 
 		public Predicate() : this(null)
 		{
 		}
 
-		public Predicate(System.Type extentType)
+		public Predicate(Type extentType)
 		{
 			_extentType = extentType;
 		}
 
-		internal virtual System.Reflection.MethodInfo GetFilterMethod()
+		// IMPORTANT: must have package visibility because it is used as
+		// internal on the .net side
+		internal virtual MethodInfo GetFilterMethod()
 		{
 			if (cachedFilterMethod != null)
 			{
 				return cachedFilterMethod;
 			}
-			System.Reflection.MethodInfo[] methods = GetType().GetMethods();
-			System.Reflection.MethodInfo untypedMethod = null;
+			MethodInfo[] methods = GetType().GetMethods();
+			MethodInfo untypedMethod = null;
 			for (int methodIdx = 0; methodIdx < methods.Length; methodIdx++)
 			{
-				System.Reflection.MethodInfo method = methods[methodIdx];
-				if (IsFilterMethod(method))
+				MethodInfo method = methods[methodIdx];
+				if (PredicatePlatform.IsFilterMethod(method))
 				{
-					if (!OBJECT_CLASS.Equals(Sharpen.Runtime.GetParameterTypes(method)[0]))
+					if (!ObjectClass.Equals(Sharpen.Runtime.GetParameterTypes(method)[0]))
 					{
 						cachedFilterMethod = method;
 						return method;
@@ -144,22 +142,12 @@ namespace Db4objects.Db4o.Query
 				cachedFilterMethod = untypedMethod;
 				return untypedMethod;
 			}
-			throw new System.ArgumentException("Invalid predicate.");
-		}
-
-		private bool IsFilterMethod(System.Reflection.MethodInfo method)
-		{
-			if (Sharpen.Runtime.GetParameterTypes(method).Length != 1)
-			{
-				return false;
-			}
-			return Sharpen.Runtime.EqualsIgnoreCase(method.Name, PREDICATEMETHOD_NAME);
-			return method.Name.Equals(PREDICATEMETHOD_NAME);
+			throw new ArgumentException("Invalid predicate.");
 		}
 
 		/// <summary>public for implementation reasons, please ignore.</summary>
 		/// <remarks>public for implementation reasons, please ignore.</remarks>
-		public virtual System.Type ExtentType()
+		public virtual Type ExtentType()
 		{
 			return (_extentType != null ? _extentType : Sharpen.Runtime.GetParameterTypes(GetFilterMethod
 				())[0]);
@@ -171,13 +159,16 @@ namespace Db4objects.Db4o.Query
 		{
 			try
 			{
-				System.Reflection.MethodInfo filterMethod = GetFilterMethod();
-				Db4objects.Db4o.Internal.Platform4.SetAccessible(filterMethod);
+				MethodInfo filterMethod = GetFilterMethod();
+				Platform4.SetAccessible(filterMethod);
 				object ret = filterMethod.Invoke(this, new object[] { candidate });
 				return ((bool)ret);
 			}
-			catch
+			catch (Exception)
 			{
+				// FIXME: Exceptions should be logged for app developers,
+				// but we can't print them out here.
+				// e.printStackTrace();
 				return false;
 			}
 		}
