@@ -1,14 +1,10 @@
-/* Copyright (C) 2004 - 2007  db4objects Inc.  http://www.db4o.com
+/* This file is part of the db4o object database http://www.db4o.com
 
-This file is part of the db4o open source object database.
+Copyright (C) 2004 - 2009  Versant Corporation http://www.versant.com
 
 db4o is free software; you can redistribute it and/or modify it under
-the terms of version 2 of the GNU General Public License as published
-by the Free Software Foundation and as clarified by db4objects' GPL 
-interpretation policy, available at
-http://www.db4o.com/about/company/legalpolicies/gplinterpretation/
-Alternatively you can write to db4objects, Inc., 1900 S Norfolk Street,
-Suite 350, San Mateo, CA 94403, USA.
+the terms of version 3 of the GNU General Public License as published
+by the Free Software Foundation.
 
 db4o is distributed in the hope that it will be useful, but WITHOUT ANY
 WARRANTY; without even the implied warranty of MERCHANTABILITY or
@@ -16,30 +12,31 @@ FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
 for more details.
 
 You should have received a copy of the GNU General Public License along
-with this program; if not, write to the Free Software Foundation, Inc.,
-59 Temple Place - Suite 330, Boston, MA  02111-1307, USA. */
+with this program.  If not, see http://www.gnu.org/licenses/. */
+using System;
+using Db4objects.Db4o.Reflect;
+using Sharpen.Lang.Reflect;
+
 namespace Db4objects.Db4o.Reflect.Core
 {
 	/// <exclude></exclude>
-	public abstract class AbstractReflectArray : Db4objects.Db4o.Reflect.IReflectArray
+	public abstract class AbstractReflectArray : IReflectArray
 	{
-		protected readonly Db4objects.Db4o.Reflect.IReflector _reflector;
+		protected readonly IReflector _reflector;
 
-		public AbstractReflectArray(Db4objects.Db4o.Reflect.IReflector reflector)
+		public AbstractReflectArray(IReflector reflector)
 		{
 			_reflector = reflector;
 		}
 
-		public abstract object NewInstance(Db4objects.Db4o.Reflect.IReflectClass componentType
-			, int[] dimensions);
+		public abstract object NewInstance(IReflectClass componentType, int[] dimensions);
 
-		public abstract object NewInstance(Db4objects.Db4o.Reflect.IReflectClass componentType
-			, int length);
+		public abstract object NewInstance(IReflectClass componentType, int length);
 
 		public virtual int[] Dimensions(object arr)
 		{
 			int count = 0;
-			Db4objects.Db4o.Reflect.IReflectClass claxx = _reflector.ForObject(arr);
+			IReflectClass claxx = _reflector.ForObject(arr);
 			while (claxx.IsArray())
 			{
 				count++;
@@ -53,7 +50,7 @@ namespace Db4objects.Db4o.Reflect.Core
 					dim[i] = GetLength(arr);
 					arr = Get(arr, 0);
 				}
-				catch
+				catch (Exception)
 				{
 					return dim;
 				}
@@ -87,8 +84,7 @@ namespace Db4objects.Db4o.Reflect.Core
 			return Sharpen.Runtime.GetArrayValue(onArray, index);
 		}
 
-		public virtual Db4objects.Db4o.Reflect.IReflectClass GetComponentType(Db4objects.Db4o.Reflect.IReflectClass
-			 a_class)
+		public virtual IReflectClass GetComponentType(IReflectClass a_class)
 		{
 			while (a_class.IsArray())
 			{
@@ -108,13 +104,13 @@ namespace Db4objects.Db4o.Reflect.Core
 			{
 				return Get(onArray, index);
 			}
-			catch
+			catch (Exception)
 			{
 				return null;
 			}
 		}
 
-		public virtual bool IsNDimensional(Db4objects.Db4o.Reflect.IReflectClass a_class)
+		public virtual bool IsNDimensional(IReflectClass a_class)
 		{
 			return a_class.GetComponentType().IsArray();
 		}
@@ -127,18 +123,21 @@ namespace Db4objects.Db4o.Reflect.Core
 				{
 					Sharpen.Runtime.SetArrayValue(onArray, index, element);
 				}
-				catch
+				catch (Exception)
 				{
 				}
 			}
 			else
 			{
+				// This can happen on primitive arrays
+				// and we are fine with ignoring it.
+				// TODO: check if it's a primitive array first and don't ignore exceptions
 				Sharpen.Runtime.SetArrayValue(onArray, index, element);
 			}
 		}
 
-		public virtual int Shape(object[] a_flat, int a_flatElement, object a_shaped, int[]
-			 a_dimensions, int a_currentDimension)
+		public virtual int Shape(object[] a_flat, int a_flatElement, object a_shaped, int
+			[] a_dimensions, int a_currentDimension)
 		{
 			if (a_currentDimension == (a_dimensions.Length - 1))
 			{
@@ -157,5 +156,9 @@ namespace Db4objects.Db4o.Reflect.Core
 			}
 			return a_flatElement;
 		}
+
+		public abstract void Analyze(object arg1, ArrayInfo arg2);
+
+		public abstract object NewInstance(IReflectClass arg1, ArrayInfo arg2);
 	}
 }
