@@ -1,14 +1,10 @@
-/* Copyright (C) 2004 - 2007  db4objects Inc.  http://www.db4o.com
+/* This file is part of the db4o object database http://www.db4o.com
 
-This file is part of the db4o open source object database.
+Copyright (C) 2004 - 2009  Versant Corporation http://www.versant.com
 
 db4o is free software; you can redistribute it and/or modify it under
-the terms of version 2 of the GNU General Public License as published
-by the Free Software Foundation and as clarified by db4objects' GPL 
-interpretation policy, available at
-http://www.db4o.com/about/company/legalpolicies/gplinterpretation/
-Alternatively you can write to db4objects, Inc., 1900 S Norfolk Street,
-Suite 350, San Mateo, CA 94403, USA.
+the terms of version 3 of the GNU General Public License as published
+by the Free Software Foundation.
 
 db4o is distributed in the hope that it will be useful, but WITHOUT ANY
 WARRANTY; without even the implied warranty of MERCHANTABILITY or
@@ -16,19 +12,21 @@ FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
 for more details.
 
 You should have received a copy of the GNU General Public License along
-with this program; if not, write to the Free Software Foundation, Inc.,
-59 Temple Place - Suite 330, Boston, MA  02111-1307, USA. */
+with this program.  If not, see http://www.gnu.org/licenses/. */
+using Db4objects.Db4o.Foundation;
+using Db4objects.Db4o.Reflect;
+using Db4objects.Db4o.Reflect.Generic;
+
 namespace Db4objects.Db4o.Reflect.Generic
 {
 	/// <exclude></exclude>
-	public class GenericClass : Db4objects.Db4o.Reflect.IReflectClass, Db4objects.Db4o.Foundation.IDeepClone
+	public class GenericClass : IReflectClass, IDeepClone
 	{
-		private static readonly Db4objects.Db4o.Reflect.Generic.GenericField[] NO_FIELDS = 
-			new Db4objects.Db4o.Reflect.Generic.GenericField[0];
+		private static readonly GenericField[] NoFields = new GenericField[0];
 
-		private readonly Db4objects.Db4o.Reflect.Generic.GenericReflector _reflector;
+		private readonly GenericReflector _reflector;
 
-		private readonly Db4objects.Db4o.Reflect.IReflectClass _delegate;
+		private readonly IReflectClass _delegate;
 
 		private readonly string _name;
 
@@ -42,9 +40,9 @@ namespace Db4objects.Db4o.Reflect.Generic
 
 		private int _isCollection;
 
-		private Db4objects.Db4o.Reflect.Generic.IGenericConverter _converter;
+		private IGenericConverter _converter;
 
-		private Db4objects.Db4o.Reflect.Generic.GenericField[] _fields = NO_FIELDS;
+		private GenericField[] _fields = NoFields;
 
 		private int _declaredFieldCount = -1;
 
@@ -52,9 +50,8 @@ namespace Db4objects.Db4o.Reflect.Generic
 
 		private readonly int _hashCode;
 
-		public GenericClass(Db4objects.Db4o.Reflect.Generic.GenericReflector reflector, Db4objects.Db4o.Reflect.IReflectClass
-			 delegateClass, string name, Db4objects.Db4o.Reflect.Generic.GenericClass superclass
-			)
+		public GenericClass(GenericReflector reflector, IReflectClass delegateClass, string
+			 name, Db4objects.Db4o.Reflect.Generic.GenericClass superclass)
 		{
 			_reflector = reflector;
 			_delegate = delegateClass;
@@ -69,16 +66,14 @@ namespace Db4objects.Db4o.Reflect.Generic
 			{
 				return _array;
 			}
-			_array = new Db4objects.Db4o.Reflect.Generic.GenericArrayClass(_reflector, this, 
-				_name, _superclass);
+			_array = new GenericArrayClass(_reflector, this, _name, _superclass);
 			_array._isSecondClass = _isSecondClass;
 			return _array;
 		}
 
 		public virtual object DeepClone(object obj)
 		{
-			Db4objects.Db4o.Reflect.Generic.GenericReflector reflector = (Db4objects.Db4o.Reflect.Generic.GenericReflector
-				)obj;
+			GenericReflector reflector = (GenericReflector)obj;
 			Db4objects.Db4o.Reflect.Generic.GenericClass superClass = null;
 			if (_superclass != null)
 			{
@@ -88,12 +83,10 @@ namespace Db4objects.Db4o.Reflect.Generic
 			Db4objects.Db4o.Reflect.Generic.GenericClass ret = new Db4objects.Db4o.Reflect.Generic.GenericClass
 				(reflector, _delegate, _name, superClass);
 			ret._isSecondClass = _isSecondClass;
-			Db4objects.Db4o.Reflect.Generic.GenericField[] fields = new Db4objects.Db4o.Reflect.Generic.GenericField
-				[_fields.Length];
+			GenericField[] fields = new GenericField[_fields.Length];
 			for (int i = 0; i < fields.Length; i++)
 			{
-				fields[i] = (Db4objects.Db4o.Reflect.Generic.GenericField)_fields[i].DeepClone(reflector
-					);
+				fields[i] = (GenericField)_fields[i].DeepClone(reflector);
 			}
 			ret.InitFields(fields);
 			return ret;
@@ -122,7 +115,7 @@ namespace Db4objects.Db4o.Reflect.Generic
 			return _name.Equals(otherGC._name);
 		}
 
-		public virtual Db4objects.Db4o.Reflect.IReflectClass GetComponentType()
+		public virtual IReflectClass GetComponentType()
 		{
 			if (_delegate != null)
 			{
@@ -131,18 +124,9 @@ namespace Db4objects.Db4o.Reflect.Generic
 			return null;
 		}
 
-		public virtual Db4objects.Db4o.Reflect.IReflectConstructor[] GetDeclaredConstructors
-			()
-		{
-			if (_delegate != null)
-			{
-				return _delegate.GetDeclaredConstructors();
-			}
-			return null;
-		}
-
-		public virtual Db4objects.Db4o.Reflect.IReflectField GetDeclaredField(string name
-			)
+		// TODO: consider that classes may have two fields of
+		// the same name after refactoring.
+		public virtual IReflectField GetDeclaredField(string name)
 		{
 			if (_delegate != null)
 			{
@@ -158,7 +142,7 @@ namespace Db4objects.Db4o.Reflect.Generic
 			return null;
 		}
 
-		public virtual Db4objects.Db4o.Reflect.IReflectField[] GetDeclaredFields()
+		public virtual IReflectField[] GetDeclaredFields()
 		{
 			if (_delegate != null)
 			{
@@ -167,7 +151,7 @@ namespace Db4objects.Db4o.Reflect.Generic
 			return _fields;
 		}
 
-		public virtual Db4objects.Db4o.Reflect.IReflectClass GetDelegate()
+		public virtual IReflectClass GetDelegate()
 		{
 			if (_delegate != null)
 			{
@@ -195,8 +179,8 @@ namespace Db4objects.Db4o.Reflect.Generic
 			return _fieldCount;
 		}
 
-		public virtual Db4objects.Db4o.Reflect.IReflectMethod GetMethod(string methodName
-			, Db4objects.Db4o.Reflect.IReflectClass[] paramClasses)
+		public virtual IReflectMethod GetMethod(string methodName, IReflectClass[] paramClasses
+			)
 		{
 			if (_delegate != null)
 			{
@@ -210,7 +194,7 @@ namespace Db4objects.Db4o.Reflect.Generic
 			return _name;
 		}
 
-		public virtual Db4objects.Db4o.Reflect.IReflectClass GetSuperclass()
+		public virtual IReflectClass GetSuperclass()
 		{
 			if (_superclass != null)
 			{
@@ -220,8 +204,7 @@ namespace Db4objects.Db4o.Reflect.Generic
 			{
 				return _reflector.ForClass(typeof(object));
 			}
-			Db4objects.Db4o.Reflect.IReflectClass delegateSuperclass = _delegate.GetSuperclass
-				();
+			IReflectClass delegateSuperclass = _delegate.GetSuperclass();
 			if (delegateSuperclass != null)
 			{
 				_superclass = _reflector.EnsureDelegate(delegateSuperclass);
@@ -234,8 +217,7 @@ namespace Db4objects.Db4o.Reflect.Generic
 			return _hashCode;
 		}
 
-		public virtual void InitFields(Db4objects.Db4o.Reflect.Generic.GenericField[] fields
-			)
+		public virtual void InitFields(GenericField[] fields)
 		{
 			int startIndex = 0;
 			if (_superclass != null)
@@ -249,6 +231,8 @@ namespace Db4objects.Db4o.Reflect.Generic
 			}
 		}
 
+		// TODO: Consider: Will this method still be necessary 
+		// once constructor logic is pushed into the reflectors?
 		public virtual bool IsAbstract()
 		{
 			if (_delegate != null)
@@ -267,8 +251,7 @@ namespace Db4objects.Db4o.Reflect.Generic
 			return false;
 		}
 
-		public virtual bool IsAssignableFrom(Db4objects.Db4o.Reflect.IReflectClass subclassCandidate
-			)
+		public virtual bool IsAssignableFrom(IReflectClass subclassCandidate)
 		{
 			if (subclassCandidate == null)
 			{
@@ -314,12 +297,11 @@ namespace Db4objects.Db4o.Reflect.Generic
 			{
 				return _delegate.IsInstance(candidate);
 			}
-			if (!(candidate is Db4objects.Db4o.Reflect.Generic.GenericObject))
+			if (!(candidate is GenericObject))
 			{
 				return false;
 			}
-			return IsAssignableFrom(((Db4objects.Db4o.Reflect.Generic.GenericObject)candidate
-				)._class);
+			return IsAssignableFrom(((GenericObject)candidate).GetGenericClass());
 		}
 
 		public virtual bool IsInterface()
@@ -340,25 +322,16 @@ namespace Db4objects.Db4o.Reflect.Generic
 			return _isPrimitive;
 		}
 
-		public virtual bool IsSecondClass()
-		{
-			if (IsPrimitive())
-			{
-				return true;
-			}
-			return _isSecondClass;
-		}
-
 		public virtual object NewInstance()
 		{
 			if (_delegate != null)
 			{
 				return _delegate.NewInstance();
 			}
-			return new Db4objects.Db4o.Reflect.Generic.GenericObject(this);
+			return new GenericObject(this);
 		}
 
-		public virtual Db4objects.Db4o.Reflect.IReflector Reflector()
+		public virtual IReflector Reflector()
 		{
 			if (_delegate != null)
 			{
@@ -367,8 +340,7 @@ namespace Db4objects.Db4o.Reflect.Generic
 			return _reflector;
 		}
 
-		internal virtual void SetConverter(Db4objects.Db4o.Reflect.Generic.IGenericConverter
-			 converter)
+		internal virtual void SetConverter(IGenericConverter converter)
 		{
 			_converter = converter;
 		}
@@ -388,46 +360,36 @@ namespace Db4objects.Db4o.Reflect.Generic
 			_isSecondClass = true;
 		}
 
-		public virtual bool SkipConstructor(bool flag)
-		{
-			if (_delegate != null)
-			{
-				return _delegate.SkipConstructor(flag);
-			}
-			return false;
-		}
-
 		public override string ToString()
 		{
 			return "GenericClass " + _name;
 		}
 
-		public virtual string ToString(Db4objects.Db4o.Reflect.Generic.GenericObject obj)
+		public virtual string ToString(object obj)
 		{
 			if (_converter == null)
 			{
 				return "(G) " + GetName();
 			}
-			return _converter.ToString(obj);
+			return _converter.ToString((GenericObject)obj);
 		}
 
-		public virtual void UseConstructor(Db4objects.Db4o.Reflect.IReflectConstructor constructor
-			, object[] @params)
+		public virtual bool EnsureCanBeInstantiated()
 		{
 			if (_delegate != null)
 			{
-				_delegate.UseConstructor(constructor, @params);
+				return _delegate.EnsureCanBeInstantiated();
 			}
+			return true;
 		}
 
-		public virtual object[] ToArray(object obj)
+		public virtual object NullValue()
 		{
-			if (!IsCollection())
+			if (_delegate == null)
 			{
-				return new object[] { obj };
+				return null;
 			}
-			return Db4objects.Db4o.Internal.Platform4.CollectionToArray(_reflector.GetStream(
-				), obj);
+			return _delegate.NullValue();
 		}
 	}
 }
