@@ -1,14 +1,10 @@
-/* Copyright (C) 2004 - 2007  db4objects Inc.  http://www.db4o.com
+/* This file is part of the db4o object database http://www.db4o.com
 
-This file is part of the db4o open source object database.
+Copyright (C) 2004 - 2009  Versant Corporation http://www.versant.com
 
 db4o is free software; you can redistribute it and/or modify it under
-the terms of version 2 of the GNU General Public License as published
-by the Free Software Foundation and as clarified by db4objects' GPL 
-interpretation policy, available at
-http://www.db4o.com/about/company/legalpolicies/gplinterpretation/
-Alternatively you can write to db4objects, Inc., 1900 S Norfolk Street,
-Suite 350, San Mateo, CA 94403, USA.
+the terms of version 3 of the GNU General Public License as published
+by the Free Software Foundation.
 
 db4o is distributed in the hope that it will be useful, but WITHOUT ANY
 WARRANTY; without even the implied warranty of MERCHANTABILITY or
@@ -16,8 +12,9 @@ FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
 for more details.
 
 You should have received a copy of the GNU General Public License along
-with this program; if not, write to the Free Software Foundation, Inc.,
-59 Temple Place - Suite 330, Boston, MA  02111-1307, USA. */
+with this program.  If not, see http://www.gnu.org/licenses/. */
+using Db4objects.Db4o.Replication;
+
 namespace Db4objects.Db4o.Replication
 {
 	/// <summary>
@@ -32,6 +29,8 @@ namespace Db4objects.Db4o.Replication
 	/// was modified in both ObjectContainers since the last replication run between
 	/// the two.
 	/// </summary>
+	[System.ObsoleteAttribute(@"Since db4o-5.2. Use db4o Replication System (dRS) instead.<br><br>"
+		)]
 	public interface IReplicationConflictHandler
 	{
 		/// <summary>the callback method to be implemented to resolve a conflict.</summary>
@@ -60,7 +59,7 @@ namespace Db4objects.Db4o.Replication
 		/// 	</seealso>
 		/// <seealso cref="Db4objects.Db4o.Replication.IReplicationProcess.PeerB">Db4objects.Db4o.Replication.IReplicationProcess.PeerB
 		/// 	</seealso>
-		object ResolveConflict(Db4objects.Db4o.Replication.IReplicationProcess replicationProcess
-			, object a, object b);
+		object ResolveConflict(IReplicationProcess replicationProcess, object a, object b
+			);
 	}
 }
