@@ -1,14 +1,10 @@
-/* Copyright (C) 2004 - 2007  db4objects Inc.  http://www.db4o.com
+/* This file is part of the db4o object database http://www.db4o.com
 
-This file is part of the db4o open source object database.
+Copyright (C) 2004 - 2009  Versant Corporation http://www.versant.com
 
 db4o is free software; you can redistribute it and/or modify it under
-the terms of version 2 of the GNU General Public License as published
-by the Free Software Foundation and as clarified by db4objects' GPL 
-interpretation policy, available at
-http://www.db4o.com/about/company/legalpolicies/gplinterpretation/
-Alternatively you can write to db4objects, Inc., 1900 S Norfolk Street,
-Suite 350, San Mateo, CA 94403, USA.
+the terms of version 3 of the GNU General Public License as published
+by the Free Software Foundation.
 
 db4o is distributed in the hope that it will be useful, but WITHOUT ANY
 WARRANTY; without even the implied warranty of MERCHANTABILITY or
@@ -16,14 +12,18 @@ FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
 for more details.
 
 You should have received a copy of the GNU General Public License along
-with this program; if not, write to the Free Software Foundation, Inc.,
-59 Temple Place - Suite 330, Boston, MA  02111-1307, USA. */
+with this program.  If not, see http://www.gnu.org/licenses/. */
+using Db4objects.Db4o;
+using Db4objects.Db4o.Query;
+
 namespace Db4objects.Db4o.Replication
 {
 	/// <summary>db4o replication interface.</summary>
 	/// <remarks>db4o replication interface.</remarks>
 	/// <seealso cref="Db4objects.Db4o.Ext.IExtObjectContainer.ReplicationBegin">Db4objects.Db4o.Ext.IExtObjectContainer.ReplicationBegin
 	/// 	</seealso>
+	[System.ObsoleteAttribute(@"Since db4o-5.2. Use db4o Replication System (dRS) instead.<br><br>"
+		)]
 	public interface IReplicationProcess
 	{
 		/// <summary>
@@ -45,7 +45,10 @@ namespace Db4objects.Db4o.Replication
 		/// <br /><br />Call this method after replication is completed to
 		/// write all changes back to the database files. This method
 		/// synchronizes both ObjectContainers by setting the transaction
-		/// serial number (@link ExtObjectContainer#version()) on both
+		/// serial number
+		/// <see cref="Db4objects.Db4o.Ext.IExtObjectContainer.Version">Db4objects.Db4o.Ext.IExtObjectContainer.Version
+		/// 	</see>
+		/// on both
 		/// ObjectContainers to be equal
 		/// to the higher version number among the two. A record with
 		/// information about this replication task, including the
@@ -58,13 +61,13 @@ namespace Db4objects.Db4o.Replication
 		/// 	</summary>
 		/// <remarks>returns the "peerA" ObjectContainer involved in this ReplicationProcess.
 		/// 	</remarks>
-		Db4objects.Db4o.IObjectContainer PeerA();
+		IObjectContainer PeerA();
 
 		/// <summary>returns the "peerB" ObjectContainer involved in this ReplicationProcess.
 		/// 	</summary>
 		/// <remarks>returns the "peerB" ObjectContainer involved in this ReplicationProcess.
 		/// 	</remarks>
-		Db4objects.Db4o.IObjectContainer PeerB();
+		IObjectContainer PeerB();
 
 		/// <summary>replicates an object.</summary>
 		/// <remarks>
@@ -91,8 +94,7 @@ namespace Db4objects.Db4o.Replication
 		/// </summary>
 		/// <param name="relicateFrom">the ObjectContainer to replicate from</param>
 		/// <param name="replicateTo">the ObjectContainer to replicate to</param>
-		void SetDirection(Db4objects.Db4o.IObjectContainer relicateFrom, Db4objects.Db4o.IObjectContainer
-			 replicateTo);
+		void SetDirection(IObjectContainer relicateFrom, IObjectContainer replicateTo);
 
 		/// <summary>
 		/// adds a constraint to the passed Query to query only for objects that
@@ -105,6 +107,6 @@ namespace Db4objects.Db4o.Replication
 		/// ObjectContainers involved in this replication process.
 		/// </remarks>
 		/// <param name="query">the Query to be constrained</param>
-		void WhereModified(Db4objects.Db4o.Query.IQuery query);
+		void WhereModified(IQuery query);
 	}
 }
