@@ -1,14 +1,10 @@
-/* Copyright (C) 2004 - 2007  db4objects Inc.  http://www.db4o.com
+/* This file is part of the db4o object database http://www.db4o.com
 
-This file is part of the db4o open source object database.
+Copyright (C) 2004 - 2009  Versant Corporation http://www.versant.com
 
 db4o is free software; you can redistribute it and/or modify it under
-the terms of version 2 of the GNU General Public License as published
-by the Free Software Foundation and as clarified by db4objects' GPL 
-interpretation policy, available at
-http://www.db4o.com/about/company/legalpolicies/gplinterpretation/
-Alternatively you can write to db4objects, Inc., 1900 S Norfolk Street,
-Suite 350, San Mateo, CA 94403, USA.
+the terms of version 3 of the GNU General Public License as published
+by the Free Software Foundation.
 
 db4o is distributed in the hope that it will be useful, but WITHOUT ANY
 WARRANTY; without even the implied warranty of MERCHANTABILITY or
@@ -16,16 +12,17 @@ FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
 for more details.
 
 You should have received a copy of the GNU General Public License along
-with this program; if not, write to the Free Software Foundation, Inc.,
-59 Temple Place - Suite 330, Boston, MA  02111-1307, USA. */
+with this program.  If not, see http://www.gnu.org/licenses/. */
+using Db4objects.Db4o.Types;
+
 namespace Db4objects.Db4o.Types
 {
 	/// <summary>
-	/// the db4o Blob type to store blobs independant of the main database
+	/// the db4o Blob type to store blobs independent of the main database
 	/// file and allows to perform asynchronous upload and download operations.
 	/// </summary>
 	/// <remarks>
-	/// the db4o Blob type to store blobs independant of the main database
+	/// the db4o Blob type to store blobs independent of the main database
 	/// file and allows to perform asynchronous upload and download operations.
 	/// <br /><br />
 	/// <b>Usage:</b><br />
@@ -38,13 +35,13 @@ namespace Db4objects.Db4o.Types
 	/// previously stored. It may also help you to track the completion
 	/// of the current process.
 	/// <br /><br />
-	/// db4o client/server carries out all blob operations in a seperate
+	/// db4o client/server carries out all blob operations in a separate
 	/// thread on a specially dedicated socket. One socket is used for
 	/// all blob operations and operations are queued. Your application
 	/// may continue to access db4o while a blob is transferred in the
 	/// background.
 	/// </remarks>
-	public interface IBlob : Db4objects.Db4o.Types.IDb4oType
+	public interface IBlob : IDb4oType
 	{
 		/// <summary>returns the name of the file the blob was stored to.</summary>
 		/// <remarks>
@@ -124,5 +121,13 @@ namespace Db4objects.Db4o.Types
 		/// </exception>
 		/// <param name="file">the file the blob is to be written to.</param>
 		void WriteTo(Sharpen.IO.File file);
+
+		/// <summary>Deletes the current file stored in this BLOB.</summary>
+		/// <remarks>Deletes the current file stored in this BLOB.</remarks>
+		/// <exception cref="System.IO.IOException">
+		/// in case of errors and in case no
+		/// data was stored
+		/// </exception>
+		void DeleteFile();
 	}
 }
