@@ -1,14 +1,10 @@
-/* Copyright (C) 2004 - 2007  db4objects Inc.  http://www.db4o.com
+/* This file is part of the db4o object database http://www.db4o.com
 
-This file is part of the db4o open source object database.
+Copyright (C) 2004 - 2009  Versant Corporation http://www.versant.com
 
 db4o is free software; you can redistribute it and/or modify it under
-the terms of version 2 of the GNU General Public License as published
-by the Free Software Foundation and as clarified by db4objects' GPL 
-interpretation policy, available at
-http://www.db4o.com/about/company/legalpolicies/gplinterpretation/
-Alternatively you can write to db4objects, Inc., 1900 S Norfolk Street,
-Suite 350, San Mateo, CA 94403, USA.
+the terms of version 3 of the GNU General Public License as published
+by the Free Software Foundation.
 
 db4o is distributed in the hope that it will be useful, but WITHOUT ANY
 WARRANTY; without even the implied warranty of MERCHANTABILITY or
@@ -16,8 +12,7 @@ FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
 for more details.
 
 You should have received a copy of the GNU General Public License along
-with this program; if not, write to the Free Software Foundation, Inc.,
-59 Temple Place - Suite 330, Boston, MA  02111-1307, USA. */
+with this program.  If not, see http://www.gnu.org/licenses/. */
 using System;
 
 namespace Db4objects.Db4o.Foundation
@@ -30,7 +25,7 @@ namespace Db4objects.Db4o.Foundation
 
 			IConvertible convertible = obj as IConvertible;
 			if (null != convertible) return convertible.ToSByte(null);
-			return Db4objects.Db4o.Foundation.No4.INSTANCE;
+			return Db4objects.Db4o.Foundation.No4.Instance;
 		}
 
 		public static object ToShort(object obj)
@@ -39,7 +34,7 @@ namespace Db4objects.Db4o.Foundation
 
 			IConvertible convertible = obj as IConvertible;
 			if (null != convertible) return convertible.ToInt16(null);
-			return Db4objects.Db4o.Foundation.No4.INSTANCE;
+			return Db4objects.Db4o.Foundation.No4.Instance;
 		}
 
 		public static object ToInt(object obj)
@@ -48,7 +43,7 @@ namespace Db4objects.Db4o.Foundation
 
 			IConvertible convertible = obj as IConvertible;
 			if (null != convertible) return convertible.ToInt32(null);
-			return Db4objects.Db4o.Foundation.No4.INSTANCE;
+			return Db4objects.Db4o.Foundation.No4.Instance;
 		}
 
 		public static object ToLong(object obj)
@@ -57,7 +52,7 @@ namespace Db4objects.Db4o.Foundation
 
 			IConvertible convertible = obj as IConvertible;
 			if (null != convertible) return convertible.ToInt64(null);
-			return Db4objects.Db4o.Foundation.No4.INSTANCE;
+			return Db4objects.Db4o.Foundation.No4.Instance;
 		}
 
 		public static object ToFloat(object obj)
@@ -66,7 +61,7 @@ namespace Db4objects.Db4o.Foundation
 
 			IConvertible convertible = obj as IConvertible;
 			if (null != convertible) return convertible.ToSingle(null);
-			return Db4objects.Db4o.Foundation.No4.INSTANCE;
+			return Db4objects.Db4o.Foundation.No4.Instance;
 		}
 
 		public static object ToDouble(object obj)
@@ -75,7 +70,7 @@ namespace Db4objects.Db4o.Foundation
 
 			IConvertible convertible = obj as IConvertible;
 			if (null != convertible) return convertible.ToDouble(null);
-			return Db4objects.Db4o.Foundation.No4.INSTANCE;
+			return Db4objects.Db4o.Foundation.No4.Instance;
 		}
 	}
 }
