@@ -1,14 +1,10 @@
-/* Copyright (C) 2004 - 2007  db4objects Inc.  http://www.db4o.com
+/* This file is part of the db4o object database http://www.db4o.com
 
-This file is part of the db4o open source object database.
+Copyright (C) 2004 - 2009  Versant Corporation http://www.versant.com
 
 db4o is free software; you can redistribute it and/or modify it under
-the terms of version 2 of the GNU General Public License as published
-by the Free Software Foundation and as clarified by db4objects' GPL 
-interpretation policy, available at
-http://www.db4o.com/about/company/legalpolicies/gplinterpretation/
-Alternatively you can write to db4objects, Inc., 1900 S Norfolk Street,
-Suite 350, San Mateo, CA 94403, USA.
+the terms of version 3 of the GNU General Public License as published
+by the Free Software Foundation.
 
 db4o is distributed in the hope that it will be useful, but WITHOUT ANY
 WARRANTY; without even the implied warranty of MERCHANTABILITY or
@@ -16,23 +12,16 @@ FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
 for more details.
 
 You should have received a copy of the GNU General Public License along
-with this program; if not, write to the Free Software Foundation, Inc.,
-59 Temple Place - Suite 330, Boston, MA  02111-1307, USA. */
+with this program.  If not, see http://www.gnu.org/licenses/. */
 using System;
+using Db4objects.Db4o.Foundation;
+using Db4objects.Db4o.Marshall;
+
 
 namespace Db4objects.Db4o.Internal.Handlers
 {
 	public class UShortHandler : IntegralTypeHandler
 	{
-		public UShortHandler(ObjectContainerBase containerBase)
-			: base(containerBase)
-		{
-        }
-
-        public override int Compare(Object o1, Object o2){
-            return ((ushort)o2 > (ushort)o1) ? 1 : -1;
-        }
-
         public override Object DefaultValue(){
             return (ushort)0;
         }
@@ -52,5 +41,30 @@ namespace Db4objects.Db4o.Internal.Handlers
             bytes[--offset] = (byte)us;
             bytes[--offset] = (byte)(us >>= 8);
         }
+
+        public override object Read(IReadContext context)
+        {
+            byte[] bytes = new byte[2];
+            context.ReadBytes(bytes);
+            return (ushort)(
+                     bytes[1] & 255 |
+                    (bytes[0] & 255) << 8
+                );
+        }
+
+        public override void Write(IWriteContext context, object obj)
+        {
+            ushort us = (ushort)obj;
+            context.WriteBytes(
+                new byte[] { 
+                    (byte)(us>>8),
+                    (byte)us,
+                });
+        }
+
+        public override IPreparedComparison InternalPrepareComparison(object obj)
+        {
+            return new PreparedComparasionFor<ushort>(((ushort)obj));
+        }
     }
 }
