@@ -1,14 +1,10 @@
-/* Copyright (C) 2004 - 2007  db4objects Inc.  http://www.db4o.com
+/* This file is part of the db4o object database http://www.db4o.com
 
-This file is part of the db4o open source object database.
+Copyright (C) 2004 - 2009  Versant Corporation http://www.versant.com
 
 db4o is free software; you can redistribute it and/or modify it under
-the terms of version 2 of the GNU General Public License as published
-by the Free Software Foundation and as clarified by db4objects' GPL 
-interpretation policy, available at
-http://www.db4o.com/about/company/legalpolicies/gplinterpretation/
-Alternatively you can write to db4objects, Inc., 1900 S Norfolk Street,
-Suite 350, San Mateo, CA 94403, USA.
+the terms of version 3 of the GNU General Public License as published
+by the Free Software Foundation.
 
 db4o is distributed in the hope that it will be useful, but WITHOUT ANY
 WARRANTY; without even the implied warranty of MERCHANTABILITY or
@@ -16,13 +12,13 @@ FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
 for more details.
 
 You should have received a copy of the GNU General Public License along
-with this program; if not, write to the Free Software Foundation, Inc.,
-59 Temple Place - Suite 330, Boston, MA  02111-1307, USA. */
+with this program.  If not, see http://www.gnu.org/licenses/. */
 using System;
-using System.Text;
 using System.Collections;
+using System.Collections.Generic;
 using System.Globalization;
-
+using System.IO;
+using System.Text;
 using Db4objects.Db4o.Config;
 using Db4objects.Db4o.Config.Attributes;
 using Db4objects.Db4o.Ext;
@@ -34,7 +30,10 @@ using Db4objects.Db4o.Query;
 using Db4objects.Db4o.Reflect;
 using Db4objects.Db4o.Reflect.Generic;
 using Db4objects.Db4o.Reflect.Net;
+using Db4objects.Db4o.Typehandlers;
 using Db4objects.Db4o.Types;
+using Sharpen.IO;
+using Db4objects.Db4o.Foundation;
 
 namespace Db4objects.Db4o.Internal
 {
@@ -50,9 +49,12 @@ namespace Db4objects.Db4o.Internal
                     new string[] { "com.db4o", "Db4objects.Db4o"}, 
                 };
 
+
         private static ArrayList shutDownStreams;
 
-        private static byte[][] oldAssemblies;
+		private static object _lock = new object();
+
+        private static readonly byte[][] oldAssemblies;
 
 		public static object[] CollectionToArray(ObjectContainerBase stream, object obj)
         {
@@ -63,8 +65,8 @@ namespace Db4objects.Db4o.Internal
         }
 
         static Platform4()
-        {
-           	LatinStringIO stringIO = new UnicodeStringIO();
+        {   
+            LatinStringIO stringIO = new UnicodeStringIO();
             oldAssemblies = new byte[OldAssemblyNames.Length][];
             for (int i = 0; i < OldAssemblyNames.Length; i++)
             {
@@ -74,37 +76,27 @@ namespace Db4objects.Db4o.Internal
 
         internal static bool IsDb4oClass(string className)
         {
-            if (className.StartsWith("Db4objects.Db4o.Tests"))
+            if (className.IndexOf(".Tests.") > 0)
             {
                 return false;
             }
             return className.StartsWith("Db4objects.Db4o");
         }
 
-        internal static string FullyQualifiedName(System.Type type)
+        internal static void AddShutDownHook(PartialObjectContainer container)
         {
-            return Sharpen.Lang.TypeReference.FromType(type).GetUnversionedName();
-        }
-
-        internal static JDK Jdk()
-        {
-            throw new NotSupportedException();
-        }
-
-        internal static void AddShutDownHook(Object stream, Object streamLock)
-        {
-            lock (typeof(Platform4))
+            lock (_lock)
             {
                 if (shutDownStreams == null)
                 {
                     shutDownStreams = new ArrayList();
-#if !CF_1_0 && !CF_2_0
-                    EventHandler handler = new EventHandler(OnShutDown);
-                    AppDomain.CurrentDomain.ProcessExit += handler;
-                    AppDomain.CurrentDomain.DomainUnload += handler;
+#if !CF
+					EventHandler handler = new EventHandler(OnShutDown);
+					AppDomain.CurrentDomain.ProcessExit += handler;
+					AppDomain.CurrentDomain.DomainUnload += handler;
 #endif
                 }
-                shutDownStreams.Add(stream);
+                shutDownStreams.Add(container);
             }
         }
 
@@ -123,9 +115,9 @@ namespace Db4objects.Db4o.Internal
             return true;
         }
 
-        internal static IDb4oCollections Collections(Object a_object)
+        internal static IDb4oCollections Collections(Transaction transaction)
         {
-            return new P2Collections(a_object);
+            return new P2Collections(transaction);
         }
 
         internal static IReflector CreateReflector(Object config)
@@ -133,6 +125,11 @@ namespace Db4objects.Db4o.Internal
             return new NetReflector();
         }
 
+        public static IReflector ReflectorForType(Type typeInstance)
+        {
+            return new NetReflector();
+        }
+
         internal static Object CreateReferenceQueue()
         {
             return new WeakReferenceHandlerQueue();
@@ -143,14 +140,14 @@ namespace Db4objects.Db4o.Internal
             return new WeakReference(obj, false);
         }
 
-        internal static Object CreateYapRef(Object referenceQueue, Object yapObject, Object obj)
+        internal static Object CreateActiveObjectReference(Object referenceQueue, Object yapObject, Object obj)
         {
             return new WeakReferenceHandler(referenceQueue, yapObject, obj);
         }
 
         internal static long DoubleToLong(double a_double)
         {
-#if CF_1_0 || CF_2_0
+#if CF
             byte[] bytes = BitConverter.GetBytes(a_double);
             return BitConverter.ToInt64(bytes, 0);
 #else
@@ -277,14 +274,14 @@ namespace Db4objects.Db4o.Internal
             }
         }
 
-        internal static String Format(Sharpen.Util.Date date, bool showSeconds)
+        internal static String Format(DateTime date, bool showSeconds)
         {
             String fmt = "yyyy-MM-dd";
             if (showSeconds)
             {
                 fmt += " HH:mm:ss";
             }
-            return new DateTime(date.GetTicks()).ToString(fmt);
+            return date.ToString(fmt);
         }
 
         public static Object GetClassForType(Object obj)
@@ -315,19 +312,16 @@ namespace Db4objects.Db4o.Internal
             }
 
             Translate(config, typeof(Delegate), new TNull());
-            Translate(config, typeof(Type), new TType());
+            Translate(config, typeof(Type), new TType()); // TODO: unnecessary?
+            Translate(config, typeof(Type).GetType(), new TType());
 
+#if !CF
             if (IsMono())
             {
-#if !CF_1_0 && !CF_2_0
+
 				Translate(config, new Exception(), new TSerializable());
+            }
 #endif
-                Translate(config, "System.MonoType, mscorlib", new TType());
-            }
-            else
-            {
-                Translate(config, "System.RuntimeType, mscorlib", new TType());
-            }
 
             Translate(config, new ArrayList(), new TList());
             Translate(config, new Hashtable(), new TDictionary());
@@ -339,11 +333,14 @@ namespace Db4objects.Db4o.Internal
             {
                 Translate(config, "System.Collections.SortedList, mscorlib", new TDictionary());
             }
+
+            new TypeHandlerConfigurationDotNet(config).Apply();
+
         }
 
         public static bool IsCompact()
         {
-#if CF_1_0 || CF_2_0
+#if CF
 			return true;
 #else
             return false;
@@ -431,12 +428,12 @@ namespace Db4objects.Db4o.Internal
             {
                 return false;
             }
-            NetClass netClass = claxx.GetDelegate() as NetClass;
+            System.Type netClass = GetNetType(claxx);
             if (netClass == null)
             {
                 return false;
             }
-            return netClass.GetNetType().IsValueType;
+            return netClass.IsValueType;
         }
 
         internal static void KillYapRef(Object obj)
@@ -450,7 +447,7 @@ namespace Db4objects.Db4o.Internal
 
         internal static double LongToDouble(long l)
         {
-#if CF_1_0 || CF_2_0
+#if CF
             byte[] bytes = BitConverter.GetBytes(l);
             return BitConverter.ToDouble(bytes, 0);
 #else
@@ -460,7 +457,17 @@ namespace Db4objects.Db4o.Internal
 
         internal static void LockFile(string path, object file)
         {
-            // do nothing. C# RAF is locked automatically upon opening
+#if !CF
+            try
+            {
+                FileStream stream = ((RandomAccessFile) file).Stream;
+                stream.Lock(0, 1);
+            }
+            catch (IOException x)
+            {
+                throw new DatabaseFileLockedException(path,x);
+            }
+#endif
         }
 
         internal static void UnlockFile(string path, object file)
@@ -483,14 +490,6 @@ namespace Db4objects.Db4o.Internal
             ((WeakReferenceHandlerQueue)referenceQueue).Poll((IExtObjectContainer)stream);
         }
 
-        internal static void PostOpen(IObjectContainer objectContainer)
-        {
-        }
-
-        internal static void PreClose(IObjectContainer objectContainer)
-        {
-        }
-
         public static void RegisterCollections(GenericReflector reflector)
         {
             reflector.RegisterCollectionUpdateDepth(
@@ -498,13 +497,13 @@ namespace Db4objects.Db4o.Internal
                 3);
         }
 
-        internal static void RemoveShutDownHook(Object yapStream, Object streamLock)
+        internal static void RemoveShutDownHook(PartialObjectContainer container)
         {
-            lock (typeof(Platform4))
+            lock (_lock)
             {
-                if (shutDownStreams != null && shutDownStreams.Contains(yapStream))
+                if (shutDownStreams != null)
                 {
-                    shutDownStreams.Remove(yapStream);
+                    shutDownStreams.Remove(container);
                 }
             }
         }
@@ -516,13 +515,13 @@ namespace Db4objects.Db4o.Internal
 
         private static void OnShutDown(object sender, EventArgs args)
         {
-            lock (typeof(Platform4))
-            {
-				while (shutDownStreams.Count > 0)
+			lock (_lock)
+			{
+				foreach (ObjectContainerBase container in shutDownStreams.ToArray())
 				{
-					Unobfuscated.ShutDownHookCallback(shutDownStreams[0]); // this will remove the stream for the list
-				}
-            }
+					container.ShutdownHook(); // this will remove the stream for the list
+				}				
+			}
         }
 
         public static bool StoreStaticFieldValues(IReflector reflector, IReflectClass clazz)
@@ -530,19 +529,10 @@ namespace Db4objects.Db4o.Internal
             return false;
         }
 
-
-        private static void Translate(Config4Impl config, object obj, IObjectTranslator translator)
-        {
-            try
-            {
-                config.ObjectClass(obj).Translate(translator);
-            }
-            catch
-            {
-                // TODO: why the object is being logged instead of the error?
-                Unobfuscated.LogErr(config, 48, obj.ToString(), null);
-            }
-        }
+		private static void Translate(Config4Impl config, object obj, IObjectTranslator translator)
+		{
+			config.ObjectClass(obj).Translate(translator);
+		}
 
         internal static byte[] UpdateClassName(byte[] bytes)
         {
@@ -596,7 +586,7 @@ namespace Db4objects.Db4o.Internal
 
         internal static object WrapEvaluation(object evaluation)
         {
-#if CF_1_0 || CF_2_0
+#if CF
 			// FIXME: How to better support EvaluationDelegate on the CompactFramework?
 			return evaluation;
 #else
@@ -606,15 +596,20 @@ namespace Db4objects.Db4o.Internal
 #endif
         }
 
-        internal static bool IsTransient(IReflectClass clazz)
+        public static bool IsTransient(IReflectClass clazz)
         {
             Type type = GetNetType(clazz);
             if (null == type) return false;
-            return type.IsPointer
-                || type.IsSubclassOf(typeof(Delegate));
+        	return IsTransient(type);
         }
 
-        private static Type GetNetType(IReflectClass clazz)
+    	public static bool IsTransient(Type type)
+    	{
+    		return type.IsPointer
+    		       || type.IsSubclassOf(typeof(Delegate));
+    	}
+
+    	private static Type GetNetType(IReflectClass clazz)
         {
             if (null == clazz)
             {
@@ -634,17 +629,17 @@ namespace Db4objects.Db4o.Internal
             return GetNetType(claxx);
         }
 
-		internal static NetTypeHandler[] Types(ObjectContainerBase stream)
+		public static NetTypeHandler[] Types(IReflector reflector)
         {
 			return new NetTypeHandler[]
 				{
 					//new DoubleHandler(stream),
-					new SByteHandler(stream),
-					new DecimalHandler(stream),
-					new UIntHandler(stream),
-					new ULongHandler(stream),
-					new UShortHandler(stream),
-					new DateTimeHandler(stream),
+					new SByteHandler(),
+					new DecimalHandler(),
+					new UIntHandler(),
+					new ULongHandler(),
+					new UShortHandler(),
+					new DateTimeHandler(),
 				};
         }
 
@@ -670,7 +665,100 @@ namespace Db4objects.Db4o.Internal
 		                                        	typeof(Char),
 		                                        	typeof(Int16),
 		                                        	typeof(String),
-		                                        	typeof(Sharpen.Util.Date)
 		                                        };
-    }
+
+        public static String StackTrace()
+        {
+#if CF_1_0 || CF
+            throw new NotImplementedException();
+#else
+            return Environment.StackTrace;
+#endif
+        }
+
+        public static DateTime Now()
+        {
+            return DateTime.Now;
+        }
+
+		internal static bool IsEnum(IReflector genericReflector, IReflectClass iReflectClass)
+		{
+			return GetNetType(iReflectClass).IsEnum;
+		}
+
+        public static bool UseNativeSerialization() 
+        {
+            return false;
+        }
+
+        public static void RegisterPlatformHandlers(ObjectContainerBase container)
+        {
+            // do nothing
+        }
+
+        public static object NullValue(Type type) 
+        {
+            if(_nullValues == null) 
+            { 
+                InitNullValues();
+			}
+			
+			return _nullValues.Get(type);                
+		}
+		
+        private static void InitNullValues()
+        {
+    	    _nullValues = new Hashtable4();
+            _nullValues.Put(typeof(int), (int)0);
+            _nullValues.Put(typeof(uint), (uint)0);
+            _nullValues.Put(typeof(byte), (byte)0);
+    	    _nullValues.Put(typeof(short), (short)0);
+    	    _nullValues.Put(typeof(float), (float)0);
+    	    _nullValues.Put(typeof(double), (double)0);
+            _nullValues.Put(typeof(ulong), (ulong)0);
+            _nullValues.Put(typeof(long), (long)0);
+    	    _nullValues.Put(typeof(bool), false);
+            _nullValues.Put(typeof(char), (char)0);
+            _nullValues.Put(typeof(sbyte), (sbyte)0);
+            _nullValues.Put(typeof(decimal), (decimal)0);
+            _nullValues.Put(typeof(ushort), (ushort)0);
+            _nullValues.Put(typeof(DateTime), DateTime.MinValue);
+        	
+        }
+
+        private static Hashtable4 _nullValues;
+		
+        public static Type NullableTypeFor(Type primitiveType) 
+        {
+            if(_primitive2Wrapper == null)
+                InitPrimitive2Wrapper();
+            Type wrapperClazz = (Type)_primitive2Wrapper.Get(primitiveType);
+            if(wrapperClazz==null)        
+                throw new System.NotImplementedException();
+            return wrapperClazz;
+        }
+    
+        private static void InitPrimitive2Wrapper()
+        {
+    	    _primitive2Wrapper = new Hashtable4();
+            _primitive2Wrapper.Put(typeof(int), typeof(int?));
+            _primitive2Wrapper.Put(typeof(uint), typeof(uint?));
+            _primitive2Wrapper.Put(typeof(byte), typeof(byte?));
+    	    _primitive2Wrapper.Put(typeof(short), typeof(short?));
+    	    _primitive2Wrapper.Put(typeof(float), typeof(float?));
+    	    _primitive2Wrapper.Put(typeof(double), typeof(double?));
+            _primitive2Wrapper.Put(typeof(ulong), typeof(ulong?));
+            _primitive2Wrapper.Put(typeof(long), typeof(long?));
+    	    _primitive2Wrapper.Put(typeof(bool), typeof(bool?));
+            _primitive2Wrapper.Put(typeof(char), typeof(char?));
+            _primitive2Wrapper.Put(typeof(sbyte), typeof(sbyte?));
+            _primitive2Wrapper.Put(typeof(decimal), typeof(decimal?));
+            _primitive2Wrapper.Put(typeof(ushort), typeof(ushort?));
+            _primitive2Wrapper.Put(typeof(DateTime), typeof(DateTime?));
+        	
+        }
+
+        private static Hashtable4 _primitive2Wrapper;
+
+	}
 }
\ No newline at end of file
