@@ -1,14 +1,10 @@
-/* Copyright (C) 2004 - 2007  db4objects Inc.  http://www.db4o.com
+/* This file is part of the db4o object database http://www.db4o.com
 
-This file is part of the db4o open source object database.
+Copyright (C) 2004 - 2009  Versant Corporation http://www.versant.com
 
 db4o is free software; you can redistribute it and/or modify it under
-the terms of version 2 of the GNU General Public License as published
-by the Free Software Foundation and as clarified by db4objects' GPL 
-interpretation policy, available at
-http://www.db4o.com/about/company/legalpolicies/gplinterpretation/
-Alternatively you can write to db4objects, Inc., 1900 S Norfolk Street,
-Suite 350, San Mateo, CA 94403, USA.
+the terms of version 3 of the GNU General Public License as published
+by the Free Software Foundation.
 
 db4o is distributed in the hope that it will be useful, but WITHOUT ANY
 WARRANTY; without even the implied warranty of MERCHANTABILITY or
@@ -16,9 +12,9 @@ FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
 for more details.
 
 You should have received a copy of the GNU General Public License along
-with this program; if not, write to the Free Software Foundation, Inc.,
-59 Temple Place - Suite 330, Boston, MA  02111-1307, USA. */
+with this program.  If not, see http://www.gnu.org/licenses/. */
 using System;
+using System.Collections;
 using Db4objects.Db4o.Ext;
 using Db4objects.Db4o.Internal.Query.Result;
 
@@ -39,7 +35,8 @@ namespace Db4objects.Db4o.Internal.Query
 
 		#region IObjectSet Members
 		
-		public Object Get(int index) {
+		public Object Get(int index)
+		{
             return _delegate.Get(index);
         }
 
@@ -78,7 +75,7 @@ namespace Db4objects.Db4o.Internal.Query
 			return _delegate.Size();
 		}
     
-		private Object StreamLock()
+		private Object Lock()
 		{
 			return _delegate.Lock();
 		}
@@ -180,7 +177,7 @@ namespace Db4objects.Db4o.Internal.Query
 
         public void CopyTo(Array array, int index)
         {
-            lock (StreamLock())
+            lock (Lock())
             {
                 int i = 0;
                 int s = _delegate.Size();
@@ -196,53 +193,35 @@ namespace Db4objects.Db4o.Internal.Query
 		{
 			get
 			{
-				return StreamLock();
+				return Lock();
 			}
 		}
 
 		#endregion
-
-		#region IEnumerable Members
-
-		class ObjectSetImplEnumerator : System.Collections.IEnumerator
-		{
-			StatefulQueryResult _result;
-			int _next = 0;
-			
-			public ObjectSetImplEnumerator(StatefulQueryResult result)
-			{
-				_result = result;
-			}
-
-			public void Reset()
-			{
-				_next = 0;
-			}
-
-			public object Current
-			{
-				get
-				{
-					return _result.Get(_next-1);
-				}
-			}
-
-			public bool MoveNext()
-			{
-				if (_next < _result.Size())
-				{
-					++_next;
-					return true;
-				}
-				return false;
-			}
-		}
-
+		
 		public System.Collections.IEnumerator GetEnumerator()
 		{
-			return new ObjectSetImplEnumerator(_delegate);
+			IEnumerator enumerator = _delegate.GetEnumerator();
+			object current;
+			while (MoveNext(enumerator, out current))
+			{
+				yield return current;
+			}
+		}
+
+		private bool MoveNext(IEnumerator enumerator, out object current)
+		{
+			lock (_delegate.Lock())
+			{
+				if (enumerator.MoveNext())
+				{
+					current = enumerator.Current;
+					return true;
+				}
+			}
+			current = null;
+			return false;
 		}
-		#endregion
 	}
 }
 
