@@ -1,14 +1,10 @@
-/* Copyright (C) 2004 - 2007  db4objects Inc.  http://www.db4o.com
+/* This file is part of the db4o object database http://www.db4o.com
 
-This file is part of the db4o open source object database.
+Copyright (C) 2004 - 2009  Versant Corporation http://www.versant.com
 
 db4o is free software; you can redistribute it and/or modify it under
-the terms of version 2 of the GNU General Public License as published
-by the Free Software Foundation and as clarified by db4objects' GPL 
-interpretation policy, available at
-http://www.db4o.com/about/company/legalpolicies/gplinterpretation/
-Alternatively you can write to db4objects, Inc., 1900 S Norfolk Street,
-Suite 350, San Mateo, CA 94403, USA.
+the terms of version 3 of the GNU General Public License as published
+by the Free Software Foundation.
 
 db4o is distributed in the hope that it will be useful, but WITHOUT ANY
 WARRANTY; without even the implied warranty of MERCHANTABILITY or
@@ -16,8 +12,7 @@ FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
 for more details.
 
 You should have received a copy of the GNU General Public License along
-with this program; if not, write to the Free Software Foundation, Inc.,
-59 Temple Place - Suite 330, Boston, MA  02111-1307, USA. */
+with this program.  If not, see http://www.gnu.org/licenses/. */
 using System;
 using System.Collections;
 using Db4objects.Db4o.Internal;
@@ -25,14 +20,14 @@ using Db4objects.Db4o.Types;
 
 namespace Db4objects.Db4o
 {
+	[Obsolete("since 7.0")]
 	internal class P2LinkedList : P1Collection, IDb4oList
 	{
 		public P1ListElement i_first;
 
 		public P1ListElement i_last;
 
-		internal P2LinkedList()
-			: base()
+		public P2LinkedList() : base()
 		{
 		}
 
@@ -282,11 +277,6 @@ namespace Db4objects.Db4o
 			return false;
 		}
 
-		public override int AdjustReadDepth(int i)
-		{
-			return 1;
-		}
-
 		protected void CheckLastAndUpdate(P1ListElement a_previous, P1ListElement a_added)
 		{
 			if (i_last == a_previous)
@@ -350,7 +340,7 @@ namespace Db4objects.Db4o
 		protected int IndexOf4(Object obj)
 		{
 			int idx = 0;
-			if (GetTrans() != null && (!GetTrans().Stream().Handlers().IsSecondClass(obj)))
+			if (GetTrans() != null && (!GetTrans().Container().Handlers().IsSecondClass(obj)))
 			{
 				long id = GetIDOf(obj);
 				if (id > 0)
@@ -432,26 +422,6 @@ namespace Db4objects.Db4o
 			return false;
 		}
 
-		public override void ReplicateFrom(Object obj)
-		{
-			CheckActive();
-			P2ListElementIterator i = Iterator4();
-			while (i.HasNext())
-			{
-				P1ListElement elem = i.NextElement();
-				elem.Delete(false);
-			}
-			i_first = null;
-			i_last = null;
-			P2LinkedList l4 = (P2LinkedList)obj;
-			i = l4.Iterator4();
-			while (i.HasNext())
-			{
-				Add4(i.NextElement());
-			}
-			UpdateInternal();
-		}
-
 		protected int Size4()
 		{
 			int size = 0;
@@ -470,13 +440,6 @@ namespace Db4objects.Db4o
 			{
 				SetTrans(transaction);
 			}
-			else
-			{
-				if (transaction != GetTrans())
-				{
-					return Replicate(GetTrans(), transaction);
-				}
-			}
 			return this;
 		}
 	}
