@@ -1,14 +1,10 @@
-/* Copyright (C) 2004 - 2007  db4objects Inc.  http://www.db4o.com
+/* This file is part of the db4o object database http://www.db4o.com
 
-This file is part of the db4o open source object database.
+Copyright (C) 2004 - 2009  Versant Corporation http://www.versant.com
 
 db4o is free software; you can redistribute it and/or modify it under
-the terms of version 2 of the GNU General Public License as published
-by the Free Software Foundation and as clarified by db4objects' GPL 
-interpretation policy, available at
-http://www.db4o.com/about/company/legalpolicies/gplinterpretation/
-Alternatively you can write to db4objects, Inc., 1900 S Norfolk Street,
-Suite 350, San Mateo, CA 94403, USA.
+the terms of version 3 of the GNU General Public License as published
+by the Free Software Foundation.
 
 db4o is distributed in the hope that it will be useful, but WITHOUT ANY
 WARRANTY; without even the implied warranty of MERCHANTABILITY or
@@ -16,22 +12,26 @@ FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
 for more details.
 
 You should have received a copy of the GNU General Public License along
-with this program; if not, write to the Free Software Foundation, Inc.,
-59 Temple Place - Suite 330, Boston, MA  02111-1307, USA. */
+with this program.  If not, see http://www.gnu.org/licenses/. */
 using System;
+using System.Reflection;
 using Sharpen.Lang;
+using Db4objects.Db4o.Reflect.Core;
+using Db4objects.Db4o.Foundation;
 
 namespace Db4objects.Db4o.Reflect.Net
 {
 	/// <summary>Reflection implementation for Class to map to .NET reflection.</summary>
 	/// <remarks>Reflection implementation for Class to map to .NET reflection.</remarks>
-	public class NetClass : Db4objects.Db4o.Reflect.IReflectClass
+	public class NetClass : Db4objects.Db4o.Reflect.Core.IConstructorAwareReflectClass
 	{
-		private readonly Db4objects.Db4o.Reflect.IReflector _reflector;
+		protected readonly Db4objects.Db4o.Reflect.IReflector _reflector;
+		
+		protected readonly Db4objects.Db4o.Reflect.Net.NetReflector _netReflector;
 
 		private readonly System.Type _type;
 
-		private Db4objects.Db4o.Reflect.IReflectConstructor _constructor;
+		private ReflectConstructorSpec _constructor;
 
 		private object[] constructorParams;
 		
@@ -39,10 +39,22 @@ namespace Db4objects.Db4o.Reflect.Net
 	    
 	    private Db4objects.Db4o.Reflect.IReflectField[] _fields;
 
-	    public NetClass(Db4objects.Db4o.Reflect.IReflector reflector, System.Type clazz)
+	    public NetClass(Db4objects.Db4o.Reflect.IReflector reflector, Db4objects.Db4o.Reflect.Net.NetReflector netReflector, System.Type clazz)
 		{
+			if(reflector == null)
+			{
+				throw new NullReferenceException();
+			}
+			
+			if(netReflector == null)
+			{
+				throw new NullReferenceException();
+			}
+			
 			_reflector = reflector;
+			_netReflector = netReflector;
 			_type = clazz;
+			_constructor = ReflectConstructorSpec.UnspecifiedConstructor;
 		}
 
 		public virtual Db4objects.Db4o.Reflect.IReflectClass GetComponentType()
@@ -50,10 +62,10 @@ namespace Db4objects.Db4o.Reflect.Net
 			return _reflector.ForClass(_type.GetElementType());
 		}
 
-		public virtual Db4objects.Db4o.Reflect.IReflectConstructor[] GetDeclaredConstructors()
+		private IReflectConstructor[] GetDeclaredConstructors()
 		{
 			System.Reflection.ConstructorInfo[] constructors = _type.GetConstructors();
-			Db4objects.Db4o.Reflect.IReflectConstructor[] reflectors = new Db4objects.Db4o.Reflect.IReflectConstructor
+			IReflectConstructor[] reflectors = new IReflectConstructor
 				[constructors.Length];
 			for (int i = 0; i < constructors.Length; i++)
 			{
@@ -86,11 +98,16 @@ namespace Db4objects.Db4o.Reflect.Net
 			Db4objects.Db4o.Reflect.IReflectField[] reflectors = new Db4objects.Db4o.Reflect.IReflectField[fields.Length];
 			for (int i = 0; i < reflectors.Length; i++)
 			{
-				reflectors[i] = new Db4objects.Db4o.Reflect.Net.NetField(_reflector, fields[i]);
+				reflectors[i] = CreateField(fields[i]);
 			}
 			return reflectors;
 		}
 
+		protected virtual IReflectField CreateField(FieldInfo field)
+		{
+			return new Db4objects.Db4o.Reflect.Net.NetField(_reflector, field);
+		}
+
 		public virtual Db4objects.Db4o.Reflect.IReflectClass GetDelegate()
 		{
 			return this;
@@ -102,7 +119,7 @@ namespace Db4objects.Db4o.Reflect.Net
 		{
 			try
 			{
-				System.Reflection.MethodInfo method = Sharpen.Runtime.GetMethod(_type, methodName, Db4objects.Db4o.Reflect.Net.NetReflector
+                System.Reflection.MethodInfo method = Sharpen.Runtime.GetMethod(_type, methodName, Db4objects.Db4o.Reflect.Net.NetReflector
 					.ToNative(paramClasses));
 				if (method == null)
 				{
@@ -171,31 +188,15 @@ namespace Db4objects.Db4o.Reflect.Net
 			       || _type == typeof(decimal);
 		}
 
-		public virtual bool IsSecondClass()
-		{
-			return IsPrimitive() || _type.IsValueType;
-		}
-
 		public virtual object NewInstance()
 		{
-			try
-			{
-				if (_constructor == null)
-				{
-					if (CanCreate(_type)) return System.Activator.CreateInstance(_type);
-					return null;
-				}
-				return _constructor.NewInstance(constructorParams);
-			}
-			catch
-			{
-			}
-			return null;
+			CreateConstructor();
+			return _constructor.NewInstance();
 		}
 
 		private static bool CanCreate(Type type)
 		{
-			return !type.IsAbstract && !type.IsInterface;
+			return !type.IsAbstract;
 		}
 
 		public virtual System.Type GetNetType()
@@ -207,29 +208,13 @@ namespace Db4objects.Db4o.Reflect.Net
 		{
 			return _reflector;
 		}
-
-		public virtual bool SkipConstructor(bool flag)
+		
+		public virtual IReflectConstructor GetSerializableConstructor()
 		{
-#if !CF_1_0 && !CF_2_0
-			if (flag)
-			{
-				IReflectConstructor constructor = new SerializationConstructor(GetNetType());
-				try
-				{
-					object o = constructor.NewInstance(null);
-					if (o != null)
-					{
-						UseConstructor(constructor, null);
-						return true;
-					}
-				}
-				catch
-				{
-				}
-			}
+#if !CF
+			return new SerializationConstructor(GetNetType());
 #endif
-			UseConstructor(null, null);
-			return false;
+			return null;
 		}
 
 		public override string ToString()
@@ -237,18 +222,24 @@ namespace Db4objects.Db4o.Reflect.Net
 			return "NetClass(" + _type + ")";
 		}
 
-		public virtual void UseConstructor(
-			Db4objects.Db4o.Reflect.IReflectConstructor constructor,
-			object[] _params)
+		public virtual object NullValue() 
 		{
-			_constructor = constructor;
-			constructorParams = _params;
+			return _netReflector.NullValue(this);
 		}
-
-		public virtual object[] ToArray(object obj)
+	
+		private void CreateConstructor() 
 		{
-			// handled in GenericClass
-			return null;
+			if(!_constructor.CanBeInstantiated().IsUnspecified())
+			{
+				return;
+			}
+			_constructor = ConstructorSupport.CreateConstructor(this, _type, _netReflector.Configuration(), GetDeclaredConstructors());
 		}
+		
+		public virtual bool EnsureCanBeInstantiated() {
+			CreateConstructor();
+			return _constructor.CanBeInstantiated().DefiniteYes();
+		}
+		
 	}
 }
