@@ -1,14 +1,10 @@
-/* Copyright (C) 2004 - 2007  db4objects Inc.  http://www.db4o.com
+/* This file is part of the db4o object database http://www.db4o.com
 
-This file is part of the db4o open source object database.
+Copyright (C) 2004 - 2009  Versant Corporation http://www.versant.com
 
 db4o is free software; you can redistribute it and/or modify it under
-the terms of version 2 of the GNU General Public License as published
-by the Free Software Foundation and as clarified by db4objects' GPL 
-interpretation policy, available at
-http://www.db4o.com/about/company/legalpolicies/gplinterpretation/
-Alternatively you can write to db4objects, Inc., 1900 S Norfolk Street,
-Suite 350, San Mateo, CA 94403, USA.
+the terms of version 3 of the GNU General Public License as published
+by the Free Software Foundation.
 
 db4o is distributed in the hope that it will be useful, but WITHOUT ANY
 WARRANTY; without even the implied warranty of MERCHANTABILITY or
@@ -16,33 +12,30 @@ FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
 for more details.
 
 You should have received a copy of the GNU General Public License along
-with this program; if not, write to the Free Software Foundation, Inc.,
-59 Temple Place - Suite 330, Boston, MA  02111-1307, USA. */
+with this program.  If not, see http://www.gnu.org/licenses/. */
 using System;
-using Sharpen.Lang;
+
+using Db4objects.Db4o.Internal;
 
 namespace Db4objects.Db4o.Reflect.Net
 {
 	public class NetReflector : Db4objects.Db4o.Reflect.IReflector
 	{
-		private Db4objects.Db4o.Reflect.IReflector _parent;
+		protected Db4objects.Db4o.Reflect.IReflector _parent;
 
 		private Db4objects.Db4o.Reflect.IReflectArray _array;
+		
+		private Db4objects.Db4o.Reflect.IReflectorConfiguration _config;
 	    
 		public virtual Db4objects.Db4o.Reflect.IReflectArray Array()
 		{
 			if (_array == null)
 			{
-				_array = new Db4objects.Db4o.Reflect.Net.NetArray(_parent);
+				_array = new Db4objects.Db4o.Reflect.Net.NetArray(Parent());
 			}
 			return _array;
 		}
 
-		public virtual bool ConstructorCallsSupported()
-		{
-			return true;
-		}
-
 		public virtual object DeepClone(object obj)
 		{
 			return new NetReflector();
@@ -50,18 +43,34 @@ namespace Db4objects.Db4o.Reflect.Net
 
 		public virtual Db4objects.Db4o.Reflect.IReflectClass ForClass(System.Type forType)
 		{
-		    return new Db4objects.Db4o.Reflect.Net.NetClass(_parent, GetUnderlyingType(forType));
+            System.Type underlyingType = GetUnderlyingType(forType);
+            if (underlyingType.IsPrimitive && ! Db4objects.Db4o.Internal.NullableArrayHandling.UseOldNetHandling())
+            {
+                return CreateClass(forType);
+            }
+            return CreateClass(underlyingType);
 		}
 
-        private static Type GetUnderlyingType(Type type)
-        {
-#if NET_2_0 || CF_2_0
+		protected virtual Db4objects.Db4o.Reflect.IReflectClass CreateClass(Type type)
+		{
+			if(type == null)
+			{
+				return null;
+			}
+			return new Db4objects.Db4o.Reflect.Net.NetClass(Parent(), this, type);
+		}
+
+		private static Type GetUnderlyingType(Type type)
+        {	
+        	if(type == null)
+        	{
+        		return null;
+        	}
             Type underlyingType = Nullable.GetUnderlyingType(type);
             if (underlyingType != null)
             {
                 return underlyingType;
             }
-#endif
             return type;
         }
 
@@ -69,7 +78,7 @@ namespace Db4objects.Db4o.Reflect.Net
 		{
 			try
 			{
-				Type type = TypeReference.FromString(className).Resolve();
+				Type type = ReflectPlatform.ForName(className);
 				if (type == null) return null;
 				return ForClass(type);
 			}
@@ -85,7 +94,7 @@ namespace Db4objects.Db4o.Reflect.Net
 			{
 				return null;
 			}
-			return _parent.ForClass(a_object.GetType());
+			return Parent().ForClass(a_object.GetType());
 		}
 
 		public virtual bool IsCollection(Db4objects.Db4o.Reflect.IReflectClass candidate)
@@ -94,12 +103,12 @@ namespace Db4objects.Db4o.Reflect.Net
 			{
 				return false;
 			}
-			if (typeof(System.Collections.ICollection).IsAssignableFrom(
-				((Db4objects.Db4o.Reflect.Net.NetClass)candidate).GetNetType()))
-			{
-				return true;
-			}
-			return false;
+		    NetClass netClass = candidate as NetClass;
+            if (null == netClass)
+            {
+                return false;
+            }
+		    return typeof(System.Collections.ICollection).IsAssignableFrom(netClass.GetNetType());
 		}
 
 		public virtual bool MethodCallsSupported()
@@ -126,7 +135,7 @@ namespace Db4objects.Db4o.Reflect.Net
 			return claxx;
 		}
 
-		internal static System.Type[] ToNative(Db4objects.Db4o.Reflect.IReflectClass[] claxx)
+		public static System.Type[] ToNative(Db4objects.Db4o.Reflect.IReflectClass[] claxx)
 		{
 			System.Type[] clazz = null;
 			if (claxx != null)
@@ -136,16 +145,53 @@ namespace Db4objects.Db4o.Reflect.Net
 				{
 					if (claxx[i] != null)
 					{
-						clazz[i] = ((Db4objects.Db4o.Reflect.Net.NetClass)claxx[i].GetDelegate()).GetNetType();
+						IReflectClass reflectClass = claxx[i];
+						clazz[i] = ToNative(reflectClass);
 					}
 				}
 			}
 			return clazz;
 		}
 
+		public static Type ToNative(IReflectClass reflectClass)
+		{
+            NetClass netClass = reflectClass.GetDelegate() as NetClass;
+            if(netClass == null)
+            {
+                return null;
+            }
+			return netClass.GetNetType();
+		}
+
 		public virtual void SetParent(IReflector reflector)
 		{
 			_parent = reflector;
 		}
+
+        public virtual void Configuration(Db4objects.Db4o.Reflect.IReflectorConfiguration config)
+		{
+			_config = config;
+		}
+		
+        public virtual Db4objects.Db4o.Reflect.IReflectorConfiguration Configuration()
+		{
+			return _config;
+		}
+
+		public virtual object NullValue(IReflectClass clazz) 
+		{
+			return Platform4.NullValue(ToNative(clazz));
+		}
+		
+		private IReflector Parent()
+		{
+			if(_parent == null)
+			{
+				return this;
+			}
+			
+			return _parent;
+		}
+		
 	}
 }
