@@ -1,14 +1,10 @@
-/* Copyright (C) 2004 - 2007  db4objects Inc.  http://www.db4o.com
+/* This file is part of the db4o object database http://www.db4o.com
 
-This file is part of the db4o open source object database.
+Copyright (C) 2004 - 2009  Versant Corporation http://www.versant.com
 
 db4o is free software; you can redistribute it and/or modify it under
-the terms of version 2 of the GNU General Public License as published
-by the Free Software Foundation and as clarified by db4objects' GPL 
-interpretation policy, available at
-http://www.db4o.com/about/company/legalpolicies/gplinterpretation/
-Alternatively you can write to db4objects, Inc., 1900 S Norfolk Street,
-Suite 350, San Mateo, CA 94403, USA.
+the terms of version 3 of the GNU General Public License as published
+by the Free Software Foundation.
 
 db4o is distributed in the hope that it will be useful, but WITHOUT ANY
 WARRANTY; without even the implied warranty of MERCHANTABILITY or
@@ -16,8 +12,9 @@ FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
 for more details.
 
 You should have received a copy of the GNU General Public License along
-with this program; if not, write to the Free Software Foundation, Inc.,
-59 Temple Place - Suite 330, Boston, MA  02111-1307, USA. */
+with this program.  If not, see http://www.gnu.org/licenses/. */
+using System;
+using System.Collections;
 using System.IO;
 
 namespace Sharpen.IO
@@ -25,15 +22,20 @@ namespace Sharpen.IO
 	public class File
 	{
 		public static readonly char separatorChar = Path.DirectorySeparatorChar;
-		public static readonly string separator = ""+Path.DirectorySeparatorChar;
+		public static readonly string separator = separatorChar.ToString();
 		
-		private string _path;
+		private readonly string _path;
 
 		public File(string path)
 		{
 			_path = path;
 		}
 
+		public static implicit operator string(File file)
+		{
+			return file.GetAbsolutePath();
+		}
+
 		public File(string dir, string file)
 		{
 			if (dir == null)
@@ -66,6 +68,11 @@ namespace Sharpen.IO
 			return Path.GetFullPath(_path);
 		}
 
+		public File GetCanonicalFile()
+		{
+			return new File(GetCanonicalPath());
+		}
+
 		public string GetAbsolutePath()
 		{
 			return Path.GetFullPath(_path);
@@ -84,7 +91,7 @@ namespace Sharpen.IO
 
 		public bool IsDirectory()
 		{
-#if CF_1_0 || CF_2_0
+#if CF
 			return System.IO.Directory.Exists(_path);
 #else
 			return (System.IO.File.GetAttributes(_path) & FileAttributes.Directory) != 0;
@@ -129,5 +136,25 @@ namespace Sharpen.IO
 		{
 			new FileInfo(_path).MoveTo(file.GetPath());
 		}
+
+        public File[] ListFiles(IFilenameFilter filter)
+        {
+            String[] ss = List();
+            if (ss == null) return null;
+            ArrayList v = new ArrayList();
+            for (int i = 0; i < ss.Length; i++)
+            {
+                if ((filter == null) || filter.Accept(this, ss[i]))
+                {
+                    v.Add(new File(ss[i], this));
+                }
+            }
+            return (File[])(v.ToArray(typeof(File)));
+        }
+
+		public override string ToString()
+		{
+			return _path;
+		}
 	}
 }
