@@ -1,14 +1,10 @@
-/* Copyright (C) 2004 - 2007  db4objects Inc.  http://www.db4o.com
+/* This file is part of the db4o object database http://www.db4o.com
 
-This file is part of the db4o open source object database.
+Copyright (C) 2004 - 2009  Versant Corporation http://www.versant.com
 
 db4o is free software; you can redistribute it and/or modify it under
-the terms of version 2 of the GNU General Public License as published
-by the Free Software Foundation and as clarified by db4objects' GPL 
-interpretation policy, available at
-http://www.db4o.com/about/company/legalpolicies/gplinterpretation/
-Alternatively you can write to db4objects, Inc., 1900 S Norfolk Street,
-Suite 350, San Mateo, CA 94403, USA.
+the terms of version 3 of the GNU General Public License as published
+by the Free Software Foundation.
 
 db4o is distributed in the hope that it will be useful, but WITHOUT ANY
 WARRANTY; without even the implied warranty of MERCHANTABILITY or
@@ -16,10 +12,10 @@ FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
 for more details.
 
 You should have received a copy of the GNU General Public License along
-with this program; if not, write to the Free Software Foundation, Inc.,
-59 Temple Place - Suite 330, Boston, MA  02111-1307, USA. */
+with this program.  If not, see http://www.gnu.org/licenses/. */
 using System;
 using System.IO;
+using Db4objects.Db4o;
 using Db4objects.Db4o.Ext;
 
 namespace Sharpen.IO
@@ -28,7 +24,7 @@ namespace Sharpen.IO
     {
         private FileStream _stream;
 
-#if NET || NET_2_0
+#if !CF && !MONO
         [System.Runtime.InteropServices.DllImport("kernel32.dll", SetLastError = true)]
         static extern int FlushFileBuffers(IntPtr fileHandle);
 #endif
@@ -42,7 +38,7 @@ namespace Sharpen.IO
             }
             catch (IOException x)
             {
-                throw new DatabaseFileLockedException(file, x);
+                throw new DatabaseFileLockedException(file,x);
             }
         }
 
@@ -80,12 +76,9 @@ namespace Sharpen.IO
         {
             _stream.Flush();
 
-#if NET_2_0
+#if !CF && !MONO
             FlushFileBuffers(_stream.SafeFileHandle.DangerousGetHandle());
-#elif NET
-            FlushFileBuffers(_stream.Handle);
 #endif
-
         }
 
         public RandomAccessFile GetFD()
@@ -95,12 +88,19 @@ namespace Sharpen.IO
 
         public void Write(byte[] bytes)
         {
-            this.Write(bytes, 0, bytes.Length);
+            Write(bytes, 0, bytes.Length);
         }
 
         public void Write(byte[] bytes, int offset, int length)
         {
-            _stream.Write(bytes, offset, length);
+            try
+            {
+                _stream.Write(bytes, offset, length);
+            }
+            catch (System.NotSupportedException e)
+            {
+                throw new Db4oIOException(e);
+            }
         }
     }
-}
\ No newline at end of file
+}
