@@ -1,14 +1,10 @@
-/* Copyright (C) 2004 - 2007  db4objects Inc.  http://www.db4o.com
+/* This file is part of the db4o object database http://www.db4o.com
 
-This file is part of the db4o open source object database.
+Copyright (C) 2004 - 2009  Versant Corporation http://www.versant.com
 
 db4o is free software; you can redistribute it and/or modify it under
-the terms of version 2 of the GNU General Public License as published
-by the Free Software Foundation and as clarified by db4objects' GPL 
-interpretation policy, available at
-http://www.db4o.com/about/company/legalpolicies/gplinterpretation/
-Alternatively you can write to db4objects, Inc., 1900 S Norfolk Street,
-Suite 350, San Mateo, CA 94403, USA.
+the terms of version 3 of the GNU General Public License as published
+by the Free Software Foundation.
 
 db4o is distributed in the hope that it will be useful, but WITHOUT ANY
 WARRANTY; without even the implied warranty of MERCHANTABILITY or
@@ -16,19 +12,20 @@ FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
 for more details.
 
 You should have received a copy of the GNU General Public License along
-with this program; if not, write to the Free Software Foundation, Inc.,
-59 Temple Place - Suite 330, Boston, MA  02111-1307, USA. */
+with this program.  If not, see http://www.gnu.org/licenses/. */
 using System;
 
 namespace Sharpen.Lang
 {
 	public class Thread : IRunnable
 	{
-		public const int MIN_PRIORITY = 1;
-		public const int MAX_PRIORITY = 10;
+		public const int MinPriority = 1;
+		public const int MaxPriority = 10;
 
 		private IRunnable _target;
 
+		private System.Threading.ThreadPriority _priority;
+
 		private string _name;
 
 		private System.Threading.Thread _thread;
@@ -50,9 +47,17 @@ namespace Sharpen.Lang
 			this._thread = thread;
 		}
 
+		private static readonly LocalDataStoreSlot _current = System.Threading.Thread.AllocateDataSlot();
+
 		public static Thread CurrentThread()
 		{
-			return new Thread(System.Threading.Thread.CurrentThread);
+			Thread current = (Thread)System.Threading.Thread.GetData(_current);
+			if (current == null)
+			{
+				current = new Thread(System.Threading.Thread.CurrentThread);
+				System.Threading.Thread.SetData(_current, current);
+			}
+			return current;
 		}
 
 		public virtual void Run()
@@ -62,7 +67,7 @@ namespace Sharpen.Lang
 		public void SetName(string name)
 		{
 			this._name = name;
-#if !CF_1_0 && !CF_2_0
+#if !CF
 			if (_thread != null && name != null)
 			{
 				try
@@ -78,7 +83,7 @@ namespace Sharpen.Lang
 
 		public string GetName()
 		{
-#if !CF_1_0 && !CF_2_0
+#if !CF
 			return _thread != null ? _thread.Name : _name;
 #else
 			return "";
@@ -88,22 +93,39 @@ namespace Sharpen.Lang
 		public void SetPriority(int priority)
 		{
 			// java priority is between 1 and 10, ThreadPriority is between 0 and 5
-			if (priority < MIN_PRIORITY || priority > MAX_PRIORITY)
+			if (priority < MinPriority || priority > MaxPriority)
 			{
-				string message = string.Format("Thread priority must be between {0} and {1}", MIN_PRIORITY, MAX_PRIORITY);
-#if !CF_1_0 && !CF_2_0
+				string message = string.Format("Thread priority must be between {0} and {1}", MinPriority, MaxPriority);
+#if !CF
 				throw new ArgumentOutOfRangeException("priority", priority, message);
 #else
 				throw new ArgumentOutOfRangeException(message);
 #endif
 			}
-
-			_thread.Priority = (System.Threading.ThreadPriority) (priority / 2);
+			// Set priority immediately on the thread if there already is one, otherwise store
+			// to set it when one is created.
+			if (_thread != null)
+			{
+				_thread.Priority = (System.Threading.ThreadPriority)(priority / 2);
+			}
+			else
+			{
+				_priority = (System.Threading.ThreadPriority)(priority / 2);
+			}
 		}
 
 		public void SetPriority(System.Threading.ThreadPriority priority)
 		{
-			_thread.Priority = priority;
+			// Set priority immediately on the thread if there already is one, otherwise store
+			// to set it when one is created.
+			if (_thread != null)
+			{
+				_thread.Priority = priority;
+			}
+			else
+			{
+				_priority = priority;
+			}
 		}
 
 		public static void Sleep(long milliseconds)
@@ -114,9 +136,12 @@ namespace Sharpen.Lang
 		public void Start()
 		{
 			_thread = new System.Threading.Thread(new System.Threading.ThreadStart(EntryPoint));
-#if !CF_1_0
+			// Apply priority if previously set
+			if (_priority != null)
+			{
+				_thread.Priority = _priority;
+			}
 			_thread.IsBackground = _isDaemon;
-#endif
 			if (_name != null)
 			{
 				SetName(_name);
@@ -126,9 +151,12 @@ namespace Sharpen.Lang
 
 		public void Join() 
 		{
-#if !CF_1_0
+			if (_thread == null)
+			{
+				string message = "A thread must be available to join";
+				throw new InvalidOperationException(message);
+			}
 			_thread.Join();
-#endif		
 		}
 		
 		public void SetDaemon(bool isDaemon)
@@ -138,7 +166,16 @@ namespace Sharpen.Lang
 
 		private void EntryPoint()
 		{
-			_target.Run();
+			try
+			{
+				_target.Run();
+			}
+			catch (Exception e)
+			{
+				// don't let an unhandled exception bring
+				// the process down
+				Sharpen.Runtime.PrintStackTrace(e);
+			}
 		}
 	}
 }
