@@ -1,14 +1,10 @@
-/* Copyright (C) 2004 - 2007  db4objects Inc.  http://www.db4o.com
+/* This file is part of the db4o object database http://www.db4o.com
 
-This file is part of the db4o open source object database.
+Copyright (C) 2004 - 2009  Versant Corporation http://www.versant.com
 
 db4o is free software; you can redistribute it and/or modify it under
-the terms of version 2 of the GNU General Public License as published
-by the Free Software Foundation and as clarified by db4objects' GPL 
-interpretation policy, available at
-http://www.db4o.com/about/company/legalpolicies/gplinterpretation/
-Alternatively you can write to db4objects, Inc., 1900 S Norfolk Street,
-Suite 350, San Mateo, CA 94403, USA.
+the terms of version 3 of the GNU General Public License as published
+by the Free Software Foundation.
 
 db4o is distributed in the hope that it will be useful, but WITHOUT ANY
 WARRANTY; without even the implied warranty of MERCHANTABILITY or
@@ -16,8 +12,7 @@ FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
 for more details.
 
 You should have received a copy of the GNU General Public License along
-with this program; if not, write to the Free Software Foundation, Inc.,
-59 Temple Place - Suite 330, Boston, MA  02111-1307, USA. */
+with this program.  If not, see http://www.gnu.org/licenses/. */
 using System;
 using System.Reflection;
 using System.Text;
@@ -35,15 +30,7 @@ namespace Sharpen.Lang
 		public static TypeReference FromType(System.Type type)
 		{
 			if (null == type) throw new ArgumentNullException("type");
-#if CF_1_0
-			StringBuilder builder = new StringBuilder();
-			builder.Append(type.FullName);
-			builder.Append(", ");
-			builder.Append(type.Assembly.FullName);
-			return FromString(builder.ToString());
-#else
 			return FromString(type.AssemblyQualifiedName);
-#endif
 		}
 
 		public abstract string SimpleName
@@ -161,7 +148,7 @@ namespace Sharpen.Lang
 
 		private Assembly LoadUnversionedAssembly(AssemblyName unversioned)
 		{	
-#if CF_1_0 || CF_2_0
+#if CF
             return Assembly.Load(unversioned);
 #else
 			Assembly found = Assembly.LoadWithPartialName(unversioned.FullName);
@@ -217,7 +204,7 @@ namespace Sharpen.Lang
 
 		public override Type Resolve()
 		{
-#if NET_2_0
+#if !CF
 			return _elementType.Resolve().MakePointerType();
 #else
 			StringBuilder builder = new StringBuilder();
@@ -229,6 +216,18 @@ namespace Sharpen.Lang
 
 	public class ArrayTypeReference : QualifiedTypeReference
 	{
+		public static Type MakeArrayType(Type elementType, int rank)
+		{
+#if !CF
+			if (rank == 1) return elementType.MakeArrayType();
+			return elementType.MakeArrayType(rank);
+#else
+			if (rank == 1) return Array.CreateInstance(elementType, 0).GetType();
+			return Array.CreateInstance(elementType, new int[rank]).GetType();
+#endif
+		}
+
+
 		private int _rank;
 
 		internal ArrayTypeReference(TypeReference elementType, int rank)
@@ -244,16 +243,10 @@ namespace Sharpen.Lang
 
 		public override Type Resolve()
 		{
-#if NET_2_0
-		    Type elementType = _elementType.Resolve();
-            if (_rank == 1) return elementType.MakeArrayType();
-		    return elementType.MakeArrayType(_rank);
-#else
-			return Array.CreateInstance(_elementType.Resolve(), new int[_rank]).GetType();
-#endif
+			return MakeArrayType(_elementType.Resolve(), _rank);
 		}
 
-	    protected override void AppendQualifier(StringBuilder builder)
+		protected override void AppendQualifier(StringBuilder builder)
 		{
 			builder.Append('[');
 			for (int i = 1; i < _rank; ++i)
@@ -281,14 +274,10 @@ namespace Sharpen.Lang
 
 		public override Type Resolve()
 		{
-#if NET_2_0 || CF_2_0
 			Type baseType = base.Resolve();
 			return _genericArguments.Length > 0
 				? baseType.MakeGenericType(Resolve(_genericArguments))
 				: baseType;
-#else
-			throw new System.NotSupportedException();
-#endif
 		}
 
 		Type[] Resolve(TypeReference[] typeRefs)
