@@ -1,14 +1,10 @@
-/* Copyright (C) 2004 - 2007  db4objects Inc.  http://www.db4o.com
+/* This file is part of the db4o object database http://www.db4o.com
 
-This file is part of the db4o open source object database.
+Copyright (C) 2004 - 2009  Versant Corporation http://www.versant.com
 
 db4o is free software; you can redistribute it and/or modify it under
-the terms of version 2 of the GNU General Public License as published
-by the Free Software Foundation and as clarified by db4objects' GPL 
-interpretation policy, available at
-http://www.db4o.com/about/company/legalpolicies/gplinterpretation/
-Alternatively you can write to db4objects, Inc., 1900 S Norfolk Street,
-Suite 350, San Mateo, CA 94403, USA.
+the terms of version 3 of the GNU General Public License as published
+by the Free Software Foundation.
 
 db4o is distributed in the hope that it will be useful, but WITHOUT ANY
 WARRANTY; without even the implied warranty of MERCHANTABILITY or
@@ -16,8 +12,7 @@ FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
 for more details.
 
 You should have received a copy of the GNU General Public License along
-with this program; if not, write to the Free Software Foundation, Inc.,
-59 Temple Place - Suite 330, Boston, MA  02111-1307, USA. */
+with this program.  If not, see http://www.gnu.org/licenses/. */
 using System;
 using System.IO;
 using System.Reflection;
@@ -28,15 +23,14 @@ namespace Sharpen
 {
 	public class Runtime 
 	{
+		private static long DIFFERENCE_IN_TICKS = 62135604000000;
+		private static long RATIO = 10000;
+
 		public static TextWriter Out
 		{
 			get
 			{
-#if CF_1_0
-				return CompactFramework1Console.Out;
-#else
 				return Console.Out;
-#endif
 			}
 		}
 
@@ -44,11 +38,7 @@ namespace Sharpen
 		{
 			get
 			{
-#if CF_1_0
-				return CompactFramework1Console.Error;
-#else
 				return Console.Error;
-#endif
 			}
 		}
 
@@ -82,18 +72,18 @@ namespace Sharpen
 		{
             return type.GetFields(DeclaredMembersIncludingStatic);
 		}
-
-        public static MethodInfo GetDeclaredMethod(Type type, string name, Type[] parameterTypes)
-        {
-            return type.GetMethod(name, DeclaredMembers, null, parameterTypes, null);
-        }
+		
+		public static MethodInfo GetDeclaredMethod(Type type, string name, Type[] parameterTypes)
+		{
+			return type.GetMethod(name, DeclaredMembers, null, parameterTypes, null);
+		}
 
         public static MethodInfo GetMethod(Type type, string name, Type[] parameterTypes)
         {
             return type.GetMethod(name, AllMembers, null, parameterTypes, null);
         }
 
-        public static Type[] GetParameterTypes(MethodBase method)
+		public static Type[] GetParameterTypes(MethodBase method)
 		{
 			ParameterInfo[] parameters = method.GetParameters();
 			Type[] types = new Type[parameters.Length];
@@ -106,7 +96,7 @@ namespace Sharpen
 
 		public static long CurrentTimeMillis() 
 		{
-			return Sharpen.Util.Date.ToJavaMilliseconds(DateTime.Now.ToUniversalTime());
+			return Runtime.ToJavaMilliseconds(DateTime.Now.ToUniversalTime());
 		}
 
 		public static int FloatToIntBits(float value) 
@@ -134,11 +124,6 @@ namespace Sharpen
 			return s.Substring(startIndex, endIndex-startIndex);
 		}
 
-		public static char GetCharAt(string str, int index) 
-		{
-			return str[index];
-		}
-
 		public static void GetCharsForString(string str, int start, int end, char[] destination, int destinationStart) 
 		{
 			str.CopyTo(start, destination, 0, end-start);
@@ -163,12 +148,28 @@ namespace Sharpen
 
 		public static String GetProperty(String key) 
 		{
-#if CF_1_0 || CF_2_0
-			return key.Equals("line.separator") ? "\n" : null;
+			return GetProperty(key, null);
+		}
+
+		public static String GetProperty(String key, String defaultValue)
+		{
+#if CF
+			return key.Equals("line.separator") ? "\n" : defaultValue;
 #else
 			return key.Equals("line.separator")
 				? Environment.NewLine
-				: null;
+				: GetEnvironmentVariable(key, defaultValue);
+#endif
+		}
+
+		public static string GetEnvironmentVariable(string variableName, string defaultValue)
+		{
+#if CF
+			return defaultValue;
+#else
+			string value = Environment.GetEnvironmentVariable(variableName);
+			if (value == null || value.Length == 0) return defaultValue;
+			return value;
 #endif
 		}
 
@@ -179,7 +180,7 @@ namespace Sharpen
 
 		public static long GetTimeForDate(DateTime dateTime) 
 		{
-			return Sharpen.Util.Date.ToJavaMilliseconds(dateTime);
+			return Runtime.ToJavaMilliseconds(dateTime);
 		}
 
 		public static int IdentityHashCode(object obj) 
@@ -192,35 +193,30 @@ namespace Sharpen
 			return BitConverter.ToSingle(BitConverter.GetBytes(value), 0);
 		}
 
-        public static void Wait(object obj)
-        {
-            Wait(obj, -1);
-        }
-
 		public static void Wait(object obj, long timeout) 
 		{
-#if !CF_1_0 && !CF_2_0
+#if !CF
 			Monitor.Wait(obj, (int) timeout);
 #endif
 		}
 
 		public static void Notify(object obj) 
 		{
-#if !CF_1_0 && !CF_2_0
+#if !CF
 			Monitor.Pulse(obj);
 #endif
 		}
 
 		public static void NotifyAll(object obj) 
 		{
-#if !CF_1_0 && !CF_2_0
+#if !CF
 			Monitor.PulseAll(obj);
 #endif
 		}
 
 		public static void PrintStackTrace(Exception exception) 
 		{
-			PrintStackTrace(exception, Sharpen.Runtime.Out);
+			PrintStackTrace(exception, Sharpen.Runtime.Err);
 		}
 
 		public static void PrintStackTrace(Exception exception, System.IO.TextWriter writer) 
@@ -238,9 +234,24 @@ namespace Sharpen
 			// do nothing
 		}
 
-        internal static System.Type GetType(string typeName)
+        public static System.Type GetType(string typeName)
         {
             return TypeReference.FromString(typeName).Resolve();
         }
+
+		public static long ToJavaMilliseconds(DateTime dateTimeNet)
+		{
+			return ToJavaMilliseconds(dateTimeNet.Ticks);
+		}
+
+		public static long ToJavaMilliseconds(long ticks)
+		{
+			return ticks / RATIO - DIFFERENCE_IN_TICKS;
+		}
+
+		public static long ToNetTicks(long javaMilliseconds)
+		{
+			return (javaMilliseconds + Runtime.DIFFERENCE_IN_TICKS) * Runtime.RATIO;
+		}
 	}
 }
\ No newline at end of file
